<?php
//
// CLASS:		CTIdentity
//			    Used for the Identity management of conftool (and optional for group reservations)
//

class CTIdentity {
	
	// holds corresponding row from identity-database
	var $data = array();
	
	//## DATABASE FUNCTIONS ##############################################
	
	// load identity data from database by id
	function load_by_id($id) {
		global $db;
		$id = (int)$id; // sanitize.
		
		$r = $db->query("select * from identities where ID='$id'");
		if ($db->num_rows($r) == 1) {
			$this->data = $db->fetch($r);
			return true;
		} else {
			return false;
		}
	}

	// load identity data from database by personID
	function load_by_personID($id) {
		global $db;
		
		$r = $db->query("select * from identities where personID='$id' order by ID");
		if ($db->num_rows($r) >= 1) {
			$this->data = $db->fetch($r);
			return true;
		} else {
			return false;
		}
	}

	
	// reload personidentity data from database
	function reload() {
		return $this->load_by_id($this->data['ID']);
	}
	
	// update data in database from object
	function persist() {
		global $db;
		
		if ($this->data['personID']=="") { // the personID has to be set!!!
			echo "ERROR SAVING IDENTITY!";
			return false;
		} else {
			// Encode the icon data before saving...
			#$img = $this->get('communityicon');
			#$this->set('communityicon', AddSlashes($img));  // Add slashes for storing...
			$db->replace_into('identities', $this->data);
			#$this->set('communityicon', $img);				// revert...
			if ($this->get_id()!="") {
				$this->save_interests();
			}
		}
	}
	
	// delete Identity
	function delete() {
		global $db;
		$this->data['deleted']="1";
		return true;
	}
	
	// undelete Identity
	function undelete() {
		global $db;
		$this->data['deleted']="0";
		return true;
	}
	
	
	//## ACCESSOR FUNCTIONS ###############################################
	
	// get a record field`s value, fieldname is key
	function get($key) {
		return isset($this->data[$key]) ? $this->data[$key] : '';
	}
	
	// get a record field`s value, with html special chars converted
	function get_special($key) {
		return ct_form_encode($this->get($key));
	}
	
	// set a record field`s value
	function set($key, $value) {
		$this->data[$key] = $value;
	}
	
	function check_visibility($v) {
		if (isset($this->data['visibility']) && !(strpos($this->data['visibility'], $v) === false)) {
			return true;
		} else {
			return false;
		}
	}
	
	function add_visibility($visibility) {
		$varr = explode(",", $this->data['visibility']);
		if (!in_array($visibility, $varr)) {
			array_push($varr, $visibility);
		}
		$this->data['visibility'] = implode(",", $varr);
	}
	
	function remove_visibility($visibility) {
		$varr = explode(",", $this->data['visibility']);
		if (in_array($visibility, $varr)) {
			reset($varr);
			while (list($k,$v) = each($varr)) {
				if ($v == $visibility) {
					unset($varr[$k]);
					break;
				}
			}
		}
		$this->data['visibility'] = implode(",", $varr);
	}
	
	
	function get_id() {
		return $this->data['ID'];
	}
	
	function get_personID() {
		return $this->data['personID'];
	}
	
	// returns an array that contains all interests of this identity
	//
	function get_interests() {
		global $db;
		
		$interests = array();
		$r = $db->query("select interest from identities2interests where identities2interests.identityID='".$this->get('ID')."' order by interest");
		for ($i = 0; $i < $db->num_rows($r); $i++) {
			$row = $db->fetch($r);
			array_push($interests, $row['interest']);
		}
		return $interests;
	}
	
	// Save interests listed by this person. The topics are contained as array in the parameter if this function.
	//
	function save_interests() {
		global $db;
		
		if (is_array($this->data['interests'])) {
			$db->unlink('identities2interests', $this->get('ID'), "");
			while (list($k,$v) = each($this->data['interests'])) {
				if (strlen(trim($v))>1)	$db->link('identities2interests', $this->get('ID'), trim($v));
			}
		}
	}

	
	// delete icon
	function deleteIcon() {
		$this->set('communityicon', null);
		$this->set('iconname', "");
		
	}
	
	// get icon string
	function getIcon() {
		return stripslashes($this->data['communityicon']);
	}



	//## FORM PROCESSING AND GENERATION #######################################
	
	function _require($field, $name) {
		global $http;
		
		if (isset($http[$name]) && ($http[$name] != "")) {
			$this->set($field, $http[$name]);
			return true;
		} else {
			if (isset($http[$name])) {
				$this->set($field, '');
			}
			$this->errors[] = $name;
			return false;
		}
	}
	
	// process a request that results from a form generated by CTPerson-object
	function process_form() {
		global $http, $session;
		
		$okay = true;
		$this->errors = array();
		
		ct_http_trim(array('fullname','firstname','lastname','email','url','organisation'));

		$this->set('ID', $http['form_id']);
		$this->set('personID', $http['form_personID']);
		$okay &= $this->_require('gender', 'form_gender');
		$this->set('title', $http['form_title']);
		$okay &= $this->_require('fullname', 'form_fullname');
		$okay &= $this->_require('name', 'form_name');
		$this->set('firstname', $http['form_firstname']);
		$okay &= $this->_require('organisation', 'form_organisation');
		$okay &= $this->_require('country', 'form_country');
		if ($http['form_country'] == "-") 
			$this->errors[]	= 'form_country';	$okay=false;

		if (isset($http['form_visibility_online'])) {
			$okay &= $this->_require('nickname', 'form_nickname');
		} else {
			$this->set('nickname', $http['form_nickname']);
		}
		$this->set('email', $http['form_email']);
		$this->set('icq', $http['form_icq']);
		$this->set('aim', $http['form_aim']);
		$this->set('msn', $http['form_msn']);
		$this->set('yahoo', $http['form_yahoo']);
		if (strtolower(substr($http['form_url'],0,4))!="http" && strlen($http['form_url'])>5) $http['form_url'] = 'http://'.$http['form_url'];
		if (substr($http['form_url'],-1)!="/" && substr_count($http['form_url'],'/')==2) $http['form_url'] = $http['form_url'].'/';
		$this->set('url', $http['form_url']);
		$this->set('state', $http['form_state']);
		$this->set('city', $http['form_city']);
		$vis = array();
		if (isset($http['form_visibility_onlist']))  { $vis[] = 'onlist'; }
		if (isset($http['form_visibility_online']))  { $vis[] = 'online'; }
		$this->set('visibility', implode($vis, ','));
		$this->data['interests'] = ct_multi_explode(array(",",";",".","\n"),$http['form_interests']);
		
		// echo "<p>Status: ".$this->get('status')."</p>";
		if ($okay) {
			return false;
		} else {
			return $this->errors;
		}
	}
	
	// Creates a HTML form to edit person`s data
	function show_form($action,$errors,$empty=false) {
		ct_load_class('CTForm');
		global $session, $ctconf, $http;
		
		$user =& $session->get_user();
		
		$form = new CTForm($action, "post", $errors);
		
		$form->width='600';
		$form->align='center';
		
		$form->add_hidden(array(array('form_personID', $this->get_personID()),
								array('form_id', $this->get_id())));
		if (in_http('nextpage'))
			$form->add_hidden(array(array('nextpage', $http['nextpage'])));
		
		$form->add_separator(ct('S_IDENTITY_MAIN_DATA'));
		$form->add_radio("* ".ct('S_USER_GENDER'), 'form_gender', array(
					array('2',ct('S_USER_GENDER_FEMALE')),
					array('1',ct('S_USER_GENDER_MALE')),
					array('3',ct('S_USER_GENDER_DR')),
					array('4',ct('S_USER_GENDER_PROF'))), $this->get('gender'));
		//$form->add_check("* ".ct('S_USER_GENDER'), array(array('form_gender','1',ct('S_USER_GENDER_MALE'), $this->get('gender')==1, "", true),
		//												 array('form_gender','2',ct('S_USER_GENDER_FEMALE'), $this->get('gender')==2, "", true)));

		$form->add_text(ct('S_USER_TITLE'), 'form_title', $this->get('title'), 10, 255);
		$form->add_text("* ".ct('S_USER_FIRSTNAME'), 'form_firstname', $this->get('firstname'), 50, 255, false );
		$form->add_text("* ".ct('S_USER_NAME'), 'form_name', $this->get('name'), 50, 255, false );
		$form->add_text("* ".ct('S_USER_FULLNAME'), 'form_fullname', $this->get('fullname'), 50, 255, false, '<br>'.ct('S_IDENTITY_FULLNAME_HINT') );
		// $form->add_hidden(array(array('form_fullname', $this->get_special('fullname'))));
		$form->add_text("*&nbsp;".ct('S_USER_ORGANISATION'), 'form_organisation', $this->get('organisation'), 50, 255);

		ct_load_lib('address.lib');
		#$states	= ct_list_states();
		#$form->add_select( ct('S_IDENTITY_STATE'),'form_state',1, $states, array($this->get('state')));
		#s.u. $form->add_text(ct('S_IDENTITY_STATE'), 'form_state', $this->get('state'),	40,	255);

		// Select State/Territory
		//	$form->add_text("* ".ct('S_USER_COUNTRY'), 'form_country', $this->get('country'), 40, 255);
		$countries = ct_list_countries();
		$form->add_select( ct('S_USER_COUNTRY'),'form_country',1, $countries, array($this->get('country')), false, (strlen($this->get('country'))>2)?"<br>(".$this->get('country').")":"" );

		$form->add_check(ct('S_IDENTITY_VISIBILITY'), array(
			array( 'form_visibility_onlist', 'onlist', ct('S_IDENTITY_VISIBILITY_ONLIST'), $this->check_visibility('onlist')))
		);
		// $form->add_submit_not_bottom('cmd_save_identity', ct('S_IDENTITY_SAVE'));

		
		$form->add_separator(ct('S_IDENTITY_COMMUNITY_DATA'));
		$form->add_check(ct('S_IDENTITY_VISIBILITY'), array(
			array( 'form_visibility_online', 'online', ct('S_IDENTITY_VISIBILITY_ONLINE'), $this->check_visibility('online')))
		);
		
		$form->add_text(ct('S_IDENTITY_NICKNAME'), 'form_nickname', $this->get('nickname'), 40, 255, false, '<br>'.ct('S_IDENTITY_NICKNAME_HINT'));
		$form->add_text(ct('S_USER_CITY'), 'form_city', $this->get('city'), 40, 255);
		$form->add_text(ct('S_IDENTITY_STATE'), 'form_state', $this->get('state'), 40, 255);
		$form->add_text(ct('S_USER_EMAIL'), 'form_email', $this->get('email'), 50, 255);
		$form->add_text(ct('S_USER_HOMEPAGE'), 'form_url', $this->get('url'), 50, 255);

		$form->add_text(ct('S_IDENTITY_ICQ'), 'form_icq', $this->get('icq'), 10, 25);
		$form->add_text(ct('S_IDENTITY_AIM'), 'form_aim', $this->get('aim'), 10, 25);
		$form->add_text(ct('S_IDENTITY_MSN'), 'form_msn', $this->get('msn'), 10, 25);
		$form->add_text(ct('S_IDENTITY_YAHOO'), 'form_yahoo', $this->get('yahoo'), 10, 25);
		
		$form->add_textarea(ct('S_IDENTITY_INTERESTS'), 'form_interests',  ct_csv_implode($this->get_interests()), 50, 6, ct('S_IDENTITY_INTERESTS_HINT'));

		// 		$form->add_separator(ct('S_IDENTITY_UPLOAD'));
		if ($this->get('iconname')=="") {
			// Maximum upload size set to 1000000 = 1MB
			$form->add_upload(ct('S_IDENTITY_ICON'), 'form_filename', '50', '1000000', ct('S_IDENTITY_ICON_HINT'));
			$form->add_submit('cmd_save_identity', ct('S_IDENTITY_SAVE'));
			$form->add_submit('cmd_upload_icon', ct('S_IDENTITY_UPLOADICON'));
		} else {
			$form->add_label(ct('S_IDENTITY_ICON'),"<a target=\"_blank\" href=\"".ct_pageurl("showCommunityIcon",array("form_id"=>$this->get_id()))."\"><img src=\"".ct_pageurl("showCommunityIcon",array("form_id"=>$this->get_id(),"width"=>"100","height"=>"150"))."\" width=\"100\" border=\"0\" /></a>");
			$form->add_label(ct('S_IDENTITY_ICONNAME'),$this->get_special('iconname'));	
			$form->add_submit('cmd_delete_icon', ct('S_IDENTITY_DELETEICON'));
			$form->add_submit('cmd_save_identity', ct('S_IDENTITY_SAVE'));
		}
		$form->add_submit('cmd_cancel', ct('S_BUTTON_CANCEL'));
		
		$form->show();
	}
	
	
	//## DISPLAY FUNCTIONS ########################################################
	
	// show row in userlist or PC-list
	function show_row($class) {
		global $session;
		ct_load_lib("address.lib");

		$user =& $session->get_user();

		if ($this->get('deleted') != '0') {
			$class = $class."_del";
		}
		echo "<tr class=\"$class\" ";
		echo "onmouseover=\"ct_row( this, 'on', '$class', '".$class."_highlight');\" ";
		echo "onmouseout=\"ct_row( this, 'off', '$class', '".$class."_highlight');\">\n";
		
		echo "<td valign=top><span class=\"fontbold font10\">";
		if (is_string(strstr($this->get('visibility'),'online'))) {
			if ($this->data['fullname']!="")
				echo "<a href=\"".ct_pageurl('showIdentity', array('form_id' => $this->get('ID')))."\">".$this->get_special('fullname')."</a>";
			else
				echo "<a href=\"".ct_pageurl('showIdentity', array('form_id' => $this->get('ID')))."\">".$this->get_special('name').", ".$this->get_special('firstname')."</a>";
		} else {
			if ($this->data['fullname']!="")
				echo $this->get_special('fullname');
			else
				echo $this->get_special('name').", ".$this->get_special('firstname');
		}
		if ($this->get('deleted') != '0') echo ' <img src="icons/deleted.gif">&nbsp;';
		if (!$this->check_visibility('onlist')) echo ' <img src="icons/sunglasses.gif">&nbsp;';
		if ($this->get('iconname') != '' && is_string(strstr($this->get('visibility'),'online'))) echo ' <img src="icons/image.gif">&nbsp;';
		echo '</span>';
		echo "</td>\n";
		echo "<td align=left valign=top>";
		echo "<span class=\"fontnormal font10\">".$this->get_special('organisation')."</span>";
		echo "</td>\n";
		
		echo "<td align=left valign=top>";
		echo "<span class=\"fontnormal font10\">";
		if (strlen($this->data['country'])==2)	echo $this->data['country'].",	";
		echo ct_get_country($this->get_special('country'));
		echo "</span>";
		echo "</td>\n";

		if ($user->is_admin() || $user->is_assistant() ) 
				echo "<td><a href=\"".ct_pageurl('editIdentity', array('form_id' => $this->get('ID')))."\">".ct('S_ADMIN_USERS_ACTION_EDIT')."</a></td>";
		
		echo "</tr>\n";
	}

	// Show details on this user...
	function show_details($width="98%", $align="center") {
		global $session;
		$user =& $session->get_user();

		echo "<br><table width=\"$width\" align=\"$align\" cellpadding=\"0\" cellspacing=\"1\" class=\"blackbg\">\n";
		echo "<tr class=\"whitebg\"><td align=\"left\" valign=\"top\">\n";

		echo "<table width=\"100%\" border=0>\n";
		echo '<tr><td align="right" width="30%">&nbsp;</td><td width="70%">';
		echo "<span	class=\"fontbold font14\">";
			echo $this->get_special('title').' '.$this->get_special('fullname');
		echo "</span><br>\n";
		echo "<span	class=\"fontbold font10\">".$this->get_special('organisation')."</span><br>\n";
		ct_load_lib("address.lib");
		echo "<span	class=\"fontbold font10\">";
		echo ct_get_country($this->get_special('country'))."</span>\n";
		echo "</td></tr>\n";
		echo "</table>\n";
	
		// Community data!		
		if ($user->is_admin() || $user->is_assistant() ||
  				is_string(strstr($this->get('visibility'),'online')) ) {

			if ($this->get('iconname')!="") {
	  			echo "<td rowspan=2 align=\"center\" valign=\"middle\" class=\"lightbg\">\n";
				echo "&nbsp;<a target=\"_blank\" href=\"".ct_pageurl("showCommunityIcon",array("form_id"=>$this->get_id()))."\"><img src=\"".ct_pageurl("showCommunityIcon",array("form_id"=>$this->get_id(),"width"=>"150","height"=>"180"))."\" width=\"150\" border=\"0\" /></a>&nbsp;";
				echo "</td>\n";
			}
			echo "</tr>\n";
  					
  			echo "<tr class=\"darkbg\"><td align=\"left\" valign=\"top\">\n";

  			$i=0;
			echo "<table cellpadding=\"3\" cellspacing=\"1\" width=\"100%\" border=0>\n";
			if ($this->get('nickname')!="") echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right" width="30%"><span class="fontlabel font10">'.ct('S_IDENTITY_NICKNAME').': </span></td><td width="70%"><span class="fontbold font10">'.$this->get_special('nickname')."</span></td></tr>\n";
			if ($this->get('email')!="") 	echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right"><span class="fontlabel font10"><img src="icons/e-mail.gif">&nbsp;'.ct('S_USER_EMAIL').": </span></td><td><span class=\"fontbold font10\"><a href=\"mailto:".$this->get_special('email')."\">".$this->get_special('email')."</a></span></td></tr>\n";
			if ($this->get('url')!="")		echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right"><span class="fontlabel font10"><img src="icons/web.gif" align="middle">&nbsp;'.ct('S_USER_HOMEPAGE').": </span></td><td><span class=\"fontbold font10\"><a target=\"_blank\" href=\"".$this->get_special('url')."\">".$this->get_special('url')."</a></span></td></tr>\n";

			if ($this->get('icq')!="")		echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right"><span class="fontlabel font10"><img src="icons/icq.gif" align="middle">&nbsp;'.ct('S_IDENTITY_ICQ').": </span></td><td><span class=\"fontnormal font10\">".$this->get_special('icq')."</span></td></tr>\n";
			if ($this->get('aim')!="")		echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right"><span class="fontlabel font10"><img src="icons/aim.gif" align="middle">&nbsp;'.ct('S_IDENTITY_AIM').": </span></td><td><span class=\"fontnormal font10\">".$this->get_special('aim')."</span></td></tr>\n";
			if ($this->get('msn')!="")		echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right"><span class="fontlabel font10"><img src="icons/msn.gif" align="middle">&nbsp;'.ct('S_IDENTITY_MSN').": </span></td><td><span class=\"fontnormal font10\">".$this->get_special('msn')."</span></td></tr>\n";
			if ($this->get('yahoo')!="")	echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right"><span class="fontlabel font10"><img src="icons/yahoo.gif" align="middle">&nbsp;'.ct('S_IDENTITY_YAHOO').": </span></td><td><span class=\"fontnormal font10\">".$this->get_special('yahoo')."</span></td></tr>\n";
			
			if ($this->get('city')!="")	 	echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right"><span class="fontlabel font10">'.ct('S_USER_CITY').': </span></td><td><span class="fontbold font10">'.$this->get_special('city')."</span></td></tr>\n";
			if ($this->get('state')!="") 	echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right"><span class="fontlabel font10">'.ct('S_IDENTITY_STATE').': </span></td><td valign="top"><span class="fontbold font10">'.$this->get_special('state')."</span></td></tr>\n";
			
			$interests = $this->get_interests();
			if ($interests!="") echo '<tr class="'.((($i++)%2)?'evenrow':'oddrow').'"><td align="right"><span class="fontlabel font10">'.ct('S_IDENTITY_INTERESTS').': </span></td><td><span class="fontnormal font10">'.stripslashes(ct_csv_implode($interests))."</span></td></tr>\n";
			echo "</table>\n";
	
			echo "</td></tr>\n";

		}	

		echo "</table>";
		
		
	}
	

	// #### Tests #######################

	// Check if the file has a legal filename!
	function isLegalIconType($fname) {
		
		$img = trim(strtolower($fname));
		$pos = strrpos($img, ".");
		if ($pos === false)
			return false;
		else {
			$img = substr($img, $pos+1);
			if ($img == 'jpg' ||
			    $img == 'jpeg' ||
			    $img == 'gif' ||
			    $img == 'png')
				return true;
			else {
				return false;
			}
		}
	}

	// Check if the file has a legal size
	// Min 100 Byte,  Max 100KBytes! That should be enough
	function isLegalIconSize($i) {
		if (strlen($i) > 10 && strlen($i) < 102400) return true;
		return false;
	}
	
	
}

?>