<?php
//
// CLASS:		CTPaper
// 				Standard class to work with submissions to a conference.
//				Includes extended accessors and modifiers as well as basic output functions
//

class CTPaper extends CTPaperData {

	// default constructor
	function CTPaper() {
		parent::CTPaperData();
	}

	// Extended accessors and modifiers ------------------------------

	/**
	 * withdraw paper from conference. it will remain in database, but
	 * marked with an "withdrawn" flag. All links to other tables remain intact.
	 */
	function withdraw() {
		$this->set('withdrawn', 1);
		return $this->persist();
	}

	/**
	 * Check if a person does review this paper
	 *
	 * @param CTPerson $person object of person to check
	 * @return boolean
	 */
	function is_reviewed_by($person) {
		global $db;
		$r = $db->query("select count(*) as count from reviews where paperID='".$this->pdata['ID']."' and personID='".$person."'");
		if ($r && $db->num_rows($r) == 1 ) {
			$row = $db->fetch($r);
			if ( $row['count'] > 0 ) { return true; } else { return false; }
		} else {
			return false;
		}
	}

	/**
	 * Acceptance Status of Paper
	 *
	 * @param ID $status ID of status
	 * @return text (description) of status
	 */
	function get_acceptstatus($status=null) {
		if ($status==null) // If status is given use this, otherwise use status of object...
			$status = $this->pdata['acceptstatus'];
		if ($status>0) {
			return ct('S_ADMIN_PAPERS_RESULTS_STATUS_P'.$status);
		} elseif ($status<0) {
			return ct('S_ADMIN_PAPERS_RESULTS_STATUS_N'.(-$status));
		}
		return ct('S_ADMIN_PAPERS_RESULTS_STATUS_0');
	}

	function get_acceptstatus_short($status=null) {
		if ($status==null) // If status is given use this, otherwise use status of object...
			$status = $this->pdata['acceptstatus'];
		if ($status>0) {
			return ct('S_ADMIN_PAPERS_RESULTS_STATUS_P'.$status.'_SHORT');
		} elseif ($status<0) {
			return ct('S_ADMIN_PAPERS_RESULTS_STATUS_N'.(-$status).'_SHORT');
		}
		return ct('S_ADMIN_PAPERS_RESULTS_STATUS_0_SHORT');
	}


	// Check if the file has a legal filename!
	function _is_legal_file_type($fname,$index="") {
		$type = trim(strtolower($fname));
		$pos = strrpos($type, ".");
		if ($pos === false)
			return false;
		else {
			$ftype = substr($type, $pos+1);
			$ftypes = $this->_get_legal_file_types($index);
			foreach ($ftypes as $t) {
				if ($t == $ftype) return true;
			}
		}
		return false;
	}

	function _get_legal_file_types($index="") {
		$legal_types=ct_csv_explode(ctconf_get('uploadFileTypes'));
		if ($index=="" || $index=="1" || $index=="2" || $index=="3") {
			$ctypes=$this->_get_contributiontype();
			if (($index=="" || $index=="1") && $ctypes['upload_filetype_A']!="")
				$legal_types=ct_csv_explode($ctypes['upload_filetype_A']);
			if ($index=="2" && $ctypes['upload_filetype_B']!="")
				$legal_types=ct_csv_explode($ctypes['upload_filetype_B']);
			if ($index=="3" && $ctypes['upload_filetype_C']!="")
				$legal_types=ct_csv_explode($ctypes['upload_filetype_C']);
		}
		return $legal_types;
	}


	// Check if the file has a legal filename!
	// Min 1KByte, max 10MBytes! That should be enough...
	function _is_legal_file_size($i) {
		if (strlen($i) > 1024 && strlen($i) < ctconf_get('paperupload/maxsize')) return true;
		return false;
	}

	/**
	* returns a reference to a CTPerson-object that represents the paper
	* "author" (the user who submitted it to the conference)
	*/
	function &get_author() {
		global $db;

		$author = $this->author;
		if ($this->get('personID')>0 && ($author==null || $author->get_id()==0 || $author->get_id()!=$this->get('personID'))) {
			$author = new CTPerson;
			$author->load_by_id($this->get('personID'));
			$this->author=$author;
		} elseif ($this->get('personID')==0 || !is_object($author)) {
			$author = new CTPerson;
		}
		return $author;
	}

	/**
	* returns an array with all CTPerson-objects that have the same
	* email-address as listed for this paper
	*/
	function get_coauthors() {
		global $db;

		$r = $db->query("select p.ID as ID from emails2papers as e, persons as p where (e.email=p.email or e.email=p.email2) and e.paperID='".$this->get_id()."' group by p.ID");
		$result = array();
		if ($r && ($db->num_rows($r) > 0)) {
			for ($i = 0; $i < $db->num_rows($r); $i++) {
				$row = $db->fetch($r);
				$person = new CTPerson();
				$person->load_by_id($row['ID']);
				$results[] = $person;
			}
		}
		return $results;
	}

	/**
	* Set status of co-authors
	* add=true: add co-author-status if aprropriate
	* add=false: remove co-author-status for this paper (but only if he isn't coauthor of another paper!)
	*/
	function set_coauthors($add=true) {
		$coauthors = $this->get_coauthors();
		if (count($coauthors)>0) {
			while (list(,$person) = each($coauthors)) {
				if ($add==true) {
					if ($person->check_coauthor())
						$person->persist();
				} else { // add == false -> remove status co-author if only this paper references him...
					if ($person->check_coauthor($this->get_id())) {
						$person->persist();
					}
				}
			}
		}
	}

	/**
	 * Returns an array with all reviews assigned to the current paper
	 *
	 * @param boolean $showAllReviews show all reviews, otherwise open reviews will not be displayed.
	 * @return array of CTReview objects
	 */
	function get_reviews($showAllReviews=true) {
		global $db;
		ct_load_class('CTReview');

		if ($showAllReviews)
			$q = "select paperID, personID from reviews where paperID='".$this->pdata['ID']."' ORDER BY reviewtype,personID";
		else
			$q = "select paperID, personID from reviews where paperID='".$this->pdata['ID']."' and creationdate>0 ORDER BY reviewtype,personID";

		$r = $db->query($q);
		$result = array();
		if ($r && ($db->num_rows($r) > 0)) {
			for ($i = 0; $i < $db->num_rows($r); $i++) {
				$row = $db->fetch($r);

				$review = new CTReview();
				$review->load( $row['paperID'], $row['personID']);
				$classname = $review->get_reviewClass();
				ct_load_class($classname);
				eval('$review_new = new '.$classname.'();');
				$review_new = ct_type_cast($review,$classname);

				$results[] = $review_new;
			}
		}
		return $results;
	}

	/**
	 * Returns the number of reviews assigned to this submission
	 *
	 * @param boolean $showAllReviews show all reviews, otherwise open reviews will not be displayed.
	 * @return int number of reviews
	 */
	function get_review_count($showAllReviews=true) {
		global $db;
		$reviews = 0;

		if ($showAllReviews)
			$q = "select count(paperID) as count FROM reviews where paperID='".$this->pdata['ID']."'";
		else
			$q = "select count(paperID) as count FROM reviews where paperID='".$this->pdata['ID']."' AND creationdate>0";

		$r = $db->query($q);
		if ($r && ($db->num_rows($r) > 0)) {
			$row = $db->fetch($r);
			$reviews = $row['count'];
		}
		return $reviews;
	}

	/**
	* returns an array that contains all titles of topics assigned to this paper
	*/
	function get_topics() {
		global $db;

		$topics = array();
		if ($this->get_id()) {
			$r = $db->query("select	topics.* from topics, topics2papers where topics.id=topics2papers.topicID and topics2papers.paperID='".$this->get('ID')."'");
			for	($i	= 0; $i	< $db->num_rows($r); $i++) {
				$row = $db->fetch($r);
				array_push($topics,	$row[ctlx($row,'title')]);
			}
		} elseif (is_array($this->get('topics'))) {
			$topics = $this->get('topics');
		}
		return $topics;
	}

	/**
	* returns an array that contains all IDs of topics assigned to this paper
	*/
	function get_topicIDs() {
		global $db;

		if (is_array($this->pdata['topics'])) return $this->pdata['topics'];

		$topics = array();
		if ($this->get_id()) {
			$rows = $db->get_links('topics2papers', $this->get('ID'), '');
			for ($i = 0; $i < sizeof($rows); $i++) {
				array_push($topics, $rows[$i]['topicID']);
			}
		} elseif (is_array($this->get('topics'))) {
			$topics = $this->get('topics');
		}
		return $topics;
	}


	/**
	* show topics separated by commas
	*/
	function show_topics() {
		global $db;
		ct_load_lib('papers.lib');

		$topics = $this->get_topicIDs();
		$j=0;
		while (list(,$v) = each($topics)) {
			$topic = ct_get_topics($v);
			$t = $topic[ctlx($topic,'title')];
			if ($j>0) echo ",";
			echo " ".$t;
			$j++;
		}
		if ($j == 0) echo "--";
	}

	// Return all Emails to this contribution...
	function get_emails() {
		global $db;

		if (is_array($this->pdata['emails']) && !empty($this->pdata['emails'])) return $this->pdata['emails'];

		$emails = array();
		if ($this->get_id()!="") {
			$r = $db->query("select email from emails2papers AS e2p, papers AS p where e2p.paperID=p.ID and e2p.paperID='".$this->get_id()."'");
			if ($r) {
				for ($i = 0; $i < $db->num_rows($r); $i++) {
					$row = $db->fetch($r);
					array_push($emails, $row['email']);
				}
			}
		}
		return $emails;
	}

	// returns an array that contains all titles of topics assigned to this paper
	//
	function get_bidding($personID) {
		global $db;
		$r = $db->query("select bidding from biddings where personID='$personID' AND paperID=".$this->get('ID'));
		if ($db->num_rows($r)==1) {
			$row = $db->fetch($r);
			return $row['bidding'];
		}
		return 0; // No bidding
	}

	// returns an array that contains all available topics. Each element is an array with two
	// elements, first is topic ID, second is topic title - also available in CTPerson
	function _list_topics() {
		if (ctconf_get('topicsTrackSelect',false) && ct_test_lib('multi_track.lib')) {	// if multi-track library exists...
			ct_load_lib('multi_track.lib');
			return mt_list_topics($this->get('contributiontypeID'));
		} else {
			// list all topics...
			ct_load_lib('papers.lib');
			return ct_list_topics();
		}
	}

	// returns an array that contains all available contribution types / Tracks of the conference.
	// Each element is an array with two elements, first is ID, second is title
	function _list_types($filter=false) {
		ct_load_lib("papers.lib");
		return ct_list_contributiontypes($filter);
	}

	/**
	 * returns the name of the contribution type, already encoded for HTML output.
	 */
	function _get_contributiontype_title($typeID="") {
		if ($typeID=="") $typeID=$this->pdata['contributiontypeID'];
		if ($typeID=="") return "<span class=\"fontbold fontnegative yellowbg\">".ct('S_ERROR_SYSTEM_MISSING_DATA')."</span>";
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		$type = $t[ctlx($t,'title')];
		if ($type!="") return ct_form_encode($type);
		else return "---"; // Contribution type not defined... (or 0)
	}

	/**
	 * returns if upload for contribution type (or submission) is still set active
	 */
	function is_upload_active($typeID="") {
		if ($typeID=="") $typeID=$this->pdata['contributiontypeID'];
		if ($typeID=="") return 0;
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		$deadline=ct_get_submission_deadline($t);
		$upload_deadline=ct_get_upload_deadline($t);

		$active = ($t['active']=='true' && ($upload_deadline>ct_time() || $deadline>ct_time()));
		return $active;
	}

	/**
	 * get deadline for reviews (timestamp)
	 */
	function get_review_deadline($typeID="") {
		if ($typeID=="") $typeID=$this->pdata['contributiontypeID'];
		if ($typeID=="") return 0;
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		// Get deadline: 1. deadline from contributiontype
		$review_deadline=ct_datetime_2_timestamp($t['deadline_review']);
		// 2. limit by total deadline for reviews
		if ($review_deadline>ct_get_phase_timeout("reviewing")) $review_deadline=ct_get_phase_timeout("reviewing");
		return $review_deadline;
	}

	/**
	 * get deadline for review results (timestamp)
	 * @return returns a timestamp...
	 */
	function get_reviewresults_deadline($typeID="") {
		if ($typeID=="") $typeID=$this->pdata['contributiontypeID'];
		if ($typeID=="") return 0;
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		// Get deadline: 1. deadline from contributiontype
		$review_deadline=ct_datetime_2_timestamp($t['deadline_results']);
		// 2. limit by total deadline for reviews
		if ($review_deadline>ct_get_phase_timeout("reviewresults")) $review_deadline=ct_get_phase_timeout("reviewresults");
		return $review_deadline;
	}

	/**
	 * get deadline for final uploads (timestamp)
	 */
	function get_finalupload_deadline($typeID="") {
		if ($typeID=="") $typeID=$this->pdata['contributiontypeID'];
		if ($typeID=="") return 0;
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		$final_deadline=ct_datetime_2_timestamp($t['deadline_final']);
		if ($final_deadline>ct_get_phase_timeout('finalupload')) $final_deadline=ct_get_phase_timeout('finalupload');
		return $final_deadline;
	}

	/**
	 * get the name of the review class for this contributiontype
	 */
	function get_reviewClass($typeID="") {
		if ($typeID=="") $typeID=$this->pdata['contributiontypeID'];
		if ($typeID=="") return "";
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		return 'CTReview_'.$t['review_classname'];
	}

	/**
	 * returns number of uploads for this type of contribution (0-3)
	 */
	function _number_of_uploads_for_contributiontype($typeID="",$uploadtype="") {
		if ($typeID=="") $typeID=$this->pdata['contributiontypeID'];
		if ($typeID=="") return 0;
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		if ($uploadtype=="final")
			return $t['upload_final'];
		else
			return $t['upload'];
	}

	/**
	 * returns number of FINAL uploads for this type of contribution (0-3)
	 */
	function _number_of_final_uploads_for_contributiontype($typeID="") {
		return $this->_number_of_uploads_for_contributiontype($typeID,'final');
	}


	# Basic display functions -------------------------------------------


	/**
	* Show a little box with information on the submitted paper plus links to edit etc. this data
	*/
	function show_infobox($width="95%",$align="left") {
		global $session;
		$user   = $session->get_user();
		$ctype  = $this->_get_contributiontype();
		$status_decided_and_not_rejected=($this->get('acceptstatus')>0 || $this->get('acceptstatus')<-1)?true:false;
		$version = (ct_check_phase_active_or_over("finalupload") && $status_decided_and_not_rejected)?'final':'';
		echo "<div align=\"$align\">\n";
		echo "<table width=\"$width\" cellspacing=1 border=0 cellpadding=2 class=\"darkbg\">\n";
		echo "<tr><td class=\"whitebg\" align=center valign=middle width=\"8%\" rowspan=\"".($this->_number_of_uploads_for_contributiontype('',$version)+1)."\">";
		echo "<span class=\"fontbold font20\">".$this->pdata['ID']."</span></td>\n";
		echo "<td class=\"tbldialog\" align=left valign=top width=\"92%\">";
		echo "<span class=\"fontlabel font8\">".ct('S_PAPER_CONTRIBUTIONTYPE').": </span><span class=\"fontbold font8\">".$this->_get_contributiontype_title()."</span><br>\n";
		if (count($this->get('title'))==0) {
			echo "<span class=\"yellowbg fontbold fontnegative font10\">".ct('S_ERROR_SYSTEM_MISSING_DATA')."</span>\n";
		} else {
			echo "<span class=\"fontlabel font10\">".ct('S_PAPER_TITLE').": </span><span class=\"fontbold font10\">".$this->get_special('title')."</span>\n";
		}
		if ($this->pdata['externalremark'] != "") {
			echo ' <a class="fontlabel" href="#" ';
			echo 'title="'.ct('S_PAPER_FORM_EXTERNALREMARK').'" ';
			if (strlen($this->pdata['externalremark'])>1) {
				echo 'ext_title="'.ct('S_PAPER_FORM_EXTERNALREMARK').'" ' ;
				echo 'ext_remark="'.substr($this->get_special('externalremark'),0,512).'" ' ;
			}
			echo '>';
			echo '<img src="icons/remark.png" border="0" alt="">'; // alt="Remark" // annoying tooltip in IE!
			echo '</a>';
		}
		echo "<br>";
		//$author = $this->get_author();
		//echo "<span class=\"fontlabel font10\">".ct('S_INDEX_PAPER_SUBMITTEDBY').":</span><span class=\"fontnormal font10\"> <a href=\"".ct_pageurl('adminUsersDetails', array('form_id'=>$this->pdata['personID']))."\" class=\"fontnormal font10\">".ct_form_encode($author->get_reversename())."</a>&nbsp;";
		//echo " - ".$author->get_special('organisation').")</span><BR>";
		echo "<span class=\"fontlabel font10\">".ct('S_PAPER_AUTHOR').":</span><span class=\"fontnormal font10\"> ".$this->get_special('author')."</span>";
		echo "</td>\n";

		// download links
		$this->show_all_download_links($version, 0, ' class="tbldialog" width="92%"','9');

		// Lower part with actions...
		echo "<tr><td class=\"mediumbg\" colspan=2><span class=\"fontbold font10\">";
		$params = array("form_id" => $this->pdata['ID']);
		// Show the 1-5 Links under the Infobox: Modify, Upload, Withdraw, Results
		// Show Abstract (always active)
		echo "<a class=\"cmda\" href=\"".ct_pageurl('showAbstract', $params)."\">".ct('S_INDEX_PAPER_ABSTRACT')."</a> ";
		// Edit submission details
		if (ct_check_phases("submission") && $this->is_contributiontype_active() &&
			($this->get('personID')==$user->get_id() || $user->is_admin()) ) {
			echo "&middot; <a class=\"cmda\" href=\"".ct_pageurl('editPaper', $params)."\">".ct('S_INDEX_PAPER_EDIT')."</a> ";
		}
		// upload paper
		if ($this->_number_of_uploads_for_contributiontype()>0 &&
				!(ct_check_phases(array("finalupload")) && $this->get_finalupload_deadline()>ct_time() && $this->pdata['acceptstatus']!=0 && $this->pdata['acceptstatus']!=-1) &&
				(ct_check_phases(array("submission")) && $this->is_upload_active()) &&
				($this->get('personID')==$user->get_id() || $user->is_admin()) ) {
			echo "&middot; <a class=\"cmda\" href=\"".ct_pageurl('uploadPaper', $params)."\">".ct('S_INDEX_PAPER_UPLOAD')."</a> ";
		}
		if ($this->pdata['acceptstatus']==0 &&
				(ct_check_phases("submission") && $this->is_contributiontype_active()) &&
				($this->get('personID')==$user->get_id() || $user->is_admin()) &&
				 $this->get_review_count(true)==0 ) {
			echo "&middot; <a class=\"cmda\" href=\"".ct_pageurl('withdrawPaper', $params)."\">".ct('S_INDEX_PAPER_WITHDRAW')."</a> ";
		}
		if (ct_check_phases("reviewresults") && $this->pdata['acceptstatus']!=0 && $this->get_reviewresults_deadline()<=ct_time()) {
			echo "&middot; <a class=\"cmda\" href=\"".ct_pageurl('reviewResults', $params)."\">".ct('S_INDEX_PAPER_DETAILS')."</a> ";
		}
		if (ct_check_phases(array("finalupload")) && $this->get_finalupload_deadline()>ct_time() && $this->_number_of_uploads_for_contributiontype('','final')>0 &&
				$status_decided_and_not_rejected &&
				($this->get('personID')==$user->get_id() || $user->is_admin()) ) {
			echo "&middot; <a class=\"cmda\" href=\"".ct_pageurl('uploadFinalPaper', $params)."\">".ct('S_INDEX_PAPER_FINALUPLOAD')."</a> ";
		}
		echo "</span></td></tr>\n";
		echo "</table>\n";
		echo "</div>\n";
	}


	/**
	* display the box with paper information and the links to review a contribution
	*/
	function show_reviewbox($review, $width="95%") {
		global $session;
		$user  = $session->get_user();
		$ctype = $this->_get_contributiontype();

		echo "<table width=\"$width\" cellspacing=1 border=0 cellpadding=2 class=\"darkbg\">\n";
		echo "<tr>\n";
		if ($review->get('creationdate')!='0000-00-00 00:00:00') // $user->get_review_count($user->pdata['ID'],$this->pdata['ID'])>0)
			echo "<td class=\"positivebg\" align=center valign=middle width=\"8%\" rowspan=\"".($this->_number_of_uploads_for_contributiontype()+1)."\">";
		else
			echo "<td class=\"negativebg\" align=center valign=middle width=\"8%\" rowspan=\"".($this->_number_of_uploads_for_contributiontype()+1)."\">";
		echo "<span class=\"fontlight fontbold font20\">\n";
		echo $this->pdata['ID']."</span></td>\n";

		echo "<td class=\"whitebg\" align=left valign=top width=\"75%\">";
		#echo "<span class=\"fontlabel font8\">".ct('S_PAPER_CONTRIBUTIONTYPE').": </span>";
		echo "<span class=\"fontbold font8\">".$this->_get_contributiontype_title()."</span><br>";
		echo "<span class=\"fontlabel font10\">".ct('S_PAPER_TITLE').": </span><span class=\"fontbold font10\">".$this->get_special('title')."</span><br>";
		// Show the author of this paper
		if ($ctype['review_anonymous']=='false') {
			echo "<span class=\"fontlabel font10\">".ct('S_PAPER_AUTHOR').":</span><span class=\"fontnormal font10\"> ".$this->get_special('author')."</span><br>";
			if ($this->get('organisation')!="") {
				echo "<span class=\"fontlabel font10\">".ct('S_PAPER_ORGANISATION').":</span><span class=\"fontnormal font10\"> ".$this->get_special('organisation')."</span><br>";
			}
		}
		echo "</td>\n";
		echo "</tr>\n";

		$this->show_all_download_links();

		echo "<tr><td class=\"lightbg\" colspan=2><span class=\"fontbold font10\">";
		$this->show_reviewer_options();
		echo "</span></td></tr>\n";
		echo "</table>\n";
	}


	function show_reviewer_options() {
		global $session,$http;
		$user  = $session->get_user();
		$params = array("form_paperID" => $this->pdata['ID']);
		$review_deadline=$this->get_review_deadline();
		if(ct_check_phases("reviewing")) {
			if ($user->is_metareviewer_for($this->get('ID'))) {
				echo "<span class=\"fontnormal font10\">".ct('S_INDEX_PAPER_METAREVIEWER').": </span>";
				echo "<a class=\"cmda\" href=\"".ct_pageurl('reviewResultsMetareviewer', array("form_id"=>$this->pdata['ID']))."\">".ct('S_INDEX_PAPER_ALLREVIEWS_SHOW')."</a><br>";
			}
			if ($http['page']!="showAbstract") {
				echo "<a class=\"cmda\" href=\"".ct_pageurl('showAbstract', $params)."\">".ct('S_INDEX_PAPER_ABSTRACT')."</a> ";
			}
			if ($user->get_review_count($user->get('ID'),$this->get('ID'))!=0) {
				if ($review_deadline>ct_time()) {
					echo " &middot; <a class=\"cmda\" href=\"".ct_pageurl('reviewPaper', $params)."\">".ct('S_INDEX_PAPER_REVIEW_EDIT')."</a>";
				}
				echo " &middot; <a class=\"cmda\" href=\"".ct_pageurl('reviewDetails', array("form_paperID"=>$this->pdata['ID'], "form_personID"=>$user->pdata['ID']))."\">".ct('S_INDEX_PAPER_REVIEW_SHOW')."</a>";
				# echo "<span class=\"fontnormal font10\">(".ct('S_REVIEW_DATE_ENTERED').": ".$xxx.")</span>";
			} else {
				echo " &middot; <a class=\"cmda\" href=\"".ct_pageurl('reviewPaper', $params)."\">".ct('S_INDEX_PAPER_REVIEW')."</a>";
				echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
				if ($review_deadline>ct_time()) {
					echo "<span class=\"fontnormal font10\">(".ct('S_PHASES_TIMELEFT').": ".ct_format_timeleft(ct_time(),$review_deadline).")</span>";
				} else {
					echo "<br><span class=\"fontnegative fontbold font10\">".ct('S_REVIEW_DEADLINEPASSED')."</span>";
				}
			}
		}
	}

	/**
	* show a paper as one row
	*/
	function show_row($class) {
		global $session,$http;
		$user =& $session->get_user();

		$version = '';
		if (isset($http['version']) && $http['version']=='final')
			$version=$http['version'];

		$topic = '';
		if (isset($http['form_topic']) && $http['form_topic']!='-')
			$topic=$http['form_topic'];

		$track = '';
		if (isset($http['form_tracks']) && $http['form_tracks']!='0')
			$track=$http['form_tracks'];

		$author = $this->get_author();
		$ctype  = $this->_get_contributiontype();

		$rowspan='';
		if ($this->_number_of_uploads_for_contributiontype('',$version)>0)
			$rowspan = ' rowspan="'.($this->_number_of_uploads_for_contributiontype('',$version)+1).'" ';

		if ($this->pdata['withdrawn'] != '0' || $author->get('ID')==0) {
			$class = $class."_del";
		}
		echo "<tr class=\"$class\" ";
		#echo "onmouseover=\"ct_row( this, 'on', '$class', '".$class."_highlight');\" ";
		#echo "onmouseout=\"ct_row( this, 'off', '$class', '".$class."_highlight');\" ";
		echo ">\n";

		// #1: ID of contribution
		if ($this->pdata['acceptstatus']==0) {
			echo "<td align=center valign=middle $rowspan><span class=\"fontbold font10\">";
		} elseif ($this->pdata['acceptstatus']>=1) {
			echo "<td align=center valign=middle $rowspan ><span class=\"fontpositive fontbold font10\">";
		} elseif ($this->pdata['acceptstatus']==-1) {
			echo "<td align=center valign=middle $rowspan ><span class=\"fontnegative fontbold font10\">";
		} else {
			echo "<td align=center valign=middle $rowspan ><span class=\"fontother fontbold font10\">";
		}
		echo $this->pdata['ID']."</span></td>\n";

		// 2: Type and title
		echo "<td align=left valign=top>";
		echo "<span class=\"fontbold font8\">";
		echo "<a href=\"".ct_pageurl('adminPapersDetails')."&amp;form_id=".$this->get('ID')."\">";
		echo $this->get_special('title')."</a>&nbsp;</span>";
		echo '<a href="'.ct_pageurl('showAbstract').'&amp;form_id='.$this->get('ID').'" title="'.ct('S_PAPER_FORMATTED_ABSTRACT',array($this->get_id())).'">';
		echo '<img src="icons/abstract.png" border="0" alt=""></a>';
		if ($this->pdata['externalremark'] != "") {
			echo ' <a class="fontlabel" href="'.ct_pageurl('adminPapersDetails', array('form_id'=>$this->get('ID'))).'" ';
			echo 'title="'.ct('S_PAPER_FORM_EXTERNALREMARK').'" ';
			if (strlen($this->pdata['externalremark'])>1) {
				echo 'ext_title="'.ct('S_PAPER_FORM_EXTERNALREMARK').'" ' ;
				echo 'ext_remark="'.substr($this->get_special('externalremark'),0,512).'" ' ;
			}
			echo '>';
			echo '<img src="icons/remark.png" border="0" alt="">'; // alt="Remark" // annoying tooltip in IE!
			echo '</a>';
		}
		echo "<br>\n";
		echo "<span class=\"fontnormal font8\">".$this->_get_contributiontype_title()."</span>";
		echo "</td>\n";

		// 3: Authors
		echo "<td align=left valign=top>";
		echo "<span class=\"fontbold font8\">".$this->get_special('author')."</span>";
		echo "<br>\n";
		echo "<span class=\"fontnormal font8\"><a href=\"".ct_pageurl('adminUsersDetails', array('form_id'=>$this->pdata['personID']))."\">".ct_form_encode($author->get_reversename())."</a>&nbsp;";
		echo "<a href=\"mailto:".$author->get_special('email')."\" title=\"".$author->get_special('email')."\"><img src=\"icons/mailto.gif\" border=0 alt='mailto'></a>&nbsp;</span>\n";
		echo "</td>\n";

		// 4: Other infos...
		// Paramters for assignment page.
		$param = array('form_id' => $this->get('ID'));
		if ($track!='') $param['form_tracks'] = $track;
		if ($topic!='') $param['form_topic'] = $topic;
		echo "<td align=left valign=top>";
		$reviewers = $user->get_review_count("",$this->get('ID'),0);
		if ($version!='final') { // Show reviewers and reviews.
			if ($ctype['do_review']=='true' || $reviewers>0) {
				$rclass="fontnormal font8";
				if ($reviewers<$this->minNumOfReviews || $reviewers>$this->maxNumOfReviews) 	$rclass="fontnegative fontbold font8";
					echo "<a class=\"$rclass\" href=\"".ct_pageurl('adminReviewAssign', $param)."\">".ct('S_REVIEWER').":&nbsp;".$reviewers."</a><br>";  // not optimized yet...
				if ($reviewers>0) {
					$submitted_reviews = $user->get_review_count("",$this->get('ID'),1);
					$rclass="fontnormal font8";
					if ($reviewers!=$submitted_reviews) 	$rclass="fontnegative fontbold font8";
					echo "<a class=\"$rclass\" href=\"".ct_pageurl('adminPapersDetails', array('form_id' => $this->get('ID')))."\">".ct('S_PAPER_REVIEWS').":&nbsp;".$submitted_reviews."</a><br>";  // not optimized yet...
				}
			} else {
				echo "<span class=\"fontnegative font8\">".ct('S_PAPER_NOTREVIEWED')."</span><br>";
			}
		}
		if ($this->get('acceptstatus')!=0) {
			$rclass="fontbold font8";
			if ($this->get('acceptstatus')>0) $rclass="fontpositive fontbold font8";
			if ($this->get('acceptstatus')==-1) $rclass="fontnegative fontbold font8";
			echo "<span class=\"$rclass\">".$this->get_acceptstatus_short()."</span><br>";
		}
		if ($version=='final') { // for final version show number of pages and if everything is OK
			echo "<span class=\"fontnormal font8\">".ct('S_PAPER_PAGECOUNT',array($this->get('pagecount')))."</span><br>";
			#if ($this->get('language')!='')
			#	echo "<span class=\"fontnormal font8\">".$this->get('language')."</span><br>";
			if ($this->get('format')=='true')
				echo "<span class=\"fontpositive fontbold font8\">".ct('S_PAPER_FORMATOK')."</span>";  // not optimized yet...
		}
		echo "</td>\n";

		// 5: Actions
		echo "<td align=right valign=top $rowspan><span class=\"fontnormal font8\">";
		if ($version!='final') {
			if ($ctype['do_review']=='true' || $reviewers>0) {
				echo "<a class=\"fontbold font10\" href=\"".ct_pageurl('adminReviewAssign', $param )."\">".ct('S_ADMIN_PAPERS_ACTION_ASSIGN')."</a><br>";
			}
			if ($user->is_admin()) {
				echo "<a href=\"".ct_pageurl('editPaper', array('form_id' => $this->get('ID')))."\">".ct('S_ADMIN_PAPERS_ACTION_EDIT')."</a>";
				if ($this->pdata['withdrawn'] == '0') {
					echo "&nbsp;&middot;&nbsp;<a href=\"".ct_pageurl('uploadPaper', array('form_id' => $this->get('ID')))."\">".ct('S_ADMIN_PAPERS_ACTION_UPLOAD')."</a><br>";
					echo "</span>";
					if ($reviewers==0)
						echo "<span class=\"fontnormal font8\"><a href=\"".ct_pageurl('withdrawPaper', array('form_id' => $this->get('ID')))."\">".ct('S_ADMIN_PAPERS_ACTION_WITHDRAW')."</a>";
				}
			}
			echo "</span>";
		} else {
			if ($user->is_admin()) {
				echo "<a href=\"".ct_pageurl('editPaper', array('form_id' => $this->get('ID')))."\">".ct('S_ADMIN_PAPERS_ACTION_EDIT')."</a><br>";
				if ($this->pdata['withdrawn'] == '0') {
					echo "<a href=\"".ct_pageurl('editFinalPaper', array('form_id' => $this->get('ID')))."\">".ct('S_ADMIN_PAPERS_ACTION_EDIT_FINAL')."</a><br>";
					echo "<a href=\"".ct_pageurl('uploadFinalPaper', array('form_id' => $this->get('ID')))."\">".ct('S_ADMIN_PAPERS_ACTION_UPLOAD_FINAL')."</a><br>";
				}
			}
			echo "</span>";
		}
		echo "</td>\n";
		echo "</tr>\n";

		$this->show_all_download_links($version, 0, "class=\"$class\" colspan=\"3\"",'8');

	}

	/**
	 * Show all details on a contribution without special
	 */
	function show_detailed($width, $align='center') {
		global $session;
		$user =& $session->get_user();
		$ctype = $this->_get_contributiontype();

		#if (!$this->get_id()>0) {
		#	ct_errorbox(ct('S_ERROR_SYSTEM'),ct('S_ERROR_SYSTEM_EMPTYOBJECT',array('CTPaper','show_detailed')));
		#	return;
		#}

		echo "<table width=\"$width\" align=\"$align\" class=\"infoview_table\">\n";
		echo "<tr class=\"lightbg\"><td align=\"left\" valign=\"top\" colspan=2>\n";
		echo "<span class=\"fontlabel fontbold  font10\">".ct('S_PAPER_DETAILED_TITLESECTION')."</span>\n";
		echo "</td></tr>\n";
		echo "<tr class=\"infoview_sep\"><td align=\"left\" valign=\"top\" colspan=2>";
		echo "<img src=\"spacer.gif\" width=1 height=1 border=0 alt=''>";
		echo "</td></tr>\n";
		echo "<tr class=\"oddrow\"><td align=\"left\" valign=\"top\" width=\"80%\">\n";
		echo "<span class=\"fontlabel font10\">".ct('S_PAPER_CONTRIBUTIONTYPE').":</span> ";
		echo "<span class=\"fontbold font10\">".$this->_get_contributiontype_title()."</span><br>";
		echo "<span class=\"fontbold font14\">".$this->get_special('title')."</span>";
		echo "</td><td width=\"20%\" align=center valign=middle class=\"whitebg\">\n";
		echo "<span class=\"fontbold font36\">".$this->get('ID')."</span>\n";
		echo "</td></tr>\n";

		if ($user->is_admin() || $user->is_conferenceChair() || $user->is_chair() || $ctype['review_anonymous']=='false' || $this->get('personID') == $user->get_id()) {
			echo "<tr class=\"evenrow\"><td colspan=2 align=left valign=top>\n";
			#echo "<span class=\"fontbold font10\">".$this->_format_author($this->get_special('author'))."</span>\n";
			echo "<span class=\"fontbold font10\">".$this->get_special('author')."</span>\n";

			if ($this->get('organisation')!="") {
				echo "<br><span class=\"fontlabel font10\">".ct('S_PAPER_FORM_ORGANISATION').":</span> ";
				echo "<span class=\"fontnormal font10\">".$this->get_special('organisation')."</span>\n";
			}

			$author =& $this->get_author();
			echo "<br><span class=\"fontlabel font10\">".ct('S_PAPER_DETAILED_SUBMITTEDBY').":</span> ";
			if ($user->is_admin() ||$user->is_chair() || $user->is_conferenceChair()) // show link to admins...
				echo "<span class=\"fontnormal font10\"><a href=\"".ct_pageurl('adminUsersDetails', array('form_id'=>$author->get('ID')))."\">".ct_form_encode($author->get_fullname())."</a> (".$author->get_special('organisation').")</span>\n";
			else
				echo "<span class=\"fontnormal font10\">".ct_form_encode($author->get_fullname())." (".$author->get_special('organisation').")</span>\n";

			echo "</td></tr>\n";
		}
		// Topics
		echo "<tr class=\"oddrow\"><td colspan=2 align=left valign=top>\n";
		if (count($this->get_topics())>0) {
			echo "<span class=\"fontlabel font10\">".ct('S_PAPER_FORM_TOPICS').":</span> <span class=\"fontnormal font10\">";
			$this->show_topics();
			echo "</span><br>\n";
		}
		// Keywords
		if ($this->get('keywords')!="") {
			echo "<span class=\"fontlabel font10\">".ct('S_PAPER_FORM_KEYWORDS').":</span> ";
			echo "<span class=\"fontnormal font10\">".$this->get_special('keywords')."</span><br>\n";
		}
		// Extratext
		if ($this->get('extratext')!="") {
			if ($ctype[ctlx($ctype,'extratext_title')]=="")
				echo "<span class=\"fontlabel font10\">".ct('S_PAPER_FORM_EXTRATEXT').":</span> ";
			else
				echo "<span class=\"fontlabel font10\">".$ctype[ctlx($ctype,'extratext_title')].":</span> ";
			echo "<span class=\"fontnormal font10\">".$this->get_special('extratext')."</span><br>\n";
		}
		if ($ctype['has_extraoption']!='false' && $this->get('extraoption') == 1) {
			echo "<img src=\"icons/ok.gif\" border=0 align=bottom>&nbsp;<span class=\"fontnormal font10\">".$ctype[ctlx($ctype,'extraoption_info')]."</span><br>\n";
		}
		// ExtraText 1-3 (nur fr spezielle Anforderungen...
		if ($this->get('extratext_1')!="") echo "<span class=\"fontlabel font10\">".ct('S_PAPER_EXTRATEXT_1').":</span> <span class=\"fontnormal font10\">".$this->get_special('extratext_1')."</span><br>\n";
		if ($this->get('extratext_2')!="") echo "<span class=\"fontlabel font10\">".ct('S_PAPER_EXTRATEXT_2').":</span> <span class=\"fontnormal font10\">".$this->get_special('extratext_2')."</span><br>\n";
		if ($this->get('extratext_3')!="") echo "<span class=\"fontlabel font10\">".ct('S_PAPER_EXTRATEXT_3').":</span> <span class=\"fontnormal font10\">".$this->get_special('extratext_3')."</span><br>\n";

		// ExtraOption 1-3
		#if ($this->get('extraoption_1')) echo "<span class=\"fontlabel font10\">".ct('S_PAPER_EXTRAOPTION_1').":</span> <span class=\"fontbold font10\">".$this->get_special('extraoption_1')."</span><br>\n";
		#if ($this->get('extraoption_2')) echo "<span class=\"fontlabel font10\">".ct('S_PAPER_EXTRAOPTION_2').":</span> <span class=\"fontbold font10\">".$this->get_special('extraoption_2')."</span><br>\n";
		#if ($this->get('extraoption_3')) echo "<span class=\"fontlabel font10\">".ct('S_PAPER_EXTRAOPTION_3').":</span> <span class=\"fontbold font10\">".$this->get_special('extraoption_3')."</span><br>\n";

		if ($ctype['has_studentcontribution']=='true' && $this->get('studentpaper') == 1) {
			echo "<img src=\"icons/studentpaper.gif\" border=0 align=bottom>&nbsp;<span class=\"fontnormal font10\">".ct('S_PAPER_FORM_STUDENTPAPER_HINT')."</span>\n";
		}
		echo "</td></tr>\n";

		// Infos about final submission...
		if ($user->is_admin() || $user->is_conferenceChair() || $user->is_chair() || $ctype['review_anonymous']=='false' || $this->get('personID') == $user->get_id()) {
			echo "<tr class=\"evenrow\"><td colspan=2 align=left valign=top>\n";
			if ($this->get('presentingauthor')!="") {
				echo "<span class=\"fontlabel font10\">".ct('S_PAPER_FORM_PRESENTINGAUTHOR').":</span> ";
				echo "<span class=\"fontnormal font10\">".$this->get_special('presentingauthor')."</span>\n";
				if ($this->get('presentingauthoremail')!="") {
					echo "(<a href=\"mailto:".$this->get_special('presentingauthoremail')."\"><span class=\"fontnormal font10\" >".$this->get_special('presentingauthoremail')."</span></a>)\n";
				}
			}
			if ($this->get('presentingauthorCV')!="") {
				echo "<br><span class=\"fontlabel font8\">".ct('S_PAPER_FORM_PRESENTINGAUTHORCV').":</span><br>";
				echo "<span class=\"fontnormal font8\">".ct_nl2br($this->get_special('presentingauthorCV'))."</span>\n";
			}
			echo "</td></tr>\n";
			echo "<tr class=\"oddrow\"><td colspan=2 align=left valign=top>\n";
			if ($this->get('pagecount')>0) {
				echo "<span class=\"fontnormal font10\">".ct('S_PAPER_PAGECOUNT', array($this->get_special('pagecount')))."</span><br>";
			}
			if ($this->get('format')=="true") {
				echo "<span class=\"fontpositive fontbold font10\">".ct('S_PAPER_FORMATOK')."</span>\n";
			}
			echo "</td></tr>\n";
		}
		echo "</table>";

	}


	/**
	* Show bibliography of user if it was entered and the option is active...
	*/
	function show_bibliography($width, $align='center') {
		$ctype = $this->_get_contributiontype();
		if ($ctype['has_bibliography']==='true' && $this->get('bibliography')!= "") {
			echo "<table width=\"$width\" align=\"$align\" class=\"infoview_table\">\n";

			echo "<tr class=\"lightbg\"><td align=\"left\" valign=\"top\" colspan=2>\n";
			echo "<span class=\"fontlabel fontbold  font10\">".ct('S_PAPER_FORM_BIBLIOGRAPHY')."</span>\n";
			echo "</td></tr>\n";

			echo "<tr class=\"infoview_sep\"><td align=\"left\" valign=\"top\" colspan=2>";
			echo "<img src=\"spacer.gif\" width=1 height=1 border=0 alt=''>";
			echo "</td></tr>\n";

			echo "<tr class=\"evenrow\"><td colspan=2 align=left valign=top><span class=\"fontnormal font8\">\n";
			echo ct_nl2br($this->get_special('bibliography'));
			echo "</span></td></tr>\n";
			echo "</table>\n\n";
		}
	}



	/**
	*  Show download link
	*/
	function show_downloads($version='',$width, $align='center') {
		echo "<table width=\"$width\" align=\"$align\" class=\"infoview_table\">\n";
		echo "<tr class=\"lightbg\"><td align=\"left\" valign=\"top\" colspan=2>\n";
		if ($version=='final')
			echo "<span class=\"fontlabel fontbold  font10\">".ct('S_INDEX_PAPER_DOWNLOAD_FINAL')."</span>\n";
		else
			echo "<span class=\"fontlabel fontbold  font10\">".ct('S_INDEX_PAPER_DOWNLOAD')."</span>\n";

		echo "</td></tr>\n";

		echo "<tr class=\"infoview_sep\"><td align=\"left\" valign=\"top\" colspan=2>";
		echo "<img src=\"spacer.gif\" width=1 height=1 border=0 alt=''>";
		echo "</td></tr>\n";

		$this->show_all_download_links($version, 0, 'class="tbldialog" colspan="2"');

		echo "</table>";
	}


	/**
	* Show up to 3 rows (tr) with download links...
	*/
	function show_all_download_links($version='', $anonymous=1, $attributes='class="tbldialog"', $fontsize='9') {
		global $session;
		if ($session->loggedin())
			$user = $session->get_user();
		else // Not logged in, create dummy user object.
			$user = new CTPerson();
		$ctype = $this->_get_contributiontype();
		$sess  = ct_get_session($this->get('track'));
		if ($this->_number_of_uploads_for_contributiontype('',$version)>0) {
			// Check user rights: Administrative, or he is author, or reviewer and has access rights.
			if ($user->is_chair() || $user->is_admin() || $user->is_conferenceChair() ||
				($user->get('ID') == $this->get('personID')) ||
				($this->is_reviewed_by($user->get('ID')) && $ctype['upload_accessible_A']=='true') ||
				(ct_check_phases('browsesessions') && $ctype['upload_accessible_A']=='true' && $sess['show_downloads']=='true') ) {
				echo "<tr><td align=left valign=top $attributes >";
				$this->_show_download_link("",$version,$anonymous,$fontsize);
				echo "</td></tr>\n";
			} else {
				echo "<tr><td align=left valign=top $attributes ></td></tr>\n";
			}
		}
		if ($this->_number_of_uploads_for_contributiontype('',$version)>1) {
			if ($user->is_chair() || $user->is_admin() || $user->is_conferenceChair() ||
				($user->get('ID') == $this->get('personID')) ||
				($this->is_reviewed_by($user->get('ID')) && $ctype['upload_accessible_B']=='true') ||
				(ct_check_phases('browsesessions') && $ctype['upload_accessible_B']=='true' && $sess['show_downloads']=='true') ) {
				echo "<tr><td align=left valign=top $attributes >";
				$this->_show_download_link("2",$version,$anonymous,$fontsize);
				echo "</td></tr>\n";
			} else {
				echo "<tr><td align=left valign=top $attributes ></td></tr>\n";
			}
		}
		if ($this->_number_of_uploads_for_contributiontype('',$version)>2) {
			if ($user->is_chair() || $user->is_admin() || $user->is_conferenceChair() ||
				($user->get('ID') == $this->get('personID')) ||
				($this->is_reviewed_by($user->get('ID')) && $ctype['upload_accessible_C']=='true') ||
				(ct_check_phases('browsesessions') && $ctype['upload_accessible_C']=='true' && $sess['show_downloads']=='true') ) {
				echo "<tr><td align=left valign=top $attributes >";
				$this->_show_download_link("3",$version,$anonymous,$fontsize);
				echo "</td></tr>\n";
			} else {
				echo "<tr><td align=left valign=top $attributes ></td></tr>\n";
			}
		}
	}


	/**
	* Show information on one upload with the link to download that file.
	*/
	function _show_download_link($index='',$version='',$anonymous=1,$fontsize='9') {
		ct_load_lib('datetime.lib');
		ct_load_lib('papers.lib');

		$file_postfix="";
		// use this postfix for downloaded files.
		if ($this->_number_of_uploads_for_contributiontype('',$version)>1)	// Many files: Add postfix!
			$file_postfix=($index=="3"?"_c":($index=="2"?"_b":"_a"));
		// Text to for anonymous links
		$text= ct_get_file_number_text($index);
		$originalname = $this->get_special($this->get_ffname('originalname',$version,$index));
		$filename = urlencode(stripslashes($this->get($this->get_ffname('originalname',$version,$index))));
		echo "<span class=\"fontnormal font$fontsize\">\n";
		echo $text;
		echo "</span>\n";
		if ($this->get($this->get_ffname('filename',$version,$index)) != "") {
			echo "<a  title=\"".ct_create_filename($originalname, $this->get_id(), $file_postfix)."\" href=\"".ct_pageurl('downloadPaper', array('filename'=>ct_create_filename($originalname, $this->get_id(), $file_postfix),'form_id'=>$this->get('ID'),'form_index'=>$index,'form_version'=>$version))."\">";
			echo "<img src=\"icons/document.gif\" border=0 align=bottom alt=\"\">";
			if ($anonymous==1)
				echo "<span class=\"fontnormal font$fontsize\">".ct_create_filename($originalname, $this->get_id(), $file_postfix)."</span>";
			echo "</a> \n";
			if ($anonymous==0) {
				echo "<a  title=\"".$originalname."\" href=\"".ct_pageurl('downloadPaper', array("filename"=>$filename,'form_id'=>$this->get('ID'),'form_index'=>$index,'form_version'=>$version))."\" class=\"fontnormal font$fontsize\">";
				echo $originalname."</a>\n";
				echo "<span class=\"fontnormal font$fontsize\">&nbsp;(".ct_datetime_format_timezone($this->get($this->get_ffname('lastupload',$version,$index))).")</span>\n";
			}
		} elseif ($this->_number_of_uploads_for_contributiontype()) {
			echo "<span class=\"fontnegative fontbold font$fontsize\">".ct('S_INDEX_PAPER_NOUPLOAD')."</span>\n";
		} else {
			echo '&nbsp;';
		}
	}


	/**
	* Show abstract of contribution...
	*/
	function show_abstract($width, $align='center') {
		if ($this->get('abstract')!='') {
			echo "<table width=\"$width\" align=\"$align\" class=\"infoview_table\">\n";
			echo "<tr class=\"lightbg\"><td align=\"left\" valign=\"top\" colspan=2>\n";
			echo "<span class=\"fontlabel fontbold  font10\">".ct('S_PAPER_FORM_ABSTRACT')."</span>\n";
			echo "</td></tr>\n";

			echo "<tr class=\"infoview_sep\"><td align=\"left\" valign=\"top\" colspan=2>";
			echo "<img src=\"spacer.gif\" width=1 height=1 border=0 alt=''>";
			echo "</td></tr>\n";

			echo "<tr class=\"evenrow\"><td colspan=2 align=left valign=top>\n";
			echo $this->_format_abstract($this->get('abstract'));
			echo "</td></tr>\n";
			echo "</table>";
		}
	}


	/**
	* Show remark of user...
	*/
	function show_remark($width, $align='center') {
		echo "<table width=\"$width\" align=\"$align\" class=\"infoview_table\">\n";
		echo "<tr class=\"lightbg\"><td align=\"left\" valign=\"top\" colspan=2>\n";
		echo "<span class=\"fontlabel fontbold  font10\">".ct('S_PAPER_FORM_EXTERNALREMARK')."</span>\n";
		echo "</td></tr>\n";

		echo "<tr class=\"infoview_sep\"><td align=\"left\" valign=\"top\" colspan=2>";
		echo "<img src=\"spacer.gif\" width=1 height=1 border=0 alt=''>";
		echo "</td></tr>\n";

		echo "<tr class=\"evenrow\"><td colspan=2 align=left valign=top>\n";
		echo "<span class=\"fontnormal font10\">".$this->get_special('externalremark')."</span>\n</td></tr>\n";
		echo "</table>";
	}


	/*
	* Show acceptance status and an overview of all review results to this contribution
	*/
	function show_accept_status($width, $align='center') {
		// Show acceptance status
		echo "<table width=\"$width\" align=\"$align\" class=\"infoview_table\">\n";
		echo "<tr class=\"lightbg\"><td align=\"left\" valign=\"top\" colspan=2>\n";
		echo "<span class=\"fontlabel fontbold  font10\">".ct('S_PAPER_DETAILED_REVIEWSRESULT')."</span>\n";
		echo "</td></tr>\n";
		echo "<tr class=\"infoview_sep\"><td align=\"left\" valign=\"top\" colspan=2>";
		echo "<img src=\"spacer.gif\" width=1 height=1 border=0 alt=''>";
		echo "<tr class=\"evenrow\"><td align=\"left\" valign=\"top\" colspan=2 class=\"boxmsgTD\">";
		echo "<span class=\"fontbold font14\">".$this->get_acceptstatus()."</span>";
		echo "</td></tr>\n";
		echo "</table>\n\n";

	}


	/**
	* Show options to admin and pc chairs...
	*/
	function show_admin_options($width, $align='center') {
		global $session;

		echo "<table width=\"$width\" align=\"$align\" class=\"infoview_table\">\n";
		echo "<tr class=\"lightbg\"><td colspan=2><img src=\"spacer.gif\" width=1 height=1 border=0 alt=''></td></tr>\n";

		echo "<tr class=\"lightbg\"><td align=\"left\" valign=\"top\" colspan=2>\n";
		echo "<span class=\"fontlabel fontbold  font10\">".ct('S_PAPER_DETAILED_COMMANDSSECTION')."</span>\n";
		echo "</td></tr>\n";
		echo "<tr class=\"infoview_sep\"><td align=\"left\" valign=\"top\" colspan=2>";
		echo "<img src=\"spacer.gif\" width=1 height=1 border=0 alt=''>";
		echo "</td></tr>\n";
		echo "<tr><td class=\"mediumbg\" colspan=2><span class=\"fontbold font10\">";
		$params = array("form_id" => $this->pdata['ID']);
		echo "<a class=\"cmda\" href=\"".ct_pageurl('editPaper', $params)."\">".ct('S_INDEX_PAPER_EDIT')."</a> &middot; ";
		echo "<a class=\"cmda\" href=\"".ct_pageurl('uploadPaper', $params)."\">".ct('S_INDEX_PAPER_UPLOAD')."</a> &middot; ";
		echo "<a class=\"cmda\" href=\"".ct_pageurl('uploadFinalPaper', $params)."\">".ct('S_INDEX_PAPER_FINALUPLOAD')."</a> &middot; ";
		echo "<a class=\"cmda\" href=\"".ct_pageurl('withdrawPaper', $params)."\">".ct('S_INDEX_PAPER_WITHDRAW')."</a> &middot; ";
		echo "<a class=\"cmda\" href=\"".ct_pageurl('adminReviewAssign', $params)."\">".ct('S_REVIEW_ASSIGN')."</a>";
		echo "</span></td></tr>\n";
		echo "</table>\n";
	}


	/**
	* Show an overview of all review results to this contribution
	*/
	function show_review_results($showAllReviews=true,$width, $align='center') {
		global $session;
		$user =& $session->get_user();

		// get right class to show the surveys.
		$classname = $this->get_reviewClass();
		ct_load_class($classname);
		eval('$review = new '.$classname.'();');

		// get all reviews
		$reviews = $this->get_reviews($showAllReviews);
		$rcount = count($reviews);
		if ($rcount > 0) {
			$review->show_survey($reviews, $width, $align );
		}
	}


	/**
	 * Process all required uploads for this contributiontype.
	 *
	 * @param string $uploadtype type of upload. Either empty string or "final".
	 * @return array uploads array with the outcome of the uploads:
	 * 				 OK => File was uploaded successfully, a infobox message is displayed
	 * 				 ERROR => File was NOT uploaded, an error occured, a errorbox message is displayed
	 * 				 EXISTS => No file name entered, but there is already a file on the server
	 * 				 MISSING => No file name entered, and no file is on server
	 */
	function process_uploadform($uploadtype="") {
		global $http, $session, $_FILES;

		if ($uploadtype!="final") $uploadtype="";

		$num_uploads = $this->_number_of_uploads_for_contributiontype("",$uploadtype);
		$upload_results=array();

		if ($num_uploads>=1) {
			$f_name	= $_FILES[$this->get_ffname('form_filename',$uploadtype,1)]['name'];
			if ($f_name!="")
				if ($this->process_upload($uploadtype, "1")) $upload_results[1]="OK"; else $upload_results[1]="ERROR";
			else
				if ($this->get($this->get_ffname('originalname',$uploadtype,1))!="") $upload_results[1]="EXISTS"; else $upload_results[1]="MISSING";
		}
		if ($num_uploads>=2) {
			$f_name	= $_FILES[$this->get_ffname('form_filename',$uploadtype,2)]['name'];
			if ($f_name!="")
				if ($this->process_upload($uploadtype, "2")) $upload_results[2]="OK"; else $upload_results[2]="ERROR";
			else
				if ($this->get($this->get_ffname('originalname',$uploadtype,2))!="") $upload_results[2]="EXISTS"; else $upload_results[2]="MISSING";
		}
		if ($num_uploads>=3) {
			$f_name	= $_FILES[$this->get_ffname('form_filename',$uploadtype,3)]['name'];
			if ($f_name!="")
				if ($this->process_upload($uploadtype, "3")) $upload_results[3]="OK"; else $upload_results[3]="ERROR";
			else
				if ($this->get($this->get_ffname('originalname',$uploadtype,3))!="") $upload_results[3]="EXISTS"; else $upload_results[3]="MISSING";
		}
		return $upload_results;
	}

	/**
	 * Create the form field name for the upload file name
	 *
	 * @param string $field name of field
	 * @param string $type
	 * @param string $index
	 * @return string
	 */
	function get_ffname($field,$type="",$index=1) {
		$postfix="";
		if ($type=="final") $postfix.="_final";
		if ($index==2) $postfix.="_2";
		if ($index==3) $postfix.="_3";
		return $field.$postfix;
	}


	/**
	* Process paper upload and save file or show error messages
	* Prefix is used to separate submissions from final uploads, posters etc.
	* Index is used for multiple uploads.
	*/
	function process_upload($uploadtype="", $index="") {
		global $http, $session, $_FILES;
		ct_load_lib('papers.lib');

		if( !ini_get('safe_mode') ){
			// Does _not_ work in SAFE MODE
			$uploaddir = ct_get_path('uploads').$this->get('personID')."/";
			//check if the directory is writable.
			if (!is_dir($uploaddir)) {
				//	mkdir($uploaddir, 0750); // User access by ftp may be "difficult".
				if (mkdir($uploaddir, 0777)) {
					chmod($uploaddir, 0777);  // Set permissions (The above sometimes fails!)
				} else {
					$uploaddir = ct_get_path('uploads');
				}
			}
		} else {
			$uploaddir = ct_get_path('uploads');
		}
		if (!is_writeable($uploaddir)){
			die ("<H3>ConfTool SETUP ERROR</H3> The directory <b><code>".$uploaddir."</code></b> is NOT writable.");
		}

		$postfix = "";
		if ($uploadtype!="") 	$postfix.="_".$uploadtype;
		if ("$index"=="2")		$postfix.="_2";
		if ("$index"=="3")		$postfix.="_3";
		$file_number_text = "";
		if ($this->_number_of_uploads_for_contributiontype("",$uploadtype)>1)
			$file_number_text = ct_get_file_number_text($index).': ';

		$f_name		=$_FILES['form_filename'.$postfix]['name'];
		$f_tmp_name	=$_FILES['form_filename'.$postfix]['tmp_name'];
		$f_size		=$_FILES['form_filename'.$postfix]['size'];
		$fileContents = "";
		if ($f_name != 'none' && $f_name != '' ) {
			if ($this->_is_legal_file_type($f_name, $index)) {
				if (is_uploaded_file($f_tmp_name)) {
					$tmp_name = ct_get_path('uploads').rawurlencode($f_name);
					if (move_uploaded_file($f_tmp_name, $tmp_name)) {
						chmod($tmp_name, 0666);
						$upload_file = fopen($tmp_name,"r");
						if (filesize($tmp_name) >0) $fileContents = fread($upload_file, filesize($tmp_name));
						if (strlen($fileContents) != 0) {
							if ($this->_is_legal_file_size($fileContents)) {
								fclose($upload_file);
								// create unique filename to keep old versions...
								$count = -1;
								if ($handle = opendir($uploaddir)) {
									while (false !== readdir($handle)) { $count++; }
								}

								$savename = str_replace("%20","_",rawurlencode($f_name));
								if ($uploadtype!="") {
									$savename = $uploadtype."-".$savename;
								}
								$savename = $uploaddir.$count."-".$savename;
								// Move file and set permissions.
								if (rename($tmp_name, $savename)) {
									chmod($savename, 0666); // Allow access also for conftool user (not only for web-server...)

									$savename = str_replace(ct_get_path('uploads'),'',$savename); // remove leading savepath
									$this->set('filename'.$postfix, 	addslashes($savename));
									$this->set('originalname'.$postfix, addslashes($f_name));
									$this->set('lastupload'.$postfix,	ct_timestamp_2_datetime(ct_time()));
									ct_infobox($file_number_text.ct('S_INFO_PAPER_UPLOAD'), ct('S_INFO_PAPER_UPLOAD_SUCCESS'));
									return true; // Big success...
								} else {
									ct_errorbox($file_number_text.ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_COPYFILE'));
									@unlink($tmp_name);
								}
							} else {
								ct_errorbox($file_number_text.ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_FILESIZE')." ".strlen($fileContents)." Bytes.");
								fclose($upload_file);
								@unlink($tmp_name);
							}
						} else {
							ct_errorbox($file_number_text.ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_NOT_FOUND'));
							chmod($tmp_name, 0666);
							$upload_file = fopen($tmp_name,"r");
							fclose($upload_file);
							@unlink($tmp_name);
						}
					} else {
						ct_errorbox($file_number_text.ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_NOT_FOUND'));
					}
				} else {
					ct_errorbox($file_number_text.ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_FAILED'));
				}

			} else {
				ct_errorbox($file_number_text.ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_FILETYPE')." <strong>".implode(", ",$this->_get_legal_file_types($index))."</strong>");
			}
		} else {
			ct_warningbox($file_number_text.ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_NO_FILE'));
		}
		return false;
	}


}

?>