<?php
//
// CLASS:		CTPaperData
// 				Basic class to represent submissions to a conference.
//				Loaded at page load time, required for session variable
//

class CTPaperData {

	var $pdata = array();
	var $persistID = 0;
	var $minNumOfReviews = 2;
	var $maxNumOfReviews = 3;
	var $form;
	var $author = null;

	// default constructor
	function CTPaperData() {
		$this->_init();
	}

	function _init() {
		$pdata = array();
		$persistID = 0;
		$form = null;
	}

	function load_by_id($id) {
		global $db;
		$id = (int)$id; // sanitize.
		$r = $db->query("select * from papers where id='$id'");
		if ($db->num_rows($r) == 1) {
			$this->pdata = $db->fetch($r);
			$this->persistID = $this->pdata['ID'];
			return true;
		} else {
			$this->pdata['ID']=$id;
			return false;
		}
	}

	// update data in database from object
	function persist() {
		global $db;

		if ($this->get('track') == "") $this->pdata['track'] = 0;
		if ($this->get('acceptstatus') == "") $this->pdata['acceptstatus'] = 0;
		if ($this->get('withdrawn') == "") $this->pdata['withdrawn'] = 0;

		if ($this->pdata['ID'] == "") {
			$this->pdata['ID'] = "0";
			$this->pdata['creationdate'] = ct_timestamp_2_datetime(ct_time());
			$result = $db->insert_into('papers', $this->pdata);
			$this->pdata['ID'] = $db->last_id();
		} else {
			$this->pdata['lastupdate'] = ct_timestamp_2_datetime(ct_time());
			$result = $db->replace_into('papers', $this->pdata);
		}
		if (is_array($this->pdata['emails'])) {
			$db->unlink('emails2papers', $this->pdata['ID'], "");
			while (list(,$v) = each($this->pdata['emails'])) {
				$db->link('emails2papers', $this->pdata['ID'], trim($v));
			}
		}

		if (is_array($this->pdata['topics'])) {
			$db->unlink('topics2papers', $this->pdata['ID'], "");
			while (list($k,$v) = each($this->pdata['topics'])) {
				$db->link('topics2papers', $this->pdata['ID'], $v);
			}
		}
		return $result;
	}

	/**
	 * get the papers ID
	 */
	function get_id() {
		return $this->pdata['ID'];
	}

	/**
	 * get a record field's value, fieldname is key
	 */
	function get($key) {
		return isset($this->pdata[$key]) ? $this->pdata[$key] : '';
	}

	/**
	 * get a record field value, with html special chars converted
	 */
	function get_special($key) {
		return ct_form_encode($this->get($key));
	}

	/**
	 * set a record field value
	 */
	function set($key, $value) {
		$this->pdata[$key] = $value;
	}

	// returns the database record of the contribution type
	function _get_contributiontype($typeID="") {
		if ($typeID=="") $typeID=$this->pdata['contributiontypeID'];
		if ($typeID=="") return "";
		ct_load_lib('papers.lib');
		return ct_get_contributiontypes($typeID);
	}

	/**
	 * returns if submission of contribution type is currently set active
	 */
	function is_contributiontype_active($typeID="") {
		if ($typeID=="") $typeID=$this->pdata['contributiontypeID'];
		if ($typeID=="") return 0;
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		$active = ($t['active']=='true' && ct_datetime_2_timestamp($t['deadline'])>ct_time());
		return $active;
	}

	/**
	 * get the name of the paper class for this contributiontype
	 */
	function get_paperClass($typeID="") {
		$default_class = "CTPaper_Default";
		if ($typeID=="") {
			$typeID= $this->get('contributiontypeID');
		}
		if ($typeID=="") return $default_class;  // This should never happen...
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		if ($t['paper_classname']=="") return $default_class;  // This should also never happen...
		if (!ct_test_class('CTPaper_'.$t['paper_classname'])) {
	        ct_error_log("Warning: Class .class 'CTPaper_".$t['paper_classname']."' could not be found",0);
			ct_warningbox('Class not found!',"The class 'CTPaper_".$t['paper_classname']."' could not be found! Please contact the conference organizers");
			return $default_class;
		}
		return 'CTPaper_'.$t['paper_classname'];
	}

}

?>