<?php
//
// CLASS:		CTPaper
//

class CTPaper_AbstractOnly extends CTPaper {

	// default constructor
	function CTPaper_AbstractOnly() {
		parent::CTPaper();
	}


	//#### DISPLAY ##############################################################

	/**
	* Show short info about paper in formatted way - see conftool-custom.css
	*/
	function show_formatted($showmetadata=true, $showabstract=true) {
		global $session,$http;
		$user   = $session->get_user();
		$ctype  = $this->_get_contributiontype();
		$author = $this->get_author();

		echo "<div class=\"paper\">";

		if ($this->get('withdrawn'))
			echo "<span class=\"fontnegative yellowbg fontbold font12\">".ct('S_PAPER_WITHDRAWN')."</span><br>";

		if ($showmetadata) {
			#echo "<span class=\"fontlabel font8\">".ct('S_PAPER_METADATA')."</span><br>";
			echo "<span class=\"paper_type\">".$this->_get_contributiontype_title()."</span><br>\n";
 			echo "<span class=\"paper_label\">".ct('S_PAPER_TOPICS').": </span>";
			echo "<span class=\"paper_topics\">";
			$this->show_topics();
			echo "</span><br>";
			echo "<span class=\"paper_label\">".ct('S_PAPER_KEYWORDS').": </span>";
			echo "<span class=\"paper_keywords\">".$this->get_special('keywords')."</span><br>\n";

		}

		$ses = ct_get_sessions($this->get('track'));
		$ses_title = '';
		if (is_array($ses)) {
			$row=$ses[0];
			$ses_title = $row['shorttitle'].' ';
		}
		# Title of paper
		#echo "<span class=\"fontlabel font10\">".ct('S_PAPER_TITLE').": </span>";
		#echo "<p class=\"paper_title\">".$this->get_special('title')."</p>\n";
		echo "<p class=\"paper_title\">";
		echo $ses_title;
		echo $this->get_special('title');
		echo "</p>\n";
		// echo "<br>";

		// Show author information
		if ($http['page']=='browseSessions' || // Access is always possible
			(is_object($user) && ($user->is_admin() || $user->is_conferenceChair() || $user->is_chair())) || // Chairs can access
					$ctype['review_anonymous']=='false' ||		// OK if it is not double blind
					(is_object($user) && $this->get('personID') == $user->get_id()) ) {		// user can see his own data.
			# Authors of paper
			$author_formatted = $this->_format_author($this->get_special('author'));

			# Presenting Author
			$presauth = $this->get_special('presentingauthor');
			# If not entered, use primary author of paper...
			if ($presauth=="") $presauth = $author->get('name').', '.$author->get('firstname');

			if ($presauth!="") {
				$pattern = "/($presauth)/i";
				$format  = "<u>\$1</u>";
				$author_formatted = preg_replace($pattern, $format, $author_formatted); // underline presenting author
			}

			#echo "<span class=\"fontlabel font10\">".ct('S_PAPER_AUTHOR').":</span>";
			echo "<p class=\"paper_author\"> ".$author_formatted;
			echo "</p>\n\n";

			# Organizations of authors
			if ($this->get('organisation')!='') {
				$organisation_formatted = $this->_format_organisation($this->get_special('organisation'));
				echo "<p class=\"paper_organisation\">";
				#echo "<span class=\"paper_label\">".ct('S_PAPER_ORGANISATION').":</span><br> ";
				echo $organisation_formatted;

				// Show email, but only if user is logged in!
				if ($session->loggedin() &&	is_object($user)) {
					if ($this->get('presentingauthoremail')!='')
						#echo "<p class=\"paper_email\">Email: <a href=\"mailto:".$this->get_special('presentingauthoremail')."\"><span class=\"paper_email\" >".$this->get_special('presentingauthoremail')."</span></a></p>";
						echo "; <span class=\"paper_email\">".$this->get_special('presentingauthoremail')."</span>";
					else // use email of primary author!
						#echo "<p class=\"paper_email\">Email: <a href=\"mailto:".$author->get_special('email')."\"><span class=\"paper_email\" >".$author->get_special('email')."</a></p>";
						echo "; <span class=\"paper_email\">".$author->get_special('email')."</span>";
				}

				echo "</p>\n\n";
			}

			#if (count($this->get_emails())>0) {
			#	echo "<p class=\"paper_author\"> ";
			#	echo "<span class=\"paper_label\">".ct('S_PAPER_FORM_EMAILS').": </span>";
			#	echo ct_form_encode(ct_csv_implode($this->get_emails()));
			#	echo "</p>\n";
			#}
		}

		// Abstract
		if ($showabstract) {
			$abstract_formatted = $this->_format_abstract($this->get('abstract'));
			if ($this->get('abstract')!="" && $abstract_formatted!='') {
				#echo "<p class=\"paper_label\">".ct('S_PAPER_FORM_ABSTRACT').": </p>";
				echo $abstract_formatted;
			}
		}

		// Show bibliography only if non-anonymous reviews...
		if ($showmetadata &&
				((is_object($user) && ($user->is_admin() || $user->is_conferenceChair() || $user->is_chair() || $this->get('personID') == $user->get_id())) ||
				  $ctype['review_anonymous']=='false') &&
				($ctype['has_bibliography']==='true' && $this->get('bibliography')!= "")) {
			#echo "<tr><td class=\"whitebg\" align=left valign=top>";
			#echo "<div class=\"paper\">";
			echo "<span class=\"paper_label\">".ct('S_PAPER_FORM_BIBLIOGRAPHY')."</span><br>";
			echo "<span class=\"paper_abstract\">".ct_nl2br($this->get_special('bibliography'))."</span>\n";
			#echo "</div>\n";
			#echo "</td></tr>\n";
		}

		/*if ($this->get('externalremark')!= "") {
			echo "<div class=\"paper\">";
			echo "<span class=\"paper_label\">".ct('S_PAPER_FORM_EXTERNALREMARK')."</span><br>";
			echo "<span class=\"paper_abstract\">".$this->get_special('externalremark')."</span>\n";
			echo "</div>\n";
		}*/
		echo "</div>\n";

	}


	/**
	* Some simple formating functions
	* Set organization numbers as <sup>
	*/
	function _format_author($author) {
		// Replace kommas by colons.
		#$pattern = "/(,)/s";
		#$pattern = "/([,;]\n)([^\n]*)$/s";
		$pattern = "/([,;]\n)/s";
		$format = "; ";
		$author =  preg_replace($pattern, $format, $author); //

		// Find organization numbers, always before a ", " (space added by _check_format!)
		$pattern = "/(\()([\d, ]{1,5})(\))/is";
		// Take care if using "; " or ";" instead, as it is also used for closing entities!
		$format = "<sup>\$2</sup>";
		$author = preg_replace($pattern, $format, $author);
		return $author;
	}

	/**
	 * format organisation
	 */
	function _format_organisation($organisation) {
		// Change last CR to "and"
		$pattern = "/\n([\d]+)([^\n]*)$/";
		$format = " and $1$2";
		#$organisation =  preg_replace($pattern, $format, $organisation);

		// change CRs to "; " to show all organisations in one line.
		$pattern = "/\n([\d]+)/is";
		$format = "; $1";
		$organisation = preg_replace($pattern, $format, $organisation);

		// Change "1:" to "<sup>1</sup>" (superscript):
		$pattern = "/([\d]+)(\W)?:[\W]*/is";
		$format = "<sup>\$1</sup>";
		$organisation = preg_replace($pattern, $format, $organisation);
		#$organisation=nl2br($organisation);
		return $organisation;
	}

	/**
	* Show a nicely formatted abstract
	*/
	function _format_abstract($abstract) {
		$abstract_formatted="";
		$ctype  = $this->_get_contributiontype();
		if ($ctype['has_abstract']=='true') {
			$abstract_formatted = "\n".ct_form_encode($abstract)."\n";

			// remove double CRs
			$pattern = "/(\s*[\n|\r]+\s*)/s";
			$format  = "\n";
			$abstract_formatted = preg_replace($pattern, $format, $abstract_formatted);

			// format italics: "_italics_"
			$pattern = "/([\W\.,])_([^_^\n]{1,200})_([\W\.,])/s";
			$format  = "$1 <i> \$2 </i> $3";
			$abstract_formatted = preg_replace($pattern, $format, $abstract_formatted);

			// format *bold*, max 200 symbols
			$pattern = "/([\W\.,])\*([^\*^\n]{1,200})\*([\W\.,])/s";
			$format  = "$1 <strong>\$2</strong> $3";
			$abstract_formatted = preg_replace($pattern, $format, $abstract_formatted);

			// format <sup>superscript</sup>, max 200 symbols
			#$pattern = "/\^([^\^^\~^\n]{1,20})\^/s"; 			// format ^superscript^, max 20 symbols
			$pattern = "/&lt;sup&gt;([^\/^\n]{1,200})&lt;\/sup&gt;/s";
			$format  = "<sup>\$1</sup>";
			$abstract_formatted = preg_replace($pattern, $format, $abstract_formatted);

			// format <sup>subscript</sup>, max 200 symbols
			$pattern = "/&lt;sub&gt;([^\/^\n]{1,200})&lt;\/sub&gt;/s";
			$format  = "<sub>\$1</sub>";
			$abstract_formatted = preg_replace($pattern, $format, $abstract_formatted);

			// format paragraphs
			$pattern = '/\n([^\n]*)/s';
			$format  = "\n<p class=\"paper_abstract\">\$1</p>";
			$abstract_formatted = preg_replace($pattern, $format, $abstract_formatted);

			// format lists "- "
			$pattern = "/\n<p class=\"paper_abstract\">-\s*([^<]+)<\/p>/s";
			$format  = "\n<ul class=\"paper_abstract_list\">\n <li>\$1</li>\n</ul>";
			$abstract_formatted = preg_replace($pattern, $format, $abstract_formatted);
			$pattern = "/\n<\/ul>\n<ul class=\"paper_abstract_list\">\n/s"; 	// remove extra <ul>s
			$format  = "\n";
			$abstract_formatted = preg_replace($pattern, $format, $abstract_formatted);

		} elseif ($ctype['has_abstract']=='plaintext') {
			$abstract_formatted = "\n".ct_nl2br($abstract)."\n";

		} elseif ($ctype['has_abstract']=='html') {
			ct_load_lib('html_format.lib');
			$abstract_formatted = "\n".ct_html_strict_format($abstract)."\n";
		}
		return $abstract_formatted;
	}



	// Form Processing... -----------------------------------------------------

	/** Require a field... */
	function _require($field, $name) {
		global $http;

		if (isset($http[$name]) && ($http[$name] != "")) {
			$this->set($field, $http[$name]);
			return true;
		} else {
			$this->errors[] = $name;
			$this->set($field, "");
			return false;
		}
	}

	/** basic formatting for entered data in abstracts field */
	function _basic_formatting($text) {
		// remove double spaces
		// $text = htmlspecialchars($text);

		$pattern = "/([ |\t]+)/s";
		$format = " ";
		$text = preg_replace($pattern, $format, $text);

		// remove double CRs
		$pattern = "/(\s*[\n|\r]+\s*)/s";
		$format = "\n";
		$text = preg_replace($pattern, $format, $text);

		return $text;
	}


	/**
	 * test if the format of the entered data is fine...
	 */
	function _check_format() {
		ct_load_lib('papers.lib');

		$okay = true;
		$this->set('title', $this->_basic_formatting($this->get('title')));

		$author = $this->_basic_formatting($this->get('author'));
		$this->set('author', $author);

		// Do only basic formatting of abstract only if the type is "true" or "html".
		$ctype = $this->_get_contributiontype();
		$abstract = $this->get('abstract');
		if ($ctype['has_abstract']=='true') {
			$abstract = $this->_basic_formatting($abstract);
			$abstract = preg_replace("/\n/", "\n\n", $abstract);  // replace single with double \n's (makes editing easier...)
			$abstract = preg_replace("/\n(\n-)[\s]*/", "\$1 ", $abstract);  // format lists...
			$this->set('abstract', $abstract);
		}
		if ($ctype['has_abstract']=='html') {
			$abstract = preg_replace("/<\/p>/", "</p>\n", $abstract);  // replace paragraph signs: Add newline
			$abstract = preg_replace("/\n\n/", "\n", $abstract);  // replace double \n
			$this->set('abstract', $abstract);
		}

		// Check length.
		$clean_abstract = ct_unhtmlentities(strip_tags($abstract)); // count only characters without entities and html tags.
		#echo $clean_abstract."<br>".strlen($clean_abstract)."<br>";
		if ($ctype['abstract_maxlen']>0) {
			$maxlen = $ctype['abstract_maxlen'];
			if (strlen($clean_abstract) >($maxlen+15)) {
				ct_warningbox(ct('S_ERROR_NEWPAPER'),ct('S_ERROR_NEWPAPER_ABSTRACT_TOO_LONG',array('('.strlen($abstract).' '.ct('S_FORM_CHARACTERS').')')));
				$this->errors[] = 'form_abstract';
				$okay=false;
			}
		} elseif ($ctype['abstract_maxlen']<0) {
			$maxlen = 0-$ctype['abstract_maxlen'];
			$words = preg_match_all('|\b\S+\b|',$clean_abstract, $out);
			#$words -= preg_match_all('|\b[-,.;:!\"\']+\b|',$clean_abstract, $out);  # find punctuation symbols - do not count!
			if ($words>($maxlen+5)) {
				#ct_print_r($out);
				ct_warningbox(ct('S_ERROR_NEWPAPER'),ct('S_ERROR_NEWPAPER_ABSTRACT_TOO_LONG',array('('.$words.' '.ct('S_FORM_WORDS').')')));
				$this->errors[] = 'form_abstract';
				$okay=false;
			}
		}

		// Check formatting of authors
		#$author = $this->_basic_formatting($this->get('author'));
		$author = $this->get('author');
		$pattern = "/([,;]?[\w]?\n)/s";
		$format = ";\n";
		$author =  preg_replace($pattern, $format, $author); //
		$authors = split("\n",$author);   // Split authors at "\n"
		$authors = array_map('trim', $authors);   // Split authors at "\n"
		#!! $authors = array_map('trim', split(";",$author));   // Split authors at ";" does not work well, as you may have problems with escaped characters!!
		$author = implode("\n",$authors);	// Add "\n" again...
		$this->set('author', $author);
		//$this->errors[] = 'form_author';

		// Check and format organisations...
		$organisation = $this->_basic_formatting("\n".$this->get('organisation')."\n");
		$pattern = "/\n[\s]?([\d])[\w]?:?[\s]*/is";
		$format = "\n\$1: ";
		#$format = "\n\<sup>$1</sup> ";
		$organisation = preg_replace($pattern, $format, $organisation);
		$organisation = preg_replace("/^[\n]*/", "", $organisation);  // remove leading [\n]s
		$organisation = preg_replace("/[\n]([\D])/", " \$1", $organisation);  // remove [\n]s that are not followed by numbers
		$organisation = preg_replace("/([\.;,\s]*)[\n]/", "\n", $organisation);  // remove , . ; at the end of lines and add NL
		$organisation = preg_replace("/[\n]*$/", "", $organisation);  // remove trailing [\n]s
		$this->set('organisation', $organisation);

		return $okay;
	}


	// ----- Submission functions -------------------------------------------------

	/**
	 * Set default data
	 */
	function _set_default_data() {
		global $session;
		$user =& $session->get_user();
		if ($this->get('author')=='' && $this->get('title')=='') {
			#$this->set('author', $user->get('name').', '.$user->get('firstname'));
			#$this->set('presentingauthor', $user->get('name').', '.$user->get('firstname'));
			$this->set('author', $user->get('firstname').' '.$user->get('name'));
			$this->set('presentingauthor', $user->get('firstname').' '.$user->get('name'));
			$this->set('organisation', $user->get('organisation').", ".ct_get_country($user->get('country')));
			$this->set('presentingauthoremail', $user->get('email'));
		}
	}

	/**
	 * Show paper submission form (where authors can submit their papers)
	 */
	function show_form_step1($action, $errors=array(), $editPaper=false) {
		ct_load_class('CTForm');
		global $session,$http;
		$user =& $session->get_user();
		$ctype = $this->_get_contributiontype();

		$this->_set_default_data();

		$form = new CTForm($action, 'post', $errors);
		$form->width='100%';
		$form->align='center';

		$form->add_hidden(array(array("form_id",$this->get('ID'))));

		$form->add_separator(ct('S_PAPER_FORM_INFOSECTION'));
		if ($session->loggedin() && $editPaper &&
				($user->is_admin() || $user->is_conferenceChair()) ) { // show all types to admin
			$form->add_select(ct('S_PAPER_FORM_CONTRIBUTIONTYPE'), 'form_contributiontypeID', 1, $this->_list_types(false), array($this->get('contributiontypeID')), false);
			$form->add_submit_not_bottom('cmd_paper_updateview', ct('S_BUTTON_UPDATEVIEW'));
			$form->add_spacer();
		} else {
			/*
			if ($this->_list_types(1)==array()) {  // No Types defined
				$form->add_hidden(array(array("form_contributiontypeID",0)));
			} else {
				$form->add_select(ct('S_PAPER_FORM_CONTRIBUTIONTYPE'), 'form_contributiontypeID', 1, $this->_list_types(1), array($this->get('contributiontypeID')), false);
			} */
			$form->add_label(ct('S_PAPER_FORM_CONTRIBUTIONTYPE'), '<span class="fontbold font10">'.$this->_get_contributiontype_title().'</span>');
		}

		$form->add_text("* ".ct('S_PAPER_FORM_TITLE'), 'form_title', $this->get('title'), 60, 255);
		if ($ctype['has_organisations']==='true') {
			#$form->add_text("* ".ct('S_PAPER_FORM_AUTHOR'), 'form_author', $this->get('author'), 60, 255, false, '<br>'.ct('S_PAPER_FORM_AUTHOR_HINT2'));
			$form->add_textarea("* ".ct('S_PAPER_FORM_AUTHOR'), 'form_author', $this->get('author'), 70, 3, '',ct('S_PAPER_FORM_AUTHOR_HINT2'));
			$form->add_textarea("* ".ct('S_PAPER_FORM_ORGANISATION'), 'form_organisation', $this->get('organisation'), 70, 3, ct('S_PAPER_FORM_ORGANISATION_HINT'), ct('S_PAPER_FORM_ORGANISATION_HINT2'));
		} else {
			$form->add_textarea("* ".ct('S_PAPER_FORM_AUTHOR'), 'form_author', $this->get('author'), 70, 3, '',ct('S_PAPER_FORM_AUTHOR_HINT2'));
			#$form->add_text("* ".ct('S_PAPER_FORM_AUTHOR'), 'form_author', $this->get('author'), 60, 255, false, '<br>'.ct('S_PAPER_FORM_AUTHOR_HINT'));
		}

		$form->add_text("* ".ct('S_PAPER_FORM_PRESENTINGAUTHOR'), 'form_presentingauthor', $this->get('presentingauthor'), 60, 255, false, '<br>'.ct('S_PAPER_FORM_PRESENTINGAUTHOR_HINT'));
		$form->add_text("* ".ct('S_PAPER_FORM_PRESENTINGAUTHOREMAIL'), 'form_presentingauthoremail', $this->get('presentingauthoremail'), 60, 255, false, '<br>'.ct('S_PAPER_FORM_PRESENTINGAUTHOREMAIL_HINT'));
		$form->add_text(ct('S_PAPER_FORM_EMAILS'), 'form_emails', ct_csv_implode($this->get_emails()), 60, 1024, false, '<br>'.ct('S_PAPER_FORM_EMAILHINT'));

		// Abstract formatting...
		if ($ctype['has_abstract']==='true') {
			$form->add_textarea("* ".ct('S_PAPER_FORM_ABSTRACT'), 'form_abstract', $this->get('abstract'), 75,15, ct('S_PAPER_FORM_ABSTRACT_HINT'),ct('S_PAPER_FORM_ABSTRACT_HINT2'),$ctype['abstract_maxlen']);
		} elseif ($ctype['has_abstract']==='plaintext') {
			$form->add_textarea("* ".ct('S_PAPER_FORM_ABSTRACT'), 'form_abstract', $this->get('abstract'), 75,15, ct('S_PAPER_FORM_ABSTRACT_HINT'),ct('S_FORM_PLAINTEXT_ONLY'),$ctype['abstract_maxlen']);
		} elseif ($ctype['has_abstract']==='html') {
			$abstractlength = "";
			if ($ctype['abstract_maxlen']<0) $abstractlength = ct('S_PAPER_FORM_ABSTRACT_MAXLEN',array((-$ctype['abstract_maxlen']).' '.ct('S_FORM_WORDS')));
			if ($ctype['abstract_maxlen']>0) $abstractlength = ct('S_PAPER_FORM_ABSTRACT_MAXLEN',array($ctype['abstract_maxlen'].' '.ct('S_FORM_CHARACTERS')));
			$form->add_textarea_wysiwyg("* ".ct('S_PAPER_FORM_ABSTRACT'), 'form_abstract', $this->get('abstract'), 75,15, ct('S_PAPER_FORM_ABSTRACT_HINT'),"<span class=fontbold>".$abstractlength."</span><br><span class=font8>".ct('S_FORM_WYSIWYG_HINT')."</span>");
		}

		// Does the user have to select topics?
		$topicboxes = array();	// Create array for topics...
		$topics=$this->_list_topics();
		$selectedtopics=$this->get_topicIDs();
		foreach ($topics as $t) {
			$topicboxes[]=array('form_topics[]',$t[0],$t[1],in_array($t[0],$selectedtopics),false);
		}
		if ($ctype['has_topics']!='false' && count($topics)>0) {
			if ($ctype['has_topics']=='1') {  // Only one!
				$form->add_select("* ".ct('S_PAPER_FORM_TOPIC'), 'form_topics[]', 1, $this->_list_topics(), $this->get_topicIDs(), false, '<br>'.ct('S_PAPER_FORM_TOPICSNEWHINT'));
			} elseif ($ctype['has_topics']=='true') {  // any number
				$form->add_check("* ".ct('S_PAPER_FORM_TOPICS'), array_merge($topicboxes,array(array('','',ct('S_PAPER_FORM_TOPICSNEWHINT')))));
				#$form->add_select("* ".ct('S_PAPER_FORM_TOPICS'), 'form_topics[]', 6, $this->_list_topics(), $this->get_topicIDs(), true, "<br>".ct('S_PAPER_FORM_TOPICSHINT'));
			} else { // A max number >1 was given
				$form->add_check("* ".ct('S_PAPER_FORM_TOPICS'), array_merge($topicboxes,array(array('','',ct('S_PAPER_FORM_TOPICSNEWHINT')),array('','','<b>'.ct('S_PAPER_FORM_TOPICS_MAX',array($ctype['has_topics'])).'</b>'))));
				#$form->add_select("* ".ct('S_PAPER_FORM_TOPICS'), 'form_topics[]', 6, $this->_list_topics(), $this->get_topicIDs(), true, "<br>".ct('S_PAPER_FORM_TOPICSHINT').'<br><b>'.ct('S_PAPER_FORM_TOPICS_MAX',array($ctype['has_topics'])).'</b>');
			}
		} elseif ($ctype['has_topics']!='false' && count($topics)==0) {
			$form->add_label("* ".ct('S_PAPER_FORM_TOPICS'), ct('S_PC2TOPICS_NOTOPICS'));
		}

		if ($ctype['has_keywords']==='true')
			$form->add_text("* ".ct('S_PAPER_FORM_KEYWORDS'), 'form_keywords', $this->get('keywords'), 60, 255, false, '<br>'.ct('S_PAPER_FORM_KEYWORDSHINT'));
		if ($ctype['has_extratext']!='false') {
			$required = ($ctype['has_extratext']=='required')?'* ':'';
			if ($ctype[ctlx($ctype,'extratext_title')]=="")
				$form->add_text($required.ct('S_PAPER_FORM_EXTRATEXT'), 'form_extratext', $this->get('extratext'), 60, 255, false, '<br>'.$ctype[ctlx($ctype,'extratext_info')]);
			else
				$form->add_text($required.$ctype[ctlx($ctype,'extratext_title')], 'form_extratext', $this->get('extratext'), 60, 255, false, '<br>'.$ctype[ctlx($ctype,'extratext_info')]);
		}
		if ($ctype['has_extraoption']!='false') {
			$required = ($ctype['has_extraoption']=='required')?'* ':'';
			$form->add_check($required.ct('S_PAPER_FORM_EXTRAOPTION'), array(array('form_extraoption','1',$ctype[ctlx($ctype,'extraoption_info')],$this->get_special('extraoption'))));
		}
		if ($ctype['has_studentcontribution']==='true')
			$form->add_check(ct('S_PAPER_FORM_STUDENTPAPER'), array(array('form_studentpaper','1',ct('S_PAPER_FORM_STUDENTPAPER_HINT'),$this->get_special('studentpaper'))));

		if ($ctype['has_bibliography']==='true')
			$form->add_textarea("* ".ct('S_PAPER_FORM_BIBLIOGRAPHY'), 'form_bibliography', $this->get('bibliography'), 70, 5, '', ct('S_PAPER_FORM_BIBLIOGRAPHY_HINT')); #.'<br>'.ct('S_FORM_PLAINTEXT_ONLY'));

		$form->add_spacer();
		$form->add_textarea(ct('S_PAPER_FORM_EXTERNALREMARK'), 'form_externalremark', $this->get('externalremark'), 70, 4);

		if ($http['page']=='newPaper')
			$form->add_submit('cmd_paper_save', ct('S_PAPER_INFOFORM_SUBMIT'));
		else
			$form->add_submit('cmd_paper_save', ct('S_BUTTON_SAVE'));
		$form->show();
	}

	/**
	 * Function to show step 2 of upload
	 */
	function show_form_step2() {
		ct_load_class('CTForm');
		global $session;

		$type = $this->_get_contributiontype();
		if (!is_array($type)) $type = array();

		// Show only if uploads are enabled...
		if ($type['upload']>0) {
			echo "<p class=\"font10\">".ct('S_NEWPAPER_INTRO_STEP2_1')."</p>\n";
		}

		echo "<table  width=\"95%\" align=\"center\" cellspacing=1 border=0 cellpadding=2>";
		echo "<tr><td valign=top align=left class=\"form_td_separator_gradient\">\n";
		echo "<span class=\"form_separator_label\">".ct('S_NEWPAPER_CHECKENTRIES')."</span>\n";
		echo "</td></tr>\n";
		echo "</table>\n";
		$this->show_detailed('95%');
		$this->show_abstract('95%');
		$this->show_bibliography('95%');
		if ($type['upload']>0 && ($this->get($this->get_ffname('originalname','',1))!="" ||
								  $this->get($this->get_ffname('originalname','',2))!="" ||
								  $this->get($this->get_ffname('originalname','',3))!="")) {
			$this->show_downloads('','95%');
		}

		$form = new CTForm(ct_pageurl('newPaper'), 'post');
		$form->width = "95%";
		$form->align = "center";
		if ($type['upload']>0) {
			$form->add_separator(ct('S_NEWPAPER_SKIPUPLOAD'));
			$form->add_submit("cmd_newpaper_back_to_step1", ct('S_NEWPAPER_BACK_TO_STEP1'));
			$form->add_submit("cmd_newpaper_skipupload", ct('S_NEWPAPER_SUBMIT_SKIPUPLOAD'));
		} else {
			$form->add_separator(ct('S_NEWPAPER_CONFIRM'));
			$form->add_submit("cmd_newpaper_back_to_step1", ct('S_NEWPAPER_BACK_TO_STEP1'));
			$form->add_submit("cmd_newpaper_skipupload", ct('S_NEWPAPER_SUBMIT'));
		}
		$form->show();

		if ($type['upload']>0) {
			echo "<p class=\"font10\">".ct('S_NEWPAPER_INTRO_STEP2_2')."</p>\n";
			$this->show_uploadform(ct_pageurl('newPaper'));
		}
	}


	// Show paper upload form
	//
	function show_uploadform($action, $errors=array()) {
		ct_load_class('CTForm');
		ct_load_lib("papers.lib");
		ct_load_lib('datetime.lib');

		$type = $this->_get_contributiontype();
		if (!is_array($type)) $type = array();

		$this->form = new CTForm($action, 'post', array());
		$this->form->waitmessage=true;// show waitmessage!
		$this->form->width='95%';
		$this->form->align='center';

		$this->form->add_hidden(array(array("form_id",$this->get('ID'))));

		// Start upload section
		$this->form->add_separator(ct('S_PAPER_FORM_UPLOADSECTION'));

		$upload_deadline=ct_get_upload_deadline($type);
		if (ct_get_submission_deadline($type)>$upload_deadline) $upload_deadline=ct_get_submission_deadline($type);
		$this->form->add_label(ct('S_PAPER_UPLOAD_DEADLINE'),ct_datetime_format_timezone($upload_deadline));
		if ($upload_deadline>ct_time())
			$this->form->add_label(ct('S_PHASES_TIMELEFT'),ct_format_timeleft(ct_time(),$upload_deadline));
		$this->form->add_spacer();

		$this->_show_upload_selections("");

		$this->form->show();
	}

	/**
	* Show form for final uploads
	*/
	function show_finaluploadform($action, $errors=array()) {
		ct_load_class('CTForm');
		ct_load_lib("papers.lib");
		ct_load_lib('datetime.lib');
		global $session;

		$user =& $session->get_user();

		$type = $this->_get_contributiontype();
		if (!is_array($type)) $type = array();

		$this->form = new CTForm($action, 'post', $errors);
		$this->form->waitmessage=true;// show waitmessage!
		$this->form->width='90%';
		$this->form->align='center';

		$this->form->add_hidden(array(array("form_id",$this->get('ID'))));

		$this->form->add_separator(ct('S_PAPER_FORM_INFOSECTION'));
		$this->form->add_label(ct('S_PAPER_FORM_CONTRIBUTIONTYPE'),$type[ctlx($type,'title')]);
		$this->form->add_label(ct('S_PAPER_FORM_TITLE'), $this->get_special('title'));
		$this->form->add_label(ct('S_PAPER_FORM_AUTHOR'), $this->get_special('author'));

		$this->form->add_text('* '.ct('S_PAPER_FORM_PRESENTINGAUTHOR'), 'form_presentingauthor', $this->get('presentingauthor'), 60, 255, false, '<br>'.ct('S_PAPER_FORM_PRESENTINGAUTHOR_HINT'));
		$this->form->add_text('* '.ct('S_PAPER_FORM_PRESENTINGAUTHOREMAIL'), 'form_presentingauthoremail', $this->get('presentingauthoremail'), 60, 255, false, '<br>'.ct('S_PAPER_FORM_PRESENTINGAUTHOREMAIL_HINT'));
		$this->form->add_textarea(ct('S_PAPER_FORM_PRESENTINGAUTHORCV'), 'form_presentingauthorCV', $this->get('presentingauthorCV'), 60, 4, '', ct('S_PAPER_FORM_PRESENTINGAUTHORCV_HINT'));
		$this->form->add_textarea(ct('S_PAPER_FORM_EXTERNALREMARK'), 'form_externalremark', $this->get('externalremark'), 60, 4);
		if ($user->is_admin() || $user->is_chair() || $user->is_conferenceChair()) {
			$this->form->add_text(ct('S_PAPER_FORM_PAGECOUNT'), 'form_pagecount', $this->get('pagecount'), 6, 11, false);
			$this->form->add_text(ct('S_PAPER_FORM_LANGUAGE'), 'form_language', $this->get('language'), 16, 32, false);
			$this->form->add_check(ct('S_PAPER_FORM_FORMAT_OK'),array(array('form_format','true',ct('S_PAPER_FORM_FORMAT_OK_HINT'),($this->get('format')=="true"))));
		} else {
			$this->form->add_hidden(array(array('form_format',$this->get('format'),array('form_language',$this->get('language')),array('form_pagecount',$this->get('pagecount')))));
		}
		if (stristr($action,"uploadFinalPaper")) {
			$this->form->add_submit("cmd_finalupload_skipupload", ct('S_PAPER_FINALUPLOAD_SUBMIT_SKIPUPLOAD'));
			$this->form->add_submit_not_bottom("cmd_finalupload_skipupload", ct('S_PAPER_FINALUPLOAD_SUBMIT_SKIPUPLOAD'));
			// Start upload section
			$this->form->add_separator(ct('S_PAPER_FORM_UPLOADSECTION'));

			// Get deadline for final uploads: 1. Final Upload deadline from contributiontype
			$deadline=$this->get_finalupload_deadline();
			$this->form->add_label(ct('S_PAPER_FINALUPLOAD_DEADLINE'),ct_datetime_format_timezone($deadline));

			$this->_show_upload_selections("final"); // & = call by reference
		} else {
			$this->form->add_submit("cmd_save", ct('S_BUTTON_SAVE'));
		}
		$this->form->show();

	}

	/**
	 * Show the up to three upload fields and infos for uploads and final uploads
	 */
	function _show_upload_selections($version="") {
		ct_load_lib('datetime.lib');

		// $this->form->add_label('',ct('S_PAPER_UPLOAD_DETAILS')); // Old, from ConfTool Standard!
		$type = $this->_get_contributiontype();
		$uploads = 0;

		if ($version=="final") {
			$uploadtype='_final';
			$uploads = $this->_number_of_final_uploads_for_contributiontype();
		} else {
			$uploadtype='';
			$uploads = $this->_number_of_uploads_for_contributiontype();
		}

		$this->form->add_label(ct('S_PAPER_FORM_CONTRIBUTIONTYPE'),$type[ctlx($type,'title')]);
		if ($type['info']!="")
			$this->form->add_label(ct('S_PAPER_CONTRIBUTIONTYPE_INFO'),$type[ctlx($type,'info')]);
		$this->form->add_label('','<strong>'.ct('S_PAPER_UPLOAD_MAX').'</strong>');
		if ($uploads >= 2)
			$this->form->add_label('',ct('S_PAPER_UPLOAD_MAX_MULTIPLE'));

		// First upload-box
		$this->form->add_subseparator(ct('S_PAPER_UPLOAD_A'));
		if (!empty($type[ctlx($type,'upload'.$uploadtype.'_info_A')]))
			$this->form->add_label(ct('S_PAPER_UPLOAD_INFO'),$type[ctlx($type,'upload'.$uploadtype.'_info_A')]);
		$this->form->add_label(ct('S_PAPER_UPLOAD_FILETYPES'),ct('S_PAPER_UPLOAD_FILETYPES_INFO',array(implode(", ",$this->_get_legal_file_types("")))));

		$this->form->add_upload(ct('S_PAPER_FORM_FILE'), 'form_filename'.$uploadtype, '50', ctconf_get('paperupload/maxsize'));
		if ($this->get('filename'.$uploadtype) != "") {
			$this->form->add_label(ct('S_PAPER_FORM_LASTUPLOAD'),
			"<span class=\"fontbold font9\">".$this->get_special('originalname'.$uploadtype)."</span>".
			"<br>".ct_datetime_format_timezone($this->get('lastupload'.$uploadtype)));
		}else {
			$this->form->add_label('','<span class="fontnegative fontbold font10">'.ct('S_INDEX_PAPER_NOUPLOAD').'</span>');
		}
		// second upload-box
		if ($uploads >= 2) {
			$this->form->add_subseparator(ct('S_PAPER_UPLOAD_B'));
			if (!empty($type[ctlx($type,'upload'.$uploadtype.'_info_B')]))
				$this->form->add_label(ct('S_PAPER_UPLOAD_INFO'),$type[ctlx($type,'upload'.$uploadtype.'_info_B')]);
			$this->form->add_label(ct('S_PAPER_UPLOAD_FILETYPES'),ct('S_PAPER_UPLOAD_FILETYPES_INFO',array(implode(", ",$this->_get_legal_file_types("2")))));
			$this->form->add_upload(ct('S_PAPER_FORM_FILE_2'), 'form_filename'.$uploadtype.'_2', '50', ctconf_get('paperupload/maxsize'));
			if ($this->get('filename'.$uploadtype.'_2') != "") {
				$this->form->add_label(ct('S_PAPER_FORM_LASTUPLOAD'),
				"<span class=\"fontbold font9\">".$this->get_special('originalname'.$uploadtype.'_2')."</span>".
				"<br>".ct_datetime_format_timezone($this->get('lastupload'.$uploadtype.'_2')));
			} else {
				$this->form->add_label('','<span class="fontnegative fontbold font10">'.ct('S_INDEX_PAPER_NOUPLOAD').'</span>');
			}
		}
		// third upload-box
		if ($uploads >= 3) {
			$this->form->add_subseparator(ct('S_PAPER_UPLOAD_C'));
			if (!empty($type[ctlx($type,'upload'.$uploadtype.'_info_C')]))
				$this->form->add_label(ct('S_PAPER_UPLOAD_INFO'),$type[ctlx($type,'upload'.$uploadtype.'_info_C')]);
			$this->form->add_label(ct('S_PAPER_UPLOAD_FILETYPES'),ct('S_PAPER_UPLOAD_FILETYPES_INFO',array(implode(", ",$this->_get_legal_file_types("3")))));
			$this->form->add_upload(ct('S_PAPER_FORM_FILE_3'), 'form_filename'.$uploadtype.'_3', '50', ctconf_get('paperupload/maxsize'));
			if ($this->get('filename'.$uploadtype.'_3') != "") {
				$this->form->add_label(ct('S_PAPER_FORM_LASTUPLOAD'),
				"<span class=\"fontbold font9\">".$this->get_special('originalname'.$uploadtype.'_3')."</span>".
				"<br>".ct_datetime_format_timezone($this->get('lastupload'.$uploadtype.'_3')));
			} else {
				$this->form->add_label('','<span class="fontnegative fontbold font10">'.ct('S_INDEX_PAPER_NOUPLOAD').'</span>');
			}
		}
		if ($uploadtype=="final") {
			$this->form->add_submit('cmd_paper_upload', ct('S_PAPER_FINALUPLOAD_SUBMIT_UPLOAD'));
		} else {
			$this->form->add_submit('cmd_paper_upload', ct('S_PAPER_UPLOADFORM_SUBMIT'));
		}
		// $this->form->add_reset(ct('S_BUTTON_RESET'));
	}


	// Process the paper submission forms...
	// ----------------------------------------------------------------

	// Process data submission
	function process_form_step1() {
		ct_load_lib('mail.lib');
		global $http, $session;

		$ctype = $this->_get_contributiontype();

		$this->errors = array();
		$okay = true;

		// Reset withdrawn status...
		$this->set('withdrawn', 0);

		// set and checked in newpaper
		// $okay &= $this->_require('contributiontypeID', 'form_contributiontypeID');

		ct_http_trim(array('title','author'));

		$okay &= $this->_require('title', 'form_title');
		$okay &= $this->_require('author', 'form_author');

		if ($ctype['has_organisations']==='true')
			$okay &= $this->_require('organisation', 'form_organisation');

		if ($ctype['has_abstract']!='false') {
			$okay &= $this->_require('abstract', 'form_abstract');
			// Length is tested in _check_format
		}
		if ($ctype['has_keywords']==='true')
			$okay &= $this->_require('keywords', 'form_keywords');
			#$this->set('keywords', $http['form_keywords']);

		if ($ctype['has_extratext']=='required')
			$okay &= $this->_require('extratext', 'form_extratext');
		elseif ($ctype['has_extratext']=='true')
			$this->set('extratext', $http['form_extratext']);

		if ($ctype['has_extraoption']=='required')
			$okay &= $this->_require('extraoption', 'form_extraoption');
		elseif ($ctype['has_extraoption']=='true')
			$this->set('extraoption', $http['form_extraoption']);

		if ($ctype['has_studentcontribution']==='true')
			$this->set('studentpaper', $http['form_studentpaper']);  // non-obligatory

		$okay &= $this->_require('presentingauthor', 'form_presentingauthor');

		$authors = array_map('trim', split("\n",$this->get('author')));	// Take care if using ";" as it is also used for closing entities!!
		$found = false;
		if ($this->get('presentingauthor')!="") {
			while (list(,$v) = each($authors)) {
				if (!(strpos($v,$this->get('presentingauthor'))===false)) $found=true;
			}
			if (!$found) {
				ct_warningbox(ct('S_ERROR_SAVE'),ct('S_ERROR_NEWPAPER_INVALID_PRESENTINGAUTHOR'));
				$this->errors[] = 'form_presentingauthor';
				$okay=false;
			}
		}

		// Check Email of presenting author.
		$okay &= $this->_require('presentingauthoremail', 'form_presentingauthoremail');

		$presentingauthoremail = $this->get('presentingauthoremail');
		if (!ct_validate_email($presentingauthoremail)) {
			ct_warningbox(ct('S_ERROR_SAVE'),ct('S_ERROR_NEWPAPER_INVALID_EMAIL'));
			$this->errors[] = 'form_presentingauthoremail';
			$okay=false;
		}


		// Are topics to be selected?
		if ($ctype['has_topics']!='false') {
			if (isset($http['form_topics']) && is_array($http['form_topics']) && (sizeof($http['form_topics']) > 0)) {
				$this->pdata['topics'] = $http['form_topics'];
				// was a maximum number given?
				if ($ctype['has_topics']!='true') {
					$maxnum = $ctype['has_topics']+0;
					// Check if too many were selected.
					if (sizeof($http['form_topics'])>$maxnum) {
						$okay = false;
						$this->errors[] = 'form_topics[]';
					}
				}
			} else {
				// If no topics are available don't show an error...
			    if (sizeof($this->_list_topics())) {
					$okay = false;
					$this->errors[] = 'form_topics[]';
				}
			}
		}

		if (isset($http['form_emails']) && ($http['form_emails'] != "")) {
			$emails = ct_multi_explode(array(' ',',',';'),$http['form_emails']);
			$this->pdata['emails'] = $emails;
			foreach ($emails as $email) {
				if (!ct_validate_email($email))	{
					$this->errors[]	= 'form_emails'; $okay=false;
				}
			}
		} else {
		    $this->pdata['emails'] = array();
		}

		if ($ctype['has_bibliography']==='true')
			$okay &= $this->_require('bibliography', 'form_bibliography');

		$this->set('externalremark', $http['form_externalremark']);

		$okay &= $this->_check_format();

		if ($okay) {
			return false;
		} else {
			return $this->errors;
		}
	}

	//------------------------------------------------------------------

	/**
	* Process fields of final upload form
	*/
	function process_form_finals() {
		global $http, $session;

		$ctype = $this->_get_contributiontype();

		$this->errors = array();
		$okay = true;

		// Reset withdrawn status...
		$this->set('withdrawn', 0);

		// Check presenting author
		$okay &= $this->_require('presentingauthor', 'form_presentingauthor');

		$authors = array_map('trim', split("\n",$this->get('author')));	// Take care if using ";" as it is also used for closing entities!!
		$found = false;
		if ($this->get('presentingauthor')!="") {
			while (list(,$v) = each($authors)) {
				if (!(strpos($v,$this->get('presentingauthor'))===false)) $found=true;
			}
			if (!$found) {
				ct_warningbox(ct('S_ERROR_SAVE'),ct('S_ERROR_NEWPAPER_INVALID_PRESENTINGAUTHOR'));
				$this->errors[] = 'form_presentingauthor';
				$okay=false;
			}
		}

		// Check Email of presenting author.
		$okay &= $this->_require('presentingauthoremail', 'form_presentingauthoremail');

		ct_load_lib('mail.lib');
		$presentingauthoremail = $this->get('presentingauthoremail');
		if (!ct_validate_email($presentingauthoremail)) {
			ct_warningbox(ct('S_ERROR_SAVE'),ct('S_ERROR_NEWPAPER_INVALID_EMAIL'));
			$this->errors[] = 'form_presentingauthoremail';
			$okay=false;
		}
		#$this->set('presentingauthoremail',$presentingauthoremail);

		$this->set('presentingauthorCV', $http['form_presentingauthorCV']);  // non-obligatory
		$this->set('pagecount', $http['form_pagecount']);  // non-obligatory
		$this->set('language', $http['form_language']);  // non-obligatory
		$this->set('externalremark', $http['form_externalremark']);  // non-obligatory
		$this->set('format', $http['form_format']);  // non-obligatory

		if ($okay) {
			return false;
		} else {
			return $this->errors;
		}
	}
}

?>