<?php
//
// CLASS:       CTParticipationData
// 				This is the core class of the participation classes.
//				It is used to load and persist participants and is always loaded as it may be kept persistent.
//

class CTParticipationData {

	// holds corresponding row from participants-database
	var $pdata = array();

	//  $eventdata_number['eventID']=eventnumber
	var $eventdata_number = array();
	var $eventdata_start = array();
	var $eventdata_end = array();
	var $eventdata_text = array();

	//  holds the fee information for this participant
	var $fee = array();

	//  holds the person information...
	var $person;
	// to create the registration form...
	var $form;

	// Constructor
	function CTParticipationData() {
		$this->_init();
	}

	function _init() {
		// delete old data
		$this->pdata = array();
		$this->eventdata_number = array();
		$this->eventdata_start = array();
		$this->eventdata_end = array();
		$this->eventdata_text = array();
		$this->fee = array();
		$this->person = null;
		$this->form = null;
	}


	//## DATABASE FUNCTIONS ##############################################

	/**
	 * load participation data from database by id
	 */
	function load_by_id($personID) {
		global $db;
		$personID = (int)$personID; // sanitize.

		$this->_init();

		$r = $db->query("select * from participants where personID='".$personID."'");
		if ($db->num_rows($r) == 1) {
			$this->pdata = $db->fetch($r);
		} else {
			// Not yet registered!
			$this->pdata['personID']=$personID;
			$this->_load_persondata();
			return false;
		}
		// Participant loaded successfully. Now also load person and event data.
		if ($this->_load_persondata() && $this->_load_eventdata())
			return true;
		else
			return false;
	}

	/**
	 * Reload participation data from database
	 */
	function reload() {
		if ($this->get('personID')>0)
			return $this->load_by_id($this->pdata['personID']);
		else
			return false;
	}

	function _load_persondata() {
		global $db;
		// create person
		$this->person = new CTPerson;
		if ($this->person->load_by_id($this->pdata['personID'])) { // Does person exist!?
			return true;
		}
		return false;
	}

	function _load_eventdata() {
		global $db;
		// get events and store them in $this->eventdata_number etc.
		$query = 'select e.ID AS ID, ';
		$query .=  ' p2e.number AS number, p2e.start as start, p2e.end as end, p2e.text as text ';
		$query .=  ' from participants2events AS p2e, events AS e';
		$query .=  ' where p2e.eventID=e.ID AND ';
		$query .=  ' p2e.personID="'.$this->pdata['personID'].'"';
		$query .=  ' order by e.title asc';
		$r = $db->query($query);
		if ($r && ($db->num_rows($r) > 0)) {
			for ($i=0; $i < $db->num_rows($r); $i++) {
				$p2e = $db->fetch($r);
				$this->eventdata_number[$p2e['ID']] = $p2e['number'];
				$this->eventdata_start[$p2e['ID']] = ct_datetime_2_timestamp($p2e['start']);
				$this->eventdata_end[$p2e['ID']] = ct_datetime_2_timestamp($p2e['end']);
				$this->eventdata_text[$p2e['ID']] = $p2e['text'];
			}
		}
		return true;
	}

	/**
	 * save participant object
	 */
	function persist($personID=0) {
		global $db;

		//# calculate total fee
		$this->_calculate_fee();

		//## if participant does not yet exist in DB, set values
		if ($this->pdata['personID'] == "" && $personID!=0) {
			$this->pdata['personID'] = $personID;
			$this->pdata['regdate'] = ct_timestamp_2_datetime(ct_time());
			$this->pdata['deleted'] = '0';
		}
		if ($this->pdata['personID']==0) // to avoid errors!
			return false;   // do NOT save if no id is set.

		// Update paid amount
		$this->_calculate_total_paid();

		// Create new invoice number if not yet created and total is not '0'
		if ($this->pdata['invoiceNo']=="" && $this->pdata['deleted']=='0' && $this->pdata['total']!=0)
			$this->pdata['invoiceNo']=ctconf_get('invoicePrefix').str_pad(ctconf_increment('invoiceNo'), ctconf_get('invoiceDigits'), "0", STR_PAD_LEFT);

		// Set default data for some enum fields.
		if (!isset($this->pdata['invoice']) || $this->pdata['invoice']=='') $this->pdata['invoice'] = 'false';
		if (!isset($this->pdata['billingaddress']) || $this->pdata['billingaddress']=='') $this->pdata['billingaddress'] = 'false';

		// Now SAVE #################################
		$db->replace_into('participants', $this->pdata);

		//# save participant to events
		$this->_save_events();


		//# change person data and set his participant status.
		$this->person = new CTPerson();
		$this->person->load_by_id($this->pdata['personID']);  // reload for consistency reasons.
		if ($this->pdata['deleted'] == "0") {
			$this->person->add_status('participant');
		} else {
			$this->person->remove_status('participant');
		}
		$this->person->persist();
	}

	/**
	 * delete participant.
	 */
	function delete() {
		global $db;

		// first set deleted = true
		$this->set('deleted','1');
		$this->persist();

		// unlink (do not delete) the events for this registration - done already above in persist!
		// $q2=$db->query("update participants2events set deleted='1' where personID='".$this->pdata['personID']."'");

		// delete the identity(es)
		ct_load_class('CTIdentity');
		$identity=new CTIdentity();
		if ($identity->load_by_personID($this->pdata['personID'])) {$identity->delete(); $identity->persist(); }

		return true;
	}

	/**
	 * save events of participant
	 */
	function _save_events() {
		global $db;
		// delete all old events of this participant
		$db->delete('participants2events',"personID='".$this->pdata['personID']."'");

		// now persist currently selected events
		ct_load_lib('participation.lib');
		$events=ct_list_events();
		foreach ($events as $e){
			$db->insert_into('participants2events',array('personID'=>$this->pdata['personID'],
																		'eventID'=>$e[0],
																		'number'=>$this->eventdata_number[$e[0]],
																		'start'=>ct_timestamp_2_datetime($this->eventdata_start[$e[0]]),
																		'end'=>ct_timestamp_2_datetime($this->eventdata_end[$e[0]]),
																		'text'=>$this->eventdata_text[$e[0]],
																		'deleted'=>$this->pdata['deleted']));
		}
	}

	//## Basic ACCESSOR FUNCTIONS ###############################################

	// get a record field`s value, with html special chars converted
	function get_special($key) {
		return ct_form_encode($this->get($key));
	}

	/**
	* get value
	* if value is found in http: return this value, otherwise
	*/
	function get($key){
		return isset($this->pdata[$key]) ? $this->pdata[$key] : '';
	}

	// set a record field`s value
	function set($key, $value) {
		$this->pdata[$key] = $value;
	}

	/**
	 * How much has the participant already paid?
	 *
	 */
	function _calculate_total_paid() {
		//# Update payment data
		ct_load_lib('payment.lib');
		$paytotal = 0;
		$paydate = '0000-00-00 00:00:00';

		$personID=$this->get('personID');
		$payments = ct_list_payments($personID);
		foreach ($payments as $pay) {
			$paydate  =  $pay[2];
			$paytotal += $pay[3];
		}
		$this->pdata['payamount'] = $paytotal;
		$this->pdata['paydate'] = $paydate;
	}

	// Calculation of fees asf.
	// ################################################

	/**
	 * calculates and returns the total fee.
	 */
	function _calculate_fee(){
		ct_load_lib('participation.lib');
		ct_load_lib('datetime.lib');
		global $db;

		$this->fee=array();
		$this->fee['total']=0.00;
		$this->fee['net_total']=0.00;
		$this->fee['vat_total']=0.00;

		ct_load_lib('participation.lib');
		$timediscountID=get_timediscountID($this->get('regdate'));
		$etypes = ct_get_eventtypes();

		foreach ($etypes as $etype){
			$events = ct_get_events($etype['ID']);
			if (count($events)>0){
				foreach ($events as $e){
					if (isset($this->eventdata_number[$e['ID']]) && $this->eventdata_number[$e['ID']]!=0){
						$singlefee=$this->_calculate_singlefee($e['pricecategory'],$this->pdata['status'],$timediscountID);
						if ($etype['negative']!='normal' && $singlefee<0) $singlefee=-$singlefee; // negative is used to disable/hide events.

						// consider days...
						$stay_factor = 1;
						if ($e['datemode']=="perdiem")  $stay_factor = ct_count_days($this->eventdata_start[$e['ID']],$this->eventdata_end[$e['ID']]);
						if ($e['datemode']=="pernight") $stay_factor = ct_count_nights($this->eventdata_start[$e['ID']],$this->eventdata_end[$e['ID']]);

						// calculate total
						$eventTotal=$this->eventdata_number[$e['ID']]*$singlefee*$stay_factor;

						// VAT
						$vat=$this->_get_vat($e['vat']);
						// store
						if (ctconf_get('conferenceNetPrices')==1) {
							$eventVat=$eventTotal*($vat/100);
							$this->fee['net_total']+=$eventTotal;
							$this->fee['vat_total']+=$eventVat;
							$this->fee['total']+=$eventTotal+$eventVat;
						} else {
							$eventVat=$eventTotal-($eventTotal/(($vat/100)+1));
							$this->fee['net_total']+=($eventTotal-$eventVat);
							$this->fee['vat_total']+=$eventVat;
							$this->fee['total']+=$eventTotal;
						}
					}
				}
			}
		}
		$this->pdata['total']=$this->fee['total'];
	}


	/**
	 * calculates and returns the fee for an event/product.
	 */
	function _calculate_singlefee($pricecategory,$status,$timediscountID){
		ct_load_lib('participation.lib');
		global $db;
		if ($this->get('paymethod')=="free") return 0;
		ct_load_lib('participation.lib');
		$fee = ct_get_singlefee($pricecategory,$status,$timediscountID);
		if ($this->get('discount')!=0)
			$fee = $fee * (1- ($this->get('discount') / 100));
		return $fee;
	}

	/**
	 * returns the vat percentage of a vatID.
	 */
	function _get_vat($vatID){
		global $db;
		$r = $db->query("select percentage from vats where ID='$vatID'");
		if ($r && ($db->num_rows($r)) == 1){
			$v = $db->fetch($r);
			return  $v['percentage'];
		}
	}


}



?>