<?php
//
// CLASS:		CTPayment
//

class CTPayment {
	
	 // holds corresponding entry from payments table
	var $pdata = array();
	
	// holds the person information...
	var $person;
	
	// holds the participation information...
	var $participation;
	
	//## DATABASE FUNCTIONS ##############################################
	
	/**
	 * clear data to create new payment object
	 */
	function init() {
		// delete old data
		$this->pdata = array();
		
		ct_load_class('CTParticipation');
		$this->participation      = new CTParticipation;
	}
	
	/**
	 * load payment data from database by id of the payment
	 */
	function load_by_id($paymentID) {
		global $db;
		$paymentID = (int)$paymentID; // sanitize.
		
		// delete old data
		$this->init();
		
		// read data from DB
		$r = $db->query("select * from participants2payments where paymentID='".$paymentID."'");
		if ($db->num_rows($r) == 1) {
			$this->pdata = $db->fetch($r);
		} else {
			$this->pdata['paymentID']=$paymentID;
			return false;
		}
		
		if ($this->participation->load_by_id($this->pdata['personID'])) {
			return true;
		} else {
			return false;
		}
	}
	
	/**
	 * Reload payment data from database, discard old object
	 */
	function reload() {
		return $this->load_by_id($this->pdata['personID']);
	}
	
	/**
	 * Save payment object
	 */
	function persist() {
		global $db;

		// to avoid errors, don't save if no personID is set.
		if ($this->pdata['personID']==0) return false;	
		
		$db->replace_into('participants2payments', $this->pdata);
		// Update payment data of participant in database
		$this->update_participation_data($this->pdata['personID']);
	}
	
	
	/**
	 * Delete this payment
	 *
	 * @return did it succeed?
	 */
	function delete() {
		global $db;
	
		if ($this->get_id()==0) return false;

		$db->query('delete from participants2payments where paymentID='.$this->get_id());
		$this->update_participation_data($this->get('personID'));
		$this->init();

		return true;
	}
	
	
	/**
	 * update payment and paydate in participation table...
	 */
	function update_participation_data($personID) {
		ct_load_lib('payment.lib');
		$paytotal = 0;
		$paydate = '0000-00-00 00:00:00';
		
		$payments = ct_list_payments($personID);
		foreach ($payments as $pay) {
			$paydate  =  $pay[2];
			$paytotal += $pay[3];
		}
		ct_load_class('CTParticipation');
		$this->participation = new CTParticipation;
		$this->participation->load_by_id($this->pdata['personID']);
		$this->participation->pdata['payamount'] = $paytotal;
		$this->participation->pdata['paydate'] = $paydate;
		$this->participation->persist($this->pdata['personID']);
	}
	
	
	
	//## ACCESSOR FUNCTIONS ###############################################
	
	/**
	 * get a record field`s value, with html special chars converted
	 */
	function get_special($key) {
		return ct_form_encode($this->get($key));
	}
	
	function get($key){
		return isset($this->pdata[$key]) ? $this->pdata[$key] : '';
	}
	
	function get_id(){
		return $this->get('paymentID');
	}
	
	/**
	 * set a record field`s value
	 */
	function set($key, $value) {
		$this->pdata[$key] = $value;
	}
	
	
	
	//## FORM PROCESSING AND GENERATION #######################################
	
	/**
	 * Check if user entered the required data...
	 */
	function _require($field, $name) {
		global $http;
		if (isset($http[$name]) && ($http[$name] != "")) {
			$this->set($field, $http[$name]);
			return true;
		} else {
			if (isset($http[$name])) {
				$this->set($field, '');
			}
			$this->errors[] = $name;
			return false;
		}
	}
	
	
	/**
	 * shows part one of the participant payment form.
	 */
	function show_form_payment1($action, $errors=array()) {
		ct_load_class('CTForm');
		ct_load_lib('payment.lib');
		global $db,$session,$http;
		$payments = ct_list_payments($http['form_personID']);
		
		if (sizeof($payments)>0){
			$form = new CTform($action, 'post');
			$form->width='90%';
			$form->align='center';
			$form->add_hidden(array(array('form_personID',$http['form_personID'])));
			$form->add_select(ct('S_MANAGE_PAYMENTS_CMD'), 'form_paymentID', 6, $payments, array($http['form_paymentID']), false);
			// Payments should NOT be edited! Enter a new payment or an entry for a cancelled payment...
			### $form->add_submit('cmd_payments_edit', ct('S_MANAGE_PAYMENTS_EDITCMD'));
			if (ctconf_get('participationPaymentMail')) {
				$form->add_submit_not_bottom('cmd_payments_delete_mail', ct('S_MANAGE_PAYMENTS_DELETE_MAILCMD'));
				$form->add_submit('cmd_payments_delete', ct('S_MANAGE_PAYMENTS_DELETECMD'));
			} else {
				$form->add_submit('cmd_payments_delete', ct('S_MANAGE_PAYMENTS_DELETECMD'));
			}
			$form->show();
		} else {
			echo "<p>".ct('S_PARTICIPATE_NOT_PAID')."</p>";
		}
	}
	
	
	/**
	 * shows part two of participant payment form.
	 */
	function show_form_payment2($action, $personID="", $errors=array()) {
		ct_load_class('CTForm');
		ct_load_lib('participation.lib');
		ct_load_lib('payment.lib');
		global $db,$session,$http,$ctconf;

		if ($personID!="") {
			// new payment: Load participant data...
			ct_load_class('CTParticipation');
			$this->participation = new CTParticipation();
			$this->participation->load_by_id($personID);
		}
		$form = new CTform($action, 'post');
		$form->width='90%';
		$form->align='center';
		$form->add_label(ct('S_PARTICIPATION_PAYMENT_TOTAL_BILL'),'<b>'.ct_currency_format($this->participation->pdata['total']).'</b>');
		if ($this->participation->pdata['payamount']==0)
			$form->add_label(ct('S_PARTICIPATION_PAYMENT_ALREADYPAID'),'<span class="fontbold font10">'.ct_currency_format($this->participation->pdata['payamount']).'</span>');
		elseif ($this->participation->pdata['total']==$this->participation->pdata['payamount'])
			$form->add_label(ct('S_PARTICIPATION_PAYMENT_ALREADYPAID'),'<span class="fontpositive fontbold font10">'.ct_currency_format($this->participation->pdata['payamount']).'</span>');
		else
			$form->add_label(ct('S_PARTICIPATION_PAYMENT_ALREADYPAID'),'<span class="fontnegative fontbold font10">'.ct_currency_format($this->participation->pdata['payamount']).'</span>');
		$form->add_hidden(array(array('form_personID',$http['form_personID'])));
		$form->add_hidden(array(array('form_paymentID',$http['form_paymentID'])));
		$form->add_hidden(array(array('form_paydate','1')));
		
		if (!isset($this->pdata['paydate']) || $this->pdata['paydate']=='0000-00-00 00:00:00'){
			$paydate_day=date("d",ct_time());
			$paydate_month=date("m",ct_time());
			$paydate_year=date("Y",ct_time());
			$this->pdata['payamount']=round($this->participation->pdata['total']-$this->participation->pdata['payamount'],2);
			$this->pdata['note']=ct_get_payment_description($this->participation->pdata['paymethod']);
		} else {
			$paydate_day=substr($this->pdata['paydate'],8,2);
			$paydate_month=substr($this->pdata['paydate'],5,2);
			$paydate_year=substr($this->pdata['paydate'],0,4);
		}
		if ($this->get_id()>0) {
			$form->add_submit('cmd_payments_save', ct('S_MANAGE_PAYMENTS_SAVECMD'));
			$form->add_submit('cmd_payments_cancel', ct('S_MANAGE_PAYMENTS_CANCELCMD'));
		} else {
			$form->add_submit('cmd_payments_create', ct('S_MANAGE_PAYMENTS_CREATECMD'));
		}

		$form->add_date(ct('S_PARTICIPATE_PAYDATE'),'form_paydate','true',array($paydate_year,$paydate_month,$paydate_day));
		$form->add_text(ct('S_MANAGE_PAYMENTS_AMOUNT'),'form_payamount',ct_number_format($this->pdata['payamount']), 15, 15 );
		$form->add_text(ct('S_MANAGE_PAYMENTS_NOTE'),'form_note',$this->get('note'), 60, 512,'','<br>'.ct('S_MANAGE_PAYMENTS_NOTE_INFO'));
		// Credit card payment: show option to delete CC-Data...
		if ($this->participation->get('paymethod')=="cc") {
			$form->add_check(ct('S_MANAGE_PAYMENTS_DELETE_CCNUMBER'), array(
			array( 'form_delete_ccnumber', 'yes', ct('S_MANAGE_PAYMENTS_DELETE_CCNUMBER_YES'), false, '')
			) );
		}
		if (ctconf_get('participationPaymentMail')) {
			$form->add_check(ct('S_MANAGE_PAYMENTS_SENDMAIL'), array(array( 'form_sendmail', 'yes', ct('S_MANAGE_PAYMENTS_SENDMAIL_HINT'), true, '') ) );
		}
		$form->show();
	}
	
	/**
	 * process payment data form (output from payment2 form)
	 */
	function process_form_payment() {
		global $http;
		$okay = true;
		if (isset($http['form_paymentID']) && $http['form_paymentID'] != '') {
			$this->pdata['paymentID'] = $http['form_paymentID'];
		}
		if ($http['form_paydate_day']!='1' || $http['form_paydate_month']!='1' || $http['form_paydate_year']!='2005') {
			$this->pdata['paydate']=date("Y-m-d H:i:s",mktime(0,0,0,$http['form_paydate_month'],$http['form_paydate_day'],$http['form_paydate_year']));
		} else {
			$okay = false;
		}
		$this->pdata['note'] = $http['form_note'];
		$this->pdata['personID'] = $http['form_personID'];
		if (isset($http['form_payamount']) && $http['form_payamount'] != '' && ct_number_unformat($http['form_payamount']) != 0) {
			$this->pdata['payamount'] = ct_number_unformat($http['form_payamount']);
		} else {
			$okay = false;
		}
		if ($okay) {
			return $this->pdata;
		}
		return false;
	}
	
	
	//## DISPLAY FUNCTIONS ########################################################
	
	
	/**
	 * shows a row of payment data in the overview list.
	 */
	function show_row($class,$i,$page="") {
		ct_load_lib('participation.lib');
		ct_load_lib('payment.lib');
		ct_load_lib('datetime.lib');
		global $db,$session,$ctconf;

		$total       = ct_number_format($this->participation->pdata['total']);
		$invoicedate = ct_date_format($this->participation->pdata['invoicedate']);
		$regdate     = ct_date_format($this->participation->pdata['regdate']);
		
		$payamount   = ct_number_format($this->pdata['payamount']);
		$paydate     = ct_date_format($this->pdata['paydate']);
		
		echo "<tr class=\"$class\" ";
		echo "onmouseover=\"ct_row( this, 'on', '$class', '".$class."_highlight');\" ";
		echo "onmouseout=\"ct_row( this, 'off', '$class', '".$class."_highlight');\">\n";
		
		echo "<td align=center valign=top><span class=\"fontnormal font10\">".($i+1)."</span></td>\n";
		echo "<td align=right valign=top><span class=\"fontnormal font10\">".$paydate."</span></td>\n";
		echo "<td align=left valign=top><span class=\"fontbold font10\">";
		echo "<a href=\"".ct_pageurl('adminParticipantsDetails',array("form_id"=>$this->get('personID')))."\">";
		echo ct_form_encode($this->participation->person->get_reversename())."</a></span>";
		echo "<br>";
		echo "<span class=\"fontnormal font8\"><a href=\"mailto:".$this->participation->person->get_special('email')."\">";
		echo $this->participation->person->get_special('email')."</a></span>";
		if ($this->participation->get('deleted')) {
			echo "<br><span class=\"fontnegative fontbold font10\">";
			echo ct('S_ADMIN_PARTICIPANTS_CANCELLED');
			echo "</span>\n";
		}
		echo "</td>\n";
		
		echo "<td align=\"center\" valign=top><span class=\"";
		if ($this->participation->pdata['paymethod']=="cash")
			echo "fontnegative fontbold font8";
		elseif ($this->participation->pdata['paymethod']=="free")
			echo "fontpositive fontbold font8";
		else
			echo "fontnormal font8";
		echo "\">".ct_get_payment_description_short($this->participation->pdata['paymethod'])."</span><br>";
		echo "<span class=\"fontnormal font8\">".$regdate."</span>";
		echo "</td>\n";
		echo "<td align=right valign=top><span class=\"fontnormal font10\">".$total."</span><br>";
		echo "<span class=\"fontnormal font8\">".$invoicedate."</span>";
		echo "</td>\n";
		echo "<td align=right valign=top><span class=\"";
		if ($payamount>0)
			echo "fontbold font10";
		else
			echo "fontnegative fontbold font10";
		echo "\">".$payamount."</span>";
		echo "</td>\n";
		
		echo "<td align=left valign=top><span class=\"fontnormal font8\">".ct_form_encode(wordwrap($this->pdata['note'], 30, " ", true))."</span></td>\n";
		
		echo "<td align=right valign=top><span class=\"fontnormal font10\">";
		$user =& $session->get_user();
		
		if ($user->is_admin() || $user->is_assistant() ) {
			echo "<a href=\"".ct_pageurl('adminParticipantsPayments', array('form_personID' => $this->get('personID'),'form_paymentID' => $this->get_id()))."\">".ct('S_ADMIN_PAYMENTS_ACTION_EDIT')."</a> ";
			echo "<a target=\"_blank\" href=\"".ct_pageurl('adminParticipantsPayments', array('form_personID' => $this->get('personID'),'form_paymentID' => $this->get_id()))."\"><img src=\"icons/newwindow.gif\" border=0></a>";
		}
		echo "</span></td>\n";
		echo "</tr>\n";
	}
	
}

?>