<?php
//
// CLASS:	CTReview
// This is the default class for reviews. You have to extend this class if
// you want to use different types of reviews for your conference.
//

class CTReview {

	var $data = array();
	var $errors = array();
	var $reviewfactor = array();

	var $styles = array();

	function CTReview() {
		$this->_init();
	}

	function _init() {
				global $db,$session;

		if ($session->get('db_reviewfactors')) {
			$this->reviewfactor=$session->get('db_reviewfactors');
		} else {
			$r = $db->query("SELECT * FROM reviewfactors");
			$num = $db->num_rows($r);
			if ($num > 0) {
				$this->reviewfactor = array();
				for ($i = 0; $i < $num; $i++) {
					$row = $db->fetch($r);
					$this->reviewfactor[$row['criterion']] = $row['factor'];
				}
			}
			$session->put('db_reviewfactors',$this->reviewfactor);
		}
		$this->styles = array(''=>''		  ,
						'--'=>''	  ,
						'0' =>'review0',
						'1' =>'review1', '2' =>'review2',
						'3' =>'review3', '4' =>'review4',
						'5' =>'review5', '6' =>'review6',
						'7' =>'review7', '8' =>'review8',
						'9' =>'review9', '10'=>'review10');
	}


	//#### database methods #####################################################

	function load($paper, $person) {
		global $db;
		$paper = (int)$paper; $person = (int)$person; // sanitize.

		$r = $db->query("select * from reviews where paperID='$paper' and personID='$person'");
		if ($r && ($db->num_rows($r) == 1)) {
			$this->data = $db->fetch($r);
			if ($this->get('creationdate')==0) { // review not submitted, set values to "--"
				$this->data['familiarity']    = "--";
				$this->data['evaluation']    = "--";
				$this->data['significance']  = "--";
				$this->data['originality']   = "--";
				$this->data['relevance']     = "--";
				$this->data['readability']   = "--";
				$this->data['overall']       = "--";
			}
			return true;
		} else {
			$this->data = array();
			return false;
		}
	}

	function persist() {
		global $db;
		$result = $db->replace_into('reviews', $this->data);
	}

	/*
	 * process form data
	 */
	function _require($field, $name) {
		global $http;

		if (isset($http[$name]) && ($http[$name] != "")) {
			$this->set($field, $http[$name]);
			return true;
		} else {
			$this->errors[] = $name;
			$this->set($field, "");
			return false;
		}
	}


	//#### data access ##########################################################

	// get a record field's value, fieldname is key
	function get($key) {
		return isset($this->data[$key]) ? $this->data[$key] : '';
	}

	// get a record field value, with html special chars converted
	function get_special($key) {
		return htmlspecialchars($this->get($key));
	}

	// set a record fields value
	function set($key, $value) {
		$this->data[$key] = $value;
	}


	function get_reviewer() {
		$person = new CTPerson;
		$person->load_by_id($this->data['personID']);
		return $person;
	}

	function get_paper() {
		ct_load_class('CTPaper');
		$paper = new CTPaper;
		$paper->load_by_id($this->data['paperID']);
		return $paper;
	}

	// Calculate the total of this review
	function get_total() {
		if ($this->get('creationdate')==0) return "--";
		$total = intval(
		( ( $this->data['evaluation']     * $this->reviewfactor['evaluation']   ) +
		( $this->data['significance']   * $this->reviewfactor['significance'] ) +
		( $this->data['originality']    * $this->reviewfactor['originality']  ) +
		( $this->data['relevance']      * $this->reviewfactor['relevance']    ) +
		( $this->data['readability']    * $this->reviewfactor['readability']  ) +
		( $this->data['overall']        * $this->reviewfactor['overall']      ) ) /10 );
		return $total;
	}

	// Return the style sheet for this ranking (usually changes the background color..)
	function get_style($value) {
		$style = "";
		if ($this->get('creationdate')!=0 && $value<>"") $style = $this->styles[$value];
		return $style;
	}

	// Return the style sheet for this ranking (usually changes the background color..)
	function get_totalstyle() {
		$style = "";
		$total = $this->get_total();
		if ($this->get('creationdate')!=0 && $total!=="--") $style = $this->styles[intval($total/10)];
		return $style;
	}

	function get_criteria_title($criteria) {
		if ($criteria=='evaluation')
			return ct('S_REVIEW_FORM_EVALUATION_LABEL');
		if ($criteria=='significance')
			return ct('S_REVIEW_FORM_SIGNIFICANCE_LABEL');
		if ($criteria=='originality')
			return ct('S_REVIEW_FORM_ORIGINALITY_LABEL');
		if ($criteria=='relevance')
			return ct('S_REVIEW_FORM_RELEVANCE_LABEL');
		if ($criteria=='readability')
			return ct('S_REVIEW_FORM_READABILITY_LABEL');
		if ($criteria=='overall')
			return ct('S_REVIEW_FORM_OVERALL_LABEL');
		if ($criteria=='familiarity')
			return ct('S_REVIEW_FORM_FAMILIARITY_LABEL');
		return "";
	}

	/**
	 * get the name of the review class for this contributiontype
	 */
	function get_reviewClass($typeID="") {
		$default_class = "CTReview_Default_Form";
		if ($typeID=="") {
			$paper = $this->get_paper();
			$typeID= $paper->get('contributiontypeID');
		}
		if ($typeID=="") return $default_class;  // This should never happen...
		ct_load_lib('papers.lib');
		$t = ct_get_contributiontypes($typeID);
		if (!ct_test_class('CTReview_'.$t['review_classname'])) {
	        ct_error_log("Warning: Class .class 'CTReview_".$t['paper_classname']."' could not be found",0);
			ct_warningbox('Class not found!',"The class 'CTReview_".$t['review_classname']."' could not be found! Please contact the conference organizers");
			return $default_class;
		}
		return 'CTReview_'.$t['review_classname'];
	}


	/**
	* Show options to admin and pc chairs...
	*/
	function show_edit_options($width, $align='center') {
		global $session, $http;
		$user =& $session->get_user();
		$params = array("form_paperID" => $this->get('paperID'), 'form_personID'=> $this->get('personID'));

		echo "<table width=\"$width\" align=\"$align\" class=\"infoview_table\">\n";
		echo "<tr><td class=\"brightbg\" align=left valign=top>";
		if ($user->get_id()==$this->get('personID'))
			echo "<img src=\"icons/back.gif\" alt=\"go back\" border=0>";
		echo "&nbsp;<a class=\"cmda\" href=\"".ct_pageurl('reviewPaper', $params)."\">".ct('S_INDEX_PAPER_REVIEW_EDIT')."</a>";
		if ($user->get_id()==$this->get('personID'))
			echo " &middot; <a class=\"cmda\" href=\"".$session->get_besturl()."\">".ct('S_BROWSEASSIGNEDPAPERS_GOTO')."</a>";
		echo "</td></tr>\n";
		echo "</table>\n";
	}


}

?>