<?php

class CTSession {

	/**
	 * default constructor
	 * starts HTTP-session and registers array
	 */
	function CTSession() {
		global $ctconf, $http;

		// Set ConfTool session identifier name
		$sid_name = 'CTSID';
		if (isset($ctconf['web/sessionname']) && strlen(preg_replace('/[^A-Z0-9]/','',strtoupper($ctconf['web/sessionname'])))>0) 
			$sid_name .= '_'.preg_replace('/[^A-Z0-9_]/','',strtoupper($ctconf['web/sessionname']));
		session_name($sid_name);

		// Determine session ID - PHP knows many methods...
		$sid = null;
		if (isset($_REQUEST[$sid_name]))		
			$sid = $_REQUEST[$sid_name];
		elseif (isset($http[$sid_name])) {
			$sid = $http[$sid_name];
			if (session_id()=='' && $sid!='') session_id($sid); 	// if session ID was transmitted and PHP had problems to find it, set it manually.
		}
		elseif (isset($_SERVER['HTTP_COOKIE'])) {
			$cookies = split (";", $_SERVER{'HTTP_COOKIE'});
			foreach ($cookies as $cookie) {
			    $cookie = explode('=', $cookie);
			    $key    = preg_replace('|\s|', '', $cookie[0]);
		    	$value  = isset($cookie[1]) ? $cookie[1] : '';
		    	#if (!isset($_COOKIE[$key])) $_COOKIE[$key] = $value;
		    	if ($key==$sid_name) {
		    		$sid = $value;
					if (session_id()=='' && $sid!='') session_id($sid); 	// if session ID was transmitted and PHP had problems to find it, set it manually.
		    	}
			}
		}


		if(isset($sid)) {
			// Check if session key is valid
	        $sbpc = ini_get("session.hash_bits_per_character");
	        // The possible values are '4' (0-9, a-f), '5' (0-9, a-v), and '6' (0-9, a-z, A-Z, "-", ","). 4 is default.
	        // Before PHP 5, this value is 0 or '' and 4 bits (=hex string) were used.
			if ( preg_match('/^[0-9a-f]+$/',$sid) ||
				 ($sbpc==5 && preg_match('/^[0-9a-v]+$/',$sid)) ||
				 ($sbpc==6 && preg_match('/^[-,0-9a-z]+$/i',$sid)) ) {
				session_start();
			} else {
				// Session ID check failed!
				if (function_exists('session_regenerate_id')) {
					@session_start();	// Start new session and suppress error messages
					session_regenerate_id();	// Create a new session ID. (php > 4.3.2)
				} else {
					session_id(md5(microtime()));
					@session_start();
				}
				ct_redirect(ct_pageurl('logout'));
			}
		} else {
			// Start new session, no session ID found.
			@session_start();
		}

		$this->del('queries'); // Delete queries for debugging...
		$this->put('querycount',0);

		if (!isset($_SESSION['active'])) {
			$request_host = $_SERVER['HTTP_HOST'];
			$request_scheme = "http";
			if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == "on") $request_scheme = "https";
			$baseurl = parse_url(ct_getbaseurl());
			$basehost = $baseurl['port'] ? $baseurl['host'].':'.$baseurl['port'] : $baseurl['host'];
			if ($ctconf['web/redirecttobaseurl'] &&
				     ($request_host != $basehost || $request_scheme != $baseurl['scheme'])) { // if another host was explicitly defined, redirect.
				ct_redirect($ctconf['web/baseurl']);
				exit();
			}
			$_SESSION['active'] = true;
			$_SESSION['baseurl'] = ct_getbaseurl();
			//ct_redirect(ct_pageurl('',array(),'page=login')); // To allow search engines ;-)
			//ct_redirect(ct_pageurl('login'));
		}

		// if the user changed to a conference with a differenz baseurl log him out and read default configuration file!
		if ($_SESSION['baseurl']!=ct_getbaseurl()) {
			$this->put('conf');
			$this->logout();
		}
	}

	/**
	 * try to login for this session
	 */
	function login($uname, $pword) {
		$user = new CTPerson;
		if ($user->login($uname, $pword)) {
			$_SESSION['loggedin'] = true;
			$_SESSION['user'] =& $user;
			return true;
		} else {
			$_SESSION['loggedin'] = false;
			return false;
		}
	}

	/**
	 * logout this session
	 */
	function logout() {
		global $http, $db;

		// logout user
		$user =& $this->get_user();
		if (is_object($user) && is_object($db)) $user->logout(); // Logout user if user exists and db is already loaded (does not apply if the conference is switched).

		// save some parameters
		$page='login'; if (in_http('page') && $http['page']!='logout') $page=$http['page'];
		$conf = $this->get('conf');  // Save the conference.
		$msgi=$this->get('infobox');$msge=$this->get('errorbox');$msgw=$this->get('warningbox'); // Messageboxes...
		#$formpara=array(); reset ($http);
		#while (list($u,$v) = each($http)) {	if (substr($u,0,5)=='form_') $formpara=array_merge($formpara, array($u=>stripslashes($v))); }
		$formpara=ct_http_array();

		session_unset();

		$this->put('conf',$conf);    // and restore
		$this->put('infobox', $msgi); $this->put('errorbox', $msge); $this->put('warningbox', $msgw);
		$_SESSION['active'] = true;	// session key still exists...
		$_SESSION['baseurl'] = ct_getbaseurl(); // remember new baseurl
		#ct_redirect(ct_pageurl($page,array('key'=>$http['key']))); => Mit form_...
		ct_redirect(ct_pageurl($page,$formpara));
	}

	/**
	 * logout this and return to conference site
	 */
	function logout_return($uri='') {
		global $db;

		if ($uri=='') $uri=ctconf_get('conferenceURI','http://www.conftool.net/');

		// Logout user if user exists and db is already loaded
		$user =& $this->get_user();
		if (is_object($user) && is_object($db)) $user->logout();

		$conf = $this->get('conf');  // Save the conference name.
		session_unset();
		$this->put('conf',$conf);    // and restore

		ct_redirect($uri);
	}

	/**
	 * logout old user, login new user...
	 */
	function become($person) {
		$person->set('logindate',ct_timestamp_2_datetime(ct_time()));  // Save last login...
		$person->persist();
		$_SESSION['user'] =& $person;
	}

	/**
	 * check if user is logged in
	 */
	function loggedin() {
		$user=$this->get_user();
		if (isset($_SESSION['loggedin']) && $_SESSION['loggedin']==true &&
				 $user->get('deleted')==0 &&
				 $user->get('logoutdate')=='0000-00-00 00:00:00')
			return true;
		else
			return false;

	}

	/**
	 * Create a (usually green) information box that will displayed on the next page
	 */
	function put_infobox($title, $msg) {
		$oldmsg = $this->get('infobox');
		if (is_array($oldmsg)) $oldmsg[]=array($title, $msg);
		else $oldmsg=array(array($title, $msg));
		$this->put('infobox', $oldmsg);
	}

	/**
	 * Create a (usually red) error box that will displayed on the next page
	 */
	function put_errorbox($title, $msg) {
		$oldmsg = $this->get('errorbox');
		if (is_array($oldmsg)) $oldmsg[]=array($title, $msg);
		else $oldmsg=array(array($title, $msg));
		$this->put('errorbox', $oldmsg);
	}

	/**
	 * Create a (usually yellow) warning box that will displayed on the next page
	 */
	function put_warningbox($title, $msg) {
		$oldmsg = $this->get('warningbox');
		if (is_array($oldmsg)) $oldmsg[]=array($title, $msg);
		else $oldmsg=array(array($title, $msg));
		$this->put('warningbox', $oldmsg);
	}

	// get a value from session data
	function &get($key) {
		if (isset($_SESSION[$key])) {
			return $_SESSION[$key];
		} else {
			$x = false;
			return $x;  // Workaround for stupid php warning message.
		}
	}

	// remove a value from session data
	function del($key) {
		if (isset($_SESSION[$key])) {
			// if (gettype($_SESSION[$key])=="object") $_SESSION[$key]=NULL;
			$_SESSION[$key]=NULL;
			$val = $_SESSION[$key];
			unset($_SESSION[$key]);
			unset($val); // needed for a bug in some php versions
			session_unregister($key);    // needed for another bug in php 4.2!
		}
	}

	// returns the user object
	function &get_user() {
		return $this->get('user');
	}

	/**
	 * reload the user object from DB
	 */
	function reload_user() {
		$u = $this->get('user');
		if ($u==null) return false;
		$u->reload();
		$this->put('user',$u);
		return true;
	}

	/**
	 * reload and save in DB that user did do something
	 */
	function reload_save_useraction() {
		$u = $this->get('user');
		if ($u==null) return false;
		$u->reload_save_useraction();
		$this->put('user',$u);
		return true;
	}


	// put a key-value pair into session data
	function put($key, $val="") {
		$_SESSION[$key] = $val;
	}

	// put a key-value pair into session data (by reference!)
	function putref($key, &$val) {
		$_SESSION[$key] = $val;
	}

	function check_request() {
		return false;
	}

	// Store the URL to return to from edit pages
	function set_besturl($pageinfo="") {
		global $http;
//		if (isset($_SERVER['REQUEST_URI']))
//			$url = ct_getbaseurl(false).str_replace("&","&amp;",$_SERVER['REQUEST_URI']);
//		else {
//		    $url = ct_getbaseurl(false).$_SERVER['PHP_SELF'];
//		    if (isset($_SERVER['QUERY_STRING'])) $url = $url."?".str_replace("&","&amp;",$_SERVER['QUERY_STRING']);
//        }
		$url = ct_pageurl($http['page'],ct_http_array());
		$this->put('besturl', $url);
		$this->put('besturlinfo', $pageinfo);
	}

	// Get the URL
	function get_besturl() {
		return $this->get('besturl');
	}
	// Get the Info (One word that describes the page)
	function get_besturlinfo() {
		return $this->get('besturlinfo');
	}

}
?>