<?php
// --------------------------------------------------------------------
// ConfTool Pro - Your Conference Management Tool
// --------------------------------------------------------------------
// (c) 2001-2007 by Harald Weinreich, Hamburg, Germany
// --------------------------------------------------------------------
//
// This file loads configuration and contains some
// bootstrapping code for loading further classes and
// functions from other files.
//

require('conftool.conf.php');

// YOU MUST NOT CHANGE THE FOLLOWING LINE!
$ctconf['name'] = 'ConfTool Pro - Conference Management Tool';
$ctconf['version'] = '2.0.23';


$ctconf['downloadpages'] = array("downloadPaper","adminExport");

// Store starting time of script! Used for some timeouts, e.g. in mail.lib
$ct_starttime=ct_get_microtime();


/**
 * returns a path from configuration. Relative paths are prepended by the prefix.
 */
function ct_get_path($idx) {
	global $ctconf;

	// Return relative or absulute path.
	return (substr($ctconf['paths/'.$idx], 0, 1) == '/') ?
		$ctconf['paths/'.$idx] :
		$ctconf['paths/prefix'] . $ctconf['paths/'.$idx];
}

/**
 * class to avoid the original "include_oncs", as it is said to be slow.
 */
function ct_include_once($file){
	global $ct_included_files;
	if (!isset($ct_included_files)) $ct_included_files=array();	// initialize
    if (isset($ct_included_files[$file])) return true;  // test if file was already included.
	$ct_included_files[$file] = true; // store that file was included.
	return include($file);	// Now include the file
}

/**
* Test if a library exists
* @param $lib file name of library (with extension)
*/
function ct_test_lib($lib) {
	$etcpath = ct_get_path('etc');
	$libpath = ct_get_path('lib');
	return (file_exists($etcpath.$lib.'.php') || file_exists($libpath.$lib.'.php'));
}

/**
* load a library
* @param $lib file name of library (with extension)
*/
function ct_load_lib($lib) {
	// First try "etc"
	$etcpath = ct_get_path('etc');
	if (file_exists($etcpath.$lib.'.php')) {
		ct_include_once($etcpath.$lib.'.php');
		return true;
	}
	// Then try "lib"
	$libpath = ct_get_path('lib');
	$ret = ct_include_once($libpath.$lib.'.php');
	if ($ret===false) {
        ct_error_log("Error: Library $libpath$lib could not be loaded!",0);
		if (!file_exists($libpath.$lib)) {
		    echo "<H2 style='background: #ff8'><code>Configuration Error!<br>Please check you settings in etc/conftool.conf.php</code></H2>"; die();
		} else {
		    echo "<H2 style='background: #ff8'><code>Syntax error in ConfTool library: ".$lib."</H2>"; die();
		}
	}
}

/**
* Test if a class does exists
* @param $class name of class (without)
*/
function ct_test_class($class) {
	$classpath = ct_get_path('classes');
	$etcpath = ct_get_path('etc');
	return (file_exists($classpath.$class.'.ctcls.php') || file_exists($etcpath.$class.'.ctcls.php'));
}

/**
* load a class definition.
* @param $class class name (without file extension).
*/
function ct_load_class($class) {
	global $ctconf;

	$path = ct_get_path('etc');
	if (!file_exists($path.$class.'.ctcls.php')) {
		$path = ct_get_path('classes');
		if (!file_exists($path.$class.'.ctcls.php')) {
            ct_error_log("Error: Class $path$class could not be loaded!",0);
		    echo "<H2 style='background: #ff8'><code>Configuration Error!<br>Class $class could not be loaded. Please check you settings in etc/conftool.conf.php</code></H2>";
		    echo "<H3><code>\$ctconf['paths/prefix'] is '".$ctconf['paths/prefix']."'</code></H3>"; die();
		}
	}
	$ret = ct_include_once($path.$class.'.ctcls.php');
	if ($ret===false) {
        ct_error_log("Error: Syntax error in class $path$class !",0);
	    echo "<H2 style='background: #ff8'><code>Syntax error in ConfTool class: ".$class.'.ctcls'."</H2>"; die();
	}
}


/**
 * test if a page definition exists
 */
function ct_test_page($page) {
	// Security: Allow only alphanumeric characters for the path name, remove the rest!
	$page = preg_replace("/[^a-zA-Z0-9_\-]/","",$page);
	#$page = preg_replace("/\W+/","",$page);
	// First try "etc"
	$etcpath = ct_get_path('etc');
	if (file_exists($etcpath.$page.'.page.php')) return true;

	// Now try normal path
	$pagepath = ct_get_path('pages');
	if (preg_match("/^admin/",$page)) $pagepath = $pagepath.'admin/';
	// check if file exists
	if (file_exists($pagepath.$page.'.page.php')) return true;

	return false;
}


/**
 * load a page definition
 * @param $page name of page.
 */
function ct_load_page($page) {
	global $session, $http, $db, $user, $ctconf;

	// get user object
	$user =& $session->get_user();

	// Security: Allow only alphanumeric characters for the path name, remove the rest!
	$page = preg_replace("/\W+/","",$page);

	//set_error_handler("ct_error_handler");

	// First try "etc"
	$etcpath = ct_get_path('etc');
	if (file_exists($etcpath.$page.'.page.php')) {
		include($pagepath.$page.'.page.php');
		//restore_error_handler();
		return true;
	}

	// Now try normal path
	$pagepath = ct_get_path('pages');

	// all "admin" pages are in the subfolder admin to improve the overview...
	if (preg_match("/^admin/",$page)) $pagepath = $pagepath.'admin/';

	// check if file exists
	if (!file_exists($pagepath.$page.'.page.php')) {
        ct_error_log("Error: Page $pagepath$page could not be loaded!",0);
		$session->put_errorbox(ct('S_ERROR_SYSTEM'), ct('S_ERROR_SYSTEM_FILENOTFOUND'));
		ct_redirect(ct_pageurl('error'));
	}
	include($pagepath.$page.'.page.php');
	//restore_error_handler();
}

/**
 * conftool error handler.
 */
function ct_error_handler ($errno, $errstr, $errfile, $errline, $errcontext)
{
	// echo "<H3>Error! Please contact harald@weinreichs.de!</H3>";
	echo "<B>Debugging Information</B><BR>";
	echo "Error ".$errno.": ".$errstr."<BR>";
	echo "Context: ".$errcontext."<BR>";
	echo "File: ".$errfile."<BR>";
	echo "Line: ".$errline."<BR><BR>";
}

/**
 * Show error page for fatal errors and quit execution
 */
function ct_fatal_error() {
    ct_error_log("Fatal error!",0);
	ct_load_page('cthead');
	#require('siteheader.inc.php');
	#ct_load_page('ctheadbar');
	ct_load_page('offline');
	#ct_load_page('ctfootbar');
	ct_load_page('ctfoot');
	die();
}

/**
 * print an object or array nicely formatted on the screen.
 */
function ct_print_r($object, $name='') {
	if ($name) echo ( "'" . $name . "' : " ) ;
	echo "<pre>\n";
	if ( is_array ( $object ) )
		{ print_r($object); }
   	else
		{ var_dump($object); }
	echo "</pre>\n";
}

/**
 * load base classes and libraries at system startup
 */
function ct_base_classes() {
	ct_load_lib('phases.lib');
	ct_load_class('CTSession');
	ct_load_class('CTPerson');

	ct_load_class('CTParticipationData'); // Required for participant registration, to store him in session variables

	ct_load_class('CTPaperData');	      // Required for paper submission, to store in session variables
	ct_load_class('CTReview');		  	  // Required for entering reviews, to store them in session variable
}

/**
 * A function to read all main settings of conftool. These parameters might be
 * set in conftool.conf.php or in the table 'ctconf'
 * @return the value of this parameter
 * @param the name of the parameter
 * @param default value. Will be returned if no value can be found in db.
 */
function ctconf_get($name,$default='') {
	global $ctconf,$session,$db;
	if (isset($ctconf[$name])) return $ctconf[$name];
	else {
		if (is_object($session) && is_array($session->get('db_ctconf'))) {
			$c=$session->get('db_ctconf');
		} elseif (is_object($db) && $db->dberror===false) {
			$c = array();
			$res = $db->select("ctconf","name,value"); // ,"name='$name'");
			if ($res) {
				if ($db->num_rows($res) > 0) {
					for ($i = 0; $i < $db->num_rows($res); $i++) {
						$g = $db->fetch_raw($res);
						$c[$g['name']] = $g['value'];
					}
					if (is_object($session)) {
						$session->put('db_ctconf', $c);
					}
				}
			} else {
	            ct_error_log("Database error: table 'ctconf' not found!",0);
			    echo "<H2 style='background: #ff8'>Database Error!</h2><code>The table 'ctconf' could not be found in the database '".$ctconf['db/database']."'</code>";
			    die();
			}
		}
		if ($c[$name]=="|||") return "";
		elseif ($c[$name] || $c[$name]=='0') return $c[$name];
		else return $default;
	}
}

/**
 * A function to wite the main settings of conftool to the database.
 * @return success or not.
 * @param the name of the parameter
 * @param the value of the parameter. Must be a string.
 */
function ctconf_set($name,$value) {
	global $db;
	if ($value=="") $value="|||";
	$db->replace_into('ctconf',array('name'=>$name,'value'=>$value));
	if ($res && $db->num_rows($res) > 1)
		return true;
	else
		return $name;
}

/**
 * A function to read a current value from the ctconf table and increment it just afterwards.
 * @return the value of this parameter
 * @param the name of the parameter
 */
function ctconf_increment($name) {
	global $db;
	$res = $db->query("SELECT value FROM ctconf WHERE name='$name' FOR UPDATE;");
	$upd = $db->query("UPDATE ctconf SET value = value + 1 WHERE name='$name';");
	if ($res && $upd) {
		if ($db->num_rows($res) == 1) {
			$row = $db->fetch($res);
			return $row['value'];
		}
	}
	echo "<h1>FATAL ERROR: Database Table 'ctconf' not initialized!</h1></table>";
	die();
}


/**
 * A simple type cast for PHP 4 ff.
 * @return the target (child) class
 * @param $original_object the object of the type of the parent class
 * @param $new_type_name the name of the child class (must have the same attributes!)
 */
function ct_type_cast($original_object,$new_type_name) {
  $tmp = explode(':', serialize($original_object));
  $tmp[1] = strlen($new_type_name);
  $tmp[2] = '"' . $new_type_name . '"';
  $obj = unserialize(implode(':', $tmp));
  return $obj;
}

/**
 * An explode function that works for many different kinds of elements.
 *
 * @param array $spacer array with spacer elements
 * @param string to split $string
 * @return array with the splitted string. Empty elements will be removed, strings are trimmed.
 */

function ct_multi_explode($spacer,$string)  {
	$astring = array($string);
	if (is_string($spacer)) $spacer=array($spacer);
	// Do this for all elements of $spacer
	foreach ($spacer as $s) {
		$helper = array();
		// Do it for every substring in the array and merge the results.
		foreach ($astring as $a) {
			$helper = array_merge($helper,array_map('trim', explode($s,$a)));
		}
		$astring = $helper;
	}
	// now remove all empty elements. They can occur if two separators followed each other.
	$return = array();
	foreach ($astring as $a) { if ($a!='') $return[]=$a; }
	return $return;
}

/**
 * Explode csv to array, remove leading and trailing spaces and empty elements.
 */
function ct_csv_explode($csv_string) {
	$a = array_map('trim', explode(",",$csv_string));
	$b = array();
	foreach ($a as $k=>$v) if ($v!="") $b[]=$v; // remove empty strings
	return $b;
}

/**
 * Implode array to a "readable" csv string.
 */
function ct_csv_implode($array) {
	return implode(", ",$array);
}

// load database adapter
function ct_database_adapter() {
	global $ctconf;
	ct_load_lib($ctconf['db/dbms'].'.dbi');
}

// build a url that points to a ct page
function ct_pageurl($page, $getvars=array(), $pathinfo="", $fragment="") {
	global $session;
	$q = "?";
	$url = ct_getbaseurl(true, $page);
	$url .= "index.php";
	if ($pathinfo<>"") {
		if (substr($pathinfo,0,1)!="/") $pathinfo = "/".$pathinfo;
		$url .= $pathinfo;
	}
	if ($page<>"") {
		$url .= $q."page=".$page;
		$q = "&amp;";
	}
	if (is_object($session)) {
		$conference = $session->get('conf');
		if ($conference<>"") {
			$url .= $q."conf=".$conference;
			$q = "&amp;";
		}
	}

	if (is_array($getvars) && count($getvars)>0) { // security check to avoid errors.
		while (list($k,$v) = each($getvars)) {
			if (is_array($v)) {
				// $v may be an array, when check-boxes or multiple select fields are being used.
				while (list($va,$vb) = each($v)) {
					$url .= $q.urlencode($k)."[]=".urlencode($vb);
				}
			} else {
				$url .= $q.urlencode($k)."=".urlencode($v);
			}
			$q = "&amp;";
		}
	}

	//   Add session ID if cookies are disables...
	//	SID should work but php 4.2 caused problems! :-(
	//	echo SID;
	if (SID != "" && !(substr($pathinfo,0,6)=="/page=")) {
		$url.= $q.strip_tags(SID);
		$q = "&amp;";
		// so try another (my) method as well
	} else if ($_COOKIE[session_name()]=="" && !(substr($pathinfo,0,6)=="/page=")) {
		$url.= $q.strip_tags(session_name())."=".session_id();
		$q = "&amp;";
    }

	if ($fragment!="" && substr($fragment,0,1)!="#") $fragment = "#".$fragment;
	$url .= $fragment;

	return $url;
}

/**
 * @return string from language array (in session).
 * @param $include_path return the path of the installation as well? If set to false, only the protocpl and domain name will be returned.
 * @param $page name of page
 * @desc get baseurl of conftool. this is either %ctconf['web/baseurl'] or if not set it will be extracted
 *       from the URL of the current document.
 */
function ct_getbaseurl($include_path = true, $page="") {
	global $ctconf, $http;

	// if web/baseurl was set, return it a s the basis url of ConfTool
	if (isset($ctconf['web/baseurl']) && $ctconf['web/baseurl'] != "" ) {
		// http is forced for downloads
		if ($ctconf['web/forcehttpdownloads']===true && in_array($page,$ctconf['downloadpages']) && substr($ctconf['web/baseurl'],0,8)=='https://')
			$baseurl = 'http://'.substr($ctconf['web/baseurl'],8);
		else
			$baseurl = $ctconf['web/baseurl'];

		if ($include_path)
			return $baseurl;
		else
			// Return only domain name from web/baseurl!
			return substr($baseurl, 0, strpos($baseurl,"/",8));  // skip "/" from "https://" etc.
	}
	// Otherwise return the submitted domain name and the current path as baseurl
	else {
		if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == "on") {
			// for downloads use http if required.
			if ($ctconf['web/forcehttpdownloads']===true && in_array($page,$ctconf['downloadpages']))
				$protocol="http";
			else // use default.
				$protocol="https";
		} else {
			$protocol="http";
		}

	    // Remove filename (index.php, imprint.php, browseSessions.php) and query parameters
	    // Request URI is everything behind the host, always starting with "/"
	    $path = preg_replace('|[#\?].*|', '', $_SERVER['REQUEST_URI']);	# remove everything after the first "?"
	    $path = preg_replace('|([a-z-_]+\.php.*)|i','',$path);	# remove filename

		// Return domain name or also base path?
		if ($include_path)
			return $protocol."://".$_SERVER['HTTP_HOST'].$path;
		else
			return $protocol."://".$_SERVER['HTTP_HOST'];
	}
}

/**
 * Get HTTP PATH_INFO (what is behind the /index.php/ (with a slash!))
 * For Apache 2.0: Requires that "AcceptPathInfo On" is set in .htaccess
 * (or in httpd.conf)
 */
function ct_getpathinfo() {
	$pathInfoArray = array();
	if (isset($_SERVER['PATH_INFO'])) {
		$ps = explode("&",urldecode(substr($_SERVER['PATH_INFO'],1)));
		while (list(, $pi) = each($ps)) {
			$k = explode("=",$pi);
			$pathInfoArray = array_merge($pathInfoArray, array($k[0]=>$k[1]));
		}
	}
	return $pathInfoArray;
}


// set navigation path to be displayed at foot of page.
function ct_pagepath($path) {
	global $pagepath;
	$pagepath = $path;
}

// redirect browser to another URL, script execution ends here!
function ct_redirect($url) {
	ob_end_clean();
	//	header("HTTP/1.1 301 Moved Permanently");
	header("Location: ".str_replace("&amp;","&",$url));
	#header("Location: ".str_replace("&amp;","&",$url), true, 301);
	//	header("Connection: close");
	//	flush();
	exit();
}

// send a redirect response to browser to reload the current page
function ct_reload_page() {
	ct_redirect($_SERVER['REQUEST_URI']);
}


// FUNCTIONS THAT CHECK PERMISSIONS
// =====================================================================

// function ct_check_phases($phases) can be found in phases.lib


// check if the current user has administration rights...
function ct_requireadmin() {
	global $session,$http;
	$user =& $session->get_user();
	if (!$user->is_admin()) {
        ct_error_log("Warning: Admin access denied.");
		$session->put_errorbox(ct('S_ERROR_ACCESSDENIED'), ct('S_ERROR_ACCESS_ADMINONLY'));
		ct_redirect(ct_pageurl('error'));
	}
}

// Access only for conference PC Chair
function ct_requirechair() {
	global $session,$http;
	$user =& $session->get_user();
	if (!$user->is_chair() && !$user->is_conferenceChair() && !$user->is_admin()) {
        ct_error_log("Warning:Chair access denied.");
		$session->put_errorbox(ct('S_ERROR_ACCESSDENIED'), ct('S_ERROR_ACCESS_ADMINONLY'));
		ct_redirect(ct_pageurl('error'));
	}
}

// Access only for conference PC Chair
function ct_requireconferenceChair() {
	global $session,$http;
	$user =& $session->get_user();
	if (!$user->is_conferenceChair() && !$user->is_admin()) {
        ct_error_log("Warning: ConferenceChair access denied.");
		$session->put_errorbox(ct('S_ERROR_ACCESSDENIED'), ct('S_ERROR_ACCESS_ADMINONLY'));
		ct_redirect(ct_pageurl('error'));
	}
}

// Access only for staff people (conference assistant: User, Participants and Payments!
function ct_requireassistant() {
	global $session,$http;
	$user =& $session->get_user();
	if (!$user->is_assistant() && !$user->is_admin()) {
        ct_error_log("Warning: Assistant access denied.");
		$session->put_errorbox(ct('S_ERROR_ACCESSDENIED'), ct('S_ERROR_ACCESS_ADMINONLY'));
		ct_redirect(ct_pageurl('error'));
	}
}

// Access only for staff and PC chairs: e.g. for list of PC members...
function ct_requireassistantorchair() {
	global $session;
	$user =& $session->get_user();
	if (!$user->is_assistant() && !$user->is_chair() && !$user->is_conferenceChair() && !$user->is_admin()) {
        ct_error_log("Warning: AssistantOrChair access denied.");
		$session->put_errorbox(ct('S_ERROR_ACCESSDENIED'), ct('S_ERROR_ACCESS_ADMINONLY'));
		ct_redirect(ct_pageurl('error'));
	}
}

// Access only for staff and main conference chairs: e.g. for lists of users and papers...
function ct_requireassistantorconferencechair() {
	global $session;
	$user =& $session->get_user();
	if (!$user->is_assistant() && !$user->is_conferenceChair() && !$user->is_admin()) {
        ct_error_log("Warning: AssistOrConfChair access denied.");
		$session->put_errorbox(ct('S_ERROR_ACCESSDENIED'), ct('S_ERROR_ACCESS_ADMINONLY'));
		ct_redirect(ct_pageurl('error'));
	}
}

// Access only for frontdesk people (and assistants and conference chairs...)
function ct_requirefrontdesk() {
	global $session;
	$user =& $session->get_user();
	if (!$user->is_frontdesk() && !$user->is_assistant() && !$user->is_conferenceChair() && !$user->is_admin()) {
        ct_error_log("Warning: Frontdesk access denied.");
		$session->put_errorbox(ct('S_ERROR_ACCESSDENIED'), ct('S_ERROR_ACCESS_ADMINONLY'));
		ct_redirect(ct_pageurl('error'));
	}
	ct_load_lib('frontdesk.lib');
}


// display error message
function ct_error_msg($msg) {
	echo "<br><span class=\"error_msg\">$msg</span><br>\n";
}

function ct_error_log($msg,$type=0) {
	global $http, $session;
	if (is_object($session)) $user =& $session->get_user();
	if (is_object($user)) 	 $id   = $user->get_id(); else $id="-";
	$page = $http['page'];
	$uri  = $_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
	error_log("[$msg (ID:$id, Page:$page, URI:$uri)]",0);
}

// display an errorbox on the current page
function ct_errorbox($title, $msg) {
	_ct_messagebox($title, $msg, "errorboxTitleTD", "errorboxTitle");
}

// display an warning on the current page
function ct_warningbox($title, $msg) {
	_ct_messagebox($title, $msg, "warningboxTitleTD", "warningboxTitle");
}

// show an information box on the current page
function ct_infobox($title, $msg) {
	_ct_messagebox($title, $msg, "infoboxTitleTD", "infoboxTitle");
}

function _ct_messagebox($title, $msg, $tdclass, $spanclass) {
#	echo "<hr size=1 noshade>\n";
	ct_vspacer();
	echo "<table width=\"100%\" cellspacing=0 cellpadding=5 border=0 align=center>\n";
	echo "<tr><td class=\"$tdclass\" align=left colspan=3>\n";
	echo "<span class=\"$spanclass\">&nbsp;&nbsp;$title</span></td></tr>\n";
	echo "<tr>";
	echo "<td class=\"$tdclass\" align=left valign=top width=\"5%\">&nbsp;</td>\n";
	echo "<td class=\"boxMsgTD\" align=left valign=top width=\"85%\">\n";
	echo "<span class=\"boxMsg\">$msg</span></td>\n";
	echo "<td class=\"boxMsgTD\" align=left valign=top width=\"10%\">&nbsp;</td>\n";
	echo "</tr></table>\n";
	ct_vspacer();
}

/**
 * Create a spacer of about X pixels height, that considers the average screen size.
 *
 * @param int $pixel height
 */
function ct_vspacer($pixel='4') {
	echo "\n<span style=\"font-size:".$pixel."pt;\">&nbsp;</span><br>\n"; // small empty line.
}

/**
 * detect language and load language file...
 */
function ct_load_lang() {
	global $ctconf,$http,$session;

	// Did the user choose another (valid) language?
	if (isset($http['lang']) && $http['lang'] >=1 && $http['lang']<=4) {
		if (isset($ctconf['lang'][$http['lang']]['language'])) {
			$lang = $ctconf['lang'][$http['lang']]['language'];
			if (file_exists(ct_get_path('etc').$lang.".lang")) {
				$session->put('lang',$lang); // expires in one year
				$session->put('langno',$http['lang']);
				setcookie("ct_language",$http['lang'],time()+60*60*24*366);
			    ct_load_lib('language.lib');
				ct_read_language_file();
			}
		}
	}

	// Choose default language if no language was set before during this session.
	if ($session->get('lang')===false || $session->get('lang')=="" || $session->get('langno')===false ||$session->get('langno')=="") {
		if (isset($_COOKIE['ct_language']) && $_COOKIE['ct_language']!="" && $_COOKIE['ct_language']<=count($ctconf['lang']))
			$default=$_COOKIE['ct_language'];
		else
			$default=$ctconf['lang/default'];
		$session->put('langno',$default);
		$session->put('lang',$ctconf['lang'][$default]['language']);
	    ct_load_lib('language.lib');
		ct_read_language_file();
	} elseif ($ctconf['language/debug']===true) { // reload for debugging...
	    ct_load_lib('language.lib');
		ct_read_language_file();
	}

}


/**
 * @return string from language array (in session).
 * @param $c constant name for this expression
 * @param $var_array array of variables that shall be inserted at %1, %2, %3 etc.
 * @desc Language constants are defined in the etc/xxxx.lang files.
 *       If you want to return a value empty use "_" as constant value
 *       If you want to replace parts of the text use %1, %2 etc. The values in
 *           the array will replace these placeholders.
 */
function ct($c,$var_array=array()) {
	global $session,$db;
	$text = $session->get($c);

	if ($text=="|||") { // Language strings with a value of "_" will be interpreted as empty.
		$text = "";
	} else if (!$text===false) {
		; // OK that constant exists! :-)
	} else {
		$text = $c; // not found! Return name of constant...
	}

	// now replace variables if available.
	$i=1;
	foreach($var_array as $var) {
		$text = ereg_replace('%'.$i, ''.$var, $text);
		$i++;
	}
	return $text;
}

/**
 * @return the correct array field name that fits to the current language number
 * @param $array_name name of the array where the row from the database is stored
 * @param $field_name the name of the database field e.g. "title" for "title" (default, used if others left empty), "title2", "title3" and "title4"
 */
function ctlx($array_name,$field_name) {
	global $session;
	$c="";
	//  get language number if not 1 (default!)
	if ($session->get('langno')!="1")
		$c=$session->get('langno');
    // test if language field was defined (e.g. title2)...
	if ($array_name[$field_name.$c]!="")
		return $field_name.$c;		// return that name (e.g. title2)
	else
		return $field_name;			// take default (e.g. title)
}

/**
 * look if post parameter is present and has a certain parameter
 *
 * @param string $name name of form field like "form_personID"
 * @param string or array $xue test if value of form field is equal to this string or one of these strings
 * @return boolean
 */
function in_http($name, $value=false) {
	global $http;
	if (isset($http[$name])) {
		if (is_string($value)) {
			return (stripslashes($http[$name]) == $value);
		} elseif (is_array($value)) {
			return in_array(stripslashes($http[$name]),$value);
		} else {
			return true;
		}
	} else {
		return false;
	}
}

/**
 * ct_http_array returns an array of all current http variables, not including $page (the current page),
 * $cmd_xxx (the last pushed button), PHPSESSID (the session ID...)
 *
 * @param array $new_array Replace current http variable values with values in $new_array
 * @return array with all significant http values
 */
function ct_http_array($new_array=array()) {
	global $http;
	reset ($http);
	$array = array();
	while (list($u,$v) = each($http)) {
		if ($u!="page" &&
			$u!="lang" &&
			$u!="conf" &&
			substr($u,0,3)!="cmd" &&
			#$u!=session_name() &&	// Do not remove, or Cookies will be required...
			!array_key_exists($u,$new_array) &&
			$v!=='') {
				if (is_array($v)) { // this was an array!
					array_map(stripslashes,$v); // strip slashes for each element of array...
					$array = array_merge($array, array($u=>$v));
				} else {
					$array = array_merge($array, array($u=>stripslashes($v)));
				}
		}
	}
	while (list($u,$v) = each($new_array)) {
		if ($v!='')
		$array = array_merge($array,array($u=>$v));
	}
	reset ($http);
	return $array;
}

/**
 * Trim all http variables which names are declared in the array.
 */
function ct_http_trim($totrim=array()) {
	global $http;
	#reset ($http);
	#if (count($totrim)==0) $totrim=$http;
	while (list($u,$v) = each($totrim)) {
		{
			if (isset($http['form_'.$v])) $http['form_'.$v]=trim($http['form_'.$v]);
			if (isset($http[$v])) $http[$v]=trim($http[$v]);
		}
	}
	#reset ($http);
}


/* take a simple an array with all values and create an hash array
 * with all the according http values...
 * Add '?lang' to your value and the function will try to read all according language values, like 'title_lang' for title, title2, title3 and title4.
 * Add '?boolean' to your value and the function will assign "true" if a checkbox was set (e.g. value was 1) and "false" if no http value was found.
 * Add '?date' for the interpretation of date fields (time is set to 00:00:00)
 * Add '?datetime' for interpretation of datetime fields
 */
function ct_create_hash_read_http($values=array()) {
	global $http;
	$array = array();
	while (list(,$u) = each($values)) {
		if (in_http('form_'.$u)) {
			$array = array_merge($array, array($u=>$http['form_'.$u]));
		}
		elseif (!(stristr($u,'?lang')===false)) {
			$v = substr($u,0,-5);
			$array = array_merge($array, array($v=>$http['form_'.$v]));
			$array = array_merge($array, array($v.'2'=>$http['form_'.$v.'2']));
			$array = array_merge($array, array($v.'3'=>$http['form_'.$v.'3']));
			$array = array_merge($array, array($v.'4'=>$http['form_'.$v.'4']));
		}
		elseif (!(stristr($u,'?boolean')===false)) {
			$v = substr($u,0,-8);
			if (in_http('form_'.$v)) $b="true"; else $b="false";
			$array = array_merge($array, array($v=>$b));
		}
		elseif (!(stristr($u,'?datetime')===false)) {
			$v = substr($u,0,-9);
			$http['form_'.$v] = $http['form_'.$v.'_year']."-".$http['form_'.$v.'_month']."-".$http['form_'.$v.'_day']." ".$http['form_'.$v.'_hour'].":".$http['form_'.$v.'_minute'].":".$http['form_'.$v.'_second'];
			if ($http['form_'.$v.'_day'] > 0 && $http['form_'.$v.'_year'] > 0) {
				$array = array_merge($array, array($v=>$http['form_'.$v]));
			}
		}
		elseif (!(stristr($u,'?date')===false)) {
			$v = substr($u,0,-5);
			$http['form_'.$v] = $http['form_'.$v.'_year']."-".$http['form_'.$v.'_month']."-".$http['form_'.$v.'_day']." 00:00:00";
			if ($http['form_'.$v.'_day'] > 0 && $http['form_'.$v.'_year'] > 0) {
				$array = array_merge($array, array($v=>$http['form_'.$v]));
			}
		}


	}
	return $array;
}

/**
 * @desc Converts all array an array with all values that have a key starting like "form_" to a new array
 */
function ct_form_array_convert($form_array) {
	$result = array();
	reset($form_array);
	while (list($key, $val) = each($form_array)) {
		if (strpos($key,"form_") == 0)
		    $result[substr($key,5)] = $val;
	}
	// print_r($result);
	return $result;
}


// take an hash array and transform it to an array of arrays...
function hash2aa($hash) {
	$array = array();
	while (list($u,$v) = each($hash)) {
		array_push($array, array($u,$v));
	}
	//    while (list(,$v) = each($array)) { echo $v[0]."-".$v[1]."<br>"; }
	//    reset ($array);

	return $array;
}

// format string for textareas and other form fields
function ct_form_encode($text) {
	$text = stripslashes($text);
	$text = str_replace("&","&amp;",$text);
	$text = str_replace("<","&lt;",$text);
	$text = str_replace(">","&gt;",$text);
	$text = str_replace("\"","&quot;",$text);
	$text = str_replace("'","&#39;",$text);
	$text = ereg_replace("&amp;#([0-9]{3,5});","&#\\1;",$text);
	return $text;
}

// format string for textareas and other form fields
function ct_form_encode_noentities($text) {
	$text = stripslashes($text);
	$text = str_replace("<","&lt;",$text);
	$text = str_replace(">","&gt;",$text);
	$text = str_replace("\"","&quot;",$text);
	$text = str_replace("'","&#39;",$text);
	return $text;
}

// format text from input fields for HTML output. Replaces nl2br of PHP
function ct_nl2br($text) {
	$text = ct_form_encode($text);
	$text = nl2br($text);
	$text = str_replace("  ","&nbsp;&nbsp;",$text);
	return $text;
}

/**
 * Add slashes to every element of an array and any subarray
 */
function ct_deepslash($v){
	return (is_array($v)) ? array_map("ct_deepslash", $v) : addslashes($v);
}

/**
 * Remove slashes from every element of an array and the subarrays
 */
function ct_deepunslash($v){
	return (is_array($v)) ? array_map("ct_deepunslash", $v) : stripslashes($v);
}

/**
 * convert any string or blob to mysql format. Self-written, as there
 * are different functions in different versions of php for this
 */
function ct_mysql_escape_string($s) {
	#return addslashes($s);
	#$search =  array("\x00", "\x5c"    ,'"'       , "'"       , "\x0a", "\x0d", "\x1a", "\x09", "\x08");
	#$replace = array('\0'  , "\x5c\x5c","\x5c\x22", "\x5c\x27", '\n'  , '\r'  , '\Z'  , '\t'  , '\b');
	$search =  array("\x5c"    ,'"'       , "'"       , "\x0a", "\x0d");
	$replace = array("\x5c\x5c","\x5c\x22", "\x5c\x27", '\n'  , '\r'  );
	return str_replace($search, $replace, $s);
}

/**
 * return the number as currency
 * @param number The number as value
 * @param long Long currency format (US$) or short ($)
 */
function ct_currency_format($number,$long=true,$plaintext=false) {
	global $ctconf,$session;
	$spacer = ($plaintext)?' ':'&nbsp;';
	$value = ct_number_format($number);
	if ($long)
		$code = ctconf_get('currencyCode','EUR');
	else
		$code = ctconf_get('currencySymbol','&euro;');
	if ($ctconf['lang'][$session->get('langno')]['currency/style']) // 1 = german format
		return $value.$spacer.$code;
	else		// 0 = US-Style
		return $code.$spacer.$value;
}

/**
 * number formatting for currencies etc.
 */
function ct_number_format($number,$decimals=-1) {
	global $ctconf,$session;
	$d=$ctconf['lang'][$session->get('langno')]['currency/decimals'];
	if ($decimals!=-1) $d=$decimals;
	$p=$ctconf['lang'][$session->get('langno')]['currency/decimal_separator'];
	$s=$ctconf['lang'][$session->get('langno')]['currency/thousands_separator'];
	return number_format($number,$d,$p,$s);
}

/**
 * "Unformat" a number from a form field.
 *
 * @param string $number
 * @return number in international format for database
 */
function ct_number_unformat($number) {
	global $ctconf,$session;
	$p=$ctconf['lang'][$session->get('langno')]['currency/decimal_separator'];
	$s=$ctconf['lang'][$session->get('langno')]['currency/thousands_separator'];
	$number = str_replace($s,"",$number);
	$number = str_replace($p,".",$number);
	return $number;
}

/**
 * Returns the current unix timestamp in ConfTool considering the time zone offset.
 *
 * @return int Unix timestamp: seconds since 1st Jan 1970
 */
function ct_time() {
	$offset = ctconf_get('timezoneOffset',0);
	return time()+$offset;
}

/**
 * @return convernt timestamp in sec since 1970. If invalid or empty return -1
 * @param $date mysql date "2004-12-31 10:15:33"
 * @desc Create a unix timestamp (sec from 1970) from a mysql date format.
 */
function ct_datetime_2_timestamp($datetime) {
   if (!isset($datetime) || !$datetime || strlen($datetime)!=19 || $datetime=='0000-00-00 00:00:00') return -1;
   return( mktime(substr($datetime, 11, 2), substr($datetime, 14, 2), substr($datetime, 17, 2), substr($datetime, 5, 2), substr($datetime, 8, 2), substr($datetime, 0, 4)) );
}

/**
 * @return datetime format for mysql database
 * @param $timestamp unix timestamp (sec from 1970)
 * @desc Createa mysql date format mysql "2004-12-31 10:15:33" from a unix timestamp (sec from 1970).
 */
function ct_timestamp_2_datetime($timestamp) {
   if (!isset($timestamp) || $timestamp<1) return "0000-00-00 00:00:00";
   return date("Y-m-d H:i:s", $timestamp);
}

/**
 * Returns the current time with ms.
 */
function ct_get_microtime() {
   	$mtime = explode(" ",microtime());
	return ((float)$mtime[1] + (float)$mtime[0]);
}

/**
 * Explode a datetime string into an array of 6 numbers
 *
 * @param $datetime datetime
 * @return array exploded datetime
 */
function ct_explode_datetime($datetime) {
	return explode(" ",str_replace("-"," ", str_replace(":"," ", $datetime ) ));
}

// Detect browser version
// Returns array with keys "name", "version"
// browser may be: "opera", "msie", "koqueror", "safari", "firefox", "mozilla"
// Based on code by Gary White
function ct_detect_browser() {
	$ua = strtolower($_SERVER['HTTP_USER_AGENT']);

	$b['name']  = "";
	$b['version']  = "";

	// test for Opera
	if (eregi("opera",$ua)){
		$x = stristr($ua, "opera");
		if (eregi("/", $x)){
			$x = explode("/",$x);
			$b['name'] = $x[0];
			$x = explode(" ",$x[1]);
			$b['version'] = $x[0];
		}else{
			$x = explode(" ",stristr($x,"opera"));
			$b['name'] = $x[0];
			$b['version'] = $x[1];
		}

	// test for MS Internet Explorer
	}elseif(eregi("msie",$ua) && !eregi("opera",$ua)){
		$x = explode(" ",stristr($ua,"msie"));
		$b['name'] = $x[0];
		$b['version'] = $x[1];

	// test for Konqueror
	}elseif(eregi("konqueror",$ua)){
		$x = explode(" ",stristr($ua,"konqueror"));
		$x = explode("/",$x[0]);
		$b['name'] = $x[0];
		$b['version'] = $x[1];

	// test for Safari
	}elseif(eregi("safari", $ua)){
		$b['name'] = "safari";

	// test for Firefox
	}elseif(eregi("firefox", $ua)){
		$b['name']="firefox";
		$x = stristr($ua, "firefox");
		$x = explode("/",$x);
		$b['version'] = $x[1];

	// test for Mozilla
	}elseif(eregi("mozilla",$ua) &&
		eregi("rv:[0-9]\.[0-9]",$ua) && !eregi("netscape",$ua)){
		$b['name'] = "mozilla";
		$x = explode(" ",stristr($ua,"rv:"));
		eregi("rv:[0-9]\.[0-9]\.[0-9]",$ua,$x);
		$b['version'] = str_replace("rv:","",$x[0]);

	// tests for Netscape
	}elseif(eregi("netscape",$ua)){
		$x = explode(" ",stristr($ua,"netscape"));
		$x = explode("/",$x[0]);
		$b['name'] = $x[0];
		$b['version'] = $x[1];
	}elseif(eregi("mozilla",$ua) && !eregi("rv:[0-9]\.[0-9]\.[0-9]",$ua)){
		$x = explode(" ",stristr($ua,"mozilla"));
		$x = explode("/",$x[0]);
		$b['name'] = "netscape";
		$b['version'] = $x[1];
	}

	// clean up browser and version strings
	$b['name'] = ereg_replace("[^a-z,A-Z]", "", $b['name']);
	$b['version'] = ereg_replace("[^0-9,.,a-z,A-Z]", "", $b['version']);
	return $b;
}

// Encode e-mails to avoid spam robots (C) by Harald Weinreich 2000
function ct_encodeMail($email,$name="") {
	$c="";
	eregi("^([_\.0-9a-z-]+)\@([0-9a-z][\.0-9a-z-]+)\.([a-z]{2,4})$",$email,$regs);
	#$c .= $regs[1]."--".$regs[2]."--".$regs[3];
	if ($regs[0]=="")
        $c = $email;
	else
	{
        $c .= "<script type=\"text/javascript\">\n<!--\n";
        $c .= "document.write('<A HREF=\"mailto:'+'".$regs[1]."'+unescape('%40')+'".$regs[2]."'+unescape('%2E')+'".$regs[3]."\">'+'";
        if ($name=="")
			$c .= $regs[1]."'+unescape('%40')+'".$regs[2]."'+unescape('%2E')+'".$regs[3]."<\/A>');\n";
        else
			$c .= $name."<\/A>');\n";
        $c .= "// -->\n</script>\n";
        $c .= "<noscript>\n";
        $c .= $regs[1]."<font color=#800000>&#x40;</font>".$regs[2]."<font color=#800000>&#x2E;</font>".$regs[3]."\n";
        $c .= "</noscript>";
	}
	return $c;
}

?>