<?php

// Make compatible with older version of PHP (<4.2)
if (!isset($_SERVER) && isset($HTTP_SERVER_VARS)) 	define('_SERVER', 'HTTP_SERVER_VARS');
if (!isset($_POST) 	 && isset($HTTP_POST_VARS)) 	define('_POST', 'HTTP_POST_VARS');
if (!isset($_GET) 	 && isset($HTTP_GET_VARS)) 		define('_GET', 'HTTP_GET_VARS');
if (!isset($_COOKIE) && isset($HTTP_COOKIE_VARS)) 	define('_COOKIE', 'HTTP_COOKIE_VARS');
if (!isset($_FILES)  && isset($HTTP_POST_FILES)) 	define('_FILES', 'HTTP_POST_FILES');

// Load basic php settings (usually only necessary on a shared host)
include('settings.php');

// load configuration and basic functions
$ret = include('conftool.inc.php');
if ($ret===false) {
    echo "<H2 style='background: #ff8'><code>Configuration Error!<br>Please check you Apache / php settings</code></H2>";
    echo "<H3 style='background: #fc8; padding: 12px'><code>'include_path' is '".ini_get('include_path')."'</code></H3>";
    die();
}

// Parse HTTP variables
$http = array();
$path_info = ct_getpathinfo();  // Load variables in path info - an alternative to post and get...
if (is_array($path_info)) {
	while (list($k, $v) = each($path_info)) {
		$http[$k] = $v;
	}
}
if (isset($_GET) && is_array($_GET)) {
	while (list($k, $v) = each($_GET)) {
		$http[$k] = $v;
	}
}
if (isset($_POST) && is_array($_POST)) {
	while (list($k, $v) = each($_POST)) {
		$http[$k] = $v;
	}
}

// Disable magic quotes for database access.
set_magic_quotes_runtime(0);

// Enable Magic Quotes for all HTTP variables: Add slashes to all post and get values.
if(!get_magic_quotes_gpc()){
	$http = array_map("ct_deepslash", $http);
    #$_SERVER = array_map("ct_deepslash", $_SERVER);
} else {
  	$_SERVER = array_map("ct_deepunslash", $_SERVER);
}

// Do not add Session ID automatically
ini_set('url_rewriter.tags','');
ini_set('session.use_trans_sid', false);

// Some security settings
ini_set('register_globals','Off');
ini_set('allow_url_fopen','Off');
ini_set('register_globals','Off');

// Sanitize 'page' variable
$http['page']=(isset($http['page'])?preg_replace("/[^a-zA-Z0-9_\-]/",'',$http['page']):"");

// pages must not be cached!
// However, due to a bug in the https implementation of the Internet Explorer
// we must allow caching for thepaper downloads and data exports
if ( ! (isset($http['page']) && in_array($http['page'],$ctconf['downloadpages']) )) {
	session_cache_limiter('nocache');
	ini_set("session.cache_expire", "");  	// Pages expire immediately - usually useless when nocache is set, but...
	header('Last-Modified: ' . gmdate("D, d M Y H:i:s") . " GMT");	 // always changed...
	header('Expires: Sun, 13 Dec 1998 05:00:00 GMT');			     // always outdated...
	header('Pragma: no-cache');     							   // HTTP 1.0
	header('Cache-Control: no-store, no-cache, must-revalidate, post-check=0, pre-check=0, max-age=0, private');  // HTTP 1.1
	//header('Cache-Control: private', false);
} else {
	// Explicitly allow caching for download pages
	header('Pragma: public');
	header('Cache-Control: cache, must-revalidate');
}

// load standard classes
ct_base_classes();

// initialize session object
// this will redirect to the actual URL if not already in a session
$session = new CTSession;

// If multi-conference: check the current conference (user may be logged out!)
if (ct_test_lib('multi_conference.lib')) {
	ct_load_lib('multi_conference.lib');
	ct_check_conference();
}

// Load database adapter (and select database for the conference)
ct_database_adapter();
if ($db->dberror===true) ct_fatal_error();

// Turn on output buffering
ob_start();

// load language file
ct_load_lang();

// send charset header...
if (isset($ctconf['charset']))
	header('Content-Type: text/html; charset='.$ctconf['charset']);
else  // default
    header('Content-Type: text/html; charset=iso-8859-1');

// retrieve phases when module is loaded
if (!ct_load_phases()) ct_fatal_error();

// is conftool offline?
if (isset($ctconf['offline']) && $ctconf['offline']) $http['page']='offline';

// check if user is logged in
if ($session->loggedin()) {
	if ($session->get_user()=="") {
		$session->logout();  // User object got lost! Logout and start again...
		exit();
	} else {
		$session->reload_save_useraction();
	}
	# die ("logged in!");
	if (!isset($http['page']) || ($http['page'] == "")) {
		ct_redirect(ct_pageurl("index"));
	}
} // if (!$session->loggedin())
else {
	// the following pages do NOT require a login:
	$publicpages = array('login','register','sendUsername','sendPassword','passwordChangeRequested',
						 'imprint','browseSessions','offline');
	if (!isset($http['page']) || !in_array($http['page'],$publicpages)) {
		$http['page']="login";
	}
}

// Print view?
if (!isset($http["print"])) {
	// Load general html-head
	ct_load_page('cthead');

	// Load conference specific head
    if ( !$session->get('conf')===false && !$session->get('conf')=="" && file_exists(ct_get_path('etc').$session->get('conf')."/siteheader.inc.php"))
        require($session->get('conf').'/siteheader.inc.php');
	elseif (file_exists(ct_get_path('etc')."main/siteheader.inc.php"))  // first look in folder "main"
	    require(ct_get_path('etc').'main/siteheader.inc.php');
	else
	    require('siteheader.inc.php'); // default header

	// load navigation bar
	ct_load_page('ctheadbar');
} else {
	ct_load_page('printheader');
}

// Show info, error and warning box
$errorbox = $session->get('errorbox');
if ($errorbox && is_array($errorbox)) {
	foreach ($errorbox as $box) ct_errorbox($box[0], $box[1]);
	$session->del('errorbox');
}
$warningbox = $session->get('warningbox');
if ($warningbox && is_array($warningbox)) {
	foreach ($warningbox as $box) ct_warningbox($box[0], $box[1]);
	$session->del('warningbox');
}
$infobox = $session->get('infobox');
if ($infobox && is_array($infobox)) {
	foreach ($infobox as $box) ct_infobox($box[0], $box[1]);
	$session->del('infobox');
}

ct_load_page($http['page']);

if (!isset($http["print"])) {
	// load footer bar
	ct_load_page('ctfootbar');
	// load conference footer
    if ( !$session->get('conf')===false && !$session->get('conf')=="" && file_exists(ct_get_path('etc').$session->get('conf')."/sitefooter.inc.php"))
        require($session->get('conf').'/sitefooter.inc.php');
	elseif (file_exists(ct_get_path('etc')."main/sitefooter.inc.php"))  // first look in folder "main"
	    require(ct_get_path('etc').'main/sitefooter.inc.php');
	else
	    require('sitefooter.inc.php'); // use default footer...
	// general footer, closing main table
	ct_load_page('ctfoot');
} else {
	ct_load_page('printfooter');
}
ob_end_flush();

?>