# Initialize the ConfTool database: create all required tables.
#
# -------------------------------------------------------------
#
# Run this script with the following command:
#
#   mysql conference -u confuser -p < initdb.sql
#
# where "conference" is the name of your database
# "confuser" is the user of your database
# "initdb.sql" is the name (and location) of this file
# you will be prompted for the password.


# Create and use database...
#CREATE DATABASE IF NOT EXISTS conference;
#USE conference;



#
# Table structure for table 'biddings'
#

CREATE TABLE biddings (
  personID int(11) NOT NULL,
  paperID int(11) NOT NULL,
  bidding int(4) NOT NULL,
  conflict int(4) NOT NULL,
  PRIMARY KEY  (paperID,personID),
  KEY bidding (bidding)
);



#
# Table structure for table 'contributiontypes'
#

CREATE TABLE contributiontypes (
   ID int(11) NOT NULL auto_increment,
   title varchar(255) NOT NULL,                         # Title of this contribution type
   title2 varchar(255) NOT NULL,
   title3 varchar(255) NOT NULL,
   title4 varchar(255) NOT NULL,
   shorttitle varchar(255) NOT NULL default '',         # Pro: Shorttitle of this contribution type, used e.g. as Prefix for outputs.
   email_chair varchar(255),                            # e-mail address of the chair
   info text,                                   # Additional info for authors
   info2 text,
   info3 text,
   info4 text,
   has_abstract enum('true','false','plaintext','html') NOT NULL default 'true',  # PRO: Will the user have to enter an abstract? What formattin options does he have?
   abstract_maxlen int(11) NOT NULL default 0,                          # PRO: Maximum length for Abstracts
   has_organisations enum('true','false') NOT NULL default 'false',     # PRO: Will the user have to enter all organisations of the other authors?
   has_bibliography enum('true','false') NOT NULL default 'false',      # PRO: Does person have to enter his biblography?
   has_keywords enum('true','false') NOT NULL default 'true',           # Will the user have to enter keywords?
   has_topics enum('true','false','1','2','3','4','5') NOT NULL default 'true', # Will the user have to select topics from the list?
   has_studentcontribution enum('true','false') NOT NULL default 'false',       # May he check that this is a student contribution?
   has_extratext enum('true', 'false', 'required') NOT NULL default 'false',    # PRO: Extra field shown and required?
   extratext_title varchar(255) NOT NULL default '',                        # Title for extra text field.
   extratext_title2 varchar(255) NOT NULL default '',
   extratext_title3 varchar(255) NOT NULL default '',
   extratext_title4 varchar(255) NOT NULL default '',
   extratext_info varchar(255) NOT NULL default '',                         # Info for extra text field.
   extratext_info2 varchar(255) NOT NULL default '',
   extratext_info3 varchar(255) NOT NULL default '',
   extratext_info4 varchar(255) NOT NULL default '',
   has_extraoption enum('true', 'false', 'required') NOT NULL default 'false',   # PRO: Extra checkbox shown and required?
   extraoption_info varchar(255) NOT NULL default '',                       # Info for extra checkbox
   extraoption_info2 varchar(255) NOT NULL default '',
   extraoption_info3 varchar(255) NOT NULL default '',
   extraoption_info4 varchar(255) NOT NULL default '',
   deadline datetime NOT NULL default '2020-12-31 00:00:00',        # Deadline for submissions
   deadline_upload datetime NOT NULL default '2006-01-01 00:00:00', # Deadline for uploads (usually the same as for submissions)
   deadline_final datetime NOT NULL default '2020-12-31 00:00:00',  # Deadline for final uploads
   deadline_review datetime NOT NULL default '2020-12-31 00:00:00', # Deadline for reviews
   deadline_results datetime NOT NULL default '2006-01-01 00:00:00',# Deadline for results: When will they be accessible
   upload int(11) NOT NULL default '1',                             # Number of uploads (0-3)
   upload_filetype_A varchar(255) NOT NULL,                         # Filetypes (sting, comma separated) for uploads (first and final!)
   upload_filetype_B varchar(255) NOT NULL,
   upload_filetype_C varchar(255) NOT NULL,
   upload_accessible_A enum('true','false') NOT NULL default 'true',        # Is this upload accessible to not-administrative users (e.g. PC members)
   upload_accessible_B enum('true','false') NOT NULL default 'true',
   upload_accessible_C enum('true','false') NOT NULL default 'true',
   upload_info_A varchar(255) NOT NULL,                             # Info field for fist upload
   upload_info_A2 varchar(255) NOT NULL,
   upload_info_A3 varchar(255) NOT NULL,
   upload_info_A4 varchar(255) NOT NULL,
   upload_info_B varchar(255) NOT NULL,                             # Info for second upload
   upload_info_B2 varchar(255) NOT NULL,
   upload_info_B3 varchar(255) NOT NULL,
   upload_info_B4 varchar(255) NOT NULL,
   upload_info_C varchar(255) NOT NULL,                             # Info for third upload
   upload_info_C2 varchar(255) NOT NULL,
   upload_info_C3 varchar(255) NOT NULL,
   upload_info_C4 varchar(255) NOT NULL,
   upload_final int(11) NOT NULL default '1',                       # Number of final uploads (1-3)
   upload_final_info_A varchar(255) NOT NULL,                       # Info for first final upload
   upload_final_info_A2 varchar(255) NOT NULL,
   upload_final_info_A3 varchar(255) NOT NULL,
   upload_final_info_A4 varchar(255) NOT NULL,
   upload_final_info_B varchar(255) NOT NULL,
   upload_final_info_B2 varchar(255) NOT NULL,
   upload_final_info_B3 varchar(255) NOT NULL,
   upload_final_info_B4 varchar(255) NOT NULL,
   upload_final_info_C varchar(255) NOT NULL,
   upload_final_info_C2 varchar(255) NOT NULL,
   upload_final_info_C3 varchar(255) NOT NULL,
   upload_final_info_C4 varchar(255) NOT NULL,
   active enum('true','false') DEFAULT 'true' NOT NULL,             # Is this contributiontype active, e.g. are submissions, uploads etc. currently possible?
   review_anonymous enum('true','false') DEFAULT 'true' NOT NULL,   # Anonymous reviews, e.g. don't show author?
   do_bidding enum('true','false') NOT NULL default 'true',         # Will this be considered in the bidding phase?
   do_review enum('true','false') NOT NULL default 'true',          # Will this be considered for reviews?
   do_discussion enum('true','false') NOT NULL default 'true',      # Will this be considered for the discussion?
   review_details_to_author enum('true','false') DEFAULT 'true' NOT NULL,   # Show details of reviews to authors (or not at all)
   paper_classname varchar(255) NOT NULL,                           # OPT: Class Name of the submission form
   review_classname varchar(255) NOT NULL,                          # PRO: Class Name of the review form.
   PRIMARY KEY (id),
   KEY title (title),
   KEY active (active),
   KEY deadline (deadline),
   KEY deadline_final (deadline_final)
);



#
# Table structure for table `contributiontypes2chairs`
# Assign Contribution types to a chair. He will only have access to those listed here.
#
CREATE TABLE contributiontypes2chairs (
  typeID int(11) NOT NULL default '0',
  personID int(11) NOT NULL default '0',
  PRIMARY KEY  (typeID, personID),
  key typeID (typeID),
  key personID (personID)
);



#
# Table structure for table `contributiontypes2pcs`
# Assign Contribution types to a pc member (reviewer). He will only have access to those listed here.
#
CREATE TABLE contributiontypes2pcs (
  typeID int(11) NOT NULL default '0',
  personID int(11) NOT NULL default '0',
  PRIMARY KEY  (typeID, personID),
  key typeID (typeID),
  key personID (personID)
);



#
# Table structure for table 'contributiontypes2topics'
# Assign topics to specific contribution types.
#
CREATE TABLE contributiontypes2topics (
  typeID int(11) NOT NULL,
  topicID int(11) NOT NULL,
  PRIMARY KEY  (typeID, topicID),
  key typeID (typeID),
  key topicID (topicID)
);



#
# Table structure for table 'countries'
#
CREATE TABLE `countries` (
  `ID` char(2) NOT NULL default '',
  `shorttitle` char(255) default '',
  `title` char(255) default '',
  `title2` char(255) default '',
  `title3` char(255) default '',
  `title4` char(255) default '',
  `eu_country` smallint(4) NOT NULL default '0',
  PRIMARY KEY  (`ID`),
  KEY `shorttitle` (`shorttitle`),
  KEY `title` (`title`),
  KEY `title2` (`title2`),
  KEY `title3` (`title3`),
  KEY `title4` (`title4`)
);



#
# Table structure for table 'ctconf'
# The main Parameters of ConfTool
#

CREATE TABLE ctconf (
  `name` varchar(255) NOT NULL default '',
  `value` text  NOT NULL default '',
  PRIMARY KEY (name)
);



#
# Table structure for table 'emails2papers'
# all emails of co-authors.
#

CREATE TABLE emails2papers (
  paperID int(11) NOT NULL,
  email char(255) NOT NULL,
  KEY paperID (paperID),
  KEY email (email)
);



#
# Table structure for table 'events'
#

CREATE TABLE events (
  ID int(11) NOT NULL auto_increment,
  seqorder int(11) NOT NULL,
  title varchar(255),
  title2 varchar(255),
  title3 varchar(255),
  title4 varchar(255),
  info text,
  info2 text,
  info3 text,
  info4 text,
  short varchar(255) NOT NULL,
  pricecategory int(11) NOT NULL,
  eventtype int(11) NOT NULL,
  vat int(11) NOT NULL,
  eventdate varchar(255) NOT NULL,
  eventdate2 varchar(255) NOT NULL,
  eventdate3 varchar(255) NOT NULL,
  eventdate4 varchar(255) NOT NULL,
  eventlocation varchar(255) NOT NULL,
  eventlocation2 varchar(255) NOT NULL,
  eventlocation3 varchar(255) NOT NULL,
  eventlocation4 varchar(255) NOT NULL,
  unit varchar(32),
  unit2 varchar(32),
  unit3 varchar(32),
  unit4 varchar(32),
  minnumber tinyint(4) NOT NULL default '0',
  maxnumber tinyint(4) NOT NULL default '1',
  defaultnumber tinyint(4) NOT NULL default '1',
  hastext enum('false','textfield','textarea') NOT NULL default 'false',
  texthint varchar(255) NOT NULL,
  texthint2 varchar(255) NOT NULL,
  texthint3 varchar(255) NOT NULL,
  texthint4 varchar(255) NOT NULL,
  datemode enum('false','selectday','selectspan','perdiem','pernight') NOT NULL default 'false',
  start datetime NOT NULL default '0000-00-00 00:00:00',
  end datetime NOT NULL default '0000-00-00 00:00:00',
  availability int(11) NOT NULL,
  disable enum('true','false') NOT NULL default 'false',
  style enum('normal','hidden','spacer','spacer2') NOT NULL default 'normal',
  PRIMARY KEY  (ID),
  KEY eventorder (seqorder),
  KEY title (title)
);



#
# Table structure for table 'eventtypes'
#

CREATE TABLE eventtypes (
  ID int(11) NOT NULL auto_increment,
  seqorder int(11) NOT NULL,
  title  char(255) NOT NULL,
  title2 char(255) NOT NULL,
  title3 char(255) NOT NULL,
  title4 char(255) NOT NULL,
  shorttitle varchar(255) NOT NULL,
  info  char(255) NOT NULL,
  info2 char(255) NOT NULL,
  info3 char(255) NOT NULL,
  info4 char(255) NOT NULL,
  mode enum('normal','exclusive','joint') NOT NULL default 'normal',
  style enum('normal','main','spacer','hidden') NOT NULL default 'normal',
  showremaining enum('true','false') NOT NULL default 'false',
  nocharge enum('true','false','hideoninvoice') NOT NULL default 'false',	# Group without prices? false=normal, true=don't show 0.00 prices on registration form, "hideoninvoice"=don't list on invoice or receipt.
  negative enum('normal','disabled','hidden') NOT NULL default 'normal',
  PRIMARY KEY  (ID),
  KEY eventtypeorder (seqorder)
);



#
# Table structure for table 'groups'
#

CREATE TABLE groups (
  ID int(11) NOT NULL auto_increment,
  title  char(255) NOT NULL,
  title2 char(255) NOT NULL,
  title3 char(255) NOT NULL,
  title4 char(255) NOT NULL,
  regexpression char(255),      # regular expression to be testen when user enters member number
  active tinyint(1) default '1',    # is this group selectable for normal users? (0 = only admin)
  PRIMARY KEY  (ID)
);



#
# Table structure for table 'identities'
#

CREATE TABLE identities (
  ID int(11) NOT NULL auto_increment,
  personID int(11) NOT NULL,
  nickname varchar(255) NOT NULL,
  fullname varchar(255) NOT NULL,
  name varchar(255) NOT NULL,
  firstname varchar(255),
  title varchar(255),
  gender tinyint(4) default '0',
  organisation varchar(255),
  city varchar(255) NOT NULL,
  state varchar(255) NOT NULL,
  country varchar(255) NOT NULL,
  email varchar(255) NOT NULL,
  icq varchar (255),
  aim varchar (255),
  msn varchar (255),
  yahoo varchar (255),
  url varchar(255),
  communityicon mediumblob,
  iconname varchar(255),
  visibility set('online','onlist'),
  password varchar(255),
  deleted tinyint(4) default '0',
  PRIMARY KEY  (ID),
  KEY personID (personID),
  KEY nickname (nickname),
  KEY name (name),
  KEY city (city),
  KEY state (state),
  KEY country (country)
);



#
# Table structure for table 'identities2interests'
#

CREATE TABLE identities2interests (
  identityID int(11) NOT NULL,
  interest char(100) NOT NULL,
  PRIMARY KEY (identityID, interest)
);



#
# Table structure for table 'papers'
# All submissions
#

CREATE TABLE papers (
  ID int(11) NOT NULL auto_increment,
  personID int(11) NOT NULL,
  contributiontypeID int(11),
  title varchar(255) NOT NULL,
  author varchar(255) NOT NULL,
  organisation text,
  bibliography text,
  presentingauthor varchar(255),
  presentingauthoremail varchar(255),
  presentingauthorCV text,
  keywords varchar(255),
  abstract text,
  externalremark text,                          # External remark done by author
  studentpaper tinyint(4) default '0',          # Is this a student paper?
  pagecount tinyint(4) default '0',             # Number of pages (for final version)
  format varchar(255) NOT NULL default '',      # Is the format OK? Any additional infos?
  language varchar(255) NOT NULL default '',    # OPT: Language info
  lastupload datetime default '0000-00-00 00:00:00', # Date of the last upload!
  filename text,                                # Filename on harddisk
  originalname varchar(255),                    # Original filename as found in upload.
  lastupload_2 datetime default '0000-00-00 00:00:00',
  filename_2 text,
  originalname_2 varchar(255),
  lastupload_3 datetime default '0000-00-00 00:00:00',
  filename_3 text,
  originalname_3 varchar(255),
  lastupload_final datetime default '0000-00-00 00:00:00',
  filename_final text,
  originalname_final varchar(255),
  lastupload_final_2 datetime default '0000-00-00 00:00:00',
  filename_final_2 text,
  originalname_final_2 varchar(255),
  lastupload_final_3 datetime default '0000-00-00 00:00:00',
  filename_final_3 text,
  originalname_final_3 varchar(255),
  extraoption tinyint(4) default '0',       # An extra option field (set in Backoffice!)
  extraoption_1 tinyint(4) default '0',     # 3 extra option for customized paper form
  extraoption_2 tinyint(4) default '0',     #
  extraoption_3 tinyint(4) default '0',     #
  extratext text,                           # Extra text field for the submission (set in Backoffice!)
  extratext_1 text,                         # 3 extra text field for customzed paper form
  extratext_2 text,                         #
  extratext_3 text,                         #
  acceptstatus tinyint(4) default '0',      # Status of paper.
  track int(11),                         	# Assigned session (was: track, should have been: sessionID)
  numberInTrack float(10,2) default '1',    # Number of contribution in this session/track (float to make ordering more simple)
  withdrawn tinyint(4) default '0',         # Was this paper withdrawn? 0=false/OK, 1=true/withdrawn
  PRIMARY KEY  (ID),
  KEY personID (personID),
  KEY withdrawn (withdrawn),
  KEY title (title),
  KEY author (author)
) AUTO_INCREMENT=100 ;


#
# Table structure for table 'participants'
#
CREATE TABLE participants (
  personID int(11) NOT NULL,
  regdate datetime default '0000-00-00 00:00:00',
  status int(11),           # groupID of this participant (student etc.)
  memberID varchar(64) NOT NULL default '',
  invoiceNo varchar(32) NOT NULL default '',
  invoice enum('true','false') NOT NULL default 'false',
  invoicedate datetime default '0000-00-00 00:00:00',
  reference varchar(255) NOT NULL default '',	# Reference for invoice
  discount float NOT NULL default '0',  		# Discount for invoice: Percentage value (0-100)
  total float(10,2),
  payamount float(10,2),
  paydate datetime default '0000-00-00 00:00:00',
  paystatus varchar(16),        # PRO: Payment status of this registration. Is it "pending", "confirmed"
  externalremark text,
  internalremark text,
  paymethod enum('cash', 'free', 'transfer', 'cc', 'ccexternal', 'fax', 'paypal', 'cheque', 'open', 'extra1', 'extra2', 'extra3') default 'open',
  cctype varchar(32),
  ccnumber varchar(32) NOT NULL default '',
  ccvc varchar(16) NOT NULL default '',
  ccissueno VARCHAR(16) DEFAULT '',
  ccissuedate VARCHAR(16) DEFAULT '',
  ccexpdate varchar(16) NOT NULL default '',
  ccholder varchar(255) NOT NULL default '',        # Full Name (len: 60)
  ccaddress varchar(255) NOT NULL default '',       # Pro: Address of CC-Holder. Here only one line: street of credit card holder (len: 120)
  cccity varchar(255) NOT NULL default '',          # City (len: 32)
  cczip varchar(16) NOT NULL default '',            # ZIP-Code (len: 15)
  ccstate varchar(32) NOT NULL default '',          # State-Code (len: 20)
  cccountry varchar(255) NOT NULL default '',       # Country (len: 32)
  ccemail varchar(255) NOT NULL default '',         # e-mail Addresse (len: 40)
  ccresult varchar(255) NOT NULL default '',	# RETURN: Result code of credit card processor (e.g. verisign, 0=OK)
  ccrespmsg text,       						# RETURN: Is a response message from credit card processor
  ccauthcode varchar(255) NOT NULL default '',  # RETURN: Authorization code returned from payflow link
  ccavsdata varchar(3) NOT NULL default '',		# RETURN: 3-character response for the Address Verification Check
  ccpnref varchar(255) NOT NULL default '',		# RETURN: PNREF is the Payment Network Reference ID from Verisign
  ccpaylink blob,               				# Link for credit card payment including special payment parameters..., e.g. used for saferpay
  billingaddress enum('true','false') NOT NULL default 'false',   # Use extra address for invoice?
  name varchar(255) NOT NULL default '',   		# PRO: Billing data for invoice
  firstname varchar(255) NOT NULL default '',
  gender tinyint(4) NOT NULL default '0',
  organisation varchar(255) NOT NULL default '',
  organisation2 varchar(255) NOT NULL default '',
  addr1 varchar(255) NOT NULL default '',
  addr2 varchar(255) NOT NULL default '',
  zip varchar(16) NOT NULL default '',
  city varchar(255) NOT NULL default '',
  state varchar(32) NOT NULL default '',
  country varchar(255) NOT NULL default '',
  email varchar(255) NOT NULL default '',
  phone varchar(255) NOT NULL default '',
  fax varchar(255) NOT NULL default '',
  passport varchar(32),         # PRO: ID of passport might be required...
  extraoption_1 INT NOT NULL DEFAULT '0', # Field for extra options -> participation_extraoption.lib
  extraoption_2 INT NOT NULL DEFAULT '0',
  extraoption_3 INT NOT NULL DEFAULT '0',
  extratext_1 text NOT NULL,
  extratext_2 text NOT NULL,
  extratext_3 text NOT NULL,
  frontdesk set('arrived','confirmed','onlist'),    # Frontdesk data
  deleted tinyint(4) default '0',                   # Is participant deleted?
  PRIMARY KEY  (personID)
);



#
# Table structure for table 'participants2events'
#

CREATE TABLE participants2events (
  personID int(11) NOT NULL,
  eventID  int(11) NOT NULL,
  number   tinyint(4) default '0',
  start    datetime NOT NULL default '0000-00-00 00:00:00',
  end      datetime NOT NULL default '0000-00-00 00:00:00',
  text     char(255),
  deleted  tinyint(4) NOT NULL default '0',
  PRIMARY KEY  (eventID,personID),
  KEY deleted (deleted)
);



#
# Table structure for table `participants2payments`
#

CREATE TABLE participants2payments (
  paymentID int(11) NOT NULL auto_increment,
  personID  int(11) NOT NULL default '0',
  paydate   datetime NOT NULL default '0000-00-00 00:00:00',
  payamount float(10,2) default NULL,
  note      char(255),
  PRIMARY KEY  (paymentID),
  KEY personID (personID),
  KEY paydate (paydate)
);



#
# Table structure for table 'pc2topics'
#

CREATE TABLE pc2topics (
  personID int(11) NOT NULL,
  topicID  int(11) NOT NULL,
  PRIMARY KEY  (personID,topicID)
);



#
# Table structure for table 'persons'
#

CREATE TABLE persons (
  ID int(11) NOT NULL auto_increment,
  username  varchar(255) NOT NULL,
  name      varchar(255) NOT NULL default '',
  firstname varchar(255),
  title     varchar(255),
  gender    tinyint(4) default '0',
  organisation varchar(255),
  organisation2 varchar(255),
  addr1     varchar(255),
  addr2     varchar(255),
  addr3     varchar(255),
  addr4     varchar(255),
  zip       varchar(255),
  city      varchar(255),
  state     varchar(255),
  country   varchar(255),
  email     varchar(255) NOT NULL default '',
  emailvalidatekey varchar(64) default '',		# Key to validate the email of the user.
  emailvalidated tinyint(4) default 0,			# Did the user validate the email?
  email2    varchar(255) default '',			# Second optional email-address
  email2validatekey varchar(64) default '',		# Key to validate the second email of the user
  email2validated tinyint(4) default 0,			# Did the user validate the second email address?
  phone     varchar(255),
  fax       varchar(255),
  password  varchar(255),							# Password. Might be encrypted, see below.
  passwordencrypted tinyint(4) NOT NULL default 0,	# Is the password MD5-encrypted?
  passwordrequestkey varchar(64) default '',		# If the user requested a new password
  passwordrequestdatetime datetime default '0000-00-00 00:00:00',	# When was the new password requested. Request key has a timeout
  passwordrequesthost varchar(64) default '',		# The hostname from which the new password was requested.
  url       varchar(255),
  internalremark text,
  externalremark text,
  language tinyint(4) NOT NULL default 0,			# Preferred language of user...
  creationdate   datetime default '0000-00-00 00:00:00',
  logindate      datetime default '0000-00-00 00:00:00',
  logoutdate     datetime default '0000-00-00 00:00:00',
  lastactiondate datetime default '0000-00-00 00:00:00',
  loginhost varchar(255),
  status set('admin','conferenceChair','assistant','frontdesk','chair','pc','reviewer','subreviewer','author','coauthor','participant'),
  accounttype  ENUM( 'normal', 'blocked', 'volatile' ) DEFAULT 'normal' NOT NULL,
  deleted tinyint(4) NOT NULL default 0,
  PRIMARY KEY  (ID),
  KEY username (username),
  KEY name (name),
  KEY email (email)
) AUTO_INCREMENT=100 ;



#
# Table structure for table 'phases'
#

CREATE TABLE phases (
  ID     char(32) NOT NULL,
  starts datetime NOT NULL default '2005-01-01 00:00:00',
  ends   datetime default '2010-12-31 23:59:59',
  active tinyint(1) default '1',
  PRIMARY KEY  (ID),
  KEY starts (starts)
);



#
# Table structure for table 'pricecategories'
#

CREATE TABLE pricecategories (
  ID     tinyint(4) NOT NULL auto_increment,
  title  char(255) NOT NULL,
  title2 char(255) NOT NULL,
  title3 char(255) NOT NULL,
  title4 char(255) NOT NULL,
  PRIMARY KEY (ID),
  KEY title (title)
);



#
# Table structure for table 'prices'
#

CREATE TABLE prices (
  ID      int(11) NOT NULL auto_increment,
  groupID int(11) NOT NULL,
  timediscountID  int(11) NOT NULL,
  pricecategoryID int(11) NOT NULL,
  gross float(10,2) NOT NULL default '0.00',
  PRIMARY KEY (ID),
  KEY `groupID` (`groupID`,`timediscountID`,`pricecategoryID`)
);


#
# Table structure for table 'pcdiscussionmessages'
#

CREATE TABLE pcdiscussionmessages (
  ID int(11) NOT NULL auto_increment,
  paperID int(11) NOT NULL,
  personID int(11) NOT NULL,
  creationdate datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
  vote tinyint(4) NOT NULL default '0',
  subject varchar(255),
  message text,
  deleted tinyint(4) default '0',
  PRIMARY KEY  (ID),
  KEY paperID (paperID),
  KEY personID (personID),
  KEY creationdate (creationdate),
  KEY deleted (deleted)
) AUTO_INCREMENT=100;



#
# Table structure for table 'reviewfactors'
#

CREATE TABLE reviewfactors (
  ID int(11) NOT NULL auto_increment,
  criterion char(255) default NULL,
  factor int(4) default NULL,
  PRIMARY KEY (ID)
);



#
# Table structure for table 'reviews'
#

CREATE TABLE reviews (
  paperID int(11) NOT NULL,                     # ID of paper
  personID int(11) NOT NULL,                    # ID of person to do the review.
  reviewtype enum('normal','meta') NOT NULL default 'normal',		# PRO: Meta-Reviews have access to all other reviews of this paper.
  creationdate datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,     # When was the review created/last updated?
  downloaddate datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,     # PRO: When did the Reviewer download the contribution
  evaluation tinyint(4) NOT NULL default '0',   # Evaluation
  significance tinyint(4) NOT NULL default '0', # Significance for theory and practice
  originality tinyint(4) NOT NULL default '0',  # Originality
  relevance tinyint(4) NOT NULL default '0',    # Relevance
  readability tinyint(4) NOT NULL default '0',  # Readability of Contribution
  overall tinyint(4) NOT NULL default '0',      # Overall Rating
  familiarity tinyint(4) NOT NULL default '0',  # Familiarity of Expert (PRO: may be considered for the total rating)
  summary text,                             # Summary of Contribution
  authorcomments text,                      # Comments to Author
  pccomments text,                          # Comments to PC only
  similarPublications text,                 # OPT: Are there previous similar publications?
  formattingWording text,                   # OPT: Comments about the formatting and wording.
  extratext1 text,                          # OPT: Additional optional fields.
  extratext2 text,
  extratext3 text,
  extratext4 text,
  extraoption1 int(11) DEFAULT 0,
  extraoption2 int(11) DEFAULT 0,
  extraoption3 int(11) DEFAULT 0,
  extraoption4 int(11) DEFAULT 0,
  bestpaper tinyint(4) default '0',         # PRO: Consider for Best Paper Award?
  consider tinyint(4) default '0',          # Shall this review be considered for result list
  PRIMARY KEY  (paperID, personID),
  KEY creationdate (creationdate)
);



#
# Table structure for table 'session_rooms'
# These are the rooms for the conference sessions
#
CREATE TABLE `session_rooms` (
  `ID` int(11) NOT NULL auto_increment,
  `name`  char(255) NOT NULL default '',
  `name2` char(255),
  `name3` char(255),
  `name4` char(255),
  PRIMARY KEY  (`id`)
);



#
# Table structure for table 'sessions'
# Sessions are used to group contributions and create the conference programme
#
CREATE TABLE sessions (
  ID int(11) NOT NULL auto_increment,
  shorttitle char(255) NOT NULL default '',
  title  char(255),
  title2 char(255),
  title3 char(255),
  title4 char(255),
  info   char(255),
  info2  char(255),
  info3  char(255),
  info4  char(255),
  chairID int(11),
  roomID  int(11),
  starttime datetime NOT NULL default '2006-01-01 00:00:00',
  endtime   datetime NOT NULL default '2006-01-01 00:00:00',
  show_abstracts enum('true','false') NOT NULL default 'true',
  show_downloads enum('true','false') NOT NULL default 'false',
  PRIMARY KEY  (ID),
  KEY shorttitle (shorttitle),
  KEY starttime (starttime),
  KEY roomID (roomID)
);



#
# Table structure for table 'timediscounts'
#

CREATE TABLE timediscounts (
  ID int(11) NOT NULL auto_increment,
  title  char(255),
  title2 char(255),
  title3 char(255),
  title4 char(255),
  effectivefrom datetime NOT NULL,
  effectiveuntil datetime,
  PRIMARY KEY  (ID),
  KEY effectivefrom (effectivefrom)
);



#
# Table structure for table 'topics'
#

CREATE TABLE topics (
  ID int(11) NOT NULL auto_increment,
  title  char(255),
  title2 char(255),
  title3 char(255),
  title4 char(255),
  PRIMARY KEY  (ID),
  KEY title (title)
);



#
# Table structure for table 'topics2papers'
#

CREATE TABLE topics2papers (
  paperID int(11) NOT NULL,
  topicID int(11) NOT NULL,
  PRIMARY KEY  (paperID,topicID)
);



#
# Table structure for table 'tracks'
#

CREATE TABLE tracks (
  ID int(11) NOT NULL auto_increment,
  title char(255),
  shorttitle char(255),
  time char(255),
  PRIMARY KEY  (ID)
);


#
# Table structure for table 'vats'
#

CREATE TABLE vats (
  ID int(11) NOT NULL auto_increment,
  percentage float(5,2) NOT NULL default '0.00',
  PRIMARY KEY  (ID)
);
