<?php
// ConfTool date and time conversion functions

/**
 * @return formatted date "13.12.2005" (set in conftool.conf.php)
 * @param $date any - either mysql date as String "2004-12-31 10:15:33" OR a unix timestamp as integer.
 * @desc Create a readable formatted date from a mysql date format.
 */
function ct_date_format($date){
	global $ctconf,$session;
	if (!isset($date) || !$date) return "---";	// is parameter set?
	$t=-1;
	if (is_string($date)) $t=ct_datetime_2_timestamp($date); 	// is it a string => create timestamp
	if (is_int($date)) $t=$date;	// is it an integer => use as timestamp
	if ($t<=0) return "---";		// legal value?
	$f=$ctconf['lang'][$session->get('langno')]['dateformat'];
	$d=date($f,$t);
	$d=str_replace(" ","&nbsp;",$d);
	return $d;
}

/**
 * @return day of week in the current language like "Monday" or "Montag"
 * @param $date mysql date as String "2004-12-31 10:15:33" OR a unix timestamp as integer.
 * @desc Create a text for the day of week
 */
function ct_get_dow($date, $short=false) {
	if (!isset($date) || !$date) return "";	// is parameter set?
	if (is_string($date)) $t=ct_datetime_2_timestamp($date); 	// is it a string => create timestamp
	if (is_int($date)) $t=$date;	// is it an integer => use as timestamp
	if ($t<=0) return "";		// legal value?
	$day=date('w',$t); 
	if ($short)
		return substr(ct('S_DATE_DOW_'.$day),0,3);
	else
		return ct('S_DATE_DOW_'.$day);
} 

/**
 * @return formatted date & time like "13.12.2005 15:32:11" (set in conftool.conf.php)
 * @param $date mysql date as String "2004-12-31 10:15:33" OR a unix timestamp as integer.
 * @desc Create a readable formatted date and time from a mysql date format.
 */
function ct_datetime_format($date){
	global $ctconf,$session;
	if (!isset($date) || !$date) return "---";
	$t=-1;
	if (is_string($date)) $t=ct_datetime_2_timestamp($date); 	// is it a string => create timestamp
	if (is_int($date)) $t=$date;	// is it an integer => use as timestamp
	if ($t<=0) return "---";		// legal value?
	$f=$ctconf['lang'][$session->get('langno')]['datetimeformat'];
	$d=date($f,$t);
	$php_months=array('Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec');
	for ($i=0; $i<=11; $i++) {
		if (strstr($d,$php_months[$i].' ') || strstr($d,$php_months[$i].',')) { 
			$d = str_replace($php_months[$i], substr(ct('S_DATE_MON_'.($i+1)),0,3), $d); 
			break;
		}
	}
	$d=str_replace(" ","&nbsp;",$d);
	return $d;
}

/**
 * @return formatted time like "15:32" or "3:32pm" (set in conftool.conf.php)
 * @param $date mysql date as String "2004-12-31 15:32:33" OR a unix timestamp as integer.
 * @desc Create a formatted time 
 */
function ct_time_format($date=-1){
	global $ctconf,$session;
	$t=-1;
	if (is_string($date)) $t=ct_datetime_2_timestamp($date); 	// is it a string => create timestamp
	if (is_int($date)) $t=$date;	// is it an integer => use as timestamp
	if ($t<=0) return "-:--";		// legal value?
	$f=$ctconf['lang'][$session->get('langno')]['timeformat'];
	if (!is_string($f)) $f='H:i';
	return date($f,$t);
}

/**
 * @return formatted date & time like "13.12.2005 15:32:11" (set in conftool.conf.php)
 * @param $date mysql date as String "2004-12-31 10:15:33" OR a unix timestamp as integer.
 * @desc Create a readable formatted date and time from a mysql date format.
 */
function ct_datetime_format_timezone($date){
	return ct_datetime_format($date).'&nbsp;'.ctconf_get('timezoneName');
	#setlocale(LC_ALL, 'en_US','us','usa','eng');
	#echo ", ".date('T').
}

/**
 * @return days
 * @param $from timestamp date (seconds from 1.1.1970)
 * @param $to timestamp date (seconds from 1.1.1970)
 * @desc Count days between two dates, including both dates.
 */
function ct_count_days($date1,$date2){
	return ct_count_nights($date1,$date2)+1;
}

/**
 * @return integer number of nights
 * @param $from timestamp date (seconds from 1.1.1970)
 * @param $to timestamp date (seconds from 1.1.1970)
 * @desc Count nights between two dates.
 */
function ct_count_nights($date1,$date2){
	return intval(($date2-$date1)/60/60/24);
}

/**
 * @return hours
 * @param $from timestamp date (seconds from 1.1.1970)
 * @param $to timestamp date (seconds from 1.1.1970)
 * @param $modulo boolean: hours modulo 24 or not? default=true
 * @desc Count hours between two dates.
 */
function ct_count_hours($date1,$date2,$modulo=true){
	if ($modulo)
		return intval(($date2-$date1)/60/60)%24;
	else
		return intval(($date2-$date1)/60/60);
}

/**
 * @return minutes
 * @param $from timestamp date (seconds from 1.1.1970)
 * @param $to timestamp date (seconds from 1.1.1970)
 * @param $modulo boolean: minutes modulo 60 or not? default=true
 * @desc Count minutes between two dates.
 */
function ct_count_minutes($date1,$date2,$modulo=true){
	if ($modulo)
		return intval(($date2-$date1)/60)%60;
	else
		return intval(($date2-$date1)/60);
}

/**
 * @return seconds
 * @param $from timestamp date (seconds from 1.1.1970)
 * @param $to timestamp date (seconds from 1.1.1970)
 * @param $modulo boolean: seconds modulo 60 or not? default=true
 * @desc Count seconds between two dates.
 */
function ct_count_seconds($date1,$date2,$modulo=true){
	if ($modulo)
		return intval($date2-$date1)%60;
	else
		return intval($date2-$date1);
}

// return the appropriate text for days/hours/minutes/seconds
function ct_format_days($days) {
	if ($days==1) 	return ct("S_PHASES_DAY",array($days));
    else			return ct("S_PHASES_DAYS",array($days));
}
function ct_format_hours($hours) {
	if ($hours==1) 	return ct("S_PHASES_HOUR",array($hours));
    else			return ct("S_PHASES_HOURS",array($hours));
}
function ct_format_minutes($minutes) {
	if ($minutes==1) 	return ct("S_PHASES_MINUTE",array($minutes));
    else			    return ct("S_PHASES_MINUTES",array($minutes));
}
function ct_format_seconds($seconds) {
	if ($seconds==1) return ct("S_PHASES_SECOND",array($seconds));
    else			 return ct("S_PHASES_SECONDS",array($seconds));
}

?>