<?php
//
// special javascript functions for Conftool
//


/**
 * Return JavaScript code for tinyMCE WYSIWYG editor.
 *
 * @param array $element_names the names of all elements that shall be converted to WYSIWYG-Edotirs
 * @param string $options a list with all available options of the JavaScript editor.
 * @return string the javascript code
 */
function get_js_wysiwyg_editor($element_names=array(), $options="bold,italic,underline,separator,sub,sup,separator,bullist,numlist,separator,outdent,indent,separator,undo,redo,separator,cleanup,removeformat,charmap,help") {
	global $session,$ctconf;
	$use_gzip_compression=true; // Should be true. If you have problems, set to false.

	$language="en";
	if (strpos($ctconf['lang'][$session->get('langno')]['language'],"german")===0) $language="de";
	if (strpos($ctconf['lang'][$session->get('langno')]['language'],"french")===0) $language="fr";
	if (strpos($ctconf['lang'][$session->get('langno')]['language'],"spanish")===0) $language="es";
	if (strpos($ctconf['lang'][$session->get('langno')]['language'],"portuguese")===0) $language="pt";
	if (strpos($ctconf['lang'][$session->get('langno')]['language'],"portuguese_br")===0) $language="pt_br";
	if (strpos($ctconf['lang'][$session->get('langno')]['language'],"polish")===0) $language="pl";
	
	if ($use_gzip_compression) {	
		// Default: Use the gzip compressed version for dramatical speed enhancement
		$ret =  "\n<script language='javascript' type='text/javascript' src='jscripts/tiny_mce/tiny_mce_gzip.js'></script>";
		$ret .= "\n	<script type='text/javascript'>";
		$ret .= "\ntinyMCE_GZ.init({";
		$ret .= "\n	plugins : 'table',";
		$ret .= "\n	themes : 'advanced',";
		$ret .= "\n	languages : '$language',";
		$ret .= "\n	disk_cache : true,";
		$ret .= "\n	debug : false";
		$ret .= "\n});";
		$ret .= "\n</script>";
	}else {
		// the following line is for the "normal" loading of the editor
		$ret =  "\n<script language='javascript' type='text/javascript' src='jscripts/tiny_mce/tiny_mce.js'></script>";
	}		
	
	// the init script for tinyMCE
	$ret .= "\n<script language=\"javascript\" type=\"text/javascript\">";
	$ret .= "\n	tinyMCE.init({";
	$ret .= "\n		mode : \"exact\",";
	$ret .= "\n		elements : \"".ct_csv_implode($element_names)."\","; // set textareas to convert to wysiwyg editors-
	$ret .= "\n		language : \"$language\",";   // language code
	$ret .= "\n		dialog_type : \"modal\",";
	$ret .= "\n		theme : \"advanced\",";
	$ret .= "\n		theme_advanced_layout_manager : \"SimpleLayout\",";
	$ret .= "\n		theme_advanced_toolbar_location : \"top\",";
	$ret .= "\n		theme_advanced_toolbar_align : \"left\",";
	$ret .= "\n		theme_advanced_statusbar_location: \"none\","; // top,bottom,none
	$ret .= "\n		theme_advanced_resizing : true,"; // allow resizing...
	$ret .= "\n		theme_advanced_resize_horizontal : false,"; // but only height
	$ret .= "\n		theme_advanced_blockformats : \"p,h1,h2,h3,h4,pre\","; // blockformats for \"formatselect\"
	$ret .= "\n		content_css : \"conftool-wysiwyg.css\","; // Stylesheet for theme_advaned_styles and \"styleselect\"
	//$ret .= "\n		theme_advanced_styles : \"Header 1=header1;Header 2=header2;Header 3=header3\","; // Styles for select box
	//$ret .= "\n		theme_advanced_buttons1 : \"formatselect,styleselect,separator,bold,italic,underline,separator,sub,sup,separator,bullist,numlist,separator,outdent,indent,separator,undo,redo,separator,cleanup,removeformat,charmap,help\",";
	//$ret .= "\n		theme_advanced_buttons1 : \"bold,italic,underline,separator,sub,sup,separator,bullist,numlist,separator,outdent,indent,separator,undo,redo,separator,cleanup,removeformat,charmap,help\",";
	$ret .= "\n		theme_advanced_buttons1 : \"$options\",";
	$ret .= "\n		theme_advanced_buttons2 : \"\","; // remove row 2
	$ret .= "\n		theme_advanced_buttons3 : \"\","; // remove row 3

	$ret .= "\n		valid_elements : \"blockquote[dir|cite|class|dir<ltr?rtl|id|lang],\"";
	$ret .= "\n			+\"br[class|clear<all?left?none?right|id|title],\"";
	$ret .= "\n			+\"code[class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"dd[class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"div[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"dl[class|compact<compact|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"dt[class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"em/i[class|dir<ltr?rtl|id|lang|title],\"";
	#$ret .= "\n			+\"h1[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|title],\"";
	#$ret .= "\n			+\"h2[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|title],\"";
	#$ret .= "\n			+\"h3[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|title],\"";
	#$ret .= "\n			+\"h4[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|title],\"";
	#$ret .= "\n			+\"h5[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|title],\"";
	#$ret .= "\n			+\"h6[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|title],\"";
	#$ret .= "\n			+\"p[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"p/h1/h2/h3/h4/h5/h6/address[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"li[class|dir<ltr?rtl|id|lang|title|type|value],\"";
	$ret .= "\n			+\"ol[class|compact<compact|dir<ltr?rtl|id|lang|start|title|type],\"";
	$ret .= "\n			+\"pre/listing/plaintext/xmp[align|class|dir<ltr?rtl|id|lang|title|width],\"";
	$ret .= "\n			+\"small[class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"strong/b[class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"sub[class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"sup[class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"u[class|dir<ltr?rtl|id|lang|title],\"";
	$ret .= "\n			+\"ul[class|compact<compact|dir<ltr?rtl|id|lang|title|type]\"";	
	
	/* $ret .= "\n		valid_elements : \"address[class|align|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"blockquote[dir|style|cite|class|dir<ltr?rtl|id|lang],\"";
	$ret .= "\n			+\"br[class|clear<all?left?none?right|id|style|title],\"";
	$ret .= "\n			+\"code[class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"dd[class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"div[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"dl[class|compact<compact|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"dt[class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"em/i[class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"h1[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"h2[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"h3[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"h4[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"h5[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"h6[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"p[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"hr[align<center?left?right|class|dir<ltr?rtl|id|lang|noshade<noshade|size|style|title|width],\"";
	$ret .= "\n			+\"li[class|dir<ltr?rtl|id|lang|style|title|type|value],\"";
	$ret .= "\n			+\"ol[class|compact<compact|dir<ltr?rtl|id|lang|start|style|title|type],\"";
	$ret .= "\n			+\"pre/listing/plaintext/xmp[align|class|dir<ltr?rtl|id|lang|style|title|width],\"";
	$ret .= "\n			+\"small[class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"span[align<center?justify?left?right|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"strike[class|class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"strong/b[class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"style[dir<ltr?rtl|lang|media|title|type],\"";
	$ret .= "\n			+\"sub[class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"sup[class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"u[class|dir<ltr?rtl|id|lang|style|title],\"";
	$ret .= "\n			+\"ul[class|compact<compact|dir<ltr?rtl|id|lang|style|title|type]\""; */
	$ret .= "\n		});";
	$ret .= "\n</script>";
	return $ret;
}

?>