<?php
//
// send e-mails to users when they submit, upload, revise or withdraw a paper.
//

/**
 * Send email when paper was submitted or modified
 *
 * @param CTPaper $paperclass  object with details about paper
 * @param boolean $newpaper is it a new submission (true) or not (and update)
 * @param string $extratext addtional text
 * @return boolean was mail successfully sent?
 */
function ct_mail_author_submission_confirmation($paperclass,$newpaper=true,$extratext='') {
	if (!ctconf_get('submissionMail','0')) return false; // Do not send a mail...
	
	ct_load_lib('mail.lib');
	ct_load_lib('papers.lib');
	ct_load_lib('datetime.lib');
	global $session;
	
	$mail_content="";

	// Dear...
	$mail_content =ct_get_mail_greeting_fullname($paperclass->author).",\n\n";

	// body text
	if ($newpaper)
		$mail_content.=ct('S_PAPER_EMAIL_NEW_BODY')."\n\n";
	else
		$mail_content.=ct('S_PAPER_EMAIL_UPDATED_BODY')."\n\n";

	// Details about submission...
	if (method_exists($paperclass,'get_papertext')) {
		$mail_content.=$paperclass->get_papertext();
	} else {
		$mail_content.=ct_mail_autor_get_papertext($paperclass,'');
	}	

	$mail_content.="\n";
	
	if ($extratext!='')
		$mail_content.=$extratext."\n\n";
	
	if (ctconf_get('submissionMailMessage')!='')
		$mail_content.=ctconf_get('submissionMailMessage')."\n\n";

	$mail_content.=ct('S_USER_REG_EMAIL_REGARDS',array(strip_tags(ctconf_get('conferenceShortName'))))."\n";
		
	$mail_content.=ct_get_mail_signature();
		
	// Subject
	if ($newpaper)
		$subject=ctconf_get('conferenceShortName').': '.ct('S_PAPER_EMAIL_NEW_SUBJECT',array($paperclass->get_id()))	;
	else
		$subject=ctconf_get('conferenceShortName').': '.ct('S_PAPER_EMAIL_UPDATED_SUBJECT',array($paperclass->get_id()));

	// BCC
	$bcc = array();
	if (ctconf_get('submissionMailBCC','')!='') $bcc[]=ctconf_get('submissionMailBCC');
	
	// send email now...
	$ret = ct_mail(stripslashes($paperclass->author->get('email')),$subject,$mail_content,'','','',$bcc);


	return $ret;
}


/**
 * Send email when final version was submitted
 *
 * @param CTPaper $paperclass  object with details about paper
 * @param string $extratext addtional text
 * @return boolean was mail successfully sent?
 */
function ct_mail_author_finalversion_confirmation($paperclass,$extratext='') {
	if (!ctconf_get('submissionMail','0')) return false; // Do not send a mail...
	
	ct_load_lib('mail.lib');
	ct_load_lib('papers.lib');
	ct_load_lib('datetime.lib');
	global $session;
	
	$mail_content="";

	// Dear...
	$mail_content =ct_get_mail_greeting_fullname($paperclass->author).",\n\n";

	// body text
	$mail_content.=ct('S_PAPER_EMAIL_FINALVERSION_BODY')."\n\n";

	// Details about submission...
	if (method_exists($paperclass,'get_papertext')) {
		$mail_content.=$paperclass->get_papertext('final');
	} else {
		$mail_content.=ct_mail_autor_get_papertext($paperclass,'final');
	}	

	$mail_content.="\n";
	
	if ($extratext!='')	$mail_content.=$extratext."\n\n";
	
	if (ctconf_get('submissionMailFinalMessage')!='') 
		$mail_content.=ctconf_get('submissionMailFinalMessage')."\n\n";

	$mail_content.=ct('S_USER_REG_EMAIL_REGARDS',array(strip_tags(ctconf_get('conferenceShortName'))))."\n";
	$mail_content.=ct_get_mail_signature();
		
	// Subject
	$subject=ctconf_get('conferenceShortName').': '.ct('S_PAPER_EMAIL_FINALVERSION_SUBJECT',array($paperclass->get_id()))	;

	// BCC
	$bcc = array();
	if (ctconf_get('submissionMailBCC','')!='') $bcc[]=ctconf_get('submissionMailBCC');
	
	// send e-mail now.
	$ret = ct_mail(stripslashes($paperclass->author->get('email')),$subject,$mail_content,'','','',$bcc);

	return $ret;
}


/**
 * Send email when paper was withdrawn
 *
 * @param CTPaper $paperclass object with details about paper
 * @param string $extratext addtional text
 * @return boolean was mail successfully sent?
 */
function ct_mail_author_withdrawn_confirmation($paperclass,$extratext='') {
	if (!ctconf_get('submissionMail','0')) return false; // Do not send a mail...
	
	ct_load_lib('mail.lib');
	ct_load_lib('papers.lib');
	ct_load_lib('datetime.lib');
	global $session;
	
	$mail_content="";

	// Dear...
	$mail_content =ct_get_mail_greeting_fullname($paperclass->author).",\n\n";

	// body text
	$mail_content.=ct('S_PAPER_EMAIL_WITHDRAWN_BODY')."\n\n";

	// Details about submission...
	if (method_exists($paperclass,'get_papertext')) {
		$mail_content.=$paperclass->get_papertext();
	} else {
		$mail_content.=ct_mail_autor_get_papertext($paperclass,'');
	}	

	$mail_content.="\n";
	if ($extratext!='')	$mail_content.=$extratext."\n\n";

	$mail_content.=ct('S_USER_REG_EMAIL_REGARDS',array(strip_tags(ctconf_get('conferenceShortName'))))."\n";
	$mail_content.=ct_get_mail_signature();
		
	// Subject
	$subject=ctconf_get('conferenceShortName').': '.ct('S_PAPER_EMAIL_WITHDRAWN_SUBJECT',array($paperclass->get_id()));

	// BCC
	$bcc = array();
	if (ctconf_get('submissionMailBCC','')!='') $bcc[]=ctconf_get('submissionMailBCC');
	
	// send email now...
	$ret = ct_mail(stripslashes($paperclass->author->get('email')),$subject,$mail_content,'','','',$bcc);
	return $ret;
}

/**
 * Get default info text about submitted paper.
 *
 * @param CTPaper $paperclass class of this paper.
 * @param string $version
 * @return string with text for email.
 */

function ct_mail_autor_get_papertext($paperclass,$version="") {
	ct_load_lib('papers.lib');
	$mail_content="";
	$ctype = $paperclass->_get_contributiontype();
	
	$mail_content.= ct('S_PAPER_EMAIL_DETAILS')."\n";
	$mail_content.= str_repeat("=",strlen(ct('S_PAPER_EMAIL_DETAILS')))."\n";
	
	$maxlen = max(array_map('strlen',array(ct('S_PAPER_FORM_ID'),ct('S_PAPER_TYPE'),ct('S_PAPER_TITLE'),ct('S_PAPER_AUTHOR'))));
	if ($maxlen>50) $maxlen=50;
	$mail_content.= str_pad(ct('S_PAPER_FORM_ID'),$maxlen).": ".$paperclass->get('ID')."\n";
	$mail_content.= str_pad(ct('S_PAPER_TYPE'),$maxlen).": ".strip_tags(stripslashes($ctype[ctlx($ctype,'title')]))."\n";
	$mail_content.= str_pad(ct('S_PAPER_TITLE'),$maxlen).": ".stripslashes($paperclass->get('title'))."\n";
	$mail_content.= str_pad(ct('S_PAPER_AUTHOR'),$maxlen).": ".stripslashes(str_replace("\n"," ",$paperclass->get('author')))."\n";
	#$mail_content.= str_pad(ct('S_PAPER_SUBMITTINGAUTHOR'),$maxlen).": ".$paperclass->author->get_fullname()."\n";

	$maxlen = max(array_map('strlen',array(ct('S_PAPER_PRESENTINGAUTHOR'),ct('S_PAPER_PRESENTINGAUTHOREMAIL'))));
	if ($maxlen>50) $maxlen=50;
	if ($paperclass->get('presentingauthor')) $mail_content.= str_pad(ct('S_PAPER_PRESENTINGAUTHOR'),$maxlen).": ".stripslashes($paperclass->get('presentingauthor'))."\n";
	if ($paperclass->get('presentingauthoremail')) $mail_content.= str_pad(ct('S_PAPER_PRESENTINGAUTHOREMAIL'),$maxlen).": ".stripslashes($paperclass->get('presentingauthoremail'))."\n";

	$mail_content.="\n";
	
	$uploads = $paperclass->_number_of_uploads_for_contributiontype('',$version);
	if ($uploads>0) {
		$maxlen = max(array_map('strlen',array(ct('S_PAPER_UPLOAD_A'),ct('S_PAPER_UPLOAD_B'),ct('S_PAPER_UPLOAD_C'),ct('S_PAPER_LASTUPLOAD'))));
		if ($maxlen>50) $maxlen=50;
		$mail_content.= ct('S_PAPER_EMAIL_UPLOADS')."\n";
		$mail_content.= str_repeat("=",strlen(ct('S_PAPER_EMAIL_UPLOADS')))."\n";
		for ($i=1 ; $i<=$uploads; $i++) {
			$originalname = stripslashes($paperclass->get_special($paperclass->get_ffname('originalname',$version,$i)));
			if ($originalname=="") {
				$mail_content.= str_pad(ct(ct_get_file_number_text($i)),$maxlen).': '.ct('S_INDEX_PAPER_NOUPLOAD')."\n\n";
			} else {
				$mail_content.= str_pad(ct(ct_get_file_number_text($i)),$maxlen).': '.$originalname."\n";
				$mail_content.= str_pad(ct('S_PAPER_LASTUPLOAD'),$maxlen).': '.ct_unhtmlentities(ct_datetime_format_timezone($paperclass->get($paperclass->get_ffname('lastupload',$version,$i))))."\n\n";
			}
		}
	}
	return $mail_content;
}


?>