<?php
//
// send a mail about a payment to the participant 
//



/**
 * Send confirmation of a payment...
 *
 * @param CTpayment $payment the payment object
 * @param CTparticipation $participation participant object
 * @param string $extratext extra text to add to mail...
 */
function mail_payment_received_confirmation($payment,$participation,$extratext='') {
	ct_load_lib('mail.lib');
	ct_load_lib('payment.lib');
	ct_load_lib('datetime.lib');
	global $session;

	if (!ctconf_get('participationPaymentMail','0')) return false; // Do not send a mail...
	
	$mail_content =ct_get_mail_greeting_fullname($participation->person).",\n\n";
	
	$amount = strip_tags(ct_currency_format($payment->get('payamount'),true,true));
	$mail_content.=strip_tags(ct('S_PAYMENT_RECEIVED_DETAILS',array($amount,$participation->person->get_fullname())))."\n\n";

	$mail_content.=ct('S_PARTICIPATE_PAYMENT_INTRO')."\n";
	$mail_content.="-----------------------------------------\n";
	$mail_content.=strip_tags(ct('S_PARTICIPATE_PAYMETHOD').': '.ct_get_payment_description($participation->get('paymethod')))."\n";
	$mail_content.=strip_tags(ct('S_MANAGE_PAYMENTS_DATE').': '.ct_date_format($payment->get('paydate')))."\n";
	$mail_content.=strip_tags(ct('S_MANAGE_PAYMENTS_AMOUNT').': '.$amount)."\n";
	$mail_content.=strip_tags(ct('S_MANAGE_PAYMENTS_NOTE').': '.$payment->get('note'))."\n\n";
	$mail_content.="-----------------------------------------\n";
	$mail_content.=strip_tags(ct('S_PARTICIPATE_PAIDTOTAL').': '.ct_currency_format($participation->get('payamount'),true,true))."\n";
	if ($participation->get('total')-$participation->get('payamount')>=0) {
		$mail_content.=strip_tags(ct('S_PARTICIPATE_FEE_OPEN').': '.ct_currency_format($participation->get('total')-$participation->get('payamount'),true,true))."\n";
	}
	$mail_content.="\n";
	
	// Add extra message
	if ($extratext!='')
		$mail_content.=$extratext;

	// Add another extra message entered in backoffice
	if (ctconf_get('participationPaymentMailHintOK')!='')
		$mail_content.=ctconf_get('participationPaymentMailHintOK')."\n\n";
		
	#$mail_content.=ct('S_USER_PART_EMAIL_CONTENT2')."\n\n";
	$mail_content.=ct_get_mail_signature();
	
	$cc = array();
	if ($participation->get('email')) $cc[]=$participation->get('email');	// Copy e-mail to receiver of invoice
	if ($participation->get('ccemail')) $cc[]=$participation->get('ccemail');	// Copy e-mail to credit card owner

	$bcc = array();
	if (ctconf_get('participationPaymentMailBCC','')!='') $bcc[]=ctconf_get('participationPaymentMailBCC');

	ct_mail(stripslashes($participation->person->get('email')),ct('S_PAYMENT_RECEIVED_MAILSUBJECT',array(ctconf_get('conferenceShortName'))),$mail_content,'','',$cc,$bcc);
}

/**
 * Send a message that a payment was cancelled
 *
 * @param CTpayment $payment the payment object
 * @param CTparticipation $participation participant object
 * @param string $extratext extra text to add to mail...
 */
function mail_payment_cancelled_message($payment,$participation,$extratext='') {
	ct_load_lib('mail.lib');
	ct_load_lib('payment.lib');
	ct_load_lib('datetime.lib');
	global $session;

	if (!ctconf_get('participationPaymentMail','0')) return false; // Do not send a mail...
	
	$mail_content =ct_get_mail_greeting_fullname($participation->person).",\n\n";
	
	$amount = strip_tags(ct_currency_format($payment->get('payamount'),true,true));
	$mail_content.=strip_tags(ct('S_PAYMENT_CANCELLED'))."\n"; // ,array($amount,$participation->person->get_fullname())))."\n\n";
	$mail_content.="---------------------------------\n";
	$mail_content.=strip_tags(ct('S_PARTICIPATE_PAYMETHOD').': '.ct_get_payment_description($participation->get('paymethod')))."\n";
	$mail_content.=strip_tags(ct('S_MANAGE_PAYMENTS_DATE').': '.ct_date_format($payment->get('paydate')))."\n";
	$mail_content.=strip_tags(ct('S_MANAGE_PAYMENTS_AMOUNT').': '.$amount)."\n";
	$mail_content.=strip_tags(ct('S_MANAGE_PAYMENTS_NOTE').': '.$payment->get('note'))."\n\n";
	
	$mail_content.=strip_tags(ct('S_PARTICIPATE_PAIDTOTAL').': '.ct_currency_format($participation->get('payamount'),true,true))."\n";
	$mail_content.=strip_tags(ct('S_PARTICIPATE_FEE_OPEN').': '.ct_currency_format($participation->get('total')-$participation->get('payamount'),true,true))."\n\n";

	// Add extra message
	if ($extratext!='')
		$mail_content.=$extratext;

	// Add another extra message entered in backoffice
	if (ctconf_get('participationPaymentMailHintCancelled')!='')
		$mail_content.=ctconf_get('participationPaymentMailHintCancelled')."\n\n";
		
	$mail_content.=ct_get_mail_signature();
	
	$cc = array();
	if ($participation->get('email')) $cc[]=$participation->get('email');	// Copy e-mail to receiver of invoice
	if ($participation->get('ccemail')) $cc[]=$participation->get('ccemail');	// Copy e-mail to credit card owner

	$bcc = array();
	if (ctconf_get('participationPaymentMailBCC','')!='') $bcc[]=ctconf_get('participationPaymentMailBCC');

	ct_mail(stripslashes($participation->person->get('email')),ct('S_PAYMENT_CANCELLED_MAILSUBJECT',array(ctconf_get('conferenceShortName'))),$mail_content,'','',$cc,$bcc);
}

?>