<?php
//
// send mails to the user with his account/login/password data
//

/**
 * Send registration confirmation email
 *
 * @param CTPerson $person Person object to send...
 * @param boolean $send_password shall password be sent as well?
 * @return boolean Did the mail operation succeed?
 */
function ct_mail_user_registration_confirmation($person,$send_password=false,$extratext='') {
	ct_load_lib('mail.lib');
	global $session;
	
	$mail_content="";
	// Dear...
	$mail_content =ct_get_mail_greeting_fullname($person).",\n\n";

	$mail_content.=ct('S_USER_REG_EMAIL_CONTENT1')."\n\n";

	$mail_content.=ct_mail_get_conferencenameurl();
	
	// Username
	$mail_content.=ct('S_USER_REG_EMAIL_CONTENT4')." ".stripslashes($person->get('username'))."\n";
	#$mail_content.=ct('S_USER_REG_EMAIL_CONTENT5')." ".stripslashes($person->get('password'))."\n\n";
	if ($send_password)
		$mail_content.=ct('S_USER_REG_EMAIL_CONTENT_PASSWORD_EXTRAMAIL')."\n";

	$mail_content.="\n";
	
	if ($extratext!='')
		$mail_content.=$extratext."\n\n";
	
	if (ctconf_get('userRegistrationMailHint')!='')
		$mail_content.=ctconf_get('userRegistrationMailHint')."\n\n";

	$mail_content.=ct('S_USER_REG_EMAIL_REGARDS',array(strip_tags(ctconf_get('conferenceShortName'))))."\n";
		
	$mail_content.=ct_get_mail_signature();
		
	// Subject
	$subject=ctconf_get('conferenceShortName').': '.ct('S_USER_REG_EMAIL_SUBJECT')	;

	// BCC
	$bcc = array();
	if (ctconf_get('userRegistrationMailBCC','')!='') $bcc[]=ctconf_get('userRegistrationMailBCC');

	// send email now...
	$ret = ct_mail(stripslashes($person->get('email')),$subject,$mail_content,'','','',$bcc);

	// Send extra mail with the password?
	if ($send_password){
		sleep(1); // so the password mail will be sent after the registration mail.
		$ret &= ct_mail_user_password($person);
	}

	return $ret;
}


/**
 * Send password reminder email
 *
 * @param CTPerson $person Person object to send...
 * @return boolean Did the mail operation succeed?
 */
function ct_mail_user_password($person) {
	ct_load_lib('mail.lib');
	global $session;

	$mail_content='';
	// Dear...
	$mail_content =ct_get_mail_greeting_fullname($person).",\n\n";

	$mail_content.=ct('S_USER_REG_EMAIL_CONTENT1')."\n\n";

	// Username
	#$mail_content.=ct('S_USER_REG_EMAIL_CONTENT4')." ".stripslashes($person->get('username'))."\n\n";
	$mail_content.=ct('S_USER_REG_EMAIL_CONTENT5')." ".stripslashes($person->get('password'))."\n\n";

	$mail_content.=ct('S_USER_REG_EMAIL_REGARDS',array(strip_tags(ctconf_get('conferenceShortName'))))."\n";

	$mail_content.=ct_get_mail_signature();
	
	// send email
	return ct_mail(stripslashes($person->get('email')),ct('S_USER_SENDPASSWORD_EMAIL_SUBJECT').' - '.ctconf_get('conferenceShortName'),$mail_content);
}


/**
 * Send registration confirmation email
 *
 * @param CTPerson $person Person object to send...
 * @param String $email the receiver of the mail
 * @return boolean Did the mail operation succeed?
 */
function ct_mail_username($person,$email) {
	ct_load_lib('mail.lib');
	ct_load_lib('datetime.lib');
	ct_load_lib('person.lib');
	global $session;
	
	$mail_content =ct_get_mail_greeting_fullname($person).",\n\n";
	$mail_content.=ct('S_SENDUSERNAME_REQUESTINTRO',array(str_replace('&nbsp;',' ',ct_datetime_format(ct_time())),ct_get_client_ip(),strip_tags(ctconf_get('conferenceName'))) )."\n\n";
	$mail_content.=ct('S_USER_REG_EMAIL_CONTENT4')." ".stripslashes($person->get('username'))."\n\n";
	$mail_content.=ct('S_SENDUSERNAME_EXPLANATION')."\n\n";
	$mail_content.=ct('S_USER_REG_EMAIL_REGARDS',array(strip_tags(ctconf_get('conferenceShortName'))))."\n";

	$mail_content.=ct_get_mail_signature();
		
	// Subject
	$subject=ctconf_get('conferenceShortName').': '.ct('S_USER_SENDUSERNAME_EMAIL_SUBJECT')	;
	// send email now...
	$ret = ct_mail(stripslashes($email),$subject,$mail_content);
	return $ret;
}


/**
 * Send email to get a new password...
 *
 * @param CTPerson $person Person object to send...
 * @return boolean Did the mail operation succeed?
 */
function ct_mail_user_newpasswordlink($person) {
	ct_load_lib('mail.lib');
	global $session;

	$mail_content='';
	// Dear...
	$mail_content =ct_get_mail_greeting_fullname($person).",\n\n";

	$mail_content.=ct('S_SENDPW_EMAIL_REQUESTINTRO',array(str_replace('&nbsp;',' ',ct_datetime_format($person->get('passwordrequestdatetime'))),$person->get('passwordrequesthost')))."\n\n";
	$mail_content.=ct('S_SENDPW_EMAIL_EXPLANATION')."\n\n";
	$link = ct_getbaseurl().'pcr.php?key='.$person->get('passwordrequestkey');

	if (ct_test_lib('multi_conference.lib')) {
		if ( $session->get('conf')!="" ) 
			$link.='&conf='.$session->get('conf');
		else	 					
			$link.='&conf=main';
	}

	$mail_content.=ct('S_SENDPW_EMAIL_NEWPASSWORD_LINK',array($link))."\n\n";
	$mail_content.=ct('S_USER_REG_EMAIL_REGARDS',array(strip_tags(ctconf_get('conferenceShortName'))))."\n";

	$mail_content.=ct_get_mail_signature();

	$email2=array();
	if ($person->get('email2')!='') $email2[] = $person->get('email2');
	// send email
	return ct_mail(stripslashes($person->get('email')),ct('S_USER_SENDPASSWORD_EMAIL_SUBJECT').' - '.ctconf_get('conferenceShortName'),$mail_content,'','',$email2);
}



/**
 * @return string mail text with name and URL of conference.
 */
function ct_mail_get_conferencenameurl() {
	// Conference name
	$mail_content.=ct('S_USER_REG_EMAIL_CONTENT2')." ".strip_tags(ctconf_get('conferenceName'))."\n";
	// Conference URL
	$mail_content.=ct('S_USER_REG_EMAIL_CONTENT3')." ".ct_get_loginurl();
	#$mail_content.='&ctusername='.$person->get('username');

	$mail_content.="\n\n";

	return $mail_content;
}

/**
 * Get Text for user status for user registration emails.
 *
 * @param CTPerson $person person object
 * @return string plain text with details about user status.
 */
function ct_mail_get_userstatustext($person) {
	$extratext = '';
	if ($person->is_admin())     	$extratext.=ct('S_USER_STATUS').": ".ct('S_USER_STATUS_ADMIN_SHORT').".\n";
	if ($person->is_conferenceChair()) $extratext.=ct('S_USER_STATUS').": ".ct('S_USER_STATUS_CONFERENCECHAIR').".\n";
	if ($person->is_assistant()) 	$extratext.=ct('S_USER_STATUS').": ".ct('S_USER_STATUS_ASSISTANT').".\n";
	if ($person->is_frontdesk()) 	$extratext.=ct('S_USER_STATUS').": ".ct('S_USER_STATUS_FRONTDESK').".\n";
	if ($person->is_chair())     	$extratext.=ct('S_USER_STATUS').": ".ct('S_USER_STATUS_CHAIR').".\n";
	if ($person->is_pc())        	$extratext.=ct('S_USER_STATUS').": ".ct('S_USER_STATUS_PC').".\n";
	if ($person->is_reviewer())    	$extratext.=ct('S_USER_STATUS').": ".ct('S_USER_STATUS_REVIEWER').".\n";
	return $extratext;
}

?>