<?php

/**
 * list all sessions with 'id' and 'shorttitle:title'
 */
function ct_list_sessions($id="",$short_format=false) {
	global $db;
	
	if ($id!='') {
		$s = array(ct_get_sessions($id));
	} else {
		$s = ct_get_sessions();
	}
	$sessions = array();
	foreach ($s as $g) {
		if ($short_format)
			$sessions[] = array($g['ID'], $g['shorttitle'] );
		else
			$sessions[] = array($g['ID'], $g['shorttitle'].': '.$g[ctlx($g,'title')] );
	}
	return $sessions;
}

/**
 * get all data of all sessions
 *
 * @param number $id of session
 * @return array with arrays of selected sessions
 */
function ct_get_sessions($id="") {
	global $db,$session;
	
	if ($session->get('db_sessions')) {
		$c = $session->get('db_sessions');
	} else {
		$c = array();
		$q = "select * from sessions order by shorttitle";
		$r = $db->query($q);
		if ($r and ($db->num_rows($r) > 0)) {
			for ($i = 0; $i < $db->num_rows($r); $i++) {
				$g = $db->fetch_raw($r);
				$key=$g['ID'];
				$c[$key] = $g;
			}
		}
		$session->put('db_sessions',$c);
	}		
	if ($id!='')
		return $c[$id];
	else 		
		return $c;
}

/**
 * get all data of one sessions
 *
 * @param number $id of session
 * @return array with selected session data
 */
function ct_get_session($id="") {
	if ($id!='') {
		return ct_get_sessions($id);
	} else 		
		return array();
}


/**
 * gets all fields of all contributiontype
 * @return array $id the data of this contributiontype
 */
function ct_get_contributiontypes($id='') {
	global $db, $session;

	if ($session->get('db_contributiontypes')) {
		$c = $session->get('db_contributiontypes');
	} else {
		$c = array();
		$q = "select * from contributiontypes order by title";
		$r = $db->query($q);
		if ($r and ($db->num_rows($r) > 0)) {
			for ($i = 0; $i < $db->num_rows($r); $i++) {
				$g = $db->fetch_raw($r);
				$key=$g['ID'];
				$c[$key] = $g;
			}
		}
		$session->put('db_contributiontypes',$c);
	}		
	if ($id!='')
		return $c[$id];
	else 		
		return $c;
}

/**
 * gets all available contributiontypeIDs
 */
function ct_get_contributiontypeIDs($onlyactive=false) {
	global $session;

	$types = array();
	$ctypes = ct_get_contributiontypes();
	while (list(,$v) = each($ctypes)) {
		if ($v['active']=='true' && ct_datetime_2_timestamp($v['deadline'])>ct_time()) 
			$types[] = $v['ID'];
		elseif ($onlyactive===false)
			$types[] = $v['ID'];
	}
	return $types;
}

/**
 * returns an array that contains all available tracks / contribution types.
 * Each element is an array with two elements, first is the ID, second is the title.
 * Enter description here...
 *
 * @param bool $onlyactive if true, list only active contributiontypes!
 */
function ct_list_contributiontypes($onlyactive=false) {
	global $db,$session;
	
	$types = array();
	$ctypes = ct_get_contributiontypes();
	while (list(,$v) = each($ctypes)) {
		#echo $v[active]."--".$v[deadline]."<br>";
		if ($v['active']=='true' && ct_datetime_2_timestamp($v['deadline'])>ct_time()) {
			$types[] = array($v['ID'], $v[ctlx($v,'title')]);
		} elseif ($onlyactive===false) {
			$types[] = array($v['ID'], $v[ctlx($v,'title')]." (".ct('S_NEWPAPER_SUBMISSIONCLOSED').")");
		}
	}
	return $types;
}


/**
 * gets all topics available for this conference
 * $id returns the data of only this contributiontype
 */
function ct_get_topics($topicID=0) {
	global $db, $session;

	if ($session->get('db_topics')) {
		$c = $session->get('db_topics');
	} else {
		$c = array();
		$q = "select * from topics order by title";
		$r = $db->query($q);
		if ($r and ($db->num_rows($r) > 0)) {
			for ($i = 0; $i < $db->num_rows($r); $i++) {
				$g = $db->fetch_raw($r);
				$key=$g['ID'];
				$c[$key] = $g;
			}
		}
		$session->put('db_topics',$c);
	}		
	if ($topicID>0)
		return $c[$topicID];
	else		
		return $c;
}

/**
 * returns an array that contains all available topics. 
 * Each element is an array with two elements, first is the ID, second is the title.
 */
function ct_list_topics() {
	global $db,$session;
	
	$topics = ct_get_topics();
	$ctopics = array();
	while (list(,$v) = each($topics)) {
		$ctopics[] = array($v['ID'], $v[ctlx($v,'title')]);
	}
	return $ctopics;
}


/**
 * returns an array that contains all available rooms. Each element is an array with two
 * elements, first is room ID, second is room name
 */
function ct_list_session_rooms() {
	global $db;

	$rooms = array();
	$r = $db->query('select * from session_rooms order by name asc');
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$t = $db->fetch_raw($r);
			$rooms[] = array($t['ID'], $t[ctlx($t,'name')]);
		}
	}
	return $rooms;
}

/**
 * returns the name of the session room
 *
 * @param number $roomID ID of room
 * @return name of room
 */
function ct_get_session_room($roomID="") {
	global $db, $session;

	if ($session->get('db_session_room_names')) {
		$c = $session->get('db_session_room_names');
	} else {
		$c = array();
		$r = $db->query('select * from session_rooms');
		if ($r && ($db->num_rows($r) > 0)) {
			for ($i=0; $i < $db->num_rows($r); $i++) {
				$t = $db->fetch_raw($r);
				$c[$t['ID']] = $t[ctlx($t,'name')];
			}
		}
		$session->put('db_session_room_names',$c);
	}
	return $c[$roomID];
}
	
/**
 * Return array with all access states...
 *
 * @return array with arras with number and title of access state
 */ 
function ct_list_accessstates() {
	$states = array();
	$states[] = array("3",  ct('S_ADMIN_PAPERS_RESULTS_STATUS_P3_SHORT'));
	$states[] = array("2",  ct('S_ADMIN_PAPERS_RESULTS_STATUS_P2_SHORT'));
	$states[] = array("1",  ct('S_ADMIN_PAPERS_RESULTS_STATUS_P1_SHORT'));
	$states[] = array("0",  ct('S_ADMIN_PAPERS_RESULTS_STATUS_0_SHORT'));
	$states[] = array("-1", ct('S_ADMIN_PAPERS_RESULTS_STATUS_N1_SHORT'));
	$states[] = array("-2", ct('S_ADMIN_PAPERS_RESULTS_STATUS_N2_SHORT'));
	$states[] = array("-3", ct('S_ADMIN_PAPERS_RESULTS_STATUS_N3_SHORT'));
	$states[] = array("-4", ct('S_ADMIN_PAPERS_RESULTS_STATUS_N4_SHORT'));
	$states[] = array("-5", ct('S_ADMIN_PAPERS_RESULTS_STATUS_N5_SHORT'));
	return $states;
}

/**
 * @desc returns if any users did already register for participation.
 */
function ct_papers_exist($condition="") {
	global $db;
	if ($condition=="")
		$r = $db->query("select count(ID) as count from papers where withdrawn=0");
	else		
		$r = $db->query("select count(ID) as count from papers where withdrawn=0 && ($condition)");
	if ($r and $db->num_rows($r) == 1) {
		$row=$db->fetch($r);
		if ($row['count']>0)
			return true;
		else
			return false;
	}
	return false;
}


/**
 * Create dummy filename with correct extension: "contribution1.pdf" etc.
 * postfix is for multiple uploads, to add "_a", "_b" asf
 */
function ct_create_filename($originalFilename,$id,$postfix="") {
	// Create dummy filename with right extension.
	eregi(".*\.(.{2,4})$",$originalFilename,$regs);
	if ($regs[1]!="")
	{
		return ct('S_INDEX_PAPER_PAPER') . $id . $postfix . "." . $regs[1];
	} else {
		return ct('S_INDEX_PAPER_PAPER') . $id . $postfix . ".bin";
	}
}

/**
 * Replace HTML entities by their character code.
 *
 * @param string $string HTML string
 * @return string with removed HTML entities
 */
function ct_unhtmlentities($string) {
   // First replace numeric entities
   $string = preg_replace('~&#x([0-9a-f]+);~ei', 'chr(hexdec("\\1"))', $string);
   $string = preg_replace('~&#([0-9]+);~e', 'chr("\\1")', $string);
   // replace literal entities
   $trans_tbl = get_html_translation_table(HTML_ENTITIES);
   $trans_tbl = array_flip($trans_tbl);
   return strtr($string, $trans_tbl);
}	

function ct_get_file_number_text($index) {
	return ct('S_PAPER_UPLOAD'.($index=="3"?"_C":($index=="2"?"_B":"_A")));
}

?>