<?php

function ct_get_singlefee($pricecategory,$status,$timediscountID) {
	global $db,$session;

	if ($session->get('db_prices')) {
		$prices = $session->get('db_prices');
	} else {
		$prices = array();
		$r = $db->query('select * from prices');
		if ($r && ($db->num_rows($r) > 0)) {
			for ($i=0; $i < $db->num_rows($r); $i++) {
				$p = $db->fetch($r);
				$key = $p['pricecategoryID']."_".$p['groupID']."_".$p['timediscountID'];
				$prices[$key] = $p['gross'];
			}
		}
		$session->put('db_prices',$prices);
	}
	$key = $pricecategory.'_'.$status.'_'.$timediscountID;
	return $prices[$key];
}

// returns an array that contains all available groups. Each element is an array with two
// elements, first is group ID, second to fifth is group title (4 languages), sixth is a regular expression to check the users entry.
function ct_list_groups($listall=1) {
	global $db,$session;

	if ($session->get('db_groups')) return $session->get('db_groups');

	$groups = array();
	$r = $db->select('groups','*',($listall?'':'active>0'),'title asc');
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$g = $db->fetch_raw($r);
			$groups[] = array($g['ID'], $g[ctlx($g,'title')]);
		}
	}
	$session->put('db_groups',$groups);
	return $groups;
}

// returns an (cached) array that contains all available discounts.
function ct_get_timediscounts() {
	global $db,$session;

	if ($session->get('db_timediscounts')) return $session->get('db_timediscounts');

	$timediscounts = array();
	$r = $db->query('select * from timediscounts order by effectivefrom asc');
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$t = $db->fetch_raw($r);
			$timediscounts[] = $t;
		}
	}
	$session->put('db_timediscounts',$timediscounts);
	return $timediscounts;
}

// returns an array that contains all available discounts. Each element is an array with two
// elements, first is group ID, second is group title.
function ct_list_timediscounts() {
	global $db,$session;
	ct_load_lib('datetime.lib');

	$timediscounts = ct_get_timediscounts();
	$ttext=array();
	for ($i=0; $i < count($timediscounts); $i++) {
		$t = $timediscounts[$i];
		$ttext[] = array($t['ID'],$t[ctlx($t,'title')]." (".ct_date_format($t['effectivefrom']).") - (".ct_date_format($t['effectiveuntil']).")");
	}
	return $ttext;
}

// returns the timediscountID for a date.
function get_timediscountID($date){
	global $db;
	$regdate = ct_datetime_2_timestamp($date);
	$timediscounts = ct_get_timediscounts();
	for ($i=0; $i < count($timediscounts); $i++) {
		$t=$timediscounts[$i];
		$efffrom = ct_datetime_2_timestamp($t['effectivefrom']);
		$effuntil= ct_datetime_2_timestamp($t['effectiveuntil']);
		if ($regdate >= $efffrom && $regdate <= $effuntil){
			return $t['ID']; // return ID
			break;
		}
	}
	// not found - return most likely time discount
	if ($regdate < ct_datetime_2_timestamp($timediscounts[0]['effectivefrom'])) return $timediscounts[0]['ID'];
	if ($regdate > ct_datetime_2_timestamp($timediscounts[count($timediscounts)-1]['effectiveuntil'])) return $timediscounts[count($timediscounts)-1]['ID'];
	return 0;  // error!
}

// returns the TITLE of a timedisocunt to a timediscountID.
function get_timediscount($timediscountID){
	global $db;
	$timediscounts = ct_get_timediscounts();
	for ($i=0; $i < count($timediscounts); $i++) {
		$t=$timediscounts[$i];
		if ($t['ID']==$timediscountID)
			return $t[ctlx($t,'title')];
	}
	return "<span style=\"color:#FF0000\"> -- Current timediscount of participant is undefined! -- </span>";
}

// returns an array that contains all available pricecategories. Each element is an array with two
// elements, first is pricecategory ID, second is pricecategory title.
function ct_list_pricecategories() {
	global $db;

	$pricecategories = array();
	$r = $db->query('select * from pricecategories order by title asc');
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$p = $db->fetch($r);
			$pricecategories[] = array($p['ID'], $p[ctlx($p,'title')]);
		}
	}
	return $pricecategories;
}

// returns an array that contains all available value added taxes. Each element is an array with two
// elements, first is vat ID, second is vat percentage.
function ct_list_vats() {
	global $db;

	$vats = array();
	$r = $db->query('select ID,percentage from vats order by percentage asc');
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$v = $db->fetch($r);
			$vats[] = array($v['ID'], ct_number_format($v['percentage'],1)."%");
		}
	}
	return $vats;
}

/**
 * returns an array that contains all available eventtypes. Each element is an array with three *
 * elements, first is eventtype ID, second is eventtype title.
 */
function ct_list_eventtypes() {
	global $db;

	$eventtypes = array();
	$r = $db->query('select ID,title,title2,title3,title4 from eventtypes order by seqorder, title asc');
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$e = $db->fetch($r);
			$eventtypes[] = array($e['ID'], $e[ctlx($e,'title')]);
		}
	}
	return $eventtypes;
}

/**
 * returns an array that contains all eventtypes ordered by seqorder.
 * Each element is an array with four elements, first is event ID,
 * second is event title, third is seqorder, last event information.
 */
function ct_get_eventtypes() {
	global $db;
	$eventtypes = array();
	$r = $db->query('select * from eventtypes order by seqorder asc, title asc');
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$e = $db->fetch($r);
			$eventtypes[$i] = $e;
		}
	}
	return $eventtypes;
}

/**
 * returns an array that contains all events. Each element is an array with two
 *
 * @return array array with two elements, first is event ID, second is event title.
 */
function ct_list_events($orderedByEventgroups=false) {
	global $db;
	$events = array();
	if ($orderedByEventgroups) { // ordered by event groups
		$r = $db->query('select events.ID as ID, events.title as title, events.title2 as title2, events.title3 as title3, events.title4 as title4, eventtypes.shorttitle as typeshorttitle, eventtypes.ID as typeID '.
						 'FROM events, eventtypes WHERE events.eventtype=eventtypes.ID ORDER by eventtypes.seqorder, events.seqorder asc');
	} else { // ordered by title
		$r = $db->query('select ID,title,title2,title3,title4 from events order by title asc');
	}
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$e = $db->fetch($r);
			if (isset($e['typeshorttitle'])) {
				// $events[] = array($e['ID'], (($e['typeshorttitle']!='')?$e['typeshorttitle'].': ':'ID'.$e['typeID'].': ').$e[ctlx($e,'title')]);
				$events[] = array($e['ID'], (($e['typeshorttitle']!='')?$e['typeshorttitle'].': ':'').$e[ctlx($e,'title')]);
			} else {
				$events[] = array($e['ID'], $e[ctlx($e,'title')]);
			}
		}
	}
	return $events;
}


/**
 * returns an array that contains all events ordered by title
 * (if the eventtype is given, ordered by seqorder).
 * Each element is an array with the elements from the database
 */
function ct_get_events($eventtypeID="") {
	global $db;
	$events = array();
	if ($eventtypeID==""){
		$r = $db->query('select * from events order by title asc');
	} else {
		$r = $db->query('select * from events where eventtype="'.$eventtypeID.'" order by seqorder asc');
	}
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$e = $db->fetch($r);
			$events[$i] = $e;
		}
	}
	return $events;
}


/**
 * @desc returns if any users did already register for participation.
 * @param if a eventtype is given it is checked if someone did already select this event type.
 */
function ct_participants_exist($eventtype='') {
	global $db;
	if ($eventtype=='') {
		$r = $db->query("select * from participants where deleted=0");
		return ($db->num_rows($r) >0) ? true : false;
	} else {
		$r = $db->query("select * from participants2events where deleted=0 and eventID='".$eventtype."'");
		return ($db->num_rows($r) >0) ? true : false;
	}
}


/**
 * Format Credit Card number (enter spaces.)
 *
 * @param string $cardnumber
 * @return string the formatted cc number
 */
function ct_format_ccnumber( $cardnumber ) {
	$cardnumber = str_replace(array(" ","-","/","_"),array("","","",""),$cardnumber);
	return trim(substr($cardnumber,0,4).' '.substr($cardnumber,4,4).' '.substr($cardnumber,8,4).' '.substr($cardnumber,12,4));
}

/**
 * Check Credit Card number (check the checksum of the card.). See: http://www.sitepoint.com/print/card-validation-class-php
 *
 * @param string $cardnumber
 * @return boolean
 */
function ct_check_ccnumber( $cardnumber ) {
	// remove special characters.
	$cardnumber = ereg_replace("[^0-9]", "", $cardnumber);
	// check length
 	if(strlen($cardnumber)<13)  return false;

 	// Check if the CC is any valid CC-Number...
	$validFormat = false;
    $validFormat |= ereg("^5[1-5][0-9]{14}$", $cardnumber);				    // Mastercard
    $validFormat |= ereg("^4[0-9]{12}([0-9]{3})?$", $cardnumber);			// Visa
    $validFormat |= ereg("^3[47][0-9]{13}$", $cardnumber);					// Amex
    $validFormat |= ereg("^3(0[0-5]|[68][0-9])[0-9]{11}$", $cardnumber);	// Diners
    $validFormat |= ereg("^6011[0-9]{12}$", $cardnumber);				    // Discover
    $validFormat |= ereg("^(3[0-9]{4}|2131|1800)[0-9]{11}$", $cardnumber);	//JCB

    // Is the number valid? Do LUHN-Check
    $cardrev = strrev($cardnumber);
	$numSum = 0;
	for($i = 0; $i < strlen($cardrev); $i++) {
	  	$currentNum = substr($cardrev, $i, 1);
		// Double every second digit
		if($i % 2 == 1)	$currentNum *= 2;
		// Add digits of 2-digit numbers together (what is number=-9 as 9<number<19)
		if($currentNum > 9) $currentNum -= 9;
		$numSum += $currentNum;
	}
	// The $numSum variable will contain the sum of all of the variables from step two of the Mod 10 algorithm, which we described earlier. PHP's symbol for the modulus operator is '%', so we assign true/false to the $passCheck variable, depending on whether or not $numSum has a modulus of zero:
	// If the total has no remainder it's OK
	$validChecksum = ($numSum % 10 == 0);
	return $validFormat && $validChecksum;
}

function ct_mask_ccnumber( $cardnumber ) {
	if (strlen($cardnumber)>4)
		return 	substr($cardnumber,0,2).'XX XXXX XXXX '.substr($cardnumber,-4);
	else
		return $cardnumber;
}

/**
 * Get the key to access this invoice without login.
 */
function ct_get_invoicekey($id) {
	global $ctconf;
	if (isset($ctconf['conferenceKey']) && strlen($ctconf['conferenceKey'])>=10)
		return md5($ctconf['conferenceKey'].((int)$id));
	return false;
}

/**
 * Get link to direct invoice access (without login).
 */
function ct_get_invoicelink($id) {
	global $session,$ctconf;
	if ((int)$id<1 || !isset($ctconf['conferenceKey']) || strlen($ctconf['conferenceKey'])<10)
		return false;
	$link = ct_getbaseurl().'pi.php';
	$link .= '?ID='.$id;
	$link .= '&key='.ct_get_invoicekey($id);
	if (ct_test_lib('multi_conference.lib')) {
	if ( $session->get('conf')!="" )
		$link.='&conf='.$session->get('conf');
	else
		$link.='&conf=main';
	}
	return $link;
}


?>