<?php

/**
 * check if password is OK.
 *
 * @param string $password the password to be checked.
 * @param CTPerson $person a person object to compare the password data to.
 * @return array an array with the error messages. If the password is fine, the array is empty.
 */
function ct_validate_password($password="",$person=null) {
    $dict = array('conftool','conferen',
    				'2006','2007','2008','2009',
    				'secret','geheim','0123','12345','11111','asdf','qwert','xxx',
					ctconf_get('conferenceName'),ctconf_get('conferenceShortName'),ctconf_get('conferenceURI'),ctconf_get('conferenceCity'));

	$word = strtolower($password);
	$rword = strrev($word);
	$return = array();
	if (!isset($word) || strlen($word)<2)
		return array(ct('S_ERROR_REGISTER_PASSWORD_TOO_SHORT'));	// Password missing or really silly. Just return it is too short, remaining tests are not necessary.
	if (strlen($word)<5)
		$return[]=ct('S_ERROR_REGISTER_PASSWORD_TOO_SHORT');
	if (!(preg_match("/[a-z]/", $word) && preg_match("%\d+%", $word)))
		$return[]=ct('S_ERROR_REGISTER_PASSWORD_LETTERS_NUMBERS');
	// many similar characters
	$count_chars = count_chars($word,3);
    if(strlen($count_chars) < (strlen($password) / 2))
        $return[]=ct('S_ERROR_REGISTER_PASSWORD_TOO_SIMPLE');
       
	if ((is_object($person)) && $person->get('name')!='') {
		$dict[]=$person->get('username');
		$dict[]=$person->get('firstname'); $dict[]=$person->get('name');
		$dict[]=$person->get('organisation'); $dict[]=$person->get('organisation2');
		$dict[]=$person->get('addr1'); $dict[]=$person->get('addr2'); $dict[]=$person->get('addr3'); $dict[]=$person->get('addr4');
		$dict[]=$person->get('city');
		$dict[]=$person->get('zip');
		$dict[]=$person->get('email'); $dict[]=$person->get('email2');
		$dict[]=$person->get('url');
	}
	foreach ($dict as $d) {
		$d=strtolower(trim($d));
        if (strlen($d)>=3 && 
        	((stristr($d,$word) !== FALSE  )  || // is pwd part of dictionary-word?
        	 (stristr($word,$d) !== FALSE  && (strlen($word)-strlen($d))<=3)  || // is dictionary-word part of password (only if password not 3 or more letters longer...)
        	 (stristr($d,$rword) !== FALSE ) || 
        	 (stristr($rword,$d) !== FALSE && (strlen($rword)-strlen($d))<=3))) {
		        $return[] = ct('S_ERROR_REGISTER_PASSWORD_IN_DICTIONARY',array($d));
        }
	}
	return $return; // All fine

}

/**
 * Generates a random string with the specified length. Tries to void any "confusing" characters.
 */
function ct_randString($length=16,$alphanumeric_only=true){
	$salt   = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";  // salt to select chars from. Similar looking chars have been removed...
	$saltXL = "abcdefghijkmnpqrstuvwxyzABCDEFGHJKLMNPQRSTUVWXYZ23456789$%@#()!-+=*";  // salt to select chars from. Similar looking chars have been removed...
	mt_srand((double)microtime()*1000000);
	$string="";

	if ($alphanumeric_only) // Only a-z and 0-9
		for ($i=0;$i<$length;$i++) $string .= substr($salt, mt_rand(0,strlen($salt)), 1);
	else { // make sure the password starts with a letter and ends with a number, so it will fulfill the password requrements of conftool!
		if ($length>=1) $string.=chr(mt_rand(65,90)); // A-Z
		for ($i=0;$i<$length-2;$i++) $string .= substr($saltXL, mt_rand(0,strlen($saltXL)), 1);
		if ($length>=2) $string.=chr(mt_rand(48,57)); // 0-9
	}
	return $string;
}


?>