<?php

// returns an array that contains all payments for a given person. Each element is an array with two
// elements, first is person, second is paydate, third is payamount.
function ct_list_payments($personID) {
	global $db,$ctconf;
	$count=1;
	$payments = array();
	$r = $db->query("select * from  participants2payments where personID = '".$personID."' order by paydate asc");
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$e = $db->fetch($r);
			$payments[] = array($e['paymentID'],substr($e['paydate'],0,10).": ".ct_currency_format($e['payamount'])."&nbsp;&nbsp;&nbsp; ".stripslashes($e['note'])."&nbsp;",$e['paydate'],$e['payamount'],$e['note']);
			$count++;
		}
	}
	return $payments;
}


/**
 * function get description of payment type
 */
function ct_get_payment_description($payment_code) {
	$pa = array('transfer'=>ct('S_PARTICIPATE_PAYMENT_TRANSFER'),
				'cc'=>ct('S_PARTICIPATE_PAYMENT_CC'),
				'ccexternal'=>ct('S_PARTICIPATE_PAYMENT_CCEXTERNAL'),
				'paypal'=>ct('S_PARTICIPATE_PAYMENT_PAYPAL'),
				'cash'=>ct('S_PARTICIPATE_PAYMENT_CASH'),
		 		'cheque'=>ct('S_PARTICIPATE_PAYMENT_CHEQUE'),
		 		'fax'=>ct('S_PARTICIPATE_PAYMENT_FAX'),
				'free'=>ct('S_PARTICIPATE_PAYMENT_FREE'),
				'extra1'=>ct('S_PARTICIPATE_PAYMENT_EXTRA1'),
				'extra2'=>ct('S_PARTICIPATE_PAYMENT_EXTRA2'),
				'extra3'=>ct('S_PARTICIPATE_PAYMENT_EXTRA3'),
				''=>'UNDEFINED!');
  if (array_key_exists($payment_code, $pa))
  	return $pa[$payment_code];
  else
	return "ERROR! - Unknown payment code in ct_get_payment_desciption(): ".$payment_code;
}


/**
 * function show description of payment type in SHORT
 */
function ct_get_payment_description_short($payment_code) {
	$pa = array('transfer'=>ct('S_PARTICIPATE_PAYMENT_TRANSFER_SHORT'),
				'cc'=>ct('S_PARTICIPATE_PAYMENT_CC_SHORT'),
				'ccexternal'=>ct('S_PARTICIPATE_PAYMENT_CCEXTERNAL_SHORT'),
				'paypal'=>ct('S_PARTICIPATE_PAYMENT_PAYPAL_SHORT'),
				'cash'=>ct('S_PARTICIPATE_PAYMENT_CASH_SHORT'),
		 		'cheque'=>ct('S_PARTICIPATE_PAYMENT_CHEQUE_SHORT'),
		 		'fax'=>ct('S_PARTICIPATE_PAYMENT_FAX_SHORT'),
				'free'=>ct('S_PARTICIPATE_PAYMENT_FREE_SHORT'),
				'extra1'=>ct('S_PARTICIPATE_PAYMENT_EXTRA1_SHORT'),
				'extra2'=>ct('S_PARTICIPATE_PAYMENT_EXTRA2_SHORT'),
				'extra3'=>ct('S_PARTICIPATE_PAYMENT_EXTRA3_SHORT'),
				''=>'UNDEFINED!');
  if (array_key_exists($payment_code, $pa))
  	return $pa[$payment_code];
  else
  return "ERROR! - Unknown payment code in ct_get_payment_desciption_short(): ".$payment_code;
}

/**
 * Function to get an array with all payment modes that were used by participants of this conference.
 */
function get_applied_paymethods() {
	global $db;
	$paymethods = array();
	$r = $db->query("select paymethod from participants where paymethod!='' group by paymethod");
	if ($r && ($db->num_rows($r) > 0)) {
		for ($i=0; $i < $db->num_rows($r); $i++) {
			$e = $db->fetch($r);
			$paymethods[] = $e['paymethod'];
		}
	}
	return $paymethods;
}	

/**
 * Get array of applied payment methods in this conference with description for select boxes.
 *
 * @return array 
 */
function ct_list_paymethods() {
	$pm = get_applied_paymethods();
	$paymethods = array();
	foreach ($pm as $p) $paymethods[] = array($p, ct_get_payment_description($p));
	return $paymethods;
}

/**
 * Show list of payments: Based on suggestions by Antony Holder
 * prints a table of payment data for customer with $id
 * 
 * @param CTParticipation $participation participant object
 * @param string $width width of table
 * @param string $align alignment of table
 */
function ct_show_payments($participation, $width="100%", $align="left") {
	$payments = ct_list_payments($participation->person->get_id());
	echo "<div align='$align'>\n";
	echo "<table width=\"$width\" cellspacing=1 cellpadding=2 border=0>\n";
	echo "<tr><td colspan=3 class=\"mediumbg_gradient\"><span class=\"fontbold font10\">".ct('S_MANAGE_PAYMENTS_SHOW_ENTERED_PAYMENTS_HEADING')."</span></td></tr>\n";
	if ( count($payments) == 0) {
		echo " <tr>\n";
		echo "  <td colspan=2 class=\"oddrow\"><span class=\"fontbold font10\">".ct('S_MANAGE_PAYMENTS_NO_PAYMENTS')."</span></td>\n";
		echo " </tr>\n";
	} else {
		foreach ($payments as $payment) {
			echo " <tr>\n";
			echo "  <td width=\"20%\" valign=top align=right class=\"oddrow\"><span class=\"fontlabel font10\">".ct('S_MANAGE_PAYMENTS_DATE').":</span> <span class=\"fontnormal font10\">".substr($payment[1],0,10)."</span></td>\n";
			echo "  <td width=\"80%\" align=left valign=top class=\"evenrow\"><span class=\"fontlabel font10\">".ct('S_MANAGE_PAYMENTS_AMOUNT').": ";
			if ($payment[3]<0)
				echo "</span><span class=\"fontnegative fontbold font10\">";
            else
				echo "</span><span class=\"fontnormal font10\">";
			echo ct_currency_format($payment[3])."</span><br>";
			#echo "<span class=\"fontlabel font9\">".ct('S_MANAGE_PAYMENTS_INFO').":</span><span class=\"fontnormal font9\"> ".strtr(ct_form_encode($payment[4]),array("+"=>"+ ","/"=>"/ ","="=>"= "))."</span>\n";
			echo "<span class=\"fontlabel font9\">".ct('S_MANAGE_PAYMENTS_INFO').":</span><span class=\"fontnormal font9\"> ".ct_form_encode(wordwrap($payment[4], 40, " ", true))."</span>\n";
			echo "</td></tr>\n\n";
		}
		echo " <tr>\n";
		echo "  <td width=\"20%\" align=right class=\"oddrow\"><span class=\"fontlabel font10\">".ct('S_PARTICIPATE_PAIDTOTAL')."</span>&nbsp;</td>\n";
		echo "  <td width=\"80%\" align=left class=\"evenrow\"><span class=\"fontbold font10\">".ct_currency_format($participation->get('payamount'))."</span></td>\n";
		echo "</tr>\n\n";
		echo "<tr>\n";
		echo "  <td width=\"20%\" align=right class=\"oddrow\"><span class=\"fontlabel font10\">".ct('S_PARTICIPATE_FEE_OPEN')."</span>&nbsp;</td>\n";
		if ($participation->get('total')!=$participation->get('payamount')) 
			echo "  <td width=\"80%\" align=left class=\"evenrow\"><span class=\"fontnegative fontbold font10\">".ct_currency_format($participation->get('total') - $participation->get('payamount'))."</span></td>\n";
		else // DONE! show in green
			echo "  <td width=\"80%\" align=left class=\"evenrow\"><span class=\"fontpositive fontbold font10\">".ct_currency_format($participation->get('total') - $participation->get('payamount'))."</span></td>\n";
		echo "</tr>\n\n";
	}
	echo " </table>\n</div>\n<BR>\n";
}


// Display how much the participant did already pay: nothing, part, fully
function ct_show_payment_info($participation) {
	ct_load_lib('participation.lib');
	ct_load_lib('datetime.lib');

	$paydate = ct_date_format($participation->get('paydate'));

	// No payment has arrived yet.
	if ($participation->get('payamount') == '0.00') {
		if ($participation->get('paymethod')!='free')  // Only display if not free of charge...
			echo "<p>".ct('S_PARTICIPATE_NOT_PAID')."</p>\n";

	// Particially or fully paid.
	} else {
		if (($participation->get('total') - $participation->get('payamount')) >= 0.01 ) {
			echo "<p class=\"oddrow_del\"><span class=\"fontbold font10\">".ct('S_PARTICIPATE_NOT_FULLY_PAID')."</span></p>\n";
		} else { // fully paid...
			echo "<p><span class=\"fontbold font10\">".ct('S_PARTICIPATE_FULLY_PAID')."</span></p>\n";
		}

		// Show single payments
		ct_show_payments($participation);

	}
}

/**
 * Shows information on payment method and offer links to fulfill payment.
 */
function ct_show_paymethod_details($participant,$showlink=false) {
	global $session;
	$user =& $session->get_user();

	if ($participant->get('paymethod')=='cc')
		echo ct('S_INVOICE_PAYMENT_CC');
	if ($participant->get('paymethod')=='cash')
		echo ct('S_INVOICE_PAYMENT_CASH');
	if ($participant->get('paymethod')=='extra1')
		echo ct('S_INVOICE_PAYMENT_EXTRA1');
	if ($participant->get('paymethod')=='extra2')
		echo ct('S_INVOICE_PAYMENT_EXTRA2');
	if ($participant->get('paymethod')=='extra3')
		echo ct('S_INVOICE_PAYMENT_EXTRA3');

	if ($participant->get('paymethod')=='transfer') {
		if ($participant->get('total')>=($participant->get('payamount'))) {
			echo ct('S_INVOICE_PAYMENT_TRANSFER')."<br>\n";;
			echo '<b>'.ct('S_INVOICE_BANK_DETAILS')."</b><br>\n";
			echo ct('S_INVOICE_ACCHOLDER').' <code>'.ctconf_get('paymentTransferAccountHolder')."&nbsp;/&nbsp;</code>\n";
			echo ct('S_INVOICE_ACCOUNTNO').' <code>'.ctconf_get('paymentTransferAccountNo')."</code><br>\n";
			echo ct('S_INVOICE_BANK_NAME').' <code>'.ctconf_get('paymentTransferBankName')."&nbsp;/&nbsp;</code>\n";
			echo ct('S_INVOICE_BANK_CODE').' <code>'.ctconf_get('paymentTransferBankCode')."</code><br>\n";
			echo '<b>'.ct('S_INVOICE_INTERNATIONAL_BANK_DETAILS')."</b><br>\n";
			echo ct('S_INVOICE_SWIFTCODE').' <code>'.ctconf_get('paymentTransferSWIFT')."</code><br>";
			echo ct('S_INVOICE_IBAN_CODE').' <code>'.ctconf_get('paymentTransferIBAN')."</code><br>\n";
			echo '<b>'.ct('S_INVOICE_TRANSFER_REASON').' '.ct('S_USER_ID')." ".$participant->person->get('ID').", ".ctconf_get('conferenceShortName')."</b><br>\n";
			#echo '<b>'.ct('S_INVOICE_TRANSFER_REASON').' '.$participant->get('invoiceNo').'&nbsp;&nbsp;'.ct('S_USER_ID')." ".$participant->person->get('ID')."</b><br>\n";
		}
	}

	if ($participant->get('paymethod')=='cheque') {
		if ($participant->get('total')>=($participant->get('payamount'))) {
			echo ct('S_INVOICE_PAYMENT_CHEQUE').'<br>';
			echo ct('S_INVOICE_PAYMENT_CHEQUE_PAYABLETO').": ";
			echo '<code>'.ctconf_get('paymentChequePayableTo')."</code><br>\n";
			if (ctconf_get('paymentChequeReceiver','')!="") {
				echo ct('S_INVOICE_PAYMENT_CHEQUE_SENDTO').":<br> ";
				echo '<code>'.ct_nl2br(ctconf_get('paymentChequeReceiver'))."</code>\n";
			}
		}
	}

	if ($participant->get('paymethod')=='fax') {
		if ($user->get_id()==$participant->get('personID')) 
			echo "<a target=\"_blank\" class=\"cmda\" href=\"".ct_pageurl('statement', array('print'=>'yes'))."\">".ct('S_INDEX_CMD_STATEMENT')."&nbsp;<img src=\"icons/newwindow.gif\" border=0></a><br>\n";
		else
			echo "<a target=\"_blank\" class=\"cmda\" href=\"".ct_pageurl('adminParticipantsStatement', array('form_userID' => $participant->get('personID'),'print' =>'yes' ))."\">".ct('S_ADMIN_PARTICIPANTS_ACTION_STATEMENT')."&nbsp;<img src=\"icons/newwindow.gif\" border=0></a><br>\n";
		echo "<div class=\"fontnormal font10\">".ct('S_INDEX_OPTION_STATEMENT')."</div>\n";
		#echo ct('S_INVOICE_PAYMENT_FAX');
	}

	if ($participant->get('paymethod')=='paypal') {  // Button for PayPal Payment
		if ($participant->get('total')>=$participant->get('payamount')) { // show only if not yet paid...
			echo ct('S_INVOICE_PAYMENT_PAYPAL');

			echo "\n\n";

			if ($showlink) {
				if (ct_test_lib('paypal.lib')) {
					ct_load_lib('paypal.lib');
					show_paypal_link($participant);
				} else {
					ct_errorbox(ct('S_ERROR_SYSTEM'),ct('S_ERROR_SYSTEM_FILENOTFOUND'));
				}					
			}
		}
	}

	if ($participant->get('paymethod')=='ccexternal') {  // Link for external payment processor...
		if ($participant->get('total')>=$participant->get('payamount')+1) { // show only if not yet paid...
			echo ct('S_INVOICE_PAYMENT_CCEXTERNAL');

			echo "\n\n";

			if ($showlink) {
				if (ct_test_lib('cc_processor_saferpay.lib')) {
					ct_load_lib('cc_processor_saferpay.lib');
					cc_show_payment_link($participant);
				} elseif (ct_test_lib('cc_processor_beanstream.lib')) {
					ct_load_lib('cc_processor_beanstream.lib');
					cc_show_payment_link($participant);
				} else {
					ct_errorbox(ct('S_ERROR_SYSTEM'),ct('S_ERROR_SYSTEM_FILENOTFOUND'));
				}
			}
		}
	}
	
}



?>