<?php

/**
 * get IP Address of Client (the user who logged in...)
 */
function ct_get_client_ip() {
   if (ct_validip($_SERVER["HTTP_CLIENT_IP"])) {
       return $_SERVER["HTTP_CLIENT_IP"];
   }
   foreach (explode(",",$_SERVER["HTTP_X_FORWARDED_FOR"]) as $ip) {
       if (ct_validip(trim($ip))) {
           return $ip;
       }
   }
   if (ct_validip($_SERVER["HTTP_X_FORWARDED"])) {
       return $_SERVER["HTTP_X_FORWARDED"];
   } elseif (ct_validip($_SERVER["HTTP_FORWARDED_FOR"])) {
       return $_SERVER["HTTP_FORWARDED_FOR"];
   } elseif (ct_validip($_SERVER["HTTP_FORWARDED"])) {
       return $_SERVER["HTTP_FORWARDED"];
   } else {
       return $_SERVER["REMOTE_ADDR"];
   }
}


/**
 * Check if IP-Address is valid, (from php.net)
 */
function ct_validip($ip) {
   if (!empty($ip) && ip2long($ip)!=-1) {
       $reserved_ips = array (
       array('0.0.0.0','2.255.255.255'),
       array('10.0.0.0','10.255.255.255'),
       array('127.0.0.0','127.255.255.255'),
       array('169.254.0.0','169.254.255.255'),
       array('172.16.0.0','172.31.255.255'),
       array('192.0.2.0','192.0.2.255'),
       array('192.168.0.0','192.168.255.255'),
       array('255.255.255.0','255.255.255.255')
       );

       foreach ($reserved_ips as $r) {
           $min = ip2long($r[0]);
           $max = ip2long($r[1]);
           if ((ip2long($ip) >= $min) && (ip2long($ip) <= $max)) return false;
       }
       return true;
   } else {
       return false;
   }
}

/**
 * function to generate username and password (if required).
 */
function generate_userandpass() {
	global $http;
	ct_load_lib('password.lib');
	// a decent username will be generated if none was entered or created before.
	if (!isset($http['form_username']) || $http['form_username']=="" ) { 
		$http['form_username'] = ct_generate_username($http['form_name'],$http['form_firstname'],$http['form_email']);
	}
	#if (!isset($http['form_pwd']) || $http['form_pwd']=="" ) { 
		# Always generate a new password, to avoid that an entered password will be sent by mail.
		$http['form_pwd']=$http['form_pwd2']=ct_randString(8, false);
	#}
}

/**
 * function to generate a decent username
 */
function ct_generate_username($name, $firstname, $email) {
	global $http;
	ct_load_lib('password.lib'); // generate random string...
	ct_load_lib('mail.lib'); // generate ascii characters...

	$name = strtolower(ereg_replace( "[^A-Za-z]", "", ct_replace_iso_chars($name)));
	$firstname = strtolower(ereg_replace( "[^A-Za-z]", "", ct_replace_iso_chars($firstname)));
	$email = strtolower(ct_replace_iso_chars($email));
	
	$username = $name; // try name of user as username
	if (ct_validate_username($username) && ct_testusername($username) == 0) return $username;
	$username = substr($firstname,0,1) . "." . $name; // f.name
	if (ct_validate_username($username) && ct_testusername($username) == 0) return $username;
	$username = substr($firstname,0,1) . $name; // fname
	if (ct_validate_username($username) && ct_testusername($username) == 0) return $username;
	$username = $name . substr($firstname,0,1); // namef
	if (ct_validate_username($username) && ct_testusername($username) == 0) return $username;
	$username = $name . "." . substr($firstname,0,1); // name.f
	if (ct_validate_username($username) && ct_testusername($username) == 0) return $username;
	$username = $firstname . "." . $name; // firstname.name
	if (ct_validate_username($username) && ct_testusername($username) == 0) return $username;
	$username = $name . "." . $firstname; // name.firstname
	if (ct_validate_username($username) && ct_testusername($username) == 0) return $username;
	$username = $name; 
	while ( true ) {
		$username .= strtolower(ct_randString(1));     // ... until unique.
		if (ct_validate_username($username) && ct_testusername($username) == 0) return $username;
	}
}


/**
 * Check if username meets requirements.
 */
function ct_validate_username($username) {
	$username=trim($username);
	if (!isset($username) || strlen($username)<=2)
		return false;
	else
		return true;
}		


/**
 * Check if username already exists in DB. Return number of found entries...
 */
function ct_testusername($u,$considerDeletedUsers=true) {
	global $db;
	if ($considerDeletedUsers)
		$r = $db->query("select ID from persons where (username='$u')");
	else
		$r = $db->query("select ID from persons where (username='$u') and (deleted=0)");
	return $db->num_rows($r);
}

?>