<?php

/**
 * ct_load_phases loads all phases from database. It checks which phases are active and
 * stores the results in the session.
 */
function ct_load_phases() {
	global $db, $session, $ctconf;

	// $id = $db->query("select ID,((to_days(now()) between to_days(starts) and to_days(ends)) and (active = 1)) as isactive from phases");
	$id = $db->query("select ID, starts, ends, (active = 1) as isactive from phases");
	$phases = array();
	$phasesends = array();
	$phasesdeactivated = array();
	if (!$id) {
	    echo "<H2 style='background: #ff8'>Database Error!</h2><code>The table 'phases' could not be found in the database '".$ctconf['db/database']."'</code></H2>";
		return false;
	}
	if ($db->num_rows($id)==0) {
	    echo "<H2 style='background: #ff8'>Database Error!</h2><code>The table 'phases' is missing essential data in your database '".$ctconf['db/database']."'</code></H2>";
    	echo "Probably the default data was not inserted.<br>";
		return false;
	}
	for ($i=0;$i < $db->num_rows($id); $i++) {
		$ph = $db->fetch($id);
		if ((ct_datetime_2_timestamp($ph['starts']) < ct_time()) && (ct_datetime_2_timestamp($ph['ends']) > ct_time())) {
			$phases[$ph["ID"]] = $ph["isactive"];
		}
		$phasesstarts[$ph["ID"]] = $ph['starts'];
		$phasesends[$ph["ID"]] = $ph['ends'];
		$phasesdeactivated[$ph["ID"]] = !$ph['isactive'];  // is phase maybe deactivated?
	}
	$session->put("phases",$phases);
	$session->put("phasesdeactivated",$phasesdeactivated);
	$session->put("phasesends",$phasesends);
	$session->put("phasesstarts",$phasesstarts);
	return true;
}

/**
 * ct_check_phases takes as argument either an array with phase IDs or a single phase ID
 * and checks if all provided phases are active at the moment. It returns true or false.
 */
function ct_check_phases($phs) {
	global $session;

	if(is_array($phs)) {
		$okay = false;
		foreach ($phs as $ph) {
			$okay = $okay || ct_check_phases($ph);
		}
		return $okay;
	} else {
		$phases = $session->get("phases");
		if($phases[$phs] == 1) {
			return true;
		} else {
			return false;
		}
	}
}

/**
 * ct_check_phase_deactivated takes as argument the name of the phase IDs 
 * and checks if it is maybe deactivated
 */
function ct_check_phase_deactivated($phs) {
	global $session;

	$phases = $session->get("phasesdeactivated");
	if($phases[$phs] == 1) {
		return true;
	} else {
		return false;
	}
}


/**
 * Checks if a phase is currently active or was already active
 *
 * @param string $phase name of the phase
 * @return boolean true if phase is active or was already active
 */
function ct_check_phase_active_or_over($phase) {
	global $session;

	$phases = $session->get("phases");
	$phasesends = $session->get("phasesends");

	if($phases[$phase] == 1 || ct_datetime_2_timestamp($phasesends[$phase])<ct_time() ) {
		return true;
	}
	return false;
}


/**
 * Get time left for this phase
 */
function ct_get_phase_timeout($phs) {
	global $session;
	$phases = $session->get("phases");
	$phasesends = $session->get("phasesends");
	if($phases[$phs] == 1) {
		return ct_datetime_2_timestamp($phasesends[$phs]);
	} else {
		return 0;
	}
}

/**
 * Get end time for this phase
 */
function ct_get_phase_end($phs) {
	global $session;
	$phases = $session->get("phasesends");
	return ct_datetime_2_timestamp($phases[$phs]);
}

/**
 * Get time left for this phase
 */
function ct_get_phase_start($phs) {
	global $session;
	$phases = $session->get("phasesstarts");
	return ct_datetime_2_timestamp($phases[$phs]);
}



/**
 * Get time left for this phase
 */
function ct_get_phase_timeout_formatted($phs) {
	global $session;
	$phases = $session->get("phases");
	$phasesends = $session->get("phasesends");
	if($phases[$phs] == 1) {
		return ct_format_timeleft(ct_time(),ct_datetime_2_timestamp($phasesends[$phs]));
	} else {
		return ct('S_ADMIN_TOOL_PHASES_ACTIVE_NO');
	}
}

/**
 * Get next submission deadline...
 */
function ct_get_next_submission_deadline() {
	ct_load_lib("papers.lib");

	global $session;

	$phases = $session->get("phases");
	$phasesends = $session->get("phasesends");
	$final_deadline = ct_datetime_2_timestamp($phasesends["submission"]);

	$types=array();
	if($phases["submission"] == 1) {
		$c = ct_get_contributiontypes();
		while (list(,$v) = each($c)) {
			// Check submission deadlines
			if ($v['active']=='true' && ct_datetime_2_timestamp($v['deadline'])>ct_time() && ct_datetime_2_timestamp($v['deadline'])<$final_deadline)
				$types['deadline:'.$v['title']] = ct_datetime_2_timestamp($v['deadline']);
			// check upload deadlines as well!
			if ($v['active']=='true' && ct_datetime_2_timestamp($v['deadline_upload'])>ct_time() && ct_datetime_2_timestamp($v['deadline_upload'])<$final_deadline)
				$types['upload_deadline:'.$v['title']] = ct_datetime_2_timestamp($v['deadline_upload']);
		}
		asort($types);	// sort array by deadline
		while (list ($key, $val) = each ($types)) {
			#echo "<br>".ct_format_timeleft(ct_time(),$val)." (".$key.") ";
			if ($val<$final_deadline) {
				return $val;
			}
		}
		return $final_deadline;
	}
}

/**
 * Get upload deadline (full papers) for a certain contribution type
 */
function ct_get_submission_deadline($ctype) {
	ct_load_lib("papers.lib");

	// Get deadline for this submission:
	$deadline = ct_datetime_2_timestamp($ctype['deadline']);
	// Limit by overall deadline...
	if ($deadline>ct_get_phase_timeout("submission") && ct_get_phase_timeout("submission")>0) $deadline=ct_get_phase_timeout("submission");
	return $deadline;
}

/**
 * Get upload deadline (full papers) for a certain contribution type
 */
function ct_get_upload_deadline($ctype) {
	ct_load_lib("papers.lib");

	// Get deadline for uploads: 1. Upload deadline from contributiontype
	$upload_deadline=ct_datetime_2_timestamp($ctype['deadline_upload']);
	// 2. use contributiontype deadline if later
	if ($upload_deadline<ct_datetime_2_timestamp($ctype['deadline']) && ct_datetime_2_timestamp($ctype['deadline_upload'])>=ct_datetime_2_timestamp($ctype['deadline']))
		$upload_deadline=ct_datetime_2_timestamp($ctype['deadline']);
	// 3. limit by total submission deadline! 
	if ($upload_deadline>ct_get_phase_timeout("submission")) $upload_deadline=ct_get_phase_timeout("submission");
	return $upload_deadline;
}


/**
 * @return text with time left
 *
 * @param $from timestamp in unix format (seconds since 1970)
 * @param $to timestamp in unix format (seconds since 1970)
 * @desc create a textual representation of the time left given in seconds.
 */
function ct_format_timeleft($from,$to) {
	ct_load_lib('datetime.lib');
	
	$daysleft  = ct_count_nights($from,$to);
	$hoursleft = ct_count_hours($from,$to);
	if ($daysleft>0)
		return ct_format_days($daysleft)." ".ct_format_hours($hoursleft);
    elseif ($hoursleft>0 and $hoursleft<3)
		return ct_format_hours($hoursleft)." ".ct_format_minutes(ct_count_minutes($from,$to))." ".ct_format_seconds(ct_count_seconds($from,$to));
    elseif ($hoursleft>0)
		return ct_format_hours($hoursleft)." ".ct_format_minutes(ct_count_minutes($from,$to));
    else
		return ct_format_minutes(ct_count_minutes($from,$to))." ".ct_format_seconds(ct_count_seconds($from,$to));
}


?>
