<?php
// ConfTool session output functions

/**
 * Show a small session header for the session overview
 *
 * @param string $page name of the current page
 * @param array $row array with the session data
 * @return string with the header in html format
 */
function get_session_header_small($page, $row, $presentations_exist=true, $editMode=false) {
	$person = new CTPerson();
	$ret = '';

	// Create title of session
	$title = stripslashes($row['shorttitle']);
	if ($row[ctlx($row,'title')]!='') { // If longtitle exisits:
		// Show "shorttitle: longtitle"
		$title = stripslashes($row['shorttitle']).": ".stripslashes($row[ctlx($row,'title')]);
		// Alternatively maybe only longtitle?
		#$title = $row[ctlx($row,'title')];
	}

	if ($presentations_exist) // create text with link
		$ret .= '<a class="fontbold font12" href="'.ct_pageurl($page, ct_http_array(array('form_session'=>$row['ID'], 'form_room'=>'', 'form_date'=>''))).'">'.$title.'</a>';
	else 
		$ret .= '<span class="fontbold font12">'.$title.'</span>';
	if ($editMode)
		$ret .= ' <a class="fontnormal font8" target="editSession" href="'.ct_pageurl('adminToolSessions',array('form_session'=>$row['ID'], 'cmd_sessions_edit'=>'')).'">('.ct('S_SESSIONS_BROWSE_EDIT_SESSION').')</a>';
	$ret .= "<br>";
		

	// Show name of chair
	if ($row['chairID']>0) {
		$ret.= '<span class="fontlabel font10">'.ct('S_SESSIONS_BROWSE_CHAIR').": </span>";
		$ret.= '<span class="fontbold font10">';
		#$ret.= ct_form_encode($row['title1']).' '.ct_form_encode($row['firstname1']).' '.ct_form_encode($row['name1']);
		$ret.= $person->get_title($row['gender1']).' ';
		$ret.= ct_form_encode($row['firstname1']).' '.ct_form_encode($row['name1']);
		$ret.= '</span><br>';
	}
	if ($row['chair2ID']>0) {
		$ret.= '<span class="fontlabel font10">'.ct('S_SESSIONS_BROWSE_CHAIR').": </span>";
		$ret.= '<span class="fontbold font10">';
		#$ret.= ct_form_encode($row['title2']).' '.ct_form_encode($row['firstname2']).' '.ct_form_encode($row['name2']);
		$ret.= $person->get_title($row['gender2']).' ';
		$ret.= ct_form_encode($row['firstname2']).' '.ct_form_encode($row['name2']);
		$ret.= '</span><br>';
	}

	// Display additional info about session
	if ($row['info']!="") {
		$ret.= '<span class="fontnormal font10">'.stripslashes($row[ctlx($row,'info')]).'</span>';
	}
	return $ret;
}

function create_numberInTrack($sessionID=0) {
	ct_load_lib('papers.lib');
	global $db;

	if ($sessionID<1) 
		$a = ct_get_sessions();
	else
		$a = array('ID'=>$sessionID);
		
	foreach ($a as $s) {
		##echo "<br>".$s['ID'].": ";
	
		$r= $db->select("papers","*","withdrawn=0 AND track='".$s['ID']."'","numberInTrack, title");
		if ($r) {
			$num = $db->num_rows($r);
			for ($i = 1; $i <= $num; $i++) {
				##echo "$i, ";
				$row = $db->fetch($r);
				$paperID = $row['ID'];
				if ($row['numberInTrack']!=$i && $paperID>0) 
					$db->update("papers","ID='$paperID' LIMIT 1",array("numberInTrack"=>$i));
			}
		}
	}
}

function get_max_numberInTrack($session) {
	global $db;
	$r= $db->select("papers","MAX(numberInTrack) as max","withdrawn=0 AND track='$session'");
	if ($r && $db->num_rows($r)==1) {
		$row = $db->fetch($r);
		return $row['max'];
	}
	return 1;
}


/**
 * Get the header of a session for the detail view
 *
 * @param array $row array with the session data
 * @return string with the header in html format
 */
function get_session_header($session, $editMode=false) {
	$ret = '';
	$ret .= "<tr><td class=\"whitebg topline_printonly\" align=left valign=top>\n";
	$row = ct_get_sessions($session);
	if (is_array($row)) {
		if ($editMode)
			$ret .= ' <a class="fontnormal font8" target="editSession" href="'.ct_pageurl('adminToolSessions',array('form_session'=>$row['ID'], 'cmd_sessions_edit'=>'')).'">('.ct('S_SESSIONS_BROWSE_EDIT_SESSION').')</a><br>';
		$ret.= '<h1>'.stripslashes($row['shorttitle']).': '.stripslashes($row[ctlx($row,'title')])."</h1>\n";

		$ret.= '<p><span class="fontlabel font10">'.ct('S_SESSIONS_BROWSE_TIME').": </span>";
		$ret.= '<span class="fontbold font10">';
		$ret.= ct_get_dow($row['starttime']).', ';
		$ret.= ct_date_format($row['starttime']);
		$ret.= ': ';
		$ret.= ct_time_format($row['starttime']);
		if ($row['starttime']>0 && $row['endtime']!=$row['starttime'])
			$ret.= ' - '.ct_time_format($row['endtime']).'</span></p>';
		if ($row['chairID']>0) {
			$ret.= '<p><span class="fontlabel font10">'.ct('S_SESSIONS_BROWSE_CHAIR').": </span>";
			$ret.= '<span class="fontbold font10">';
			$person = new CTPerson();
			if ($person->load_by_id($row['chairID']))
				$ret.= ct_form_encode($person->get_fullname());
			$ret.= '</span></p>';
		}
		if ($row['roomID']>0) {
			$ret.= '<p><span class="fontlabel font10">'.ct('S_SESSIONS_BROWSE_ROOM').":</span> ";
			$ret.= '<span class="fontbold font10">';
			$ret.= ct_get_session_room($row['roomID']).'</span>';
			if ($editMode)
  			   $ret.= ' <a class="fontnormal font8" target="editRoom" href="'.ct_pageurl('adminToolSessionRooms',array('form_room'=>$row['roomID'], 'cmd_session_rooms_edit'=>'')).'">('.ct('S_SESSIONS_BROWSE_EDIT_ROOM').')</a>';
			$ret.= '</p>';
		}
		if ($row['info']!="") {
			$ret.= '<p>';
			$ret.= '<span class="fontnormal font10">';
			$ret.= stripslashes($row[ctlx($row,'info')]).'</span></p>';
		}
	}
	$ret.= "\n<br>\n";
	$ret.= "</td></tr>\n";
	return $ret;
}

/**
 * Show all presentations in the resultset.
 *
 * @param resultset $result resultset with the presentation to be shown.
 * @param boolean $metadata show metadata of the presentations?
 * @param boolean $abstracts show abstracts of the presentations?
 * @param boolean $downloads show downloads?
 */
function show_session_presentations($result,$metadata=false,$abstracts=false,$downloads=false) {
	global $http, $db;
	$paper  = new CTPaper();

	$num = $db->num_rows($result);
	for ($i = 0; $i < $num; $i++) {
		$row = $db->fetch($result);
		#$paper->load_by_id($row['ID']);
		$paper->pdata = $row;	

		// Get correct paper class name
		$classname = $paper->get_paperClass();
		ct_load_class($classname);
		eval('$paperclass = new '.$classname.'();');
		$paperclass = ct_type_cast($paper,$classname);

		$sess  = ct_get_session($paperclass->get('track'));
		$ctype = $paperclass->_get_contributiontype();

		// Show formatted details about presentation
		$paperclass->show_formatted($metadata,$abstracts && $sess['show_abstracts']=='true');

		if ($sess['show_downloads']=='true' && $downloads) {
			// "Estimate" version:. If final version exists for this contribution, then take final version
			$version='';
			if ($paperclass->get('originalname_final')!='') $version='final';
			if ($paperclass->_number_of_uploads_for_contributiontype('',$version)>0) {
				echo "<table border=0 cellpadding=3 cellspacing=0 width='100%'>";
				$paperclass->show_all_download_links($version, 1, 'class="brightbg"', '8');
				echo "</table>\n";
			}
		}
		if ($i+1 < $num) {
			if (in_http('print') &&  $http['print']=="yes" && $http['page']=='adminSessionsBrowse') {
				echo "\n\n---<br>\n\n";
			} else {
				echo '<hr noshade width="100%" align=left>';
			}
		}
		
		
	}
}	



?>