<?php
//
// PAGE:		adminImport
// DESC:		Import data into database from CSV file
//

ct_requireassistantorconferencechair();
ct_pagepath(array('index','adminTool'));

// Increase maximum execution time
if( !ini_get('safe_mode') ){
	// Does _not_ work in SAFE MODE
	set_time_limit(300); // 300s
}
ob_end_flush();


// File name on server. Will be stored in upload directory
$uploaddir = ct_get_path('uploads');
$savename = $uploaddir."import_".$user->get_id().".csv";

// Main fields of database persons (users)
$fields_users=array('---','name'=>'Name', 'firstname'=>'FirstName', 'email'=>'E-Mail', '---',
					'title'=>'Acad.Title', 'gender'=>'GenderCode',
					'organisation'=>'Organiz.', 'addr1'=>'Addr. 1', 'addr2'=>'Addr.2',
					'zip'=>'Zipcode', 'City', 'state'=>'StateCode', 'country'=>'CountryC.',
					'Phone', 'Fax', 'email2'=>'E-Mail 2', 'url'=>'Homepage', '---',
					'status'=>'Status/Role','username'=>'User Name','Password');
$fields_users_required=array('name'=>'required','firstname'=>'','email'=>'email'); // required=field must not be empty, e-mail=field must contain a valid e-mail address

# ct_print_r($http); // Debugging: Output all form data.

// Step 2: Preview import data, assign columns
if (isset($http['cmd_import_preview']) || isset($http['cmd_import_step2'])) { // && isset($http['form_filename'])) {
	$form_errors =  check_input_form_data();
	if (isset($http['cmd_import_preview']))	{
		$upload_filename = process_upload($savename);
		if ($upload_filename=='') $form_errors[]='form_filename';
	}
	if (count($form_errors)>0) {
		show_import_form($form_errors);
	} else {
		preview1_select_columns($savename,$fields_users,$fields_users_required);
	}
// Step 3: Check data and select rows to import.
} elseif (isset($http['cmd_import_check'])) { // Check if all import settings are fine...
	$form_errors =  check_input_form_data();
	if (count($form_errors)>0) {
		show_import_form($form_errors);
	}
	$import_ok = check_import_settings($fields_users,$fields_users_required);
	if (!$import_ok) { // try again!
		preview1_select_columns($savename,$fields_users,$fields_users_required);
	} else {
		preview2_select_rows($savename,$fields_users,$fields_users_required);
	}
// Step 4: Do data import.
} elseif (isset($http['cmd_import_do'])) { // Do Import
	$form_errors =  check_input_form_data();
	if (count($form_errors)>0) {
		show_import_form($form_errors);
	}
	$import_ok = check_import_settings($fields_users,$fields_users_required);
	if (!$import_ok) { // try again!
		preview1_select_columns($savename,$fields_users,$fields_users_required);
	} else {
		do_import_persons($savename,$fields_users);
	}
} else { // No special parameters - show step 1 input form.
	show_import_form();
}


/// -------------------------------------------------------------------------
/// Import functions.
/// -------------------------------------------------------------------------

/**
 * STEP 1: Show data import form. The upload file and the format are selected.
 *
 * @param array $form_errors array with erroneous fields.
 */
function show_import_form($form_errors=array()) {

	global $http;
	$page=$http['page'];
	ct_load_class('CTForm');

	echo "<h1>".ct('S_ADMIN_IMPORT')."</h1>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_ADMIN_IMPORT_INTRO')."</p>\n";
	echo "<p class=\"fontbold font10\">".ct('S_ADMIN_IMPORT_STEP1')."</p>\n";

	$form = new CTform(ct_pageurl($page), 'post', $form_errors);
	$form->width='600';
	$form->align='center';
	$form->add_separator(ct('S_ADMIN_IMPORT_SETTINGS'));
	$form->add_upload(ct('S_ADMIN_IMPORT_FILENAME'), 'form_filename', '50', ctconf_get('paperupload/maxsize'));

	// Mode: Import what kind of data and what to do with it.
    $list_mode = array(array('users',ct('S_ADMIN_IMPORT_MODE_USERS')) );
	$form->add_select(ct('S_ADMIN_IMPORT_MODE'),'form_mode', 1, $list_mode, array($http['form_mode']), false );
	// Header y/n
    $form->add_select(ct('S_ADMIN_IMPORT_CSVHEADER'), 'form_csvheader', 1, array(array('1',ct('S_YES')),array('0',ct('S_NO'))), array($http['form_csvheader']), false);
    // delimiter: , ; tab space
    $list_delimiter = array(array(';',';'), array(',',','), array(' ',ct('S_ADMIN_IMPORT_DELIMITER_SPACE')), array('tab',ct('S_ADMIN_IMPORT_DELIMITER_TAB')) );
	$form->add_select(ct('S_ADMIN_IMPORT_DELIMITER'),'form_delimiter', 1, $list_delimiter, array($http['form_delimiter']), false );
	// Enclose Char: ' "  none
    $list_enclose = array(array('"','"'), array('\'','\''), array('none',ct('S_ADMIN_IMPORT_ENCLOSE_NONE')) );
	$form->add_select(ct('S_ADMIN_IMPORT_ENCLOSE'),'form_enclose', 1, $list_enclose, array($http['form_enclose']), false );
	// Encoding: ???
    #$list_encoding = array(array('de_DE','de_DE') );
	#$form->add_select(ct('S_ADMIN_IMPORT_ENCODING'),'form_encoding', 1, $list_encoding, array($http['form_encoding']), false );
	// Escape Char: "\"
    $list_escape = array(array(addslashes('\\'),addslashes('\\')),array('',ct('S_ADMIN_IMPORT_ENCLOSE_NONE')) ); // Yes, you need 4 "\"
	$form->add_select(ct('S_ADMIN_IMPORT_ESCAPE'),'form_escape', 1, $list_escape, array($http['form_escape']), false );
	// Preview lines: 20, 50, all
    $list_preview = array(array('10',ct('S_ADMIN_IMPORT_PREVIEW_X',array('10'))), array('25',ct('S_ADMIN_IMPORT_PREVIEW_X',array('25'))), array('100',ct('S_ADMIN_IMPORT_PREVIEW_X',array('100'))), array('999999',ct('S_ADMIN_IMPORT_PREVIEW_ALL')) );
	$form->add_select(ct('S_ADMIN_IMPORT_PREVIEW'),'form_preview', 1, $list_preview, array($http['form_preview']), false );
	$form->add_submit('cmd_import_preview', ct('S_ADMIN_IMPORT_SUBMIT1'));

	if (ctconf_get('demomode')) $form->demomode=true;
	$form->show();

}

/**
 * Step 2: First preview of Data to import. Here the columns are assigned.
 *
 * @param unknown_type $upload_filename
 * @param unknown_type $fieldnames
 */
function preview1_select_columns($upload_filename,$fieldnames, $required_fieldnames) {
	global $http, $session;
	$page=$http['page'];

	echo "<h1>".ct('S_ADMIN_IMPORT')."</h1>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_ADMIN_IMPORT_STEP2')."</p>\n";

	if (!$myFile = @fopen($upload_filename, "r")) {
		$session->put_errorbox(ct('S_ADMIN_IMPORT_ERROR'),ct('S_ADMIN_IMPORT_ERROR_FILENOTFOUND',array($upload_filename)));
		ct_redirect(ct_pageurl('$page'));
	} else {
		$line = 0;
		$maxCols = 0;
		$delimiter = stripslashes($http['form_delimiter']);
		$enclosure = stripslashes($http['form_enclose']);
		$escape	   = stripslashes($http['form_escape']);
		$header    = stripslashes($http['form_csvheader']);
		$encoding  = stripslashes($http['form_encoding']);
		$maxLines  = (int)$http['form_preview'];
		#setlocale(LC_CTYPE,$encoding); // set
		#setlocale(LC_ALL,null); // reset
		#ct_print_r($http);

		// create preview of imput data
		$in_string = '';
		if ($myFile) {
			while (!feof($myFile)) { $in_string .= fread($myFile, 524288); }
		}
		$in_array = parse_CSV_string($in_string,$delimiter,$enclosure,$escape);
		
		#while (($line < $maxLines) && $data = fgetcsv($myFile, 32768, $delimiter, $enclosure)) {
		foreach ($in_array as $data) {
			if ($line>=$maxLines) break; // quit the loop...
			$numOfCols = count($data);
			if ($numOfCols>50) $numOfCols=50; // sanitize
			if ($numOfCols > $maxCols) $maxCols = $numOfCols;

			if ($header && $line==0) // show first row in gray
				$preview_block .= "\n\t<tr class=\"".($line%2?'oddrow2':'evenrow2')." fontbold\">";
			else
				$preview_block .= "\n\t<tr class=\"".($line%2?'oddrow':'evenrow')."\">";

			for ($index = 0; $index < $numOfCols; $index++) {
				$field = $data[$index];
				if ($escape=="\\") $field = stripslashes($field);
				if (strlen($field) > 10) $field = substr($field, 0,8) . '..';
				if ($field == "") $field = "&nbsp;";
				$preview_block .= "\n\t\t<td class='font8 ".(($header && $line==1)?"topline_black":"")."'>$field</td>";
			}
			$preview_block .= "\n\t</tr>";
			$line++;
		}

		$echo = "<table cellspacing=\"0\" cellpadding=\"2\" border=\"0\">";
		$echo .= "<tr class='listheader'>";

		// Create table header (now, as the number of columns had to be determined before.
		for ($index = 0; $index < $maxCols; $index++) {
			$echo .= "\n\t<td class=\"font8\"> ";
			$echo .= ct('S_ADMIN_IMPORT_COLUMN',array($index+1)).'<br>';
			$echo .= "\n\t<select size=1 class=\"optionsmall\" name=\"form_column_$index\"\">";
			// add a select box with all field names
			foreach ($fieldnames as $k=>$v) {
				if (is_int($k)) $k=$v;	// if no key was given, use value as key.
				$echo .= "\n\t\t<option class=\"optionsmall ".(array_key_exists($k,$required_fieldnames)?"yellowbg":"")."\" value=\"".$k."\" ".( (isset($http["form_column_$index"]) && $k==$http["form_column_$index"]) ? "selected" : "").">".$v."</option>";
			}
			$echo .= "\n\t</select>";
			"\n\t</td>";
		}

		$echo .= "\n\t</tr>" . $preview_block . "</table>";
	}

	if ($myFile) fclose($myFile);

	// Create Preview!
	echo "<form action=\"".ct_pageurl($page)."\" method=\"POST\">";

	echo $echo;

	echo '<input type="hidden" name="form_maxcol" value="'.$maxCols."\">\n";
	echo get_hidden_input_fields();
	echo "<input class=\"button\" type=\"submit\" name=\"cmd_import_step1\" value=\"".ct('S_ADMIN_IMPORT_BACK',array('1'))."\">\n";
	echo "<input class=\"button\" type=\"submit\" name=\"cmd_import_check\" value=\"".ct('S_ADMIN_IMPORT_SUBMIT2')."\">\n";

	echo "</form>";

}

/**
 * Step 3: Second preview: Show how all data will be imported and select rows to import. Provide extra settings.
 *
 * @param string $upload_filename local filename of import file
 * @param array $fieldnames array with all field names
 * @param array $required_fieldnames array with all field names that have to be selected.
 */
function preview2_select_rows($upload_filename,$fieldnames,$required_fieldnames) {
	global $http, $session;
	$page=$http['page'];

	echo "<h1>".ct('S_ADMIN_IMPORT')."</h1>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_ADMIN_IMPORT_STEP3')."</p>\n";

	if (!$myFile = @fopen($upload_filename, "r")) {
		$session->put_errorbox(ct('S_ADMIN_IMPORT_ERROR'),ct('S_ADMIN_IMPORT_ERROR_FILENOTFOUND',array($upload_filename)));
		ct_redirect(ct_pageurl('$page'));
	} else {
		$echo = "";
		$line = 0;
		$lines_valid = 0;
		$delimiter = stripslashes($http['form_delimiter']);
		$enclosure = stripslashes($http['form_enclose']);
		$escape	= stripslashes($http['form_escape']);
		$header = stripslashes($http['form_csvheader']);
		$encoding = stripslashes($http['form_encoding']);
		#setlocale(LC_CTYPE,$encoding); // set
		#setlocale(LC_ALL,null); // reset
		#ct_print_r($http);

		$i=0;
		$columns = array();
		while (isset($http['form_column_'.$i])) {
			if ($http['form_column_'.$i]!='') $columns[] = $http['form_column_'.$i];
			$i++;
		}

		// Start output: create form element.
		$echo .= "<form action=\"".ct_pageurl($page)."\" method=\"POST\">";
		#$echo .= "<input class=\"button\" type=\"submit\" name=\"cmd_import_step2\" value=\"".ct('S_ADMIN_IMPORT_BACK',array('2'))."\"><br>\n";

		// JavaScript to Check/Uncheck all checkboxes.
		ct_load_lib("javascript.lib");
		$function_name = "checkAll";
		$checkbox_name = "form_import_rows[]"; //
		$echo .= get_js_checkbox_selector($function_name,$checkbox_name);

		// open table
		$echo .= "<table cellspacing=\"0\" cellpadding=\"2\" border=\"0\">";
		$echo .= "<tr class='listheader'>";

		// add "global" checkbox to set/unset all checkboxes.
		$echo .= "<td align=right valign=top><span class=\"fontnormal font10\"><input type=\"checkbox\" class=\"checkboxradio\" checked onclick=\"$function_name(this);\"></span></td>\n";

		// Create table header
		$i=0;
		$selected_fields = array();
		foreach ($fieldnames as $k=>$v) {
			$column = (in_array($k,$columns)?array_search($k,$columns):-1);
			if ($column>=0 && $k!="" && $k!="---") {
				$echo .= "\n\t<td class=\"font8 fontbold\">$v</td>";
				$selected_fields[]=$column;
			}
		}
		$echo .= "\n\t</tr>";

		// check and show all rows...
		$in_string = '';
		if ($myFile) {
			while (!feof($myFile)) { $in_string .= fread($myFile, 524288); }
		}
		$in_array = parse_CSV_string($in_string,$delimiter,$enclosure,$escape);
		#while ($data = fgetcsv($myFile, 32768, $delimiter, $enclosure)) {
		foreach ($in_array as $data) {
			#ct_print_r($data);
			$numOfCols = count($data);

			if ($header && $line==0) {
				# Skip first line
			} else {

				$row = '';
				$valid_row = true;

				for ($i = 0; $i < count($selected_fields); $i++) {
					$field = trim($data[$selected_fields[$i]]);
					if ($escape=="\\") $field = stripslashes($field);
					$colname = $http['form_column_'.$selected_fields[$i]];

					// check value of this field?
					if (isset($required_fieldnames[$colname]))
						$field_value_ok = check_import_field_value($field, $required_fieldnames[$colname]); // check if this field has a valid value.
					else
						$field_value_ok = true;

					// Do some formatting for screen output
					if (strlen($field) > 40) $field = substr($field, 0,37) . '..';

					// did field pass the check? otherwise hightlight field and do not add checkbox.
					if ($field_value_ok) {
						if ($field == "") $field = "&nbsp;";
						if ($colname=="gender") ($field=$field." (".get_gender_code($field).")");
						$row .= "\n\t\t<td class='font8'>$field</td>";
					} else {
						if ($field == "") $field = "<i>".ct('S_ADMIN_IMPORT_ERROR_MISSINGFIELD')."</i>";
						$row .= "\n\t\t<td class='font8 fontnegative fontbold'>$field</td>";
						$valid_row = false;
					}
				}


				// add check box only if row is valid!
				if ($valid_row) {
					$echo .= "\n\t<tr class=\"".($line%2?'oddrow':'evenrow')."\">";
					$echo .= "\n\t<td align=right valign=top><span class=\"fontnormal font8\"><input type=\"checkbox\" class=\"checkboxradio\" name=\"$checkbox_name\" value=\"".$line."\" checked></span></td>\n";
					$lines_valid++;
				} else {
					$echo .= "\n\t<tr class=\"".($line%2?'oddrow_del':'evenrow_del')."\">";
					$echo .= "\n\t<td align=right valign=top><span class=\"fontnormal font8\">&nbsp;</span></td>\n";
				}
				$echo .= $row;
				$echo .= "\n\t</tr>";
			}
			$line++;
		}

		$echo .= "\n\t</tr></table>";
	}

	if ($myFile) fclose($myFile);

	echo $echo;

	$http_vars = hash2aa(ct_http_array(array('cmd_import_check'=>''))); // list all http variables with values
	if (sizeof($http_vars) > 0) {
		while (list(,$h) = each($http_vars)) echo "<input type=\"hidden\" name=\"".ct_form_encode_noentities($h[0])."\" value=\"".ct_form_encode_noentities(addslashes($h[1]))."\">\n";
	}
	if ($lines_valid>0) {
		echo get_extra_options_users();
		echo "<input class=\"button\" type=\"submit\" name=\"cmd_import_step2\" value=\"".ct('S_ADMIN_IMPORT_BACK',array('2'))."\">\n";
		echo "<input class=\"button\" type=\"submit\" name=\"cmd_import_do\" value=\"".ct('S_ADMIN_IMPORT_SUBMIT3')."\">\n";
	} else {
		echo "<h3>".ct('S_ADMIN_IMPORT_ERROR_NO_VALID_LINES')."</h3>\n";
		echo "<input class=\"button\" type=\"submit\" name=\"cmd_import_step2\" value=\"".ct('S_ADMIN_IMPORT_BACK',array('2'))."\">\n";
	}
	echo "</form>";
}



/**
 * Step 4: do the data import
 *
 * @param string $upload_filename local filename of import file
 * @param array $fieldnames array with all field names
 */
function do_import_persons($upload_filename,$fieldnames) {
	global $http, $session, $db;
	$page=$http['page'];

	ct_load_class('CTPerson');
	ct_load_lib('person.lib');
	ct_load_lib('password.lib');
	ct_load_lib('mail.lib');
	ct_load_lib('mail_person.lib');
	ct_load_lib('datetime.lib');

	echo "<h1>".ct('S_ADMIN_IMPORT')."</h1>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_ADMIN_IMPORT_STEP4')."</p>\n";

	$line_imported = 1;

	if (!$myFile = @fopen($upload_filename, "r")) {
		$session->put_errorbox(ct('S_ADMIN_IMPORT_ERROR'),ct('S_ADMIN_IMPORT_ERROR_FILENOTFOUND',array($upload_filename)));
		ct_redirect(ct_pageurl('$page'));
	} else {
		$line = 0;
		$delimiter = stripslashes($http['form_delimiter']);
		$enclosure = stripslashes($http['form_enclose']);
		$escape	= stripslashes($http['form_escape']);
		$header = stripslashes($http['form_csvheader']);
		$encoding = stripslashes($http['form_encoding']);
		#setlocale(LC_CTYPE,$encoding); // set
		#setlocale(LC_ALL,null); // reset
		#ct_print_r($http);
		$import_rows = $http['form_import_rows']; // Array with all rows to import

		$i=0;
		$columns = array();
		while (isset($http['form_column_'.$i])) {
			if ($http['form_column_'.$i]!='') $columns[] = $http['form_column_'.$i];
			$i++;
		}

		$echo = "<table cellspacing=\"0\" cellpadding=\"2\" border=\"0\">";
		$echo .= "<tr class='listheader'>";

		$echo .= "\n\t<td class=\"font8\">".ct('S_ADMIN_IMPORT_LINE')."</td>";

		// Create table header (now, as the number of columns was determined above.
		$i=0;
		$selected_fields = array();
		$field_names = array();
		foreach ($fieldnames as $k=>$v) {
			$column = (in_array($k,$columns)?array_search($k,$columns):-1);
			if ($column>=0 && $k!="" && $k!="---") {
				$selected_fields[]=$column;
				$field_names[]=$k;
				if ($k!="username" && $k!="status" && $k!="password")
					$echo .= "\n\t<td class=\"font8\">$v</td>";
 			}
		}
		$echo .= "\n\t<td class=\"font8\">".$fieldnames['status']."</td>";
		$echo .= "\n\t<td class=\"font8\">".$fieldnames['username']."</td>";
		$echo .= "\n\t<td class=\"font8\">".$fieldnames['password']."</td>";
		if (in_http('form_user_sendmail','do')) {
			$echo .= "\n\t<td class=\"font8\">".ct('S_ADMIN_EMAIL_SENT_STATUS')."</td>";
		}
		$echo .= "\n\t</tr>";

		echo $echo;
		$echo = "";

		// create preview of imput data
		$in_string = '';
		if ($myFile) {
			while (!feof($myFile)) { $in_string .= fread($myFile, 524288); }
		}
		$in_array = parse_CSV_string($in_string,$delimiter,$enclosure,$escape);
		
		#while ($data = fgetcsv($myFile, 32768, $delimiter, $enclosure)) {
		foreach ($in_array as $data) {
			#ct_print_r($data);
			$numOfCols = count($data);

			$person = new CTPerson();

			if ($header && $line==0) {
				# Skip first line.
			} elseif (!is_array($import_rows) || !in_array($line,$import_rows)) {
				# This line was not checked and shall not be imported.
			} else {
				$echo = "";
				$echo .= "\n\t\t<td class='font8'>$line_imported</td>";
				for ($i = 0; $i < count($selected_fields); $i++) {
					$field = $field_names[$i];
					$value = trim($data[$selected_fields[$i]]);
					if ($field=="gender") ($value=get_gender_code($value));
					if ($escape=="\\") $value = stripslashes($value);
					$person->set($field,$value);
					if ($field!="username" && $field!="status" && $field!="password") // do not output, yet.
						$echo .= "\n\t\t<td class='font8'>".ct_form_encode($value)."</td>";
				}

				echo "\n\t<tr class=\"".($line_imported%2?'oddrow':'evenrow')."\">";
				echo $echo;

				// Set user status.
				if (isset($http['form_user_status']) && is_array($http['form_user_status']) && in_array('reviewer',$http['form_user_status'])) $person->add_status('reviewer');
				if (isset($http['form_user_status']) && is_array($http['form_user_status']) && in_array('pc',$http['form_user_status'])) $person->add_status('pc');
				if (isset($http['form_user_status']) && is_array($http['form_user_status']) && in_array('chair',$http['form_user_status'])) $person->add_status('chair');
				if (isset($http['form_user_status']) && is_array($http['form_user_status']) && in_array('frontdesk',$http['form_user_status'])) $person->add_status('frontdesk');
				$person->remove_status('author'); // Has not submitted yet => is no author!
				$person->remove_status('participant'); // Is not registered yet => is no participant!
				echo "\n\t\t<td class='font8'>".str_replace(",",", ",$person->get('status'))."</td>";

				// Check username: Remove spaces, check if unique and long enough. Maybe create new username.
				$username = str_replace(" ", "", $person->get('username'));
				if (!ct_validate_username($username) || ct_testusername($username,true)>0 ) {
					$username=ct_generate_username($person->get('name'), $person->get('firstname'), $person->get('email') );
					$person->set('username',$username);
				}
				echo "\n\t\t<td class='font8'>$username</td>";

				// Check and create password.
				$password = $person->get('password');
				if (count(ct_validate_password($password))>0) {
					$password=ct_randString(8, false);
					$person->set('password',$password);
				}
				echo "\n\t\t<td class='font8'>$password</td>";

				if (in_http('form_user_sendmail','do')) {
					// Get text about user status (mail_person.lib).
					$extratext = ct_mail_get_userstatustext($person);
					if (in_http('form_user_mail_extratext')) $extratext.="\n".$http['form_user_mail_extratext'];
					$s = ct_mail_user_registration_confirmation($person,true,$extratext);
					if ($s!=0) echo "\n\t\t<td class=\"fontnormal font8\">".ct('S_ADMIN_EMAIL_SENT_SUCCESS')."</td>\n";
					else    echo "\n\t\t<td class=\"yellowbg fontbold fontnegative font8\">".ct('S_ADMIN_EMAIL_SENT_FAILED')."</td>\n";
				}

				$person->set('internalremark',ct('S_ADMIN_IMPORT_REMARK',array(html_entity_decode(ct_datetime_format(ct_time())))));
				$person->persist(false); // Save without encrypting the password now.
 				###$person->set('deleted',1); $person->persist(false); // After person got ID it can be deleted, not before.

				echo "\n\t</tr>";
				$line_imported++;
				if (($line_imported % 5) == 4) {
					ob_flush();	flush();
				}
			}
			$line++;
		}

		echo "\n\t</tr></table>\n";

	}
	if ($myFile) fclose($myFile);

	echo "<h3>".ct('S_ADMIN_IMPORT_LINES_IMPORTED',array(($line_imported-1)))."</h3>\n";

	echo "<p><a href=\"".ct_pageurl('adminUsersBrowse')."\" class=\"yellowbg fontbold font12\">".ct('S_PARTICIPATE_CONTINUE')."</a></p>";

}




/**
 * Check if import settings are OK, i.e. all required fields are selected and none is selected twice.
 *
 * @param unknown_type $fieldnames
 * @param unknown_type $required_fieldnames
 * @return unknown
 */
function check_import_settings($fieldnames, $required_fieldnames) {
	global $http;
	$columns = array();
	$i=0;
	while (isset($http['form_column_'.$i])) {
		$columns[] = $http['form_column_'.$i];
		$i++;
	}
	foreach ($required_fieldnames as $k=>$v) {
		if (!(in_array($k, $columns))) {
			ct_errorbox(ct('S_ADMIN_IMPORT_ERROR'),ct('S_ADMIN_IMPORT_ERROR_MISSINGCOLUMN',array(($fieldnames[$k]!=''?$fieldnames[$k]:$k))));
			return false;
		}
	}
	foreach ($columns as $k=>$v) {
		if ($v!='' && $v!='---' && array_search($v,$columns)!=$k) {
			ct_errorbox(ct('S_ADMIN_IMPORT_ERROR'),ct('S_ADMIN_IMPORT_ERROR_DOUBLECOLUMN',array(($fieldnames[$v]!=''?$fieldnames[$v]:$v))));
			return false;
		}
	}
	return true;
}




/**
 * STEP 2: Process upload of import file
 */
function process_upload($savename) {
	global $http, $_FILES;

	$uploaddir = ct_get_path('uploads');

	//check if the directory is writable.
    if (!is_writeable($uploaddir)){
   		die ("<H3>ConfTool SETUP ERROR</H3> The directory <b><code>".$uploaddir."</code></b> is NOT writable.");
    }

	$f_name		=$_FILES['form_filename']['name'];
	$f_tmp_name	=$_FILES['form_filename']['tmp_name'];
    $f_size		=$_FILES['form_filename']['size'];
    if ($f_name != 'none' && $f_name != '' ) {
		if (is_uploaded_file($f_tmp_name)) {
			$tmp_name = ct_get_path('uploads').rawurlencode($f_name);
			@unlink($savename); // delete old file if it exists, down't show error if it doesn't
			if (move_uploaded_file($f_tmp_name, $tmp_name)) {
				chmod($tmp_name, 0666);
				$upload_file = fopen($tmp_name,"r");
				$fileContents = @fread($upload_file, filesize($tmp_name));
				if (strlen($fileContents) != 0) {
					if (strlen($fileContents) > 10 && strlen($fileContents) < ctconf_get('paperupload/maxsize')) {
						fclose($upload_file);
						// Move file and set permissions.
						if (rename($tmp_name, $savename)) {
							chmod($savename, 0666); // Allow access also for conftool user (not only for web-server...)

							#echo('filename '. 	addslashes($savename)."<br>\n");
							#echo('originalname '. addslashes($f_name)."<br>\n");
							#echo('lastupload '.	ct_timestamp_2_datetime(ct_time())."<br>\n");
							ct_infobox($file_number_text.ct('S_ADMIN_IMPORT_INFO_UPLOAD'), ct('S_ADMIN_IMPORT_INFO_UPLOAD_MESSAGE'));
							return $savename; // Big success...
						} else {
							ct_errorbox($file_number_text.ct('S_ADMIN_IMPORT_ERROR'), ct('S_ERROR_PAPER_UPLOAD_COPYFILE'));
							@unlink($tmp_name);
						}
					} else {
						ct_errorbox($file_number_text.ct('S_ADMIN_IMPORT_ERROR'), ct('S_ERROR_PAPER_UPLOAD_FILESIZE')." ".strlen($fileContents)." Bytes.");
						fclose($upload_file);
						@unlink($tmp_name);
					}
				} else {
					ct_errorbox($file_number_text.ct('S_ADMIN_IMPORT_ERROR'), ct('S_ERROR_PAPER_UPLOAD_NOT_FOUND'));
					chmod($tmp_name, 0666);
					$upload_file = fopen($tmp_name,"r");
					fclose($upload_file);
					@unlink($tmp_name);
				}
			} else {
				ct_errorbox($file_number_text.ct('S_ADMIN_IMPORT_ERROR'), ct('S_ERROR_PAPER_UPLOAD_NOT_FOUND'));
			}
		} else {
			ct_errorbox($file_number_text.ct('S_ADMIN_IMPORT_ERROR'), ct('S_ERROR_PAPER_UPLOAD_FAILED'));
		}

	} else {
		ct_warningbox($file_number_text.ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_NO_FILE'));
	}
	return "";
}

/**
 * Check input data
 *
 * @return array with fields that caused an error.
 */
function check_input_form_data() {
	$form_errors=array();
	if (!in_http('form_csvheader',array('0','1'))) $form_errors[]='form_csvheader';
	if (!in_http('form_delimiter',array(',',';','tab','space'))) $form_errors[]='form_delimiter';
	if (!in_http('form_enclose',array('none','\'','"'))) $form_errors[]='form_enclose';
	#if (!in_http('form_encoding')) $form_errors[]='form_encoding';
	if (!in_http('form_escape')) $form_errors[]='form_escape';
	if (!in_http('form_mode',array('users','users_sendmail'))) $form_errors[]='form_mode';
	if (!in_http('form_preview')) $form_errors[]='form_preview';
	return $form_errors;
}

/**
 * Check the values of the import fields.
 *
 * @param string $value value to be checked
 * @param string $type types are "required" or "email".
 * @return boolean did the value pass the test?
 */
function check_import_field_value($value, $type='') {
	ct_load_lib('mail.lib');
	if ($type == 'required' && empty($value))
		return false;
	if ($type == 'email' && !ct_validate_email($value, false)) // do not check DNS entries, takes too long...
		return false;
	return true;
}


/**
 * Check input data
 *
 * @return array with fields that caused an error.
 */
function get_hidden_input_fields() {
	global $http;
	$ret="\n";
	$ret .= '<input type="hidden" name="form_csvheader" value="'.$http['form_csvheader']."\">\n";
	$ret .= '<input type="hidden" name="form_delimiter" value="'.ct_form_encode_noentities($http['form_delimiter'])."\">\n";
	$ret .= '<input type="hidden" name="form_enclose" value="'.ct_form_encode_noentities($http['form_enclose'])."\">\n";
	#$ret .= '<input type="hidden" name="form_encoding" value="'.$http['form_encoding']."\">\n";
	$ret .= '<input type="hidden" name="form_escape" value="'.ct_form_encode_noentities($http['form_escape'])."\">\n";
	$ret .= '<input type="hidden" name="form_mode" value="'.$http['form_mode']."\">\n";
	$ret .= '<input type="hidden" name="form_preview" value="'.$http['form_preview']."\">\n";
	return $ret;
}

/**
 * Extra input fields for users - user status
 *
 * @return string string with extra user import options...
 */
function get_extra_options_users() {
	$ret='<span class="font10 fontbold">'.ct('S_ADMIN_IMPORT_USERS_STATUS').'</span><br>';
	$ret.='<input type="checkbox" class="checkboxradio" name="form_user_status[]" value="reviewer">'.ct('S_USER_STATUS_REVIEWER').'<br>';
	$ret.='<input type="checkbox" class="checkboxradio" name="form_user_status[]" value="pc">'.ct('S_USER_STATUS_PC').'<br>';
	$ret.='<input type="checkbox" class="checkboxradio" name="form_user_status[]" value="chair">'.ct('S_USER_STATUS_CHAIR').'<br>';
	$ret.='<input type="checkbox" class="checkboxradio" name="form_user_status[]" value="frontdesk">'.ct('S_USER_STATUS_FRONTDESK').'<br>';
	$ret.="\n";
	$ret.='<br><span class="font10 fontbold">'.ct('S_ADMIN_IMPORT_USERS_MAIL_OPTIONS').'</span><br>';
	$ret.='<input type="checkbox" class="checkboxradio" name="form_user_sendmail" value="do">'.ct('S_ADMIN_IMPORT_USERS_SENDMAIL').'<br>';
	$ret.='<span class="font10 fontlabel">'.ct('S_ADMIN_IMPORT_USERS_MAILTEXT').'</span>';
	$ret.="<br>\n";
	$ret.='<textarea class="fontmonospaced font9" name="form_user_mail_extratext" cols="78" rows="10">'.'</textarea><br>';
	$ret.="\n";
	return $ret;
}

/**
 * Convert Title Text into ConfTool Gender Code
 *
 * @param string $genter_text String of the Gender Code...
 */
function get_gender_code($genter_text) {
  	$genter_text=strtolower($genter_text);
    if (strpos($genter_text,"prof")!==false) return 4;
    if (strpos($genter_text,"dr")!==false) return 3;
    if (preg_match("/frau|frulein|mrs|ms|miss|mme|mlle|madame|mademo|szanowna|pani|sra|srta|sta/",$genter_text)) return 2;
    if (preg_match("/herr|mr|mister|m.|monsieur|szanowny|pan|sr/",$genter_text)) return 1;
    return 0;
}

/**
 * Parse CSV strings to arrays, as fgetcsv does not work properly!
 * 
 * Based on	Class: parseCSV v0.2.0 beta
 * http://zhuoqe.org/svn/codeyard/trunk/php/classes/parseCSV/
 * by Jim Myhrberg (jim@zhuoqe.org).
 * which is Based on the concept of this class:
 * http://minghong.blogspot.com/2006/07/csv-parser-for-php.html
 *	
 * fully conforms to the specifications lined out on wikipedia:
 * http://en.wikipedia.org/wiki/Comma-separated_values
 * 
 * @param   data   CSV string
 * @param   string delimiter character
 * @param   string enclosure character
 * @param   string escape character, only "\" is supported now...
 * @return  2D array with CSV data, or false on failure
 */
function parse_CSV_string ($data = null,$delimiter=',',$enclosure='"',$escape='') {
	$encoding = "ISO-8859-1";
	if ($escape!="\\") $escape=''; # Currently only "\" is supported
	if ( empty($data) ) {
		return array();
	}
	
	$rows = array();
	$row = array();
	$row_count = 0;
	$current = '';
	$head = ( !empty($fields) ) ? $fields : array() ;
	$col = 0;
	$enclosed = false;
	$strlen = strlen($data);
	
	// walk through each character
	for ( $i=0; $i < $strlen; $i++ ) {
		$ch = $data[$i];
		$nch = ( isset($data[$i+1]) ) ? $data[$i+1] : false ; # next character
		$pch = ( isset($data[$i-1]) ) ? $data[$i-1] : false ; # previous character
		
		// open and closing quotes
		if ( $ch == $enclosure && $pch!==$escape && (!$enclosed || $nch != $enclosure) ) {
			$enclosed = ( $enclosed ) ? false : true ;
		
		// inline quotes	
		} elseif ( $ch == $enclosure && $enclosed ) {
			$current .= $ch;
			$i++;

		// end of field/row
		} elseif ( ($ch == $delimiter || ($ch == "\n" && $pch != "\r") || $ch == "\r") && !$enclosed ) {
			$current = trim($current);
			$key = ( !empty($head[$col]) ) ? $head[$col] : $col ;
			$row[$key] = $current;
			$current = '';
			$col++;
		
			// end of row
			if ( $ch == "\n" || $ch == "\r" ) {
				if ( $heading && empty($head) ) {
					$head = $row;
				} elseif ( empty($fields) || (!empty($fields) && (($heading && $row_count > 0) || !$heading)) ) {
					if ( !empty($sort_by) && !empty($row[$sort_by]) ) {
						if ( isset($rows[$row[$sort_by]]) ) {
							$rows[$row[$sort_by].'_0'] = &$rows[$row[$sort_by]];
							unset($rows[$row[$sort_by]]);
							for ( $sn=1; isset($rows[$row[$sort_by].'_'.$sn]); $sn++ ) {}
							$rows[$row[$sort_by].'_'.$sn] = $row;
						} else $rows[$row[$sort_by]] = $row;
					} else $rows[] = $row;
				}
				$row = array();
				$col = 0;
				$row_count++;
			}			
			
		// append character to current field
		} else {
			$current .= $ch;
		}
	}
	$titles = $head;
	return $rows;
}


?>