<?php
//
// PAGE:	 adminParticipantsEditDelete
// DESC:     Enter, edit, and delete participation data (administrator and assistant)
//
ct_requirefrontdesk();
ct_pagepath(array('index','adminUsers','adminParticipantsBrowse'));

ct_load_class('CTForm');
ct_load_class('CTParticipation');
ct_load_class('CTParticipation_Form');

$form_errors = array();
$participation = new CTParticipation_Form;

// if user has no admin rights, check if phase "participation" is active
if (!$user->is_admin() && !$user->is_assistant()&& !$user->is_frontdesk() && !ct_check_phases("participation")) {
	$session->put_errorbox(ct('S_ERROR_PHASE'), ct('S_ERROR_PHASE_INACTIVE'));
	ct_redirect(ct_pageurl('error'));
}

if (isset($http['form_personID']) && $http['form_personID']>0) {
	// show participation form to admin
	if ($participation->load_by_id($http['form_personID']) === true) { // Already known? -> Edit
		if (!($user->is_admin() || $user->is_assistant())) ct_redirect($session->get_besturl()); // frontdesk may not change this data, only edit!
	  	if ($participation->get('deleted') == 1) {
	   		echo "<h1>".ct('S_UNDELETEPARTICIPANT_TITLE')."</h1>\n";
	   	} else {
	   		echo "<h1>".ct('S_EDITPARTICIPANT_TITLE')."</h1>\n";
	   	}
	   	
	} else {	// New participant
	   	echo "<h1>".ct('S_NEWPARTICIPANT_TITLE')."</h1>\n";
	   	// set registration date to "today"
	    $participation->set('regdate',ct_timestamp_2_datetime(ct_time()));
		$participation->set('personID',$http['form_personID']);	// Set user id (to be sure)
	}
	
	echo "<p class=\"fontnormal font10\">".ct('S_EDITPARTICIPANT_INTRO')."</p>\n";
} elseif (!in_http('form_delete_ID')) {
	// personID and delete_ID is missing!
	ct_redirect($session->get_besturl());
}


if (isset($http['cmd_update_participant'])) {	// update view
	$participation->load_by_id($http['form_personID']);
	$form_errors = $participation->process_form_admin();
	$participation->show_form_adminpart(ct_pageurl('adminParticipantsEditDelete'), $form_errors);
}
elseif (isset($http['cmd_save_participant'])) {	// save participant
	$participation->load_by_id($http['form_personID']);
	$form_errors = $participation->process_form_admin();
	if (!$form_errors) {
		$participation->persist();

		// Send registration e-Mail
		ct_load_lib('mail_participation.lib');
		if ($participation->get('total')-$participation->get('payamount')>0.01) {
			participant_registration_confirmation($participation);
		}
			
		// SAFERPAY: Create a new link with the new amount!
		if ($participation->get('paymethod')=='ccexternal' &&
			$participation->get('total')>1 && $participation->get('total')-$participation->get('payamount')>1 && // at least 1$!
			ct_test_lib('cc_processor_saferpay.lib') ) {
			ct_load_lib('cc_processor_saferpay.lib'); 			// Use payflow link to process credit card data!
			cc_process_registration($participation);
		}

		$user->reload(); // reload user data, maybe it changed...

		$session->put_infobox(ct('S_INFO_EDITPARTICIPANT'),ct('S_INFO_EDITPARTICIPANT_SUCCESS'));
		if ($user->is_admin() || $user->is_frontdesk() || $user->is_assistant()) {
			ct_redirect($session->get_besturl());
		} else {
			ct_redirect(ct_pageurl('index'));
		}
	} else {
		ct_errorbox(ct('S_ERROR_EDITPARTICIPANT'), ct('S_ERROR_EDITPARTICIPANT_FAILED'));
		// ct_redirect(ct_pageurl('adminParticipantsDetail',array('form_id'=>$http['form_personID'])));
		$participation->show_form_adminpart(ct_pageurl('adminParticipantsEditDelete'), $form_errors);
	}
}
elseif (isset($http['cmd_delete_participant'])) {
	if (!($user->is_admin() || $user->is_assistant())) ct_redirect($session->get_besturl()); // frontdesk may not change this data, only edit!
	$participation->load_by_id($http['form_personID']);
	$deleted=$participation->delete();

	$user->reload(); // reload user data, maybe it changed...

	if ($deleted=='true'){
		$session->put_infobox(ct('S_INFO_DELETEPARTICIPANT'), ct('S_INFO_DELETEPARTICIPANT_SUCCESS'));
		ct_redirect($session->get_besturl());
	}
	else {
		$session->put_errorbox(ct('S_ERROR_DELETEPARTICIPANT'), ct('S_ERROR_DELETEPARTICIPANT_FAILED'));
		ct_redirect(ct_pageurl('error'));
	}
}
elseif (isset($http['form_delete_ID'])) {
	if (!($user->is_admin() || $user->is_assistant())) ct_redirect($session->get_besturl()); // frontdesk may not change this data, only edit!
	$participation->load_by_id($http['form_delete_ID']);
	echo "<h1>".ct('S_DELETEPARTICIPANT_TITLE')."</h1>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_DELETEPARTICIPANT_QUERY')."</p>\n";
	$participation->person->show_shortinfo('600');
	$form = new CTForm(ct_pageurl('adminParticipantsEditDelete'), 'post', array());
	$form->width='600';
	$form->align='center';
	$form->add_hidden(array(array('form_personID', $http['form_delete_ID'])));
	$form->add_submit('cmd_delete_participant', ct('S_DELETEPARTICIPANT_CONFIRM'));
	$form->add_submit('cmd_cancel', ct('S_BUTTON_BACK'));
	$form->show();
}
elseif(isset($http['cmd_cancel'])){
	ct_redirect($session->get_besturl());
}
elseif (isset($http['form_personID'])) {
	$participation->show_form_adminpart(ct_pageurl('adminParticipantsEditDelete'), $form_errors);
} else {
	ct_redirect($session->get_besturl());
}

?>
