<?php
//
// PAGE:		browseBidPapers
// DESC:		Show a list of all papers to PC members and allow them to bid for them
//
// Bidding values: Conflict=-2, Would dislike=-1, No bid=0, Would like=1, WANTED=2

// maximum number of "wanted" papers allowed. If you change this also change S_BROWSEBIDPAPERS_INTRO
$maxwanted=5; 

// if user has no admin rights, check if is pc member and "paperbids" is active
if (! ($user->is_admin() || (($user->is_pc() || $user->is_reviewer()) && ct_check_phases("paperbids")))) {
	$session->put_errorbox(ct('S_ERROR_PHASE'), ct('S_ERROR_PHASE_INACTIVE'));
	ct_redirect(ct_pageurl('error'));
}


ct_load_class('CTForm');
ct_load_class('CTPaper');
ct_load_lib('papers.lib');

$session->set_besturl(ct('S_BROWSEBIDPAPERS_QUICK'));

// store current biddings in array...
$oldbiddings=array();

// create where clause
$where = "papers.withdrawn=0";
if (isset($http['form_tracks']) && $http['form_tracks']>0 && $http['form_tracks']!='' ) {
	$where .= " AND (papers.contributiontypeID='".$http['form_tracks']."') ";
}

// Get all contributiontypeIDs that shall be accessible by this user. The where clause is set later...
if (ctconf_get('pcTrackSelect',false) && ct_test_lib('multi_track.lib')) {	// if multi-track library exists...
	ct_load_lib('multi_track.lib');
	$assigned_ctypeIDs = $user->get_contributiontypes_as_pc();
} else {
	$assigned_ctypeIDs = ct_get_contributiontypeIDs(); // get all contributiontype-IDs
}


// read and save old values...
$res = $db->select("biddings", "paperID, bidding", "personID='".$user->get_id()."'");
if ($res and ($db->num_rows($res) > 0)) {
	for ($i = 0; $i < $db->num_rows($res); $i++) {
		$row = $db->fetch($res);
		$oldbiddings[$row['paperID']] = $row['bidding'];
		if ($row['bidding']==2) $maxwanted--;
	}
}

// save biddings?
$form_errors=array();
if (isset($http['cmd_biddings_save'])) {

	// get new values.
	// Read all paper IDs
	$res = $db->select("papers", "ID", $where, "title asc");
	if ($db->num_rows($res) > 0) {
		for ($i = 0; $i < $db->num_rows($res); $i++) {
			$row = $db->fetch($res);
			$id = $row['ID'];
			if (in_http('form_paper_'.$id.'_bidding')) {
				$newbidding = $http['form_paper_'.$id.'_bidding'];
				if ($newbidding==2 && $oldbiddings[$id]!=2) {
 					$maxwanted--;
 					if ($maxwanted<=0) {
						$newbidding=1; // only limited number of favorite papers allowed!
						$form_errors[] = $id;
						if (in_http('navbar_lastpage')) $http['navbar_page'] = $http['navbar_lastpage']+1; // do not flip to new page!
 					}
				}
				// value changed: save it
				if ($newbidding>=-3 && $newbidding<=2 && $newbidding!=$oldbiddings[$id]) {
					$db->delete("biddings", "personID='".$user->get_id()."' AND paperID='".$id."' ");
					$db->insert_into("biddings", array("personID"=>$user->get_ID(),"paperID"=>$id,'bidding'=>$newbidding));
				}
				// Set default values for list
				$oldbiddings[$id] = $newbidding;
			}
		}
	}
	if (count($form_errors)>0) {
		ct_errorbox(ct('S_ERROR_SAVE'),ct('S_ERROR_SAVE_FAILED'));
	} else {
		$session->put_infobox(ct('S_INFO_SAVE'),ct('S_INFO_SAVE_SUCCESS'));
		// SEND MAIL to chair!
		// -----------------------------
		#ct_load_lib('mail.lib');
		#$mail_content ="NEW BIDDING SUBMITTED!\n----------------------\n\n";
		#$mail_content.=$user->get_fullname()." ";
		#$mail_content.="has submitted a new bidding. \n\n";
		#$mail_content.="Username: ".$user->get('username')."\nUser ID : ".$user->get_id()."\n";
		#$mail_content.=ct_get_mail_signature();
		#$subject=ctconf_get('conferenceShortName').': New bidding submitted';
		#$ret = ct_mail(stripslashes(ctconf_get('conferenceContactEmail')),$subject,$mail_content);
		// -----------------------------
		// ct_redirect(ct_pageurl("index"));
	}
} 
#ct_print_r($oldbiddings);

// Output -------------------------------------------------------
echo "<H1>".ct('S_BROWSEBIDPAPERS_TITLE')."</H1>\n";
echo "<p class=\"fontnormal font10\">".ct('S_BROWSEBIDPAPERS_INTRO')."</p>\n";

$topics = $user->count_topics();
if ($topics == 0) {
	 if (ct_check_phases('selecttopics'))
		echo "<p class=\"fontnegative fontbold font10\">".ct('S_INDEX_OPTION_TOPICS_INFO',array($topics))."</p>\n";
} else {
	echo "<span class=\"fontlabel font10\">".ct('S_USER_TOPICS').": </span>";
	$j=0;
	$user_topics=$user->get_topics();
	while (list(,$v) = each($user_topics)) {
		if ($j>0) echo ", ";
		echo "<span class=\"fontnormal font10\">".$v."</span>";
		$j++;
	}
	echo "<br>";
	ct_vspacer();
}

$paper = new CTPaper();

// get valid contribution types for bidding (and reviewing has to be enabled as well of course...
$ctypes = ct_get_contributiontypes();
$valid_ctypes = array();
$valid_ctypeIDs = array();
while (list(,$v) = each($ctypes)) {
	if ($v['do_bidding']=='true' && $v['do_review']=='true' && 
		($user->is_admin() || $user->is_conferenceChair() || in_array($v['ID'],$assigned_ctypeIDs))) {
	#if ($v['do_bidding']=='true' && $v['do_review']=='true' ) {
		$valid_ctypes[] = $v;
		$valid_ctypeIDs[] = $v['ID'];
	}
}
#print_r($valid_ctypeIDs);


// Show the filter... ---------------------------------------------------------------
if (count($valid_ctypeIDs)>1) {
	$form1 = new CTform('browseBidPapers', 'get');
	$form1->width='100%';
	$form1->align='center';
	$ftracks=array(array(0,ct('S_ADMIN_TOOL_CONTRIBUTIONTYPES_ALLTYPES')));
	reset($valid_ctypes);
	while (list(,$v) = each($valid_ctypes)) $ftracks[] = array($v['ID'],$v[ctlx($v,'title')]);
	$form1->add_select_autosubmit(ct('S_ADMIN_TOOL_CONTRIBUTIONTYPES_FORM_CONTRIBUTIONTYPE'), 'form_tracks', $ftracks, array($http['form_tracks']), false);
	$form1->add_submit_noscriptonly('cmd_search', ct('S_ADMIN_PAPERS_BROWSE_SUBMIT'));
	$form1->show();
}


// How many papers are on the current list?	
$papercount = 0;
$query  = "SELECT count(*) as pcount from papers where ($where) ";
$query .= "AND papers.contributiontypeID IN ('".implode("', '", $valid_ctypeIDs)."')";
$res = $db->query($query);
if ($res && ($db->num_rows($res)==1)) {
	$row = $db->fetch($res);
	$papercount = $row['pcount'];
}

	
// start form for list...
echo "<div align=\"center\">\n";
echo "<form method=\"post\" action=\"".ct_pageurl('browseBidPapers')."\">\n";
echo "<input type=hidden name='cmd_biddings_save' value=\"1\">\n";
if (isset($http['form_tracks']) && $http['form_tracks']>0 && $http['form_tracks']!='') {
	echo "<input type=hidden name='form_tracks' value=\"".$http['form_tracks']."\">";
}

// navigation bar....
ct_load_lib('navbar_submitting.lib');
$perpage    = isset($http['navbar_perpage']) && $http['navbar_perpage']!=""?$http['navbar_perpage']:ctconf_get('display_perpage_submitting',100);
$pageno     = isset($http['navbar_page'])?$http['navbar_page']-1:(isset($http['navbar_lastpage'])?$http['navbar_lastpage']:0); // default is 0
$maxpage    = intval(($papercount-1)/($perpage));
$page_item  = 0;

ct_navbar_submitting($papercount,true);

// now show list...
echo "<table width=\"100%\">\n";


$paper_shown = array();
$row = 0;
// Show all papers ordered by number matches of the topics (without conflict papers and papers without matching topics)
$query = "select count(t2p.paperID) as matches, p.ID as ID, p.personID as personID, p.author as author, p.title as title, p.contributiontypeID as contributiontypeID, p.keywords as keywords from papers as p ";
$query .= "LEFT JOIN topics2papers as t2p ON p.ID=t2p.paperID LEFT JOIN pc2topics as p2t ON t2p.topicID=p2t.topicID ";
$query .= "WHERE p2t.personID='".$user->get_id()."' AND p.withdrawn=0 AND p.personID!='".$user->get_id()."' ";
$query .= "AND p.contributiontypeID IN ('".implode("', '", $valid_ctypeIDs)."')";
if (isset($http['form_tracks']) && $http['form_tracks']>0) {
	$query .= "AND (p.contributiontypeID='".$http['form_tracks']."') ";
}
$query .= "GROUP by p.ID ORDER BY matches desc, p.title asc";
$qr = $db->query($query);
if ($qr && ($db->num_rows($qr)>0)) {
	for ($i = 0; $i < $db->num_rows($qr); $i++) {
		$row++;
		$pdata = $db->fetch($qr);
		if (intval($page_item/$perpage)==$pageno) {
			$paper->pdata = $pdata;
			$author=$paper->get_author();
			show_bidding_row($row,$paper,$pdata,$author,$user,$oldbiddings,$form_errors);
		}
		$paper_shown[] = $pdata['ID']; // Remember if row was already shown...
		$page_item++;
	}
}

echo "<tr><td colspan=\"3\" valign=top align=left class=\"form_td_separator\">";
echo "<img src=\"".ct_getbaseurl()."icons/spacer.gif\" width=1 height=1>";
echo "</td></tr>\n";

// Now show all remaining papers ordered by title
$where =  "papers.withdrawn=0 ";
$where .= "AND papers.contributiontypeID IN ('".implode("', '", $valid_ctypeIDs)."') ";
if (isset($http['form_tracks']) && $http['form_tracks']>0) {
	$where.= "AND papers.contributiontypeID='".$http['form_tracks']."' ";
}

$qr = $db->select("papers", "*", $where, "papers.title asc");
if ($qr && ($db->num_rows($qr)>0)) {
	for ($i = 0; $i < $db->num_rows($qr); $i++) {
		$pdata = $db->fetch($qr);
		if (!in_array($pdata['ID'],$paper_shown)) {// already shown?
			$row++;
			if (intval($page_item/$perpage)==$pageno) {
				$paper->pdata = $pdata;
				$author=$paper->get_author();
				show_bidding_row($row,$paper,$pdata,$author,$user,$oldbiddings,$form_errors);
			}
			$page_item++;
		}
	}
}

echo "</table>\n";

ct_navbar_submitting($papercount);

echo "</form>\n</div>\n";

// Show one row...
function show_bidding_row($i,$paper,$pdata,$author,$user,$oldbiddings,$form_errors) {
	global $session, $ctconf;
	$user =& $session->get_user();
	
	if ($i % 2) {
		echo "<tr class=\"oddrow\">\n";
	} else {
		echo "<tr class=\"evenrow\">\n";
	}
	echo "<td width=\"70%\">";
	echo "<span class=\"fontbold font9\">".$paper->_get_contributiontype_title()."</span><br>";
	echo "<span class=\"fontbold font10\"><a target=\"_blank\" href=\"".ct_pageurl('paperDetails')."&amp;form_id=".$paper->get('ID')."\">".$paper->get_special('title')."</a></span><br>";

	// Show Author information?
	$ctype = $paper->_get_contributiontype();
	if ($user->is_admin() || $user->is_conferenceChair() || $user->is_chair() || $ctype['review_anonymous']=='false' || $paper->get('personID') == $user->get_id()) {
		echo "<span class=\"fontlabel font9\">".ct('S_PAPER_AUTHOR').":</span> <span class=\"fontnormal font10\">".$paper->get_special('author')."</span><BR>\n";
		// Show author. mark if same as reviewer
		echo "<span class=\"fontlabel font9\">".ct('S_INDEX_PAPER_SUBMITTEDBY').": </span>";
		echo "<span ";
		if ($author->get_id()==$user->get_id())
		echo "class=\"fontnegative fontbold font9\">";
		else
		echo "class=\"fontbold font9\">";
		echo ct_form_encode($author->get_reversename())."</span>&nbsp;";
	
		// show organization. Mark if similar to reviwers.
		echo "<span ";
		$s = similar_text($author->get('organisation'),$user->get('organisation'));
		$l = max(strlen($author->get('organisation')),strlen($user->get('organisation')));
		if ($l>0) $similarity_pst = $s/$l * 100;
		else $similarity_pst=0;
		if (number_format($similarity_pst, 0) > 66)
		echo "class=\"fontnegative fontbold font9\">";
		elseif (number_format($similarity_pst, 0) > 33)
		echo "class=\"fontnegative font9\">";
		else
		echo "class=\"fontnormal font9\">";
		echo " (".$author->get_special('organisation').")</span><BR>\n";
	}
	
	echo "<span class=\"fontlabel font9\">".ct('S_PAPER_TOPICS').":</span>";
	$j=0;
	$topics = $paper->get_topics();
	$user_topics=$user->get_topics();
	while (list(,$v) = each($topics)) {
		if ($j>0) echo ",";
		if (in_array($v, $user_topics)) echo "<span class=\"fontpositive fontbold font9\"> ".$v."</span>";
		else echo "<span class=\"fontnormal font9\">".$v."</span>";
		$j++;
	}
	if ($j == 0) echo "---";
	if ($paper->get('keywords')!='') {
		echo "<BR>\n";
		echo "<span class=\"fontlabel font9\">".ct('S_PAPER_FORM_KEYWORDS').":</span> <span class=\"fontnormal font9\">".$paper->get_special('keywords')."</span><BR>\n";
	}
	echo "</td>\n";

	// second column
	echo "<td align=\"center\" width=\"10%\" class=\"".($i%2?"oddrow2":"evenrow2")."\" >";
	echo '<span class="fontnormal font8">';
	if (isset($pdata['matches']))
		echo ct('S_BIDDING_MATCHES').": ".$pdata['matches'];
	else
		echo ct('S_BIDDING_CONFLICT_OR_NOMATCH');

	echo "</span></td>\n";
	
	// third column
	echo "<td align=\"right\" nowrap=\"nowrap\" width=\"20%\" ";
	if (!empty($form_errors) && in_array($paper->get_id(), $form_errors))
		echo "class=\"negativebg\" >";
	else {
		if ($i % 2) {
			echo "class=\"oddrow2\">\n";
		} else {
			echo "class=\"evenrow2\">\n";
		}
	}
	// default bidding
	$bidding=0; 
	if (isset($oldbiddings[$paper->get_id()])) {
		$bidding=$oldbiddings[$paper->get_id()];
	} else {
		$coauthors = $paper->get_emails();
		if ($author->get_id()==$user->get_id() || $similarity_pst>90 || 
				in_array($user->get('email'),$coauthors) ||
				(!$user->get('email2')=='' && in_array($user->get('email2'),$coauthors)) )
			$bidding=-2; // set to conflict!
	}
	if ($author->get_id()!=$user->get_id() && $bidding>=-2){
		echo "<span class=\"".($bidding==2?'fontbold':'')." fontnormal font9\"> ".ct('S_BIDDING_WANTED')." <input type=\"radio\"  class=\"checkboxradio\" name=\"form_paper_".$paper->get('ID')."_bidding\" value=\"2\" ".($bidding==2?"CHECKED":" ").">&nbsp;</span><br>\n";
		echo "<span class=\"".($bidding==1?'fontbold':'')." fontnormal font9\"> ".ct('S_BIDDING_LIKE')." <input type=\"radio\"  class=\"checkboxradio\" name=\"form_paper_".$paper->get('ID')."_bidding\" value=\"1\" ".($bidding==1?"CHECKED":" ").">&nbsp;</span><br>\n";
		echo "<span class=\"".($bidding==0?'fontbold':'')." fontnormal font9\"> ".ct('S_BIDDING_DEFAULT')." <input type=\"radio\"  class=\"checkboxradio\" name=\"form_paper_".$paper->get('ID')."_bidding\" value=\"0\" ".($bidding==0?"CHECKED":" ").">&nbsp;</span><br>\n";
		echo "<span class=\"".($bidding==-1?'fontbold':'')." fontnormal font9\"> ".ct('S_BIDDING_DISLIKE')." <input type=\"radio\"  class=\"checkboxradio\" name=\"form_paper_".$paper->get('ID')."_bidding\" value=\"-1\" ".($bidding==-1?"CHECKED":" ").">&nbsp;</span><br>\n";
		echo "<span class=\"".($bidding==-2?'fontbold':'')." fontnegative font9\"> ".ct('S_BIDDING_CONFLICT')." <input type=\"radio\"  class=\"checkboxradio\" name=\"form_paper_".$paper->get('ID')."_bidding\" value=\"-2\" ".($bidding==-2?"CHECKED":" ").">&nbsp;</span><br>\n";
	} else {
		echo "<span class=\"fontnegative fontbold font9\"> ".ct('S_BIDDING_CONFLICT')." <input type=\"radio\"  class=\"checkboxradio\" name=\"form_paper_".$paper->get('ID')."_bidding\" value=\"$bidding\" CHECKED>&nbsp;</span><br>\n";
		echo "<span class=\"fontnormal font8\">(".ct('S_BIDDING_CONFLICT_CHAIR').")&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>";
	}
	echo "</td></tr>\n";
}

?>
