<?php
//
// PAGE:		downloadDocument
// DESC:     Download a contribution (e.g. for the reviews)
// HINT:		This page may interrupt the normal page construction by throwing away all
//			content written to the outbut buffer and send a document instead.
//

if (!in_http('form_id')) {
	ct_redirect(ct_pageurl('index'));
}

ct_load_class('CTPaper');

$paper = new CTPaper;
if (!$paper->load_by_id($http['form_id'])) {
	$session->put_errorbox(ct('S_ERROR_PAPER_DOWNLOAD'), ct('S_ERROR_PAPER_DOWNLOAD_NOACCESS'));
	ct_redirect(ct_pageurl('error'));
}

$ctype  =  $paper->_get_contributiontype();
$author =& $paper->get_author();

// Get index, if several uploads exist for this contributiontype.
$index = "";
$abc_index= 'A';
if (isset($http['form_index']) && ($http['form_index']=="2" || $http['form_index']=="3")) {
	$index="_".$http['form_index'];
	$abc_index=($http['form_index']=="3"?"C":($http['form_index']=="2"?"B":"A"));
}

// Get special version. Currently it may be "final" or nothing
$version = "";
if (isset($http['form_version']) && $http['form_version']=="final") {
	$version="_".$http['form_version'];
}

// check if paper exists
if (!$paper->load_by_id($http['form_id'])) {
	$session->put_errorbox(ct('S_ERROR_PAPER_DOWNLOAD'), ct('S_ERROR_PAPER_DOWNLOAD_NOACCESS'));
	ct_redirect(ct_pageurl('error'));
}

// get session of this contribution.
$sess  = ct_get_session($paper->get('track'));

// check user access rights
if (! ( (ct_check_phases('browsesessions') && $ctype['upload_accessible_'.$abc_index]=='true' && $sess['show_downloads']=='true') ||
        ($user->is_chair() || $user->is_admin() || $user->is_conferenceChair() || $user->get('ID') == $author->get('ID')) ||
 		($paper->is_reviewed_by($user->get('ID')) && $ctype['upload_accessible_'.$abc_index]=='true')  ) ) {
	$session->put_errorbox(ct('S_ERROR_PAPER_DOWNLOAD'), ct('S_ERROR_PAPER_DOWNLOAD_NOACCESS'));
	ct_redirect(ct_pageurl('error'));
}

// Name on harddisk
$filename = $paper->get('filename'.$version.$index);

// check if filename is ok.
if ($filename == "") {
	$session->put_errorbox(ct('S_ERROR_PAPER_DOWNLOAD'), ct('S_ERROR_PAPER_DOWNLOAD_NOACCESS'));
	ct_redirect(ct_pageurl('error'));
}

// Add upload path if it is a relative file name, e.g. there is only 1 or less "/" or "\"
if (substr_count($filename,"/")<=1 && substr_count($filename,"\\")<=1) $filename = ct_get_path('uploads').$filename;

// Get extension from filename on Disk
$extension="bin";
eregi(".*\.(.{2,4})$",$filename,$regs);
if ($regs[1]!="")	$extension =  $regs[1];

// download name
$downloadname = ct('S_INDEX_PAPER_PAPER').$paper->get_id().".".$extension;
if (isset($http['filename']) && $http['filename']!="") {
	$downloadname = $http['filename'];
}
$downloadname = str_replace("+","_",$downloadname);

$size = -1;
// check if file exists
if( !ini_get('safe_mode') ){ 	// Does _not_ work in SAFE MODE, so skip
	if (!file_exists($filename)) {
		$session->put_errorbox(ct('S_ERROR_PAPER_DOWNLOAD'), ct('S_ERROR_PAPER_DOWNLOAD_NOTFOUND'));
		ct_redirect(ct_pageurl('error'));
	} else {
		$size=filesize($filename);
	}
}

// Remark in review table that review was started (at least the download done...)
ct_load_class('CTReview');
$review = new CTReview();
if ($review->load($paper->get('ID'), $user->get('ID') )) {
	$review->set('downloaddate',ct_timestamp_2_datetime(ct_time()));
	$review->persist();
}

// 0. To start sending file, remove all old output.
ob_end_clean();


// 1. first determine mime-type from filename
$header = "Content-Type: ";
eregi(".*\.(.{2,4})$",$downloadname,$regs);
switch ($regs[1]) {
	case "pdf": case "PDF":
    $header .= "application/pdf"; break;
	case "ps": case "PS":
	$header .= "application/postscript"; break;
	case "doc": case "DOC":
	$header .= "application/msword"; break;
	case "rtf": case "RTF":
	$header .= "application/rtf"; break;
	case "zip": case "ZIP":
	$header .= "application/zip"; break;
	case "gif": case "GIF":
	$header .= "image/gif"; break;
	case "jpg": case "JPG":
	$header .= "image/jpeg"; break;
	case "html": case "HTML":  case "htm": case "HTM":
	$header .= "text/html"; break;
	case "txt": case "TXT":
	$header .= "text/plain"; break;
	case "tex": case "TEX":
	$header .= "application/x-tex"; break;
	default:
	$header.= "application/octet-stream";
}
// 2. Send header
header($header);
header('Content-Disposition: attachment; filename="' . $downloadname .'"');
if ($size>0) header('Content-Length: '.$size);


// 3. Send file.
#readfile($filename); ### This is buggy in some PHP versions, especially for bigger files > 2000000 Byte
$fp = fopen($filename, "rb");
if ($fp) {
	while (!feof($fp)) { echo fread($fp, 524288); ob_flush(); flush(); }
	fclose($fp);
}

exit();

?>