<?php
//
// PAGE:		editPaper
// DESC:     Edit the meta-information for a paper
//

// this page does only make sense if an ID for a paper was provided. If not,
// we redirect to the index page
if (!isset($http['form_id'])) {
	ct_redirect(ct_pageurl('index'));
}

ct_pagepath(array('index','submissions'));

ct_load_lib('papers.lib');
ct_load_lib('datetime.lib');

ct_load_class('CTPaper');
$paper = new CTPaper();
$oldpaper = new CTPaper();

// if user has no admin rights, check if phase "submission" is active
if (!$user->is_admin() and !ct_check_phases("submission")) {
	$session->put_errorbox(ct('S_ERROR_PHASE'), ct('S_ERROR_PHASE_INACTIVE'));
	ct_redirect(ct_pageurl('error'));
}

// Does paper exist?
if (!$paper->load_by_id($http['form_id'])) {
	// redirect to index if id does not correspond to a real paper
	$session->put_errorbox(ct('S_ERROR_PAPER_EDIT'), ct('S_ERROR_PAPER_EDIT_NOACCESS'));
	ct_redirect(ct_pageurl('index'));
}

// Set correct Contributiontype first...
if ( (isset($http['cmd_paper_updateview']) || isset($http['cmd_paper_save'])) && in_http('form_contributiontypeID') && $user->is_admin()) {
	$paper->set('contributiontypeID',$http['form_contributiontypeID']);
}

// Get correct paper class name
$classname = $paper->get_paperClass();
ct_load_class($classname);
eval('$paperclass = new '.$classname.'();');
$paperclass = ct_type_cast($paper,$classname);

// Get author
$author =& $paperclass->get_author();

// check if user is allowed to edit paper information. access is denied
// if user has no admin rights and is not the author of the paper
if (!$user->is_admin() && ($user->get('ID') != $author->get('ID'))) {
	$session->put_errorbox(ct('S_ERROR_PAPER_EDIT'), ct('S_ERROR_PAPER_EDIT_NOACCESS'));
	ct_redirect(ct_pageurl('error'));
}

// admin may change type of contribution.
if (isset($http['cmd_paper_updateview']) && in_http('form_contributiontypeID') && $user->is_admin()) {
	$paperclass->set('contributiontypeID',$http['form_contributiontypeID']);
	$errors = $paperclass->process_form_step1();
	echo "<h1>".ct('S_INFO_PAPER_EDIT')."</h1>\n";

	$paperclass->show_form_step1(ct_pageurl('editPaper'), $errors, true);
} elseif (isset($http['cmd_paper_save'])) {
	// admin may change type of contribution.
	if (in_http('form_contributiontypeID') && $user->is_admin()) {
		$paperclass->set('contributiontypeID',$http['form_contributiontypeID']);
	}
	$errors = $paperclass->process_form_step1();
	if (!$errors) {
		// remove old co-authors
		$oldpaper->load_by_id($paperclass->get_id());
		$oldpaper->set_coauthors(false);
		// add new co-authors
		$paperclass->persist();
		$paperclass->set_coauthors(true);

		// send email if the user edits his own paper!
		if ($author->get_id()==$user->get_id()) {
			ct_load_lib('mail_papers.lib');
			ct_mail_author_submission_confirmation($paperclass,false);
		}

		$session->put_infobox(ct('S_INFO_PAPER_EDIT'), ct('S_INFO_PAPER_EDIT_SAVED'));
		ct_redirect($session->get_besturl());
	} else {
		ct_errorbox(ct('S_ERROR_PAPER_EDIT'), ct('S_ERROR_PAPER_EDIT_INCOMPLETE'));
		echo "<h1>".ct('S_INFO_PAPER_EDIT')."</h1>\n";
		$paperclass->show_form_step1(ct_pageurl('editPaper'), $errors, true);
	}
} elseif ($paperclass->get_id()>0) {
	echo "<h1>".ct('S_INFO_PAPER_EDIT')."</h1>\n";

	// show deadline...
	$type=ct_get_contributiontypes($paperclass->get('contributiontypeID'));
	$deadline=ct_get_submission_deadline($type);
	echo "<p class=\"font10\">".ct('S_INDEX_PAPER_EDIT_UPDATE_UNTIL',array(ct_datetime_format_timezone($deadline)))."</p>\n";

	$paperclass->show_form_step1(ct_pageurl('editPaper'),array(), true);
}

?>
