<?php
//
// PAGE:         participate
// Register as conference participant
//

ct_pagepath(array('index'));
ct_load_class('CTParticipation'); 
ct_load_class('CTParticipation_Form'); // Participant class with form generation and processing
ct_load_lib('mail.lib');

$form_errors = array();

// check if phase "participation" is active
if (!ct_check_phases("participation") && !$user->is_admin()) {
	$session->put_errorbox(ct('S_ERROR_PHASE'), ct('S_ERROR_PHASE_INACTIVE'));
	ct_redirect(ct_pageurl('error'));
}

// If user is already participant, show participation data only.
if ($user->is_participant()) {
	echo "<h1>".ct('S_PARTICIPATE_DATA_TITLE')."</h1>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_PARTICIPATE_DATA_INTRO')."</p>\n";
	$participation = new CTParticipation;
	$participation->load_by_id($user->get_id());
	$participation->person->show_shortinfo('690');
	$participation->show_participant_data('700','center');
	ct_show_payments($participation,'700','center');

	if (in_http('nextpage',array('submissions','index'))) { // Offer link "Continue..."
		echo "<div class='yellowbg' align='right'><a class=\"fontbold font14\" href=\"".ct_pageurl($nextpage)."\">".ct('S_PARTICIPATE_CONTINUE')."</a>&nbsp;&nbsp;&nbsp;</div><br>\n";
	}
	
} else {
// user is not registered, yet.	

	// Test if registration is already set up. Otherwise show error message and quit.
	$r = $db->select('events','ID','pricecategory>0 && eventtype>0');
	if ($r && ($db->num_rows($r) == 0)) {
		$session->put_errorbox(ct('S_ERROR_PARTICIPATE'),ct('S_ERROR_PARTICIPATE_NOT_INSTALLED'));
		ct_redirect(ct_pageurl('index'));			
	}

	// get participation data from session variable
	$participation_data =& $session->get('__participant');
	// type cast it to the form class
	$participation = ct_type_cast($participation_data,'CTParticipation_Form');
	
	// if participation object is unknown, user has to start registration process
	if (!is_object($participation) || $participation==NULL) {
		$participation = new CTParticipation_form;
		$participation->load_by_id($user->get_id()); // Try to load old data...
		$participation->set('personID', $user->get_id());	// Set user id (to be sure)
		$participation->set('regdate', ct_timestamp_2_datetime(ct_time()));	// Set new registration date
		if ($participation->get('paymethod')=='free') $participation->set('paymethod', ''); // delete free registration status
		$participation->delete_cc_data();						// Delete his cc data, so he won't be alarmed
		// store data in session variable
		$participation_data = ct_type_cast($participation,'CTParticipationData');
		$session->putref('__participant',$participation_data);
		$http['go_status']=1; // Go to first page
	}
	
	// First (try to) process the data
	// Process step 1: User status --------------------------------
	if (in_http('step_status')) {
		// Check if already at least an one event was entered.
		$form_errors = $participation->process_form_status();
		// Set registration date. Maybe someone wants to cheat!
		$participation->set('regdate', ct_timestamp_2_datetime(ct_time()));	// Set new registration date
		// store data in session variable
		$participation_data = ct_type_cast($participation,'CTParticipationData');
		$session->putref('__participant',$participation_data);
		if (!empty($form_errors)) {
			$http['go_status']=1; // Return to first page
			ct_errorbox(ct('S_ERROR_PARTICIPATE'), ct('S_ERROR_PARTICIPATE_INCOMPLETE'));
		}
			
	
	// Step 2: Select events/products --------------------------------
	} elseif (in_http('step_events')) {
		$form_errors = $participation->process_form_events();
		// store data in session variable
		$participation_data = ct_type_cast($participation,'CTParticipationData');
		$session->putref('__participant',$participation_data);
		if (!in_http('go_status')) {
			if (!empty($form_errors)) {
				ct_errorbox(ct('S_ERROR_PARTICIPATE'), ct('S_ERROR_PARTICIPATE_INCOMPLETE'));
				$http['go_events']=1; // Return to second page
			} elseif(array_sum($participation->eventdata_number)==0) { 
				ct_errorbox(ct('S_ERROR_PARTICIPATE'), ct('S_ERROR_PARTICIPATE_NOSELECTION'));
				$http['go_events']=1; // Return to second page
			}
		}			
			
	// Step 3: Billing information  --------------------------------
	} elseif (in_http('step_billing')) {
		$form_errors = $participation->process_form_billing();
		// store data in session
		$participation_data = ct_type_cast($participation,'CTParticipationData');
		$session->putref('__participant',$participation_data);
		if (!in_http('go_status') && !in_http('go_events')) {
			if (!empty($form_errors)) {
				ct_errorbox(ct('S_ERROR_PARTICIPATE'), ct('S_ERROR_PARTICIPATE_INCOMPLETE'));
				$http['go_billing']=1; // Return to billing page
			}
		}
	
	// Step 4: Check confirmation and save data
	} elseif (isset($http['cmd_save_participant']) || isset($http['cmd_save_participant_submit'])) {
		if (!is_object($participation) || $participation==NULL) ct_redirect(ct_pageurl('index'));			
		$form_errors = $participation->test_eventdata();
		if (!empty($form_errors)) {
			ct_errorbox(ct('S_ERROR_PARTICIPATE'), ct('S_ERROR_PARTICIPATE_INCOMPLETE'));
			$http['go_events']=1; // Return to second page - maybe someone else was quicker and booked the event.
		}

		$form_errors = $participation->process_form_confirmation();
		if (!empty($form_errors)) {
			ct_errorbox(ct('S_ERROR_PARTICIPATE'), ct('S_ERROR_PARTICIPATE_INCOMPLETE'));
			$http['go_confirmation']=1; // Return to fourth page
		}

		// If no errors, finish process
		if (empty($form_errors)) {
			
			// Calculate total - just to be sure!
			$participation->_calculate_fee(); 
			// Make sure the participant is not marked as deleted (if he registered before...!)
			$participation->set('deleted','0');  
			// everything fine, save event...
			$participation->persist($user->get_id());  // user ID is necessary, as no personID was set.

			// reload user data, maybe it changed...
			$user->reload(); 

			// Now load "new" participant data with person ID.
			$participation->load_by_id($user->get_id());

			$nextpage="index";
			if (isset($http['cmd_save_participant_submit'])) {
				$nextpage='submissions';	// Directly go to submission page.
			}
			
			// Process payment or go to page after registration process -----------------------------
			
			// Test if payflow link is used...
			if ($participation->get('paymethod')=='cc' && 
					$participation->get('total')>1 && 
					$participation->get('total')-$participation->get('payamount')>1 && // at least 1$!
					ct_test_lib('cc_processor_payflow_link.lib') && ctconf_get('paymentCreditCardUsePayflow')) {
				// Use payflow link to process credit card data!
				ct_load_lib('cc_processor_payflow_link.lib');
				process_payment_payflow_link($participation, $form_errors, $nextpage);
		
				// reload user data, it may have changed again...
				$user->reload(); 
			
			} else {
				// Test if external credit card processor is used
				if ($participation->get('paymethod')=='ccexternal' && 
					$participation->get('total')>1 && 
					$participation->get('total')-$participation->get('payamount')>1 && // at least 1$!
					ct_test_lib('cc_processor_saferpay.lib') ) {
					// Use payflow link to process credit card data!
					ct_load_lib('cc_processor_saferpay.lib');
					cc_process_registration($participation);
				}
	
				// Send Mail: Accepted...
				ct_load_lib('mail_participation.lib');
				participant_registration_confirmation($participation);

				// Delete participant object from session
				$session->del('__participant');

				// Show info of success
				$session->put_infobox(ct('S_INFO_SAVEPARTICIPANT'),ct('S_INFO_SAVEPARTICIPANT_SUCCESS'));
				
				// Test if fax option is used				
				if ($participation->get('paymethod')=='fax' && $participation->get('total')>0) {
					ct_redirect(ct_pageurl('statement', array('print'=>'yes','continue'=>'yes','nextpage'=>$nextpage)));		// Statement to print out...
				}
				
				// Is identity management "turned on"?
				if (ctconf_get('participation/identities')=='true') {
					ct_redirect(ct_pageurl('editIdentity',array('nextpage'=>$nextpage)));	// Enter Identity Data!
				// go to submission page
				} else {
					ct_redirect(ct_pageurl($nextpage));			// Registration finished.
				}
			}
		}		
	}	

	// ---------------------------------------------------------------------------	
	// Now show forms
	// ---------------------------------------------------------------------------

	// Show form step 1
	if (in_http('go_status')) {
		// delete cached master data.
		$session->del('db_timediscounts'); 
		$session->del('db_groups');
		$session->del('db_prices'); 
	
		show_step_status($participation, $form_errors);
	
	// Show form step 2
	} elseif (in_http('go_events')) {
		show_step_selectevents($participation, $form_errors);
	
	// Show form step 3
	} elseif (in_http('go_billing')){
		// Pre-populate some data
		if ($participation->get('zip')=='') 		$participation->set('zip',$user->get('zip'));
		if ($participation->get('state')=='') 		$participation->set('state',$user->get('state'));
		if ($participation->get('country')=='') 	$participation->set('country',$user->get('country'));
		if ($participation->get('ccholder')=='') 	$participation->set('ccholder',trim($user->get_fullname()));
		if ($participation->get('cccity')=='') 		$participation->set('cccity',$user->get('city'));
		if ($participation->get('cczip')=='') 		$participation->set('cczip',$user->get('zip'));
		if ($participation->get('ccstate')=='') 	$participation->set('ccstate',$user->get('state'));
		if ($participation->get('cccountry')=='') 	$participation->set('cccountry',$user->get('country'));
		show_step_billing($participation,$form_errors);
	
	// Show form step 4		
	} elseif (in_http('go_confirmation')){
		show_step_confirmation($participation,$form_errors);
	
	} elseif (in_http('go_done')){
		#Show nothing
	
	// Show form step 1 (if user restarts process - data is still present)
	} else {
		show_step_status($participation, $form_errors);
	}
}

// local functions.
function show_step_status($participation,$form_errors) {
	echo "<h2>".ct('S_PARTICIPATE_STEPX_TITLE',array('1','4')).': '.ct('S_PARTICIPATE_STEP_STATUS')."</h2>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_PARTICIPATE_STEP_STATUS_INTRO')."</p>\n";
	$participation->show_form_status(ct_pageurl('participate'), $form_errors);
}

function show_step_selectevents($participation,$form_errors) {
	echo "<h2>".ct('S_PARTICIPATE_STEPX_TITLE',array('2','4')).': '.ct('S_PARTICIPATE_STEP_EVENTS')."</h2>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_PARTICIPATE_STEP_EVENTS_INTRO')."</p>\n";
	$participation->show_participant_status('97%','center');
	$participation->show_form_events(ct_pageurl('participate'), $form_errors);
}

function show_step_billing($participation,$form_errors) {
	echo "<h2>".ct('S_PARTICIPATE_STEPX_TITLE',array('3','4')).': '.ct('S_PARTICIPATE_STEP_PAYMENT')."</h2>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_PARTICIPATE_STEP_PAYMENT_INTRO')."</p>\n";
	$participation->show_participant_costs('97%', "center", "infoview_table", "oddrow", "evenrow", "");
	$participation->show_form_billing(ct_pageurl('participate'), $form_errors);
}

function show_step_confirmation($participation,$form_errors) {
	echo "<h2>".ct('S_PARTICIPATE_STEPX_TITLE',array('4','4')).': '.ct('S_PARTICIPATE_STEP_CONFIRM')."</h2>\n";
	echo "<p class=\"oddrow_del_highlight\">".ct('S_PARTICIPATE_STEP_CONFIRM_INTRO')."</p>\n";
	$participation->show_participant_data('90%', 'center');
	if ($participation->get('payamount')>0) {
		ct_load_lib('payment.lib');
		ct_show_payments($participation,'90%','center');
	}
	
	echo "<br>";
	$participation->show_form_confirmation(ct_pageurl('participate'), $form_errors);
}

?>
