<?php
//
// PAGE:		uploadFinalPaper
// DESC:		Upload final version of a paper/contribution. 
// 				If there are any problems with big files, please consult the INSTALL documentation!
//

// this page does only make sense if an ID for a paper was provided. If not,
// we redirect to the index page

ct_pagepath(array("index"));

ct_load_class('CTPaper');
ct_load_lib('papers.lib');

if (!isset($http['form_id'])) {
	$session->put_errorbox(ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_FAILED'));
	ct_redirect(ct_pageurl('index'));
}

$paper = new CTPaper;

// redirect to index if id does not correspond to a real paper
if (!$paper->load_by_id($http['form_id'])) {
	$session->put_errorbox(ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_FAILED'));
	ct_redirect(ct_pageurl('index'));
}

$classname = $paper->get_paperClass();
ct_load_class($classname);
eval('$paperclass = new '.$classname.'();');
$paperclass = ct_type_cast($paper,$classname);

// if user has no admin rights, check if phase "submission" or "finalupload" is active
if ($user->is_admin() || 
		(ct_check_phases(array("finalupload")) && $paperclass->get_finalupload_deadline()>ct_time() && 
				$paperclass->_number_of_uploads_for_contributiontype('','final')>0 &&
				$paperclass->get('acceptstatus')!=-1 && $paperclass->get('acceptstatus')!=0 )) {
			
	$author =& $paperclass->get_author(); 
	$errors = array();
	
	// check if user is allowed to edit paper information. access is denied
	// if user has no admin rights and is not the author of the paper
	if (!$user->is_admin() && ($user->get('ID') != $author->get('ID'))) {
		$session->put_errorbox(ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_NOACCESS'));
		ct_redirect(ct_pageurl('index'));
	}

	if (isset($http['cmd_finalupload_skipupload'])) {
		$errors = $paperclass->process_form_finals();
		if ($errors===false) {
			$paperclass->persist();

			// send email:
			ct_load_lib('mail_papers.lib');
			ct_mail_author_finalversion_confirmation($paperclass);
			
			// show messages
			// 1. are there uploads missing?
			$uploads = $paperclass->_number_of_final_uploads_for_contributiontype();
			$alldone=true;
			for ($i=1; $i<=$uploads; $i++) { 
				if ($uploads > 1) 
					$file_number_text = ct_get_file_number_text($i).': ';
				else 
					$file_number_text = '';
					
				if ($paperclass->get($paperclass->get_ffname('originalname','final',$i))=='') {
					$alldone=false;
					$session->put_warningbox($file_number_text.ct('S_INFO_PAPER_MISSING'), ct('S_INFO_PAPER_MISSING_NOTFORGET'));
				}
			}
			// 2. Show success message.
			if ($alldone)
				$session->put_infobox(ct('S_INFO_PAPER_FINALUPLOAD'), ct('S_INFO_PAPER_UPLOAD_SUCCESS'));
		 	ct_redirect($session->get_besturl());
		 	// ct_redirect(ct_pageurl('submissions'));
		}
	} 
	
	if (isset($http['cmd_paper_upload'])) {
		$errors = $paperclass->process_form_finals();
		// Check uploads
		$uploads = $paperclass->process_uploadform("final"); // Returns: OK, ERROR, MISSING, EXISTS
		# ct_print_r($uploads);
		$paperclass->persist();
		if (in_array('ERROR',$uploads) || in_array('MISSING',$uploads)) { // if there was an error, show it and stay on this page
			// Upload failed!
			// Show messages
			for ($i=1; $i<=count($uploads); $i++) {
				if (count($uploads)>1) 
					$file_number_text = ct_get_file_number_text($i).': ';
				else 
					$file_number_text = '';

				if ($uploads[$i]=="MISSING")
					ct_warningbox($file_number_text.ct('S_INFO_PAPER_MISSING'), ct('S_INFO_PAPER_MISSING_NOTFORGET'));
			}
		} elseif (!in_array('OK',$uploads)) { // if non upload succeeded, but there was no error, stay on this page and show a message
			ct_warningbox($file_number_text.ct('S_ERROR_PAPER_UPLOAD'), ct('S_ERROR_PAPER_UPLOAD_NO_FILE'));
		} else { 
			// Either all uploads succeeded or are already on the server!
			// send email:
			ct_load_lib('mail_papers.lib');
			ct_mail_author_finalversion_confirmation($paperclass);
			
			// All uploads OK! Show such a message!
			$session->put_infobox(ct('S_INFO_PAPER_FINALUPLOAD'), ct('S_INFO_PAPER_UPLOAD_SUCCESS'));
		 	ct_redirect($session->get_besturl());
		}
	} 

	echo "<h1>".ct('S_PAPER_FINALUPLOAD_TITLE')."</h1>\n";
	echo "<p class=\"fontnormal font10\">".ct('S_PAPER_FINALUPLOAD_INTRO')."</p>";
	$paperclass->show_detailed('90%');
	#echo "<table  width=\"90%\" align=\"center\" cellspacing=1 border=0 cellpadding=2 class=\"blackbg\">";
	#echo "<tr><td class=\"whitebg\" align=left valign=top>";
	#$paperclass->show_formatted(true,true);
	#echo "</td></tr></table>\n";	
	$paperclass->show_finaluploadform(ct_pageurl('uploadFinalPaper'),$errors);
} else {
	$session->put_errorbox(ct('S_ERROR_PHASE'), ct('S_ERROR_PHASE_INACTIVE'));
	ct_redirect(ct_pageurl('error'));
}

?>